package fr.unedic.cali.asu.caa14.p02.liquidation.dom;

import fr.unedic.cali.asu.asr.liquidation.parcours.ConstitutionDateAttribution;
import fr.unedic.cali.asu.asr.liquidation.parcours.ConstitutionDateLimiteIndemnisation;
import fr.unedic.cali.asu.asr.liquidation.parcours.ConstitutionDureeReglementaire;
import fr.unedic.cali.asu.asr.liquidation.parcours.ConstitutionDureeReglementaireAdhesionVolontaire;
import fr.unedic.cali.asu.asr.liquidation.parcours.ConstitutionPointDepartIndemnisation;
import fr.unedic.cali.asu.asr.liquidation.parcours.ConstitutionReglementApplicable;
import fr.unedic.cali.asu.asr.liquidation.parcours.DeterminationConditionQuantiteAffiliation;
import fr.unedic.cali.asu.asr.liquidation.parcours.DeterminationConditionRechercheEmploiAsp;
import fr.unedic.cali.asu.asr.liquidation.parcours.DeterminationConditionRechercheEmploiPap;
import fr.unedic.cali.asu.caa14.p02.liquidation.dom.gen.ObjectifExamenAdmissionGen;
import fr.unedic.cali.asu.caa14.p02.liquidation.parcours.ConstitutionDureeEffective;
import fr.unedic.cali.asu.caa14.p02.liquidation.parcours.ConstitutionProduitResultant;
import fr.unedic.cali.asu.caa14.p02.liquidation.parcours.DeterminationCompetencesProduitCourant;
import fr.unedic.cali.asu.caa14.parcours.asp.DeterminationConditionFaitGenerateur;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.parcours.ParcoursObjectifAdmission;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ObjectifExamenSpec;
import fr.unedic.cali.dom.affectation.ContexteDemandeSpec;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.Parcours;
import java.util.List;

public class ObjectifExamenAdmission
  extends ObjectifExamenAdmissionGen
{
  private static final long serialVersionUID = 768032248279081640L;
  private transient List<ContexteDemandeSpec> contexteDemande = null;
  
  public ObjectifExamenAdmission(DomPCSpec pPc)
  {
    super(pPc);
  }
  
  public ObjectifExamenAdmission() {}
  
  public ObjectifExamenAdmission(List<ContexteDemandeSpec> pContexteDemande)
  {
    contexteDemande = pContexteDemande;
  }
  
  public ObjetMetierSpec copie()
  {
    ObjectifExamenAdmission copie = new ObjectifExamenAdmission();
    copieElements(copie);
    return copie;
  }
  
  public Parcours creerParcoursObjectif()
  {
    return new ParcoursObjectifAdmission();
  }
  
  public Parcours creerParcoursConditionRechercheEmploi()
  {
    if (OutilGestionContexteDemande.estContextePresentDansRegroupement(contexteDemande, 10)) {
      return new DeterminationConditionRechercheEmploiPap();
    }
    return new DeterminationConditionRechercheEmploiAsp();
  }
  
  public Parcours creerParcoursConditionFaitGenerateur()
  {
    return new DeterminationConditionFaitGenerateur();
  }
  
  public Parcours creerParcoursConditionAge()
  {
    return getObjectifProduitActif().creerParcoursConditionAge();
  }
  
  public Parcours creerParcoursConditionQuantiteAffiliation()
  {
    return new DeterminationConditionQuantiteAffiliation();
  }
  
  public Parcours creerParcoursConditionChomageInvolontaire()
  {
    return null;
  }
  
  public Parcours creerParcoursConditionCumulAvantageVieillesse()
  {
    return null;
  }
  
  public Parcours creerParcoursConditionCumulActiviteConservee()
  {
    return getObjectifProduitActif().creerParcoursConditionCumulActiviteConservee();
  }
  
  public Parcours creerParcoursConditionCumulPrestationFamiliale()
  {
    return null;
  }
  
  public Parcours creerParcoursConditionAnciennete()
  {
    return null;
  }
  
  public Parcours creerParcoursConditionChomageTotal()
  {
    return null;
  }
  
  public Parcours creerParcoursConditionMontant()
  {
    return getObjectifProduitActif().creerParcoursConditionMontant();
  }
  
  public Parcours creerParcoursDureesReglementaires()
  {
    if (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(contexteDemande, "ADHVOLARE")) {
      return new ConstitutionDureeReglementaireAdhesionVolontaire();
    }
    return new ConstitutionDureeReglementaire();
  }
  
  public Parcours creerParcoursMontantsBruts()
  {
    return getObjectifProduitActif().creerParcoursMontantsBruts();
  }
  
  public Parcours creerParcoursDelaisReports()
  {
    return null;
  }
  
  public Parcours creerParcoursQuantiteAffiliation()
  {
    return getObjectifProduitActif().creerParcoursQuantiteAffiliation();
  }
  
  public Parcours creerParcoursCoefficientTempsPartiel()
  {
    return getObjectifProduitActif().creerParcoursCoefficientTempsPartiel();
  }
  
  public Parcours creerParcoursCoefficientSaisonnier()
  {
    return getObjectifProduitActif().creerParcoursCoefficientSaisonnier();
  }
  
  public Parcours creerParcoursReglementApplicable()
  {
    return new ConstitutionReglementApplicable();
  }
  
  public Parcours creerParcoursDateAttribution()
  {
    return new ConstitutionDateAttribution();
  }
  
  public Parcours creerParcoursPointDeDepart()
  {
    return new ConstitutionPointDepartIndemnisation();
  }
  
  public Parcours creerParcoursCaractereSaisonnier()
  {
    return getObjectifProduitActif().creerParcoursCaractereSaisonnier();
  }
  
  public Parcours creerParcoursSalaireJournalierDeReference()
  {
    return getObjectifProduitActif().creerParcoursSalaireJournalierDeReference();
  }
  
  public Parcours creerParcoursProduitResultant()
  {
    return new ConstitutionProduitResultant();
  }
  
  public Parcours creerParcoursDeterminationCompetenceFinanceAdmDroitResultant()
  {
    return null;
  }
  
  public Parcours creerParcoursCapitalAvecDureeEffective()
  {
    return null;
  }
  
  public Parcours creerParcoursDureeEffective()
  {
    return new ConstitutionDureeEffective();
  }
  
  public Parcours creerParcoursSalaireJournalierConserve()
  {
    return getObjectifProduitActif().creerParcoursSalaireJournalierConserve();
  }
  
  public Parcours creerParcoursDateLimiteIndemnisation()
  {
    return new ConstitutionDateLimiteIndemnisation();
  }
  
  public Parcours creerParcoursDeterminationCompetencesFinanceAdmDroitCourant()
  {
    return new DeterminationCompetencesProduitCourant();
  }
}

/* Location:
 * Qualified Name:     ObjectifExamenAdmission
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */