package fr.unedic.cali.asu.caa14.p02.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.DeterminationDureeEffective;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionProduitResultant;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationDroitResultant;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import java.math.BigDecimal;

public class ConstitutionProduitResultantClassique
  extends fr.unedic.cali.asu.cge01.liquidation.parcours.ConstitutionProduitResultantClassique
{
  protected void recuperationCapitaux(Demande p_demandeCourante, DossierExamen p_dossierExamenCourant, boolean p_bornerRetraite)
    throws CoucheLogiqueException, ApplicativeException
  {
    m_montantPrecedent = m_determinationProduitResultant.obtenirMontantDroitPrecedent(p_dossierExamenCourant, p_demandeCourante);
    
    m_montantCourant = ((fr.unedic.cali.asu.caa14.p02.liquidation.outilsfonctionnels.DeterminationProduitResultant)m_determinationProduitResultant).obtenirMontantDroitCourantCasGeneral(p_dossierExamenCourant);
    
    m_pointDepartUnique = m_determinationProduitResultant.determinerPointDepartUnique(p_demandeCourante, m_montantCourant, m_montantPrecedent);
    
    m_dureeIntermediaireDroitCourant = DeterminationDureeEffective.getInstance().determinerDureeEffectivePourComparaisonCapitaux(p_demandeCourante, m_pointDepartUnique, p_bornerRetraite);
    
    m_capitalComparatifDroitCourant = m_determinationProduitResultant.obtenirCapitalPourComparaison(m_dureeIntermediaireDroitCourant, m_montantCourant, p_dossierExamenCourant, p_demandeCourante, true);
    
    m_dureeIntermediaireDroitPrecedent = m_determinationProduitResultant.determinerDureeDroitPrecedentPourCalculCapital(p_demandeCourante, m_pointDepartUnique, m_montantPrecedent, p_bornerRetraite);
    
    m_capitalComparatifDroitPrecedent = m_determinationProduitResultant.obtenirCapitalPourComparaison(m_dureeIntermediaireDroitPrecedent, m_montantPrecedent, p_dossierExamenCourant, p_demandeCourante, false);
    
    verifierCapitalPrecedentSP(m_dureeIntermediaireDroitPrecedent, m_montantPrecedent, m_capitalComparatifDroitPrecedent);
    if (m_capitalComparatifDroitPrecedent.compareTo(m_capitalComparatifDroitCourant) > 0) {
      m_capitalProduitResultant = m_capitalComparatifDroitPrecedent;
    } else {
      m_capitalProduitResultant = m_capitalComparatifDroitCourant;
    }
  }
  
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    m_determinationProduitResultant = fr.unedic.cali.asu.caa14.p02.liquidation.outilsfonctionnels.DeterminationProduitResultant.getInstance();
  }
  
  protected void recuperationMontants(Demande p_demandeCourante, DossierExamen p_dossierExamenCourant)
    throws CoucheLogiqueException
  {
    AttributionAssuranceSpec attributionPrecedente = p_dossierExamenCourant.getAttributionPrecedente();
    JustificationDroitResultant justif = p_dossierExamenCourant.getConstitutionProduitResultant().getJustificationDroitResultant();
    if (attributionPrecedente != null) {
      justif.setCompetenceFinanciereDroitPrecedent(attributionPrecedente.getCompetenceFinanciere());
    } else if (p_demandeCourante.estEnContexteDroitAnterieurSecteurPublic()) {
      justif.setCompetenceFinanciereDroitPrecedent(2);
    }
    justif.setCompetenceFinanciereDroitCourant(p_dossierExamenCourant.getCompetence().getCompetenceFinanciereDroitCourant());
    justif.setCompetenceFinanciereDroitRetenu(p_dossierExamenCourant.getCompetence().getCompetenceFinanciereDroitCourant());
    
    m_montantPrecedentAvecCompetenceDuDroitAServir = m_determinationProduitResultant.obtenirMontantDroitPrecedentAvecCompetenceAServir(p_dossierExamenCourant, p_demandeCourante);
    
    m_montantCourantAvecCompetenceDuDroitAServir = m_determinationProduitResultant.obtenirMontantDroitCourantAvecCompetenceAServir(p_dossierExamenCourant);
    if (m_montantPrecedentAvecCompetenceDuDroitAServir.getMontantPrecompteEffectif().compareTo(m_montantCourantAvecCompetenceDuDroitAServir.getMontantPrecompteEffectif()) > 0) {
      m_montantProduitResultant = m_montantPrecedentAvecCompetenceDuDroitAServir;
    } else if (m_montantPrecedentAvecCompetenceDuDroitAServir.getMontantPrecompteEffectif().compareTo(m_montantCourantAvecCompetenceDuDroitAServir.getMontantPrecompteEffectif()) == 0)
    {
      if (m_montantPrecedentAvecCompetenceDuDroitAServir.getSjrNonReduit().compareTo(m_montantCourantAvecCompetenceDuDroitAServir.getSjrNonReduit()) > 0) {
        m_montantProduitResultant = m_montantPrecedentAvecCompetenceDuDroitAServir;
      } else {
        m_montantProduitResultant = m_montantCourantAvecCompetenceDuDroitAServir;
      }
    }
    else {
      m_montantProduitResultant = m_montantCourantAvecCompetenceDuDroitAServir;
    }
  }
}

/* Location:
 * Qualified Name:     ConstitutionProduitResultantClassique
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */