package fr.unedic.cali.asu.caa14.p03.calcul;

import fr.unedic.cali.asu.caa14.calcul.FacadeCalculLigneCAA14Impl;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsTrancheCalcul;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.TrancheExecutable;
import fr.unedic.cali.calcul.OutillagePeriodes;
import fr.unedic.cali.calcul.dom.ArretProduitAvecRaison;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculPeriodique;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculSpec;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.calcul.dom.QualificationPeriodes;
import fr.unedic.cali.calcul.dom.UniteTraitement;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeLimiteIndemnisationASP;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeLimiteIndemnisationPMVS;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.ContexteUT;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.util.Collection;
import java.util.Iterator;

public class FacadeCalculProduitImpl
  extends FacadeCalculLigneCAA14Impl
{
  public ChronologiePeriodes recupererPeriodesProduit(AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes chronologiePeriodes = new ChronologiePeriodes();
    IndividuSpec individu = attribution.getDemandeur();
    
    enrichirPeriodeDisponibilite(attribution, individu);
    
    chronologiePeriodes.ajouter(OutillagePeriodes.genererPeriodeRetraite(individu));
    if ((((AttributionAssuranceSpec)attribution).getContexteDateLimiteIndemnisation() != null) && (((AttributionAssuranceSpec)attribution).getContexteDateLimiteIndemnisation().equals("CRSPMVS"))) {
      if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)attribution.getDemande(), 2)) {
        chronologiePeriodes.ajouter(new ObjetChronoPeriodeLimiteIndemnisationPMVS(((Attribution)attribution).getDateLimiteIndemnisation().lendemain(), attribution.getRsod()));
      }
    }
    if (individu.getDernierJourAtteste() != null) {
      chronologiePeriodes.ajouter(OutillagePeriodes.genererLendemainDja(individu));
    }
    return chronologiePeriodes;
  }
  
  public void realiserDetectionFinDeProduitPourSuivi(AttributionSpec attribution, UniteTraitement ut, ContexteUT contexteUT)
    throws CoucheLogiqueException
  {
    super.realiserDetectionFinDeProduitPourSuivi(attribution, ut, contexteUT);
    ArretProduitAvecRaison arretProduitAvecRaison = ut.getArretProduitAvecRaison();
    genererEnquetesCourrierFinDeDroitAsp(attribution, ut, arretProduitAvecRaison);
  }
  
  public void mettreAjourDateFinDispositif(AttributionSpec attribution, UniteTraitement ut, CalendrierExecutionCalculPeriodique calendrier, QualificationPeriodes qualificationPeriodes)
    throws CoucheLogiqueException
  {
    miseAJourDateFinCSP(attribution, ut, calendrier, qualificationPeriodes);
  }
  
  public boolean enregistrerDispositifPBJCNCP(AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    boolean enregistrerDispositif = true;
    if (OutilsTrancheCalcul.estTrancheActive(attribution))
    {
      TrancheExecutable tranche = OutilsTrancheCalcul.recupererTrancheInitiale(attribution);
      enregistrerDispositif = !tranche.isContextePAPPresent();
    }
    else
    {
      ElementBaseIndemnisation ebi = ((AttributionAssuranceSpec)attribution).getElementBaseIndemnisation();
      enregistrerDispositif = !ebi.isContextePAPPresent();
    }
    return enregistrerDispositif;
  }
  
  public ConstituantsIndemnisation creationConstituantsIndemnisation(AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    ConstituantsIndemnisation constituantsIndemnisation = super.creationConstituantsIndemnisation(attribution);
    constituantsIndemnisation.setDateFinDispositifCSP(((AttributionAssuranceSpec)attribution).getDateLimiteIndemnisation());
    return constituantsIndemnisation;
  }
  
  public ConstituantsIndemnisation miseAJourConstituantsIndemnisation(UniteTraitement ut, AttributionSpec attribution, ConstituantsIndemnisation constituantsIndemnisation, Damj dateDeMiseAjour, Periode periode)
    throws CoucheLogiqueException
  {
    ConstituantsIndemnisation ci = super.miseAJourConstituantsIndemnisation(ut, attribution, constituantsIndemnisation, dateDeMiseAjour, periode);
    if ((ut != null) && (ut.getConstituantsIndemnisationEnDebutUT() != null)) {
      ci.setDateFinDispositifCSP(ut.getConstituantsIndemnisationEnDebutUT().getDateFinDispositifCSP());
    }
    return ci;
  }
  
  private void genererEnquetesCourrierFinDeDroitAsp(AttributionSpec attribution, UniteTraitement ut, ArretProduitAvecRaison arretProduitAvecRaison)
  {
    boolean estFinASP = false;
    
    Iterator itID = arretProduitAvecRaison.getPeriodesInterruptivesDefinitives().iterator();
    while (itID.hasNext())
    {
      ObjetChronoPeriode periode = (ObjetChronoPeriode)itID.next();
      if ((periode instanceof ObjetChronoPeriodeLimiteIndemnisationASP)) {
        estFinASP = true;
      }
    }
    if (estFinASP) {
      genererEnquetesFinASP(attribution, ut, arretProduitAvecRaison);
    }
  }
  
  public Damj recupererDateFinDroitTheorique(CalendrierExecutionCalculSpec calendrierExecutionCalcul, AttributionSpec attributionParam)
    throws CoucheLogiqueException
  {
    return calendrierExecutionCalcul.getDateFinDispositifCSP();
  }
}

/* Location:
 * Qualified Name:     FacadeCalculProduitImpl
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */