package fr.unedic.cali.asu.calcul.outilsfonctionnels;

import fr.unedic.cali.asu.fabriques.FabriqueStrategieBaseCalculSMICJournalier;
import fr.unedic.cali.asu.outilsfonctionnels.strategies.StrategieBaseCalculSMICJournalierSpec;
import fr.unedic.cali.calcul.dom.UniteTraitement;
import fr.unedic.cali.calcul.dom.periode.PansSpec;
import fr.unedic.cali.calcul.dom.periode.PeriodeActiviteEmploiCalcul;
import fr.unedic.cali.calcul.dom.periode.PeriodePrime;
import fr.unedic.cali.calcul.dom.periode.PeriodeTravail;
import fr.unedic.cali.calcul.outilsfonctionnels.DecoupageProratisation;
import fr.unedic.cali.calcul.outilsfonctionnels.DeterminerJustificatifsRevenusAR;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.PeriodeAnalyseSpec;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.ResultatActiviteReduite;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodePrimeCalcul;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodeTravailCalcul;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.parametres.GestionnaireDateApplication;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.math.RoundingMode;

public class ActiviteReduite
{
  private static final BigDecimal TAUX_DEDUCTION_UNIQUE = new BigDecimal("0.70");
  
  public static ResultatActiviteReduite calculActiviteReduite(BigDecimal allocationJournalierBrute, BigDecimal remunerationReprise, BigDecimal areBrute, BigDecimal sjr, String justificationCalculMontant, Periode periode)
    throws CoucheLogiqueException
  {
    ResultatActiviteReduite res = new ResultatActiviteReduite();
    
    BigDecimal montantADeduire = remunerationReprise.multiply(TAUX_DEDUCTION_UNIQUE);
    
    BigDecimal areBruteRestante = BigDecimal.valueOf(0L).max(areBrute.subtract(montantADeduire));
    
    BigDecimal plafond = recupererPlafondGlobal(sjr);
    
    plafond = BigDecimal.valueOf(0L).max(plafond.subtract(remunerationReprise));
    BigDecimal montantServi;
    BigDecimal montantServi;
    if ("04".equalsIgnoreCase(justificationCalculMontant)) {
      montantServi = areBruteRestante;
    } else {
      montantServi = areBruteRestante.min(plafond);
    }
    BigDecimal quantiteIndemnise = BigDecimal.ZERO;
    if (allocationJournalierBrute.signum() == 1) {
      if (periode.getDebut().estApresOuCoincideAvec(GestionnaireDateApplication.getInstance().recupererDateApplication("Date application NCAC17 pour arrondi"))) {
        quantiteIndemnise = Mathematiques.diviseParDefaut(montantServi, allocationJournalierBrute).setScale(0, RoundingMode.HALF_UP);
      } else {
        quantiteIndemnise = Mathematiques.diviseParDefaut(montantServi, allocationJournalierBrute).setScale(0, RoundingMode.UP);
      }
    }
    res.setQuantiteIndemnise(quantiteIndemnise);
    res.setDepassementPlafond((montantServi.compareTo(plafond) == 0) && (montantServi.compareTo(BigDecimal.ZERO) != 0));
    res.setArePlafond(plafond);
    res.setAreRestante(areBruteRestante);
    return res;
  }
  
  public static boolean estCategorieEmploiAnnexe1(PeriodeActiviteEmploiCalcul periode)
  {
    switch (periode.getCategorieEmploiParticulier())
    {
    case 20: 
    case 22: 
    case 23: 
    case 24: 
    case 36: 
    case 41: 
    case 46: 
    case 48: 
      return true;
    }
    return false;
  }
  
  public static BigDecimal getSmicJournalier(Damj date)
    throws CoucheLogiqueException
  {
    BigDecimal retour = BigDecimal.ZERO;
    try
    {
      CritereStrategie critere = new CritereStrategie();
      critere.setDatePivot(date);
      FabriqueStrategieBaseCalculSMICJournalier fabrique = FabriqueStrategieBaseCalculSMICJournalier.getInstance();
      StrategieBaseCalculSMICJournalierSpec strategie = (StrategieBaseCalculSMICJournalierSpec)fabrique.getStrategie(critere);
      return strategie.getSmicJournalier(date);
    }
    catch (CoucheLogiqueException e)
    {
      throw new CoucheLogiqueException("Calcul SMIC Journalier", "Impossible de déterminer le SMIC Journalier");
    }
  }
  
  public static Quantite traitementActiviteReduiteSurPa(PeriodeAnalyseSpec pa, ChronologiePeriodes chronoPeriodesActiviteReduite, AttributionSpec attribution, MontantBaseSpec montant, Quantite quantiteImputableSansSusp, UniteTraitement ut, BigDecimal sjr)
    throws CoucheLogiqueException
  {
    BigDecimal quantiteDecalage = null;
    BigDecimal quantiteServiApresPP = null;
    Quantite nombreDeJourDeDecalageImputes = null;
    BigDecimal areBrut = null;
    
    Damj dateDebut = null;
    if (pa.getDateDebut().coincideAvec(attribution.getPji())) {
      dateDebut = Damj.max(attribution.getDateAttribution(), ut.getDateDebut());
    } else {
      dateDebut = pa.getDateDebut();
    }
    Damj dateFin = pa.getDateFin();
    
    ChronologiePeriodes chronoDecalage = DecoupageProratisation.decoupageEtProratisationPeriodesActivites(new Periode(dateDebut, dateFin), chronoPeriodesActiviteReduite);
    
    DeterminerJustificatifsRevenusAR.traitementRevenusBS(chronoDecalage, pa.getDateDebut(), attribution);
    
    Chronologie periodesEmploiCourantes = chronoDecalage.copier(new FiltrePeriodeTravailCalcul());
    Chronologie periodesPrime = chronoDecalage.copier(new FiltrePeriodePrimeCalcul());
    BigDecimal cumulGainPrimes = BigDecimal.ZERO;
    BigDecimal cumulGainPA = BigDecimal.ZERO;
    PeriodePrime prime = null;
    periodesPrime.iterer();
    while (periodesPrime.encoreSuivant())
    {
      prime = (PeriodePrime)periodesPrime.elementSuivant();
      if (prime.getTypeActivite() != 1) {
        cumulGainPrimes = cumulGainPrimes.add(prime.getMontant().getValeur());
      }
    }
    cumulGainPA = calculerGainRetenu(periodesEmploiCourantes);
    cumulGainPA = cumulGainPA.add(cumulGainPrimes);
    
    areBrut = montant.getMontantBrut().getValeur().multiply(quantiteImputableSansSusp.getValeur());
    if ((ut.getStatut() == 8) || (ut.getStatut() == 9)) {
      areBrut = areBrut.multiply(new BigDecimal("0.7")).setScale(2, RoundingMode.DOWN);
    }
    ResultatActiviteReduite resActiviteReduite = calculActiviteReduite(montant.getMontantBrut().getValeur(), cumulGainPA, areBrut, sjr, montant.getJustificationCalculMontant(), ut.getPeriode());
    if ((ut.getStatut() == 5) || (ut.getStatut() == 9)) {
      quantiteServiApresPP = resActiviteReduite.getQuantiteIndemnise().multiply(new BigDecimal("0.8")).setScale(0, RoundingMode.DOWN);
    } else {
      quantiteServiApresPP = resActiviteReduite.getQuantiteIndemnise();
    }
    quantiteDecalage = quantiteImputableSansSusp.getValeur().subtract(quantiteServiApresPP);
    
    pa.setQuantiteDecalee(new QuantiteJour(quantiteDecalage));
    
    nombreDeJourDeDecalageImputes = quantiteImputableSansSusp.min(new QuantiteJour(quantiteDecalage));
    
    pa.setQuantiteNonIndemnisee(pa.getQuantiteNonIndemnisee().ajouter(nombreDeJourDeDecalageImputes));
    if ((ut.getListePeriodesAnalyse() == null) || (ut.getListePeriodesAnalyse().getTaille() == 0))
    {
      ut.setAreRestante(resActiviteReduite.getAreRestante());
      ut.setArePlafond(resActiviteReduite.getArePlafond());
    }
    else
    {
      ut.setAreRestante(null);
      ut.setArePlafond(null);
    }
    return new QuantiteJour(quantiteDecalage);
  }
  
  private static BigDecimal calculerGainRetenu(Chronologie periodesEmploi)
  {
    BigDecimal gainRetenu = BigDecimal.ZERO;
    BigDecimal gainConservee = BigDecimal.ZERO;
    Chronologie chronoFiltree = periodesEmploi.copier(new FiltrePeriodeTravailCalcul());
    PeriodeTravail periodeCourante = null;
    chronoFiltree.iterer();
    while (chronoFiltree.encoreSuivant())
    {
      periodeCourante = (PeriodeTravail)chronoFiltree.elementSuivant();
      if (((periodeCourante instanceof PeriodeActiviteEmploiCalcul)) && (((PeriodeActiviteEmploiCalcul)periodeCourante).getTypeActivite() == 1))
      {
        gainRetenu = gainRetenu.add(periodeCourante.getGain());
        gainConservee = gainConservee.add(periodeCourante.getGain());
      }
      else if (((periodeCourante instanceof PansSpec)) && (((PansSpec)periodeCourante).getTypeActivite() == 1))
      {
        gainRetenu = gainRetenu.add(periodeCourante.getGain());
        gainConservee = gainConservee.add(periodeCourante.getGain());
      }
      else
      {
        gainRetenu = gainRetenu.add(periodeCourante.getGain());
      }
    }
    return gainRetenu.subtract(gainConservee);
  }
  
  private static BigDecimal recupererPlafondGlobal(BigDecimal sjr)
  {
    return new BigDecimal("30.42").multiply(sjr);
  }
}

/* Location:
 * Qualified Name:     ActiviteReduite
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */