package fr.unedic.cali.asu.calcul.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculSpec;
import fr.unedic.cali.calcul.dom.periode.DsmTravail;
import fr.unedic.cali.calcul.dom.periode.PeriodeActiviteEmploiCalcul;
import fr.unedic.cali.calcul.dom.periode.PeriodeNonDeclaree;
import fr.unedic.cali.calcul.dom.periode.PeriodeTravailJustifiee;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.outilsfonctionnels.AppelAvant;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public class CreationPeriodeNonDeclareeSanction
{
  private static final int NB_JOUR_PND_MAX = 3;
  
  public static ChronologiePeriodes creerPeriodeNonDeclareeSanction(IndividuSpec p_individu, Damj p_moisEnCours, ChronologiePeriodes p_periodesDecalantes, boolean p_estSanctionnable)
  {
    ChronologiePeriodes periodesNonDeclareeSanction = null;
    
    int population = p_individu.determinerPopulationIndividu(p_moisEnCours);
    if (population == 0) {
      periodesNonDeclareeSanction = creerPeriodeNonDeclareeSanctionCasGeneral(p_periodesDecalantes, p_estSanctionnable);
    } else if (population == 1) {
      periodesNonDeclareeSanction = creerPeriodeNonDeclareeSanctionA8A10(p_periodesDecalantes, p_estSanctionnable);
    }
    return periodesNonDeclareeSanction;
  }
  
  public static ChronologiePeriodes creerPeriodeNonDeclareeSanctionPourLiquidation(Damj p_dateDebut, Damj p_dateFin, List p_listeAttributions)
    throws ApplicativeException
  {
    ChronologiePeriodes chronologiePeriodeCalculAvecPnds = null;
    CalendrierExecutionCalculSpec calendrierExecutionCalcul = null;
    Collection collectionPNDs = null;
    Iterator iteratorListeAttribution = null;
    AttributionSpec attributionCourante = null;
    
    chronologiePeriodeCalculAvecPnds = new ChronologiePeriodes();
    if ((p_listeAttributions != null) && (!p_listeAttributions.isEmpty()))
    {
      AppelAvant.executerAvant(p_listeAttributions, p_dateDebut);
      
      iteratorListeAttribution = p_listeAttributions.iterator();
      while (iteratorListeAttribution.hasNext())
      {
        attributionCourante = (AttributionSpec)iteratorListeAttribution.next();
        calendrierExecutionCalcul = attributionCourante.getCalendrierExecutionCalcul();
        if (calendrierExecutionCalcul != null)
        {
          collectionPNDs = calendrierExecutionCalcul.getListePNDS();
          if (collectionPNDs != null) {
            chronologiePeriodeCalculAvecPnds.ajouter(collectionPNDs);
          }
        }
      }
      FiltreChevauchePeriode filtre = new FiltreChevauchePeriode(new Periode(p_dateDebut, p_dateFin));
      chronologiePeriodeCalculAvecPnds = (ChronologiePeriodes)chronologiePeriodeCalculAvecPnds.copier(filtre);
    }
    return chronologiePeriodeCalculAvecPnds;
  }
  
  private static ChronologiePeriodes creerPeriodeNonDeclareeSanctionCasGeneral(ChronologiePeriodes p_periodesDecalantes, boolean p_estSanctionnable)
  {
    ChronologiePeriodes periodesNonDeclareeSanction = null;
    if (testCreationPeriodeNonDeclareePourCasGeneral(p_periodesDecalantes)) {
      periodesNonDeclareeSanction = creerPeriodeNonDeclareeSanctionPourChaquePeriodeNonDeclaree(p_periodesDecalantes, p_estSanctionnable);
    } else {
      periodesNonDeclareeSanction = new ChronologiePeriodes();
    }
    return periodesNonDeclareeSanction;
  }
  
  private static ChronologiePeriodes creerPeriodeNonDeclareeSanctionA8A10(ChronologiePeriodes p_periodesDecalantes, boolean p_estSanctionnable)
  {
    return creerPeriodeNonDeclareeSanctionPourChaquePeriodeNonDeclaree(p_periodesDecalantes, p_estSanctionnable);
  }
  
  private static ChronologiePeriodes creerPeriodeNonDeclareeSanctionPourChaquePeriodeNonDeclaree(ChronologiePeriodes p_periodesDecalantes, boolean p_estSanctionnable)
  {
    ObjetChronoPeriode objetChronoPeriode = null;
    PeriodeTravailJustifiee periodeTravailJustifieeCalcul = null;
    Iterator itPND = null;
    PeriodeNonDeclaree pndCourante = null;
    fr.unedic.cali.calcul.dom.periode.PeriodeNonDeclareeSanction pndSanction = null;
    ChronologiePeriodes periodesNonDeclareeSanction = new ChronologiePeriodes();
    
    p_periodesDecalantes.iterer();
    while (p_periodesDecalantes.encoreSuivant())
    {
      objetChronoPeriode = (ObjetChronoPeriode)p_periodesDecalantes.elementSuivant();
      if ((objetChronoPeriode instanceof PeriodeTravailJustifiee))
      {
        periodeTravailJustifieeCalcul = (PeriodeTravailJustifiee)objetChronoPeriode;
        if (periodeTravailJustifieeCalcul.getCollectionPND() != null)
        {
          itPND = periodeTravailJustifieeCalcul.getCollectionPND().iterator();
          while (itPND.hasNext())
          {
            pndCourante = (PeriodeNonDeclaree)itPND.next();
            
            pndSanction = new fr.unedic.cali.asu.calcul.dom.periode.PeriodeNonDeclareeSanction(pndCourante.getDateDebut(), pndCourante.getDateFin());
            
            pndSanction.setGain(Mathematiques.proratiser(periodeTravailJustifieeCalcul.getGain(), new BigDecimal(Integer.toString(pndSanction.getDuree())), new BigDecimal(Integer.toString(periodeTravailJustifieeCalcul.getDuree()))));
            
            pndSanction.setGain(pndSanction.getGain().setScale(periodeTravailJustifieeCalcul.getGain().scale(), 6));
            
            pndSanction.setNombreHeures(Mathematiques.proratiser(periodeTravailJustifieeCalcul.getNombreHeures(), new BigDecimal(Integer.toString(pndSanction.getDuree())), new BigDecimal(Integer.toString(periodeTravailJustifieeCalcul.getDuree()))));
            
            pndSanction.setNombreHeures(pndSanction.getNombreHeures().setScale(periodeTravailJustifieeCalcul.getNombreHeures().scale(), 6));
            if ((periodeTravailJustifieeCalcul instanceof PeriodeActiviteEmploiCalcul))
            {
              pndSanction.setIccp(Mathematiques.proratiser(((PeriodeActiviteEmploiCalcul)periodeTravailJustifieeCalcul).getIccp(), new BigDecimal(Integer.toString(pndSanction.getDuree())), new BigDecimal(Integer.toString(periodeTravailJustifieeCalcul.getDuree()))));
              
              pndSanction.setIccp(pndSanction.getIccp().setScale(((PeriodeActiviteEmploiCalcul)periodeTravailJustifieeCalcul).getIccp().scale(), 6));
            }
            pndCourante.setPeriodeNonDeclareeSanction(pndSanction);
            pndCourante.setEstSanctionnable(p_estSanctionnable);
            
            periodesNonDeclareeSanction.ajouter(pndSanction);
          }
        }
      }
    }
    return periodesNonDeclareeSanction;
  }
  
  private static boolean testCreationPeriodeNonDeclareePourCasGeneral(ChronologiePeriodes p_periodesDecalantes)
  {
    boolean pndSanction = true;
    ObjetChronoPeriode objetChronoPeriode = null;
    PeriodeTravailJustifiee periodeTravailJustifieeCalcul = null;
    Iterator it = null;
    PeriodeNonDeclaree pndCourante = null;
    DsmTravail dsmTravailCalcul = null;
    
    int cumulGainPAEC = 0;
    int cumulHeurePAEC = 0;
    int cumulGainDSM = 0;
    int cumulHeureDSM = 0;
    int cumulJourPND = 0;
    
    p_periodesDecalantes.iterer();
    while (p_periodesDecalantes.encoreSuivant())
    {
      objetChronoPeriode = (ObjetChronoPeriode)p_periodesDecalantes.elementSuivant();
      if ((objetChronoPeriode instanceof PeriodeTravailJustifiee))
      {
        periodeTravailJustifieeCalcul = (PeriodeTravailJustifiee)objetChronoPeriode;
        
        cumulGainPAEC += periodeTravailJustifieeCalcul.getGain().intValue();
        
        cumulHeurePAEC += periodeTravailJustifieeCalcul.getNombreHeures().intValue();
        if (periodeTravailJustifieeCalcul.getCollectionPND() != null)
        {
          it = periodeTravailJustifieeCalcul.getCollectionPND().iterator();
          while (it.hasNext())
          {
            pndCourante = (PeriodeNonDeclaree)it.next();
            cumulJourPND += pndCourante.getDuree();
          }
        }
      }
      else if ((objetChronoPeriode instanceof DsmTravail))
      {
        dsmTravailCalcul = (DsmTravail)objetChronoPeriode;
        
        cumulGainDSM += dsmTravailCalcul.getGain().intValue();
        
        cumulHeureDSM += dsmTravailCalcul.getNombreHeures().intValue();
      }
    }
    if ((cumulJourPND <= 3) || ((cumulGainDSM >= cumulGainPAEC) && (cumulHeureDSM >= cumulHeurePAEC))) {
      pndSanction = false;
    }
    return pndSanction;
  }
}

/* Location:
 * Qualified Name:     CreationPeriodeNonDeclareeSanction
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */