package fr.unedic.cali.asu.calcul.outilsfonctionnels;

import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.autresdoms.cohab.dom.PeriodePensionInvaliditeChainee;
import fr.unedic.cali.autresdoms.cohab.dom.PeriodeSousPensionInvaliditeChainee;
import fr.unedic.cali.autresdoms.cohab.dom.spec.PeriodePensionInvaliditeChaineeSpec;
import fr.unedic.cali.autresdoms.cohab.dom.spec.PeriodeSousPensionInvaliditeChaineeSpec;
import fr.unedic.cali.calcul.OutillagePeriodes;
import fr.unedic.cali.calcul.dom.periode.FinPeriodePensionInvalidite;
import fr.unedic.cali.calcul.dom.periode.PeriodePensionInvalidite;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeCalcul;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.ObjetChronoPeriode;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.Iterator;

public final class RecuperationPensionInvaliditeAvantDate
{
  public static BigDecimal recuperationMontantPI(IndividuSpec individu, Damj date)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes chronologiePensionInvalidite = null;
    BigDecimal montantPI = BigDecimal.ZERO;
    
    chronologiePensionInvalidite = OutillagePeriodes.recupererPensionsInvaliditeEtAvantagesVieillesse(individu, Boolean.valueOf(false));
    if (chronologiePensionInvalidite != null)
    {
      Iterator<?> iterateur = chronologiePensionInvalidite.iterer();
      while (iterateur.hasNext())
      {
        ObjetChronoPeriodeCalcul objetChronoPeriodeCalcul = (ObjetChronoPeriodeCalcul)iterateur.next();
        if (objetChronoPeriodeCalcul.getDateDebut().estAvantOuCoincideAvec(date)) {
          if ((objetChronoPeriodeCalcul instanceof PeriodePensionInvalidite)) {
            montantPI = montantPI.add(((PeriodePensionInvalidite)objetChronoPeriodeCalcul).getQuantiteEuro().getValeur());
          } else if ((objetChronoPeriodeCalcul instanceof FinPeriodePensionInvalidite)) {
            montantPI = montantPI.subtract(((FinPeriodePensionInvalidite)objetChronoPeriodeCalcul).getQuantiteEuro().getValeur());
          }
        }
      }
    }
    return montantPI;
  }
  
  public static BigDecimal recuperationMontantPIChainees(ElementBaseIndemnisation ebi, IndividuSpec individu, Damj date, Damj dateAttribution)
    throws CoucheLogiqueException
  {
    BigDecimal montantPI = BigDecimal.ZERO;
    
    Collection<?> chronologiePensionsIndividus = OutillagePeriodes.recupererPensionsInvaliditeChainees(individu).mapperVersCollection();
    if (chronologiePensionsIndividus != null)
    {
      Iterator<?> iterateurSurPensions = chronologiePensionsIndividus.iterator();
      while (iterateurSurPensions.hasNext())
      {
        ObjetChronoPeriode objetSousPension = (ObjetChronoPeriode)iterateurSurPensions.next();
        if (((objetSousPension instanceof PeriodeSousPensionInvaliditeChainee)) && (objetSousPension.getDateDebut().estAvantOuCoincideAvec(date)) && (OutilPensionInvalidite.estUneSousPensionDeductible(ebi, dateAttribution, (PeriodeSousPensionInvaliditeChainee)objetSousPension)))
        {
          PeriodeSousPensionInvaliditeChaineeSpec sousPensionInvalidite = (PeriodeSousPensionInvaliditeChaineeSpec)objetSousPension;
          if ((sousPensionInvalidite.getDateDebut().estAvantOuCoincideAvec(date)) && (sousPensionInvalidite.getDateFin().lendemain().estApres(date))) {
            montantPI = montantPI.add(sousPensionInvalidite.getMontant().getValeur());
          }
        }
      }
    }
    return montantPI;
  }
  
  public static BigDecimal recuperationMontantPIChaineesSurEBI(ElementBaseIndemnisation ebi, Damj date, Damj dateAttribution)
    throws CoucheLogiqueException
  {
    BigDecimal montantPI = BigDecimal.ZERO;
    
    Collection<PeriodePensionInvaliditeChaineeSpec> chronologiePensionsIndividus = recupererPensionsInvaliditeChainees(ebi.getListePensionInvalidite());
    if (chronologiePensionsIndividus != null)
    {
      Iterator<?> iterateurSurPensions = chronologiePensionsIndividus.iterator();
      while (iterateurSurPensions.hasNext())
      {
        ObjetChronoPeriode objetSousPension = (ObjetChronoPeriode)iterateurSurPensions.next();
        if (((objetSousPension instanceof PeriodeSousPensionInvaliditeChainee)) && (objetSousPension.getDateDebut().estAvantOuCoincideAvec(date)) && (OutilPensionInvalidite.estUneSousPensionDeductible(ebi, dateAttribution, (PeriodeSousPensionInvaliditeChainee)objetSousPension)))
        {
          PeriodeSousPensionInvaliditeChaineeSpec sousPensionInvalidite = (PeriodeSousPensionInvaliditeChaineeSpec)objetSousPension;
          if ((sousPensionInvalidite.getDateDebut().estAvantOuCoincideAvec(date)) && (sousPensionInvalidite.getDateFin().lendemain().estApres(date))) {
            montantPI = montantPI.add(sousPensionInvalidite.getMontant().getValeur());
          }
        }
      }
    }
    return montantPI;
  }
  
  public static Collection<PeriodePensionInvaliditeChaineeSpec> recupererPensionsInvaliditeChainees(Collection<PeriodePensionInvaliditeChaineeSpec> collectionPI)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes chronoARetourner = new ChronologiePeriodes();
    
    Iterator<PeriodePensionInvaliditeChaineeSpec> ite = collectionPI.iterator();
    while (ite.hasNext())
    {
      PeriodePensionInvaliditeChainee piChainee = (PeriodePensionInvaliditeChainee)ite.next();
      chronoARetourner.ajouter(piChainee.getListeSousPensionInvalidite());
      chronoARetourner.ajouter(piChainee.getListeFinsPeriodesPensionInvalite());
    }
    return chronoARetourner.mapperVersCollection();
  }
}

/* Location:
 * Qualified Name:     RecuperationPensionInvaliditeAvantDate
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */