package fr.unedic.cali.asu.cge01.antecedent;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.dom.ConteneurConditionActiviteConservee;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.OutilDonneesDeterminationSjr;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.OutilGestionActivitesConservees;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.RechercheConditionCumulActiviteConservee;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.FabriqueOutilFonctionnelDeterminationSjrSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.OutilDeterminationSjrSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieActiviteConserveeConvention2014Spec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieConditionCumulActiviteConserveeSpec;
import fr.unedic.cali.asu.cge01.outilsfonctionnels.RevalorisationSalaire;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.SaisieAntecedent;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.Antecedent;
import fr.unedic.cali.asu.produits.liquidation.dom.Competence;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionActiviteConservee;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionAge;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionFaitGenerateur;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionsAttributionAdmission;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionCaractereSaisonnier;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionCoefficientSaisonnier;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionCoefficientTempsPartiel;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDateAttribution;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionPointDepartIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionProduitResultant;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionSjc;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.Poursuite;
import fr.unedic.cali.asu.produits.liquidation.dom.Prc;
import fr.unedic.cali.asu.produits.liquidation.dom.PrcSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.Sjcip;
import fr.unedic.cali.asu.produits.liquidation.dom.SjrActiviteConservee;
import fr.unedic.cali.asu.produits.liquidation.dom.Sjrip;
import fr.unedic.cali.asu.produits.liquidation.dom.conteneurs.DonneesResultatDeterminationSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ConstitutionElementsSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.Retraite;
import fr.unedic.cali.dom.affectation.ProduitAsuCge01P06;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDemandeDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDeterminationSjrSpec;
import fr.unedic.cali.outilsfonctionnels.OutilRetraite;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.Iterator;

public abstract class GrapheAntecedent
  extends fr.unedic.cali.asu.antecedent.GrapheAntecedent
{
  protected void initialiserDossierExamen(Demande p_demande)
    throws CoucheLogiqueException
  {
    if ((7 == p_demande.getSaisieAntecedent().getContexteDemande().intValue()) || (5 == p_demande.getSaisieAntecedent().getContexteDemande().intValue())) {
      p_demande.getDossierAffectation().setDossierExamen(new Poursuite());
    } else {
      p_demande.getDossierAffectation().setDossierExamen(new Antecedent());
    }
  }
  
  protected void alimenterConditionsAdmission(Demande p_demande)
    throws CoucheLogiqueException
  {
    SaisieAntecedent saisieAntecedent = p_demande.getSaisieAntecedent();
    DossierExamen dossierExamen = (DossierExamen)p_demande.getDossierExamen();
    
    alimenterConditionFaitGenerateur(dossierExamen, saisieAntecedent);
    
    alimenterConditionAge(dossierExamen);
  }
  
  protected void alimenterConditionsAdmissionSupplementaire(Demande p_demande)
    throws CoucheLogiqueException
  {
    SaisieAntecedent saisieAntecedent = p_demande.getSaisieAntecedent();
    
    DossierExamen dossierExamen = (DossierExamen)p_demande.getDossierExamen();
    
    alimenterContionCumulActiviteConservee(dossierExamen, saisieAntecedent);
  }
  
  protected void alimenterContionCumulActiviteConservee(DossierExamen p_dossierExamen, SaisieAntecedent p_saisieAntecedent)
    throws CoucheLogiqueException
  {
    Demande demande = (Demande)p_dossierExamen.getDemande();
    StrategieActiviteConserveeConvention2014Spec strategieActiviteConservee = OutilGestionActivitesConservees.getInstance().recupererStrategieActiviteConserveeConvention2014(demande);
    
    Quantite sjcPlafonne = p_saisieAntecedent.getSalaireJournalierConservePlafonne();
    if ((sjcPlafonne != null) || (strategieActiviteConservee.persisterListeActivitesConserveesCapa12()))
    {
      DomLiquidationAssurance dom = new DomLiquidationAssurance();
      Contexte contexte = new Contexte();
      contexte.setDonnees(dom);
      
      DemandeAssuranceSpec demandeOrigine = p_dossierExamen.getDemandeAssurance();
      Damj dateExamen = demandeOrigine.getDateExamen();
      
      Demande demandeCopiee = (Demande)demandeOrigine.copie();
      demandeCopiee.getEvenementReferenceExamen().setDateEvenement(p_dossierExamen.getDateAttribution());
      dom.setDemande(demandeCopiee);
      try
      {
        DossierExamen dossierExamenDemandeCopiee = (DossierExamen)demandeCopiee.getDossierExamen();
        ConditionActiviteConservee conditionActiviteConservee = dossierExamenDemandeCopiee.createConditionActiviteConservee();
        
        Periode prc = new Periode(p_saisieAntecedent.getDateDebutPRC(), p_saisieAntecedent.getTermePRC());
        Chronologie chronoGlobaleActivitesConservees = strategieActiviteConservee.recupererChronoActivitesConservees(demande, prc);
        
        RechercheConditionCumulActiviteConservee rechercheConditionCumulActiviteConservee = RechercheConditionCumulActiviteConservee.getInstance();
        ConteneurConditionActiviteConservee conteneurConditionActiviteConservee = new ConteneurConditionActiviteConservee();
        
        Reglement reglementApplicableCourant = dossierExamenDemandeCopiee.getReglementApplicable().getReglement();
        ProduitSpec produit = ((DossierAffectation)demandeCopiee.getDossierAffectation()).getProduit();
        boolean estReglementApplicableA4 = reglementApplicableCourant.equals(produit.getReglement("A4"));
        if (strategieActiviteConservee.verifierSeuilsConditionActiviteConservee(estReglementApplicableA4))
        {
          StrategieConditionCumulActiviteConserveeSpec strategieCumulPans = rechercheConditionCumulActiviteConservee.recupererStrategieCumulPans(demandeCopiee);
          rechercheConditionCumulActiviteConservee.alimenterSeuil(demandeCopiee, conteneurConditionActiviteConservee, chronoGlobaleActivitesConservees, strategieCumulPans);
        }
        rechercheConditionCumulActiviteConservee.mapperConteneurVersConditionActiviteConservee(conteneurConditionActiviteConservee, conditionActiviteConservee);
        if ((chronoGlobaleActivitesConservees != null) && (chronoGlobaleActivitesConservees.getTaille() > 0) && (strategieActiviteConservee.persisterListeActivitesConserveesCapa12()))
        {
          Collection<SjrActiviteConservee> listeActivitesConservees = OutilGestionActivitesConservees.getInstance().mapperChronoEnListeActivitesConservees(chronoGlobaleActivitesConservees);
          
          SjrActiviteConservee sjrActiviteConserveeCourante = null;
          Iterator<SjrActiviteConservee> it = listeActivitesConservees.iterator();
          while (it.hasNext())
          {
            sjrActiviteConserveeCourante = (SjrActiviteConservee)it.next();
            conditionActiviteConservee.ajouterSjrActiviteConservee(sjrActiviteConserveeCourante);
          }
        }
        p_dossierExamen.createConditionActiviteConservee();
        conditionActiviteConservee.setEtat(0);
        conditionActiviteConservee.copieElements(p_dossierExamen.getConditionActiviteConservee());
        demandeOrigine.getEvenementReferenceExamen().setDateEvenement(dateExamen);
      }
      catch (ApplicativeException ex)
      {
        throw new CoucheLogiqueException(ex.getCode(), ex);
      }
    }
  }
  
  protected void alimenterConditionFaitGenerateur(DossierExamen p_dossierExamen, SaisieAntecedent p_saisieAntecedent)
  {
    IndividuSpec demandeur = p_dossierExamen.getDemande().getDemandeur();
    ConditionFaitGenerateur conditionFaitGenerateur = p_dossierExamen.createConditionFaitGenerateur();
    
    String identifiantFaitGenerateur = p_saisieAntecedent.getIdentifiantFaitGenerateur();
    ActiviteSalarie periodeFaitGenerateur = (ActiviteSalarie)demandeur.rechercherPeriodePasseProfessionnel(identifiantFaitGenerateur);
    
    conditionFaitGenerateur.setPeriodeFaitGenerateur(periodeFaitGenerateur);
    conditionFaitGenerateur.setAgeIndividuDateFG(demandeur.getAgeALaDate(periodeFaitGenerateur.getDateFin()));
    conditionFaitGenerateur.setEtatSatisfait(true);
  }
  
  protected void alimenterConditionAge(DossierExamen p_dossierExamen)
    throws CoucheLogiqueException
  {
    IndividuSpec demandeur = p_dossierExamen.getDemande().getDemandeur();
    ConditionAge conditionAge = p_dossierExamen.getConditionsAttributionAdmission().createConditionAge();
    
    Damj dateEffetTheoriquePensionRetraite = OutilRetraite.getInstance().determinerRetraite(demandeur).getDate();
    conditionAge.setDateEffetPension(dateEffetTheoriquePensionRetraite);
  }
  
  protected void alimenterConstituantsAdmission(Demande p_demande)
    throws CoucheLogiqueException
  {
    SaisieAntecedent saisieAntecedent = p_demande.getSaisieAntecedent();
    DossierExamen dossierExamen = (DossierExamen)p_demande.getDossierExamen();
    
    alimenterConstitutionDateAttribution(dossierExamen, saisieAntecedent);
    
    alimenterConstitutionReglementApplicable(dossierExamen, saisieAntecedent);
    
    alimenterConstitutionSjr(dossierExamen, saisieAntecedent);
    
    alimenterConstitutionSjc(dossierExamen, saisieAntecedent);
    
    alimenterConstitutionCoefficientTempsPartiel(dossierExamen, saisieAntecedent);
    
    alimenterConstitutionCaractereSaisonnier(dossierExamen, saisieAntecedent);
    
    alimenterConstitutionCoefficientSaisonnier(dossierExamen, saisieAntecedent);
    
    alimenterConstitutionDurees(dossierExamen, saisieAntecedent);
    
    Competence competence = new Competence();
    dossierExamen.setCompetence(competence);
    alimenterCompetence((Demande)dossierExamen.getDemande(), competence, saisieAntecedent);
    if ((OutilGestionContexteDemande.estContexteDemandeAssurancePresent(p_demande, "ASPARE")) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(p_demande, "ASPDC")))
    {
      Competence competenceSousJacente = new Competence();
      competenceSousJacente.setCompetenceAdministrative(1);
      competenceSousJacente.setCompetenceFinanciere(1);
      dossierExamen.setCompetenceSousJacente(competenceSousJacente);
    }
    alimenterConstitutionMontantBrut(dossierExamen, saisieAntecedent);
    
    alimenterConstitutionProduitResultant(dossierExamen, saisieAntecedent);
    
    alimenterConstitutionDelais(dossierExamen, saisieAntecedent);
    
    alimenterConstitutionPointDeDepart(dossierExamen, saisieAntecedent);
    
    alimenterDateLimiteIndemnisation(p_demande, dossierExamen, saisieAntecedent);
  }
  
  protected abstract void alimenterDateLimiteIndemnisation(Demande paramDemande, DossierExamen paramDossierExamen, SaisieAntecedent paramSaisieAntecedent)
    throws CoucheLogiqueException;
  
  protected void alimenterConstitutionDateAttribution(DossierExamen p_dossierExamen, SaisieAntecedent p_saisieAntecedent)
  {
    ConstitutionDateAttribution constitutionDateAttribution = p_dossierExamen.createConstitutionDateAttribution();
    
    Damj dateAttribution = p_saisieAntecedent.getDateAttribution();
    
    constitutionDateAttribution.setDateAttribution(dateAttribution);
  }
  
  protected void alimenterConstitutionReglementApplicable(DossierExamen p_dossierExamen, SaisieAntecedent p_saisieAntecedent)
  {
    ReglementApplicableSpec constitutionReglementApplicable = p_dossierExamen.createConstitutionReglementApplicable();
    
    Reglement reglement = ((DossierAffecte)p_dossierExamen.getDossierAffecte()).getReglementPeriodeValidationProduit();
    
    constitutionReglementApplicable.setReglement(reglement);
  }
  
  protected void alimenterConstitutionSjr(DossierExamen p_dossierExamen, SaisieAntecedent p_saisieAntecedent)
    throws CoucheLogiqueException
  {
    ConstitutionSjr constitutionSjr = p_dossierExamen.createConstitutionSjr();
    Sjrip sjrip = constitutionSjr.createSjrip();
    DonneesEntreeDeterminationSjrSpec donneesEntree = OutilDonneesDeterminationSjr.getInstance().initialiserDonneesEntreeAvecDemandeEtProduit((Demande)p_dossierExamen.getDemande());
    
    ProduitAsuSpec produitCourant = (ProduitAsuSpec)p_dossierExamen.getDossierAffecte().getProduit();
    FabriqueOutilFonctionnelDeterminationSjrSpec fabriqueOfSjr = (FabriqueOutilFonctionnelDeterminationSjrSpec)produitCourant.determinerFabriqueOutilFonctionnelDeterminationSjr(((Demande)p_dossierExamen.getDemande()).getDateFaitGenerateurOuDernierSinistre());
    
    Integer codeEmploiA2b = p_saisieAntecedent.getCodeEmploiA2B();
    Damj termePRC = p_saisieAntecedent.getTermePRC();
    Damj debutPrc = p_saisieAntecedent.getDateDebutPRC();
    
    Quantite sjrPlafonne = p_saisieAntecedent.getSalaireJournalierReferencePlafonne();
    if ((codeEmploiA2b != null) && (codeEmploiA2b.intValue() != 0))
    {
      termePRC = p_saisieAntecedent.getPeriodeFctRetenue().getDateFin();
      debutPrc = termePRC;
      DonneesEntreeDeterminationSjrSpec donneesEntreeA2b = OutilDonneesDeterminationSjr.getInstance().initialiserDonneesEntreeAvecDemandeEtProduit((Demande)p_dossierExamen.getDemande());
      
      DonneesResultatDeterminationSjr resultat = fabriqueOfSjr.getOutilDeterminationSjr().determinerSjripPourA2B(donneesEntreeA2b);
      sjrPlafonne = new QuantiteEuro(resultat.getSjri());
    }
    boolean topRemunerationBaseSMIC = p_saisieAntecedent.isSalaireReferenceSurBaseSMIC();
    if (p_saisieAntecedent.getCodeEmploiA2B() != null) {
      constitutionSjr.setCodeEmploiA2b(codeEmploiA2b.intValue());
    }
    PrcSjr prcSjr = new PrcSjr(new Periode(debutPrc, termePRC));
    sjrip.setPrc(prcSjr);
    sjrip.setDateEvenement(termePRC);
    
    BigDecimal plafondSjr = fabriqueOfSjr.getOutilDeterminationSjr().determinerPlafondSjr(termePRC, donneesEntree);
    sjrip.setPlafondSjr(new QuantiteEuro(plafondSjr));
    sjrip.setSjrInitial(new QuantiteEuro(sjrPlafonne.getValeur()));
    constitutionSjr.getSjrip().getPrc().setTopContratsDeTypeParticulier(topRemunerationBaseSMIC);
    if ((donneesEntree.getDonneesEntreeDemande() != null) && (donneesEntree.getDonneesEntreeDemande().getContexteDemande() != null) && (donneesEntree.getDonneesEntreeDemande().getContexteDemande().equals("AREMAYOTTE"))) {
      sjrip.setContexteParticulierSjr(donneesEntree.getDonneesEntreeDemande().getContexteDemande());
    }
    Sjr sjrrp = RevalorisationSalaire.revaloriserSjr(new Sjr(sjrip.getSjrInitial().getValeur(), sjrip.getDateDebut(), sjrip.getContexteParticulierSjr()), p_saisieAntecedent.getDateAttribution());
    
    constitutionSjr.setSjrrp(sjrrp);
    
    constitutionSjr.setSjnpr(null);
    prcSjr.setDiviseur(null);
  }
  
  protected void alimenterConstitutionSjc(DossierExamen p_dossierExamen, SaisieAntecedent p_saisieAntecedent)
    throws CoucheLogiqueException
  {
    Demande demande = (Demande)p_dossierExamen.getDemande();
    if ((demande.getListContexteDemande() == null) || (!OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(demande.getListContexteDemande(), "ARESJASPDC")))
    {
      Quantite sjcPlafonne = p_saisieAntecedent.getSalaireJournalierConservePlafonne();
      Damj termePRC = p_saisieAntecedent.getTermePRC();
      
      controleActivitesConservees(p_dossierExamen, sjcPlafonne);
      if (sjcPlafonne != null)
      {
        ConstitutionSjc constitutionSjc = p_dossierExamen.createConstitutionSjc();
        constitutionSjc.createSjcip();
        
        determinerListeActiviteConservees(p_dossierExamen, p_saisieAntecedent);
        
        constitutionSjc.getSjcip().setSjcInitial(new QuantiteEuro(sjcPlafonne.getValeur()));
        constitutionSjc.getSjcip().setDateEvenement(termePRC);
      }
    }
  }
  
  protected void controleActivitesConservees(DossierExamenSpec p_dossierExamen, Quantite p_sjcPlafonne)
    throws CoucheLogiqueException
  {
    Demande demande = (Demande)p_dossierExamen.getDemande();
    StrategieActiviteConserveeConvention2014Spec strategieActiviteConservee = OutilGestionActivitesConservees.getInstance().recupererStrategieActiviteConserveeConvention2014(demande);
    if ((p_sjcPlafonne != null) && (!strategieActiviteConservee.constituerSalaireJournalierConserve(demande))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_CALI_L_ALERTE_A11MB38", new Object[] { ProduitAsuCge01P06.getInstance().getPeriodeValidite().getDebut().toString() }, 1);
    }
    EvenementReferenceExamenSpec ere = p_dossierExamen.getDemande().getEvenementReferenceExamen();
    if (!"ASU_23".equals(ere.getTypeExamen()))
    {
      Chronologie chronoActivitesConservees = OutilGestionActivitesConservees.getInstance().determinerChronoGlobaleActivitesConservees((Demande)p_dossierExamen.getDemande());
      if (chronoActivitesConservees.getTaille() > 0)
      {
        if ((p_sjcPlafonne == null) && (strategieActiviteConservee.constituerSalaireJournalierConserve(demande)))
        {
          ProduitAsuSpec produitCourant = (ProduitAsuSpec)p_dossierExamen.getDossierAffecte().getProduit();
          Reglement reglementApplicableCourant = ((DossierExamenAssuranceSpec)p_dossierExamen).getReglementApplicable().getReglement();
          if (!reglementApplicableCourant.equals(produitCourant.getReglement("A4"))) {
            fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_ANTECEDENT_AC_SANS_SJC");
          }
        }
      }
      else if (p_sjcPlafonne != null) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_ANTECEDENT_SJC_SANS_AC");
      }
    }
  }
  
  private void determinerListeActiviteConservees(DossierExamen p_dossierExamen, SaisieAntecedent p_saisieAntecedent)
    throws CoucheLogiqueException
  {
    ProduitAsuSpec produit = (ProduitAsuSpec)p_dossierExamen.getDossierAffecte().getProduit();
    
    Damj dateExamen = p_dossierExamen.getDemande().getDateExamen();
    
    Damj dateExamenRechercheActiviteConservees = p_saisieAntecedent.getDateAttribution();
    p_dossierExamen.getDemande().getEvenementReferenceExamen().setDateEvenement(dateExamenRechercheActiviteConservees);
    
    produit.recalculerActivitesConserveesPourDemandeMigree(p_dossierExamen.getDemande());
    
    p_dossierExamen.getDemande().getEvenementReferenceExamen().setDateEvenement(dateExamen);
  }
  
  protected void alimenterConstitutionCoefficientTempsPartiel(DossierExamen p_dossierExamen, SaisieAntecedent p_saisieAntecedent)
  {
    ConstitutionCoefficientTempsPartiel constitutionCoefficientTempsPartiel = p_dossierExamen.getConstitutionElementsActifs().createConstitutionCoefficientTempsPartiel();
    
    BigDecimal coefficientTempsPartiel = p_saisieAntecedent.getCoefficientTempsPartiel();
    if (coefficientTempsPartiel == null) {
      coefficientTempsPartiel = new BigDecimal("1");
    }
    constitutionCoefficientTempsPartiel.setCoefficientTempsPartielRetenu(coefficientTempsPartiel);
  }
  
  protected void alimenterConstitutionCaractereSaisonnier(DossierExamen p_dossierExamen, SaisieAntecedent p_saisieAntecedent)
  {
    ConstitutionCaractereSaisonnier constitutionCaractereSaisonnier = p_dossierExamen.createConstitutionCaractereSaisonnier();
    
    boolean activite3sur5 = p_saisieAntecedent.isA3ansActiviteEn5ans();
    Integer typeCaractereSaisonnier = p_saisieAntecedent.getTypeCaractereSaisonnier();
    
    boolean caractereSaisonnierRetenu = (typeCaractereSaisonnier != null) && ((2 == typeCaractereSaisonnier.intValue()) || (1 == typeCaractereSaisonnier.intValue()));
    
    constitutionCaractereSaisonnier.setActivite3Sur5(activite3sur5);
    constitutionCaractereSaisonnier.setCaractereSaisonnierRetenu(caractereSaisonnierRetenu);
    if (caractereSaisonnierRetenu) {
      constitutionCaractereSaisonnier.setTypeCaractereSaisonnierRetenu(typeCaractereSaisonnier.intValue());
    }
    constitutionCaractereSaisonnier.setPeriodeReferenceSaisonnier(null);
    constitutionCaractereSaisonnier.setPeriodeRechercheActiviteSaisonniere(null);
  }
  
  protected void alimenterConstitutionCoefficientSaisonnier(DossierExamen p_dossierExamen, SaisieAntecedent p_saisieAntecedent)
  {
    ConstitutionCoefficientSaisonnier constitutionCoefficientSaisonnier = p_dossierExamen.createConstitutionCoefficientSaisonnier();
    
    BigDecimal coefficientSaisonnier = p_saisieAntecedent.getCoefficientSaisonnier();
    
    constitutionCoefficientSaisonnier.setCoefficientSaisonnierRetenu(coefficientSaisonnier);
    
    constitutionCoefficientSaisonnier.setJourActiviteDouzeDerniersMois(null);
  }
  
  protected void alimenterConstitutionDurees(DossierExamen p_dossierExamen, SaisieAntecedent p_saisieAntecedent)
    throws CoucheLogiqueException
  {
    ConstitutionDurees constitutionDurees = p_dossierExamen.getConstitutionElementsActifs().createConstitutionDurees();
    DureeIndemnisation dureeIndemnisation = constitutionDurees.createDureeIndemnisation();
    
    Quantite dureeInitialeDroit = p_saisieAntecedent.getDureeInitialeDroit();
    Quantite dureeRenouvellementSaisie = p_saisieAntecedent.getReliquatDureeRenouvellement();
    if (dureeInitialeDroit == null) {
      dureeInitialeDroit = new QuantiteJour("0");
    }
    dureeIndemnisation.setDureeTheorique(dureeInitialeDroit);
    dureeIndemnisation.setDureeEffective(dureeInitialeDroit);
    
    dureeIndemnisation.setDureeImputation(null);
    dureeIndemnisation.setQuantiteTotalJourImputation(null);
    dureeIndemnisation.setQuantiteJourImputationForce(null);
  }
  
  protected abstract void alimenterConstitutionMontantBrut(DossierExamenAssuranceSpec paramDossierExamenAssuranceSpec, SaisieAntecedent paramSaisieAntecedent)
    throws CoucheLogiqueException;
  
  protected void alimenterConstitutionDelais(DossierExamen p_dossierExamen, SaisieAntecedent p_saisieAntecedent)
  {
    p_dossierExamen.createConstitutionDelais();
  }
  
  protected void alimenterConstitutionPointDeDepart(DossierExamen pDossierExamen, SaisieAntecedent pSaisieAntecedent)
  {
    ConstitutionPointDepartIndemnisation constitutionPointDepartIndemnisation = pDossierExamen.createConstitutionPointDepartIndemnisation();
    
    Damj pji = pSaisieAntecedent.getPremierJourIndemnisable();
    if ((pji == null) && (12 == pSaisieAntecedent.getCodeProduit().intValue())) {
      pji = pSaisieAntecedent.getDateAttribution();
    }
    constitutionPointDepartIndemnisation.setPji(pji);
  }
  
  protected void alimenterConstitutionProduitResultant(DossierExamen pDossierExamen, SaisieAntecedent pSaisieAntecedent)
  {
    ConstitutionProduitResultant constitutionProduitResultant = pDossierExamen.createConstitutionProduitResultant();
    if (!"0".equals(pSaisieAntecedent.getMontantReadmissionRetenu())) {
      constitutionProduitResultant.setTypeMontantRetenu(2);
    } else {
      constitutionProduitResultant.setTypeMontantRetenu(1);
    }
  }
}

/* Location:
 * Qualified Name:     GrapheAntecedent
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */