package fr.unedic.cali.asu.cge01.avant;

import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.cge01.avant.outilsfonctionnels.TraitementUtAvant;
import fr.unedic.cali.asu.cge01.calcul.outilsfonctionnels.Qualification;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.SaisieAntecedent;
import fr.unedic.cali.asu.dom.cge01.AttributionAssuranceCgeSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.CarencePrefixeAFixer;
import fr.unedic.cali.asu.produits.liquidation.dom.Differe;
import fr.unedic.cali.asu.produits.liquidation.dom.Poursuite;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ElementChomageSansRuptureSpec;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnCharge;
import fr.unedic.cali.calcul.FacadeCalculProduitFactory;
import fr.unedic.cali.calcul.FacadeCalculProduitSpec;
import fr.unedic.cali.calcul.OutillagePeriodes;
import fr.unedic.cali.calcul.dom.CalendrierExecutionAvant;
import fr.unedic.cali.calcul.dom.EtatAuDernierJourAvant;
import fr.unedic.cali.calcul.dom.QualificationPeriodes;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeArretCalcul;
import fr.unedic.cali.calcul.outilsfonctionnels.GestionSuivi;
import fr.unedic.cali.calcul.outilsfonctionnels.OutilGestionPoursuite;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.RevisionSpec;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreConflitGaec;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreNegation;
import fr.unedic.cali.parcours.ResultatAvant;
import fr.unedic.cali.util.ObjetChronoPeriodeConcreteCarence;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;

public class FacadeAvantLigneSansTrancheImpl
  extends FacadeAvantLigneImpl
{
  private static FacadeAvantLigneSansTrancheImpl s_instance = new FacadeAvantLigneSansTrancheImpl();
  
  public static FacadeAvantLigneSansTrancheImpl getInstance()
  {
    return s_instance;
  }
  
  public ResultatAvant executerAvant(AttributionSpec attribution, boolean avecPriseEnCompteEvenement, Damj dateEtude, boolean executionPersistante)
    throws CoucheLogiqueException
  {
    ElementChomageSansRuptureSpec elementChomageSansRupture = ((AttributionAssuranceCgeSpec)attribution).getElementChomageSansRupture();
    if ((dateEtude != null) && (elementChomageSansRupture != null) && (elementChomageSansRupture.estDemandeEnContexteDeChomageEnCoursDeSuspension()) && (elementChomageSansRupture.estUnContexteDeRupturePendantSuspension()) && (dateEtude.estApresOuCoincideAvec(elementChomageSansRupture.getDateRepriseActivite()))) {
      return executionDeLAvant(attribution, avecPriseEnCompteEvenement, null, executionPersistante);
    }
    if ((elementChomageSansRupture != null) && (elementChomageSansRupture.estDemandeEnContexteDeChomageEnCoursDeSuspension()))
    {
      ArrayList listCarrence = new ArrayList();
      Collection carences = ((Attribution)attribution).getListeCarences();
      Iterator it = carences.iterator();
      while (it.hasNext())
      {
        CarencePrefixeAFixer carence = (CarencePrefixeAFixer)it.next();
        carence.setReliquat(carence.getQuantiteInitial());
        if (!(carence instanceof Differe)) {
          carence.setOrigineReliquat(new ObjetChronoPeriodeConcreteCarence(carence.getOrigine().getDateDebut(), carence.getDateFinPeriodeOrigine()));
        }
        listCarrence.add(carence);
      }
      return new ResultatAvant(attribution.getDateAttribution(), listCarrence, false);
    }
    return executionDeLAvant(attribution, avecPriseEnCompteEvenement, dateEtude, executionPersistante);
  }
  
  private ResultatAvant executionDeLAvant(AttributionSpec attribution, boolean avecPriseEnCompteEvenement, Damj dateEtude, boolean executionPersistante)
    throws CoucheLogiqueException
  {
    ResultatAvant resultatAvant = null;
    Damj pji = null;
    Collection carencesEffectives = new ArrayList();
    ObjetChronoPeriodePriseEnCharge periodePEC = null;
    ChronologiePeriodes chronologiePeriodes = new ChronologiePeriodes();
    ChronologiePeriodes chronologiePeriodesSansConflitGAEC = new ChronologiePeriodes();
    Collection listeCarrence = ((AttributionAssuranceSpec)attribution).getListeCarences();
    if ((attribution instanceof Poursuite)) {
      listeCarrence = construireCarencesPoursuite(attribution);
    }
    int etat = 0;
    
    Periode periodeUtAvant = null;
    Damj dateDebutUtAvant = null;
    Damj dateFinUtAvant = null;
    Damj finPEC = null;
    
    CalendrierExecutionAvant calendrierAvant = new CalendrierExecutionAvant();
    calendrierAvant.setPremierJourAvant(rechercherDateDebutAvant((AttributionAssuranceCgeSpec)attribution));
    calendrierAvant.setEtatExecutionAvant(1);
    
    dateDebutUtAvant = calendrierAvant.getPremierJourAvant().getDebutMois();
    dateFinUtAvant = dateDebutUtAvant.getFinMois();
    
    Damj dateAttribOuPjp = OutilGestionPoursuite.getInstance().recupererDateAttributionOuPjpSiPoursuite(attribution);
    if (avecPriseEnCompteEvenement)
    {
      chronologiePeriodes = recuperationDeToutesLesDesPeriodes(attribution.getDemandeur(), attribution, dateAttribOuPjp, null);
      
      periodePEC = OutillagePeriodes.recupererPeriodePECContenant(attribution.getDemandeur(), dateAttribOuPjp);
      if ((periodePEC == null) || (estContexteDeRevisionSurPecArce(attribution, periodePEC)))
      {
        if ((!(attribution instanceof RevisionSpec)) && (!"ASU_17".equals(attribution.getTypeExamen())) && (!"ASU_25".equals(attribution.getTypeExamen())) && (!"ASU_19".equals(attribution.getTypeExamen())) && (((!"ASU_22".equals(attribution.getTypeExamen())) && (!"ASU_23".equals(attribution.getTypeExamen()))) || ((attribution instanceof Poursuite)))) {
          throw new CoucheLogiqueException("HG_PR_CALI_L_PAS_DE_PEC_POUR_EXECUTION_AVANT", "Attention lors de l'execution de l'avant, impossible de retrouver une periode de prise en charge.", null);
        }
        resultatAvant = new ResultatAvant(pji, mettreAJourCarrenceSurRevisionHorsPec(listeCarrence, attribution.getDateAttribution()), false);
        resultatAvant.setDernierJourAvant(attribution.getDateAttribution());
        resultatAvant.setEtat(1);
        return resultatAvant;
      }
      finPEC = periodePEC.getDateFin();
    }
    else
    {
      chronologiePeriodes = (ChronologiePeriodes)recuperationDeToutesLesDesPeriodes(attribution.getDemandeur(), attribution, dateAttribOuPjp, dateAttribOuPjp).copier(new FiltreChevauchePeriode(new Periode(dateAttribOuPjp, dateAttribOuPjp)));
      
      chronologiePeriodesSansConflitGAEC = (ChronologiePeriodes)chronologiePeriodes.copier(new FiltreNegation(new FiltreConflitGaec()));
      
      chronologiePeriodes = chronologiePeriodesSansConflitGAEC;
      
      Qualification qualification = new Qualification();
      QualificationPeriodes periodesQualifie = new QualificationPeriodes();
      periodesQualifie = qualification.qualificationPeriodesPourAvant(chronologiePeriodes, attribution);
      
      chronologiePeriodes = periodesQualifie.getPeriodesSuspensives();
      chronologiePeriodes.ajouter(periodesQualifie.getPeriodesInterruptives());
    }
    IndividuSpec individu = attribution.getDemandeur();
    if (dateEtude != null) {
      chronologiePeriodes.ajouter(new ObjetChronoPeriodeArretCalcul(dateEtude.lendemain()));
    }
    while ((calendrierAvant.getEtatExecutionAvant() != 3) && (!listeCarrence.isEmpty()))
    {
      periodeUtAvant = new Periode(dateDebutUtAvant, dateFinUtAvant);
      if ((individu != null) && (individu.getDateNaissance() != null) && (periodeUtAvant.getDebut().estApres(individu.getDateNaissance().deplacerVersAvant(new DureeCalendaire(100))))) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_EXECUTION_ATTRIBUTION_DEMARRE_JAMAIS", new Object[] { attribution.getDateAttribution() });
      } else if (periodeUtAvant.getDebut().estApres(new Damj("2200, 01, 01"))) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_EXECUTION_ATTRIBUTION_DEMARRE_JAMAIS", new Object[] { attribution.getDateAttribution() });
      } else if (periodeUtAvant.getDebut().estApres(Damj.FIN_DES_TEMPS)) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_EXECUTION_ATTRIBUTION_DEMARRE_JAMAIS", new Object[] { attribution.getDateAttribution() });
      }
      dateDebutUtAvant = dateFinUtAvant.getDebutMoisSuivant();
      dateFinUtAvant = dateDebutUtAvant.getFinMois();
      if (Log.isTraceActive(FacadeAvantLigneImpl.class, Niveau.DEBUG)) {
        Log.ecritTrace(Niveau.DEBUG, FacadeAvantLigneImpl.class, "executerAvant", "Calcul: UT Avant [" + periodeUtAvant.getDebut() + " - " + periodeUtAvant.getFin() + "]");
      }
      etat = TraitementUtAvant.executerUtAvant(attribution, calendrierAvant, periodeUtAvant, chronologiePeriodes);
    }
    if (etat == 0) {
      pji = calendrierAvant.getDernierJourAvant().lendemain();
    }
    if (avecPriseEnCompteEvenement) {
      if ((finPEC != null) && (pji != null) && (finPEC.estAvantOuCoincideAvec(calendrierAvant.getDernierJourAvant()))) {
        if (OutillagePEC.estPecSuivanteAutreEtatMembreCoordination(attribution.getDemandeur(), finPEC))
        {
          Chronologie chronologiePecEuropeenne = OutillagePEC.getPeriodesPecAutreEtatMembreCoordinationDebutApresDate(attribution.getDemandeur(), finPEC);
          ObjetChronoPeriodePriseEnCharge pec = (ObjetChronoPeriodePriseEnCharge)chronologiePecEuropeenne.premierElement();
          if (pec.getDateDebut().estContenueDans(calendrierAvant.getPeriode()))
          {
            FacadeCalculProduitSpec facadeCalculProduit = FacadeCalculProduitFactory.getInstance().getInstanceGestionnaireCalculProduit(attribution.getProduitExecution());
            
            GestionSuivi.enregistrerEnquetePbjcNcp(attribution, pji, 31, 0, true, null, facadeCalculProduit, null);
          }
        }
      }
    }
    if (!listeCarrence.isEmpty())
    {
      if (executionPersistante) {
        attribution.setCalendrierExecutionAvant(calendrierAvant);
      }
      mettreAJour(calendrierAvant, (Attribution)attribution, carencesEffectives);
      
      resultatAvant = new ResultatAvant(pji, new ArrayList(carencesEffectives), calendrierAvant.getEtatAuDernierJourAvant().isDelaiAttenteEntame());
      
      resultatAvant.setEtat(etat);
      resultatAvant.setPremierJourAvant(calendrierAvant.getDateDebut());
      resultatAvant.setDernierJourAvant(calendrierAvant.getDateFin());
      resultatAvant.setCalendrierExecutionAvantCalcul(calendrierAvant);
    }
    else
    {
      attribution.setCalendrierExecutionAvant(null);
      if ((attribution instanceof Poursuite))
      {
        Damj pjiPoursuite = ((Poursuite)attribution).getSaisieAntecedent().getPremierJourIndemnisable();
        resultatAvant = new ResultatAvant(pjiPoursuite, new ArrayList(carencesEffectives), ((Poursuite)attribution).getSaisieAntecedent().isDelaiAttente());
        
        resultatAvant.setEtat(etat);
        resultatAvant.setPremierJourAvant(attribution.getDateAttribution());
        resultatAvant.setDernierJourAvant(pjiPoursuite.veille());
      }
      else
      {
        resultatAvant = new ResultatAvant(attribution.getDateAttribution(), new ArrayList(carencesEffectives), false);
        resultatAvant.setEtat(etat);
        resultatAvant.setPremierJourAvant(attribution.getDateAttribution());
        resultatAvant.setDernierJourAvant(attribution.getDateAttribution());
      }
    }
    if (etat == 1) {
      resultatAvant.setMessageErreur("Impossible de determiner le PJI : Un événement interruptif est survenu avant la fin du différé.");
    }
    return resultatAvant;
  }
  
  public Collection<?> recupererCarrence(AttributionSpec attribution)
  {
    Collection listeCarrence = ((AttributionAssuranceSpec)attribution).getListeCarences();
    if ((attribution instanceof Poursuite)) {
      listeCarrence = construireCarencesPoursuite(attribution);
    }
    return listeCarrence;
  }
  
  public Damj rechercherPremierJourAvant(AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    return rechercherDateDebutAvant((AttributionAssuranceCgeSpec)attribution);
  }
  
  public boolean estUnContexteDeChomageEnCoursDeSuspensionAvecRupture(AttributionSpec attribution, Damj dateEtude)
  {
    ElementChomageSansRuptureSpec elementChomageSansRupture = ((AttributionAssuranceCgeSpec)attribution).getElementChomageSansRupture();
    return (dateEtude != null) && (elementChomageSansRupture != null) && (elementChomageSansRupture.estDemandeEnContexteDeChomageEnCoursDeSuspension()) && (elementChomageSansRupture.estUnContexteDeRupturePendantSuspension()) && (dateEtude.estApresOuCoincideAvec(elementChomageSansRupture.getDateRepriseActivite()));
  }
  
  public boolean estUnContexteDeChomageEnCoursDeSuspension(AttributionSpec attribution)
  {
    ElementChomageSansRuptureSpec elementChomageSansRupture = ((AttributionAssuranceCgeSpec)attribution).getElementChomageSansRupture();
    return (elementChomageSansRupture != null) && (elementChomageSansRupture.estDemandeEnContexteDeChomageEnCoursDeSuspension());
  }
}

/* Location:
 * Qualified Name:     FacadeAvantLigneSansTrancheImpl
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */