package fr.unedic.cali.asu.cge01.avant.outilsfonctionnels;

import fr.unedic.cali.asu.calcul.dom.temps.ObjetChronoPeriodeSuspensionIndemnisation;
import fr.unedic.cali.asu.cge01.calcul.outilsfonctionnels.fabriques.FabriqueStrategieConvention2014;
import fr.unedic.cali.asu.cge01.calcul.outilsfonctionnels.strategies.StrategieConventionARE14Spec;
import fr.unedic.cali.calcul.dom.QualificationPeriodes;
import fr.unedic.cali.calcul.dom.UniteTraitementAvant;
import fr.unedic.cali.calcul.dom.periode.DsmMaladie;
import fr.unedic.cali.calcul.dom.periode.PeriodeAbsenceAuPointage;
import fr.unedic.cali.calcul.dom.periode.PeriodeEvenementPersonnel;
import fr.unedic.cali.calcul.dom.periode.PeriodeFormation;
import fr.unedic.cali.calcul.dom.periode.PeriodeInterStageFormation;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeSuspensionIslr;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.PeriodeAnalyse;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.PeriodeAnalyseSpec;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.FiltreDebutDansBornes;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import fr.unedic.util.temps.Temporel;
import java.util.ListIterator;

public class TraitementPeriodesAvant
{
  public static ChronologiePeriodes traitementPeriodesSegmentantes(Periode p_periode, UniteTraitementAvant p_utAvant, ChronologiePeriodes p_periodesSegmentantes)
    throws CoucheLogiqueException
  {
    PeriodeAnalyseSpec periodeAnalysePrecedente = null;
    PeriodeAnalyseSpec periodeAnalyseNouvelle = null;
    ObjetChronoPeriode periodeSegmentante = null;
    ChronologiePeriodes chronoPeriodesAnalyse = new ChronologiePeriodes();
    ListIterator iterateur = null;
    ChronologiePeriodes chronoPeriodesSegmentantesSurUt = null;
    
    periodeAnalysePrecedente = new PeriodeAnalyse(p_utAvant.getUniteParDefautQuantites(), new Periode(p_periode.getDebut(), p_periode.getFin()));
    
    chronoPeriodesAnalyse.ajouter(periodeAnalysePrecedente);
    
    chronoPeriodesSegmentantesSurUt = (ChronologiePeriodes)p_periodesSegmentantes.copier(new FiltreDebutDansBornes(p_periode));
    
    iterateur = chronoPeriodesSegmentantesSurUt.iterer();
    while (iterateur.hasNext())
    {
      periodeSegmentante = (ObjetChronoPeriode)iterateur.next();
      if (!periodeSegmentante.getDateDebut().coincideAvec(periodeAnalysePrecedente.getDateDebut()))
      {
        if (periodeSegmentante.getDateDebut().estApres(periodeAnalysePrecedente.getDateFin())) {
          throw new CoucheLogiqueException("HG_PR_CALI_L_ERREUR_TRAITEMENT_PERIODE_SEGMENTANTE", "Erreur de date de début lors du traitement des périodes segmentantes dans le Calcul.", null);
        }
        periodeAnalysePrecedente.setDateFin(periodeSegmentante.getDateDebut().veille());
        
        periodeAnalyseNouvelle = new PeriodeAnalyse(p_utAvant.getUniteParDefautQuantites(), new Periode(periodeSegmentante.getDateDebut(), p_periode.getFin()));
        
        chronoPeriodesAnalyse.ajouter(periodeAnalyseNouvelle);
        
        periodeAnalysePrecedente = periodeAnalyseNouvelle;
      }
    }
    return chronoPeriodesAnalyse;
  }
  
  public static boolean traitementPeriodesSuspensivesPourDebutConsommationDelaiAttente(PeriodeAnalyseSpec p_pa, QualificationPeriodes p_qualificationPeriodes, Damj p_dateDebutConsommationDelaiAttente)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes periodesSuspensivesSurPa = (ChronologiePeriodes)p_qualificationPeriodes.getPeriodesSuspensives().copier(new FiltreChevauchePeriode(p_pa.getPeriode()));
    
    periodesSuspensivesSurPa.ajouter((ChronologiePeriodes)p_qualificationPeriodes.getPeriodesInterruptives().copier(new FiltreChevauchePeriode(p_pa.getPeriode())));
    ChronologiePeriodes chronologiePeriodesSuspensivesSurPeriode = new ChronologiePeriodes();
    FabriqueStrategieConvention2014 fab = new FabriqueStrategieConvention2014();
    CritereStrategie cs = new CritereStrategie();
    cs.setDatePivot(p_pa.getDateDebut());
    StrategieConventionARE14Spec strat = (StrategieConventionARE14Spec)fab.getStrategie(cs);
    
    periodesSuspensivesSurPa.iterer();
    while (periodesSuspensivesSurPa.encoreSuivant())
    {
      Temporel periode = periodesSuspensivesSurPa.elementSuivant();
      if (strat.estAvantConventionARE14())
      {
        if (periode.getDateDebut().estAvantOuCoincideAvec(p_dateDebutConsommationDelaiAttente)) {
          if ((periode instanceof DsmMaladie)) {
            chronologiePeriodesSuspensivesSurPeriode.ajouter(periode);
          } else if ((periode instanceof PeriodeEvenementPersonnel)) {
            chronologiePeriodesSuspensivesSurPeriode.ajouter(periode);
          } else if ((periode instanceof PeriodeAbsenceAuPointage)) {
            chronologiePeriodesSuspensivesSurPeriode.ajouter(periode);
          }
        }
        if ((periode instanceof ObjetChronoPeriodeSuspensionIndemnisation)) {
          chronologiePeriodesSuspensivesSurPeriode.ajouter(periode);
        }
      }
      else if (new Periode(p_dateDebutConsommationDelaiAttente, p_dateDebutConsommationDelaiAttente).chevauche(new Periode(periode.getDateDebut(), periode.getDateFin())))
      {
        if ((periode instanceof DsmMaladie)) {
          chronologiePeriodesSuspensivesSurPeriode.ajouter(periode);
        } else if ((periode instanceof PeriodeEvenementPersonnel)) {
          chronologiePeriodesSuspensivesSurPeriode.ajouter(periode);
        } else if ((periode instanceof PeriodeAbsenceAuPointage)) {
          chronologiePeriodesSuspensivesSurPeriode.ajouter(periode);
        } else if ((periode instanceof ObjetChronoPeriodeSuspensionIslr)) {
          chronologiePeriodesSuspensivesSurPeriode.ajouter(periode);
        } else if ((periode instanceof ObjetChronoPeriodeSuspensionIndemnisation)) {
          chronologiePeriodesSuspensivesSurPeriode.ajouter(periode);
        }
      }
      if ((periode instanceof PeriodeFormation)) {
        chronologiePeriodesSuspensivesSurPeriode.ajouter(periode);
      } else if ((periode instanceof PeriodeInterStageFormation)) {
        chronologiePeriodesSuspensivesSurPeriode.ajouter(periode);
      }
    }
    if (!chronologiePeriodesSuspensivesSurPeriode.estVide()) {
      return true;
    }
    return false;
  }
}

/* Location:
 * Qualified Name:     TraitementPeriodesAvant
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */