package fr.unedic.cali.asu.cge01.calcul.outilsfonctionnels;

import fr.unedic.cali.asu.cge01.calcul.outilsfonctionnels.fabriques.FabriqueStrategieActiviteReduitePansConservee;
import fr.unedic.cali.asu.cge01.calcul.outilsfonctionnels.strategies.StrategieActiviteReduitePansConserveeSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.calcul.dom.periode.Pans;
import fr.unedic.cali.calcul.dom.periode.PansNonInstallee;
import fr.unedic.cali.calcul.dom.periode.PeriodeActiviteEmploiCalcul;
import fr.unedic.cali.calcul.dom.periode.PeriodePrime;
import fr.unedic.cali.calcul.dom.periode.PeriodeTravail;
import fr.unedic.cali.calcul.dom.periode.PeriodeTravailJustifiee;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.ResultatActiviteReduite;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodePANSConservee;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodePrimeCalcul;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodeTravailCalcul;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodeTravailCalculCESCAE;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodeTravailCalculCUI;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodeTravailCalculHorsPANSNonInstallee;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import java.math.BigDecimal;
import java.util.ListIterator;

public class ActiviteReduite
  extends fr.unedic.cali.asu.calcul.outilsfonctionnels.ActiviteReduite
{
  private static final BigDecimal COEF_AVANTAGE_VIEILLESSE_AR = new BigDecimal("0.8");
  private static final int AGE_CINQUANTE_ANS = 50;
  public static final BigDecimal SEUIL_HORAIRE_BIG = new BigDecimal("110");
  public static final int CUMUL_AR_DUREE_INDEMNISATION_MAX = 15;
  public static final int CUMUL_AR_TREIZIEME_MOIS = 13;
  
  public static BigDecimal calculerGainRetenu(Chronologie periodesEmploi)
  {
    BigDecimal gainRetenu = BigDecimal.ZERO;
    
    Chronologie chronoFiltree = periodesEmploi.copier(new FiltrePeriodeTravailCalcul());
    
    PeriodeTravail periodeCourante = null;
    chronoFiltree.iterer();
    while (chronoFiltree.encoreSuivant())
    {
      periodeCourante = (PeriodeTravail)chronoFiltree.elementSuivant();
      if (!(periodeCourante instanceof PansNonInstallee)) {
        gainRetenu = gainRetenu.add(periodeCourante.getGain());
      }
    }
    return gainRetenu;
  }
  
  public static BigDecimal calculerSeuilMensuel(Damj mois, BigDecimal sjr, BigDecimal sjc, boolean estApprenti, boolean avecSjc, BigDecimal cumulGainPansConservee, boolean presencePansConservee)
    throws CoucheLogiqueException
  {
    BigDecimal montantJournalierRetenu;
    BigDecimal montantJournalierRetenu;
    if (avecSjc) {
      montantJournalierRetenu = sjr.add(sjc);
    } else {
      montantJournalierRetenu = sjr;
    }
    BigDecimal sommeSjrSjc = sjr.add(sjc);
    BigDecimal montantMoyenMensuelRetenu = null;
    BigDecimal smicJournalier = getSmicJournalier(mois.getDebutMois());
    if ((estApprenti) && (!presencePansConservee)) {
      if (!avecSjc)
      {
        if (smicJournalier.compareTo(sjr) > 0) {
          montantJournalierRetenu = smicJournalier;
        }
      }
      else if (smicJournalier.compareTo(sommeSjrSjc) > 0) {
        montantJournalierRetenu = smicJournalier;
      }
    }
    montantMoyenMensuelRetenu = montantJournalierRetenu.multiply(new BigDecimal("30")).add(cumulGainPansConservee);
    
    return Mathematiques.tronque(montantMoyenMensuelRetenu.multiply(new BigDecimal("0.7")), 2);
  }
  
  private static boolean estMoisNeutraliseOdRgActiviteReprise(ResultatActiviteReduite resultatRetour, boolean contientPasCESEtCAE, boolean contientPasCUI, boolean contientPeriodeHorsPansNonInstallees, DureeCalendaire age, Damj mois, BigDecimal nbreHeuresCumulees, BigDecimal gainCumule, BigDecimal sjr, BigDecimal sjc, int cumulMois, boolean apprenti, boolean debutActiviteConserveAvantPrc, BigDecimal cumulGainPansConservee, boolean presencePansConservee)
    throws CoucheLogiqueException
  {
    boolean retour = false;
    BigDecimal montantMoyenMensuelCumul = calculerSeuilMensuel(mois, sjr, sjc, apprenti, debutActiviteConserveAvantPrc, cumulGainPansConservee, presencePansConservee);
    if ((contientPasCESEtCAE) && (contientPasCUI) && (contientPeriodeHorsPansNonInstallees) && (age.getAnnees() < 50) && (cumulMois >= 15))
    {
      resultatRetour.setTypeNeutralisation(3);
      retour = true;
    }
    else if ((nbreHeuresCumulees.compareTo(SEUIL_HORAIRE_BIG) > 0) && (gainCumule.compareTo(montantMoyenMensuelCumul) > 0))
    {
      resultatRetour.setTypeNeutralisation(2);
      retour = true;
    }
    else if (nbreHeuresCumulees.compareTo(SEUIL_HORAIRE_BIG) > 0)
    {
      resultatRetour.setTypeNeutralisation(0);
      retour = true;
    }
    else if (gainCumule.compareTo(montantMoyenMensuelCumul) > 0)
    {
      resultatRetour.setTypeNeutralisation(1);
      retour = true;
    }
    return retour;
  }
  
  public static ResultatActiviteReduite genererEvenementActiviteReduite(Damj dateDebutPeriodeActiviteReduite, Chronologie periodeEmploi, DureeCalendaire age, boolean apprenti, int cumulMois, String reglementAttribution, BigDecimal sjr, BigDecimal sjc, boolean estPNDS, Attribution attribution)
    throws CoucheLogiqueException
  {
    ResultatActiviteReduite evtRetour = new ResultatActiviteReduite();
    BigDecimal cumulNbHeures = BigDecimal.ZERO;
    BigDecimal cumulGain = BigDecimal.ZERO;
    BigDecimal cumulGainPrimes = BigDecimal.ZERO;
    BigDecimal cumulGainActiviteNonSalarieeNonInstallee = BigDecimal.ZERO;
    BigDecimal cumulGainJustifie = BigDecimal.ZERO;
    BigDecimal cumulNbHeuresJustifiees = BigDecimal.ZERO;
    BigDecimal cumulGainReprise = BigDecimal.ZERO;
    BigDecimal cumulNbHeuresReprise = BigDecimal.ZERO;
    BigDecimal cumulGainEstNeutralise = BigDecimal.ZERO;
    BigDecimal cumulNbJourTravail = BigDecimal.ZERO;
    BigDecimal cumulGainICCPConserve = BigDecimal.ZERO;
    BigDecimal cumulGainICCPRepris = BigDecimal.ZERO;
    BigDecimal cumulGainConserve = BigDecimal.ZERO;
    BigDecimal cumulGainPrimesConservees = BigDecimal.ZERO;
    BigDecimal cumulGainPansConservee = BigDecimal.ZERO;
    BigDecimal cumulNbHeuresConservees = BigDecimal.ZERO;
    BigDecimal cumulMontantPANS = BigDecimal.ZERO;
    
    Chronologie periodesEmploiCourantes = periodeEmploi.copier(new FiltrePeriodeTravailCalcul());
    Chronologie periodesPrime = periodeEmploi.copier(new FiltrePeriodePrimeCalcul());
    
    PeriodeTravail periodeCourante = null;
    boolean neutralisation = false;
    PeriodePrime prime = null;
    boolean calculSeuilAvecSjc = false;
    
    Chronologie chronoPeriodesConserveesLiq = attribution.getListeActiviteConservee();
    if ((chronoPeriodesConserveesLiq != null) && (!chronoPeriodesConserveesLiq.estVide())) {
      calculSeuilAvecSjc = true;
    }
    periodesPrime.iterer();
    while (periodesPrime.encoreSuivant())
    {
      prime = (PeriodePrime)periodesPrime.elementSuivant();
      if (prime.getTypeActivite() == 1) {
        cumulGainPrimesConservees = cumulGainPrimesConservees.add(prime.getMontant().getValeur());
      }
      cumulGainPrimes = cumulGainPrimes.add(prime.getMontant().getValeur());
    }
    ListIterator iterateur = periodesEmploiCourantes.iterer();
    while (iterateur.hasNext())
    {
      periodeCourante = (PeriodeTravail)iterateur.next();
      if ((periodeCourante instanceof PeriodeTravailJustifiee))
      {
        cumulGainJustifie = cumulGainJustifie.add(periodeCourante.getGain());
        cumulNbHeuresJustifiees = cumulNbHeuresJustifiees.add(periodeCourante.getNombreHeures());
      }
      if ((periodeCourante instanceof PansNonInstallee))
      {
        cumulGainActiviteNonSalarieeNonInstallee = cumulGainActiviteNonSalarieeNonInstallee.add(periodeCourante.getGain());
      }
      else
      {
        cumulNbJourTravail = cumulNbJourTravail.add(new BigDecimal(periodeCourante.getDuree()));
        if ((periodeCourante instanceof PeriodeActiviteEmploiCalcul))
        {
          if ((!estCategorieEmploiAnnexe1((PeriodeActiviteEmploiCalcul)periodeCourante)) || (!TraitementActiviteReduite.estAvantConventionARE14(dateDebutPeriodeActiviteReduite))) {
            cumulNbHeures = cumulNbHeures.add(periodeCourante.getNombreHeures());
          }
          cumulGain = cumulGain.add(((PeriodeActiviteEmploiCalcul)periodeCourante).getGainHorsIccp());
          if (((PeriodeActiviteEmploiCalcul)periodeCourante).getTypeActivite() == 1)
          {
            cumulGainConserve = cumulGainConserve.add(((PeriodeActiviteEmploiCalcul)periodeCourante).getGain());
            cumulGainICCPConserve = cumulGainICCPConserve.add(((PeriodeActiviteEmploiCalcul)periodeCourante).getIccp());
            if ((!estCategorieEmploiAnnexe1((PeriodeActiviteEmploiCalcul)periodeCourante)) || (!TraitementActiviteReduite.estAvantConventionARE14(dateDebutPeriodeActiviteReduite))) {
              cumulNbHeuresConservees = cumulNbHeuresConservees.add(((PeriodeActiviteEmploiCalcul)periodeCourante).getNombreHeures());
            }
          }
          else
          {
            cumulGainICCPRepris = cumulGainICCPRepris.add(((PeriodeActiviteEmploiCalcul)periodeCourante).getIccp());
            if ((!estCategorieEmploiAnnexe1((PeriodeActiviteEmploiCalcul)periodeCourante)) || (!TraitementActiviteReduite.estAvantConventionARE14(dateDebutPeriodeActiviteReduite))) {
              cumulNbHeuresReprise = cumulNbHeuresReprise.add(((PeriodeActiviteEmploiCalcul)periodeCourante).getNombreHeures());
            }
          }
        }
        else
        {
          cumulNbHeures = cumulNbHeures.add(periodeCourante.getNombreHeures());
          
          cumulGain = cumulGain.add(periodeCourante.getGain());
          if ((periodeCourante instanceof Pans))
          {
            evtRetour.setEstForfaitPans(((Pans)periodeCourante).getTypeRevenu() == 1 ? "1" : "0");
            cumulMontantPANS = cumulMontantPANS.add(((Pans)periodeCourante).getGain());
            if (((Pans)periodeCourante).getTypeActivite() == 1)
            {
              cumulGainConserve = cumulGainConserve.add(((Pans)periodeCourante).getGain());
              cumulGainPansConservee = cumulGainPansConservee.add(((Pans)periodeCourante).getGain());
              cumulNbHeuresConservees = cumulNbHeuresConservees.add(((Pans)periodeCourante).getNombreHeures());
            }
            else
            {
              cumulNbHeuresReprise = cumulNbHeuresReprise.add(((Pans)periodeCourante).getNombreHeures());
            }
          }
        }
      }
    }
    CritereStrategie critere = new CritereStrategie();
    critere.setDatePivot(dateDebutPeriodeActiviteReduite);
    FabriqueStrategieActiviteReduitePansConservee fabrique = new FabriqueStrategieActiviteReduitePansConservee();
    StrategieActiviteReduitePansConserveeSpec strategie = (StrategieActiviteReduitePansConserveeSpec)fabrique.getStrategie(critere);
    BigDecimal gainPansConserveeALaLiquidation = strategie.getGainPansConserveeALaLiquidation(attribution, cumulGainPansConservee);
    
    cumulGain = cumulGain.add(cumulGainPrimes);
    cumulGainConserve = cumulGainConserve.add(cumulGainPrimesConservees);
    
    cumulGainEstNeutralise = cumulGain;
    cumulGain = calculerGainRetenu(periodesEmploiCourantes);
    cumulGain = cumulGain.add(cumulGainPrimes);
    cumulGainReprise = cumulGain.subtract(cumulGainConserve).add(cumulGainActiviteNonSalarieeNonInstallee);
    
    cumulNbHeuresReprise = cumulNbHeures.subtract(cumulNbHeuresConservees);
    if (TraitementActiviteReduite.estAvantConventionARE14(dateDebutPeriodeActiviteReduite))
    {
      if (!reglementAttribution.equalsIgnoreCase("A4"))
      {
        boolean contientPasCESEtCAE = periodesEmploiCourantes.copier(new FiltrePeriodeTravailCalculCESCAE()).estVide();
        
        boolean contientPasCUI = periodesEmploiCourantes.copier(new FiltrePeriodeTravailCalculCUI()).estVide();
        boolean presencePansConservee = !periodesEmploiCourantes.copier(new FiltrePeriodePANSConservee()).estVide();
        boolean contientUneActiviteHorsPansNonInstallee = !periodesEmploiCourantes.copier(new FiltrePeriodeTravailCalculHorsPANSNonInstallee()).estVide();
        neutralisation = estMoisNeutraliseOdRgActiviteReprise(evtRetour, contientPasCESEtCAE, contientPasCUI, contientUneActiviteHorsPansNonInstallee, age, dateDebutPeriodeActiviteReduite, cumulNbHeures, cumulGainEstNeutralise, sjr, sjc, cumulMois, apprenti, calculSeuilAvecSjc, gainPansConserveeALaLiquidation, presencePansConservee);
        if (calculSeuilAvecSjc)
        {
          evtRetour.setSeuilRemuneration(null);
          evtRetour.setSeuilRemunerationAvecActConservee(calculerSeuilMensuel(dateDebutPeriodeActiviteReduite, sjr, sjc, apprenti, true, gainPansConserveeALaLiquidation, presencePansConservee));
        }
        else
        {
          evtRetour.setSeuilRemuneration(calculerSeuilMensuel(dateDebutPeriodeActiviteReduite, sjr, sjc, apprenti, false, new BigDecimal(0), presencePansConservee));
          
          evtRetour.setSeuilRemunerationAvecActConservee(null);
        }
      }
      BigDecimal smicJournalier = getSmicJournalier(dateDebutPeriodeActiviteReduite.getDebutMois());
      if (cumulGainActiviteNonSalarieeNonInstallee.compareTo(BigDecimal.ZERO) > 0)
      {
        BigDecimal nbJoursDecalage = null;
        BigDecimal montantJournalierRetenu = sjr;
        if ((apprenti) && (smicJournalier.compareTo(sjr) > 0)) {
          montantJournalierRetenu = smicJournalier;
        }
        if (age.getAnnees() >= 50)
        {
          nbJoursDecalage = Mathematiques.diviseEntier(cumulGainActiviteNonSalarieeNonInstallee, montantJournalierRetenu);
          nbJoursDecalage = nbJoursDecalage.multiply(COEF_AVANTAGE_VIEILLESSE_AR).setScale(0, 1);
        }
        else
        {
          nbJoursDecalage = Mathematiques.diviseEntier(cumulGainActiviteNonSalarieeNonInstallee, montantJournalierRetenu);
        }
        evtRetour.setDecalageDuree(nbJoursDecalage);
      }
      if ((!neutralisation) || (estPNDS))
      {
        BigDecimal nbJoursDecalage = null;
        BigDecimal montantJournalierRetenu = sjr;
        BigDecimal cumulGainPrDecalage = cumulGain.subtract(cumulGainConserve);
        if ((apprenti) && (smicJournalier.compareTo(sjr) > 0)) {
          montantJournalierRetenu = smicJournalier;
        }
        if (age.getAnnees() >= 50)
        {
          nbJoursDecalage = Mathematiques.diviseEntier(cumulGainPrDecalage, montantJournalierRetenu);
          nbJoursDecalage = nbJoursDecalage.multiply(COEF_AVANTAGE_VIEILLESSE_AR).setScale(0, 1);
        }
        else
        {
          nbJoursDecalage = Mathematiques.diviseEntier(cumulGainPrDecalage, montantJournalierRetenu);
        }
        evtRetour.setCreditDecalage(nbJoursDecalage);
      }
      evtRetour.setNeutralise(neutralisation);
    }
    evtRetour.setNbHeuresPrisesEnCompte(cumulNbHeures);
    evtRetour.setGainPrisEnCompte(cumulGain.add(cumulGainActiviteNonSalarieeNonInstallee));
    
    evtRetour.setCumulGainJustifie(cumulGainJustifie);
    evtRetour.setCumulNbHeuresJustifiees(cumulNbHeuresJustifiees);
    
    evtRetour.setCumulGainReprise(cumulGainReprise);
    evtRetour.setCumulNbHeuresReprise(cumulNbHeuresReprise);
    
    evtRetour.setCumulJourDeTravail(cumulNbJourTravail);
    
    evtRetour.setCumulGainICCPConserves(cumulGainICCPConserve);
    
    evtRetour.setCumulGainICCPRepris(cumulGainICCPRepris);
    
    evtRetour.setRacAns(gainPansConserveeALaLiquidation);
    evtRetour.setMontantPANS(cumulMontantPANS);
    return evtRetour;
  }
}

/* Location:
 * Qualified Name:     ActiviteReduite
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */