package fr.unedic.cali.asu.cge01.liquidation.outilsaffiliation;

import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeIntensite;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeMesureActivite;
import fr.unedic.cali.autresdoms.ga.dom.spec.IncidentSpec;
import fr.unedic.cali.dom.PeriodeElementaire;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.UniteAffiliation;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.List;
import java.util.Set;

public class ConstitutionPeriodesElementaires
{
  private static final int SEPT_JOURS = 7;
  private static final int NOMBRE_CHIFFRE_APRES_VIRGULE = 5;
  private static final BigDecimal ZERO = new BigDecimal("0");
  private static final Quantite QUANTITE_ZERO_HEURE = new Quantite("0", UniteAffiliation.HEURE_TRAVAIL);
  
  public static Chronologie constituer(ActiviteSalarie p_pas, Periode p_periode, Chronologie p_pnds, Chronologie p_periodesSuspension)
  {
    Chronologie periodeActiviteAvecIntensite = determinerActiviteAvecIntensite(p_pas);
    
    Chronologie periodesResultantes = new ChronologiePeriodes();
    for (Iterator iterPeriodeActivite = periodeActiviteAvecIntensite.iterer(); iterPeriodeActivite.hasNext();)
    {
      periodeElementaireAvecIntensite = (PeriodeElementaire)iterPeriodeActivite.next();
      
      periodeElementaire = null;
      
      projectionEnPeriodeElementaire = ProjectionChronologie.decouper(periodeElementaireAvecIntensite.getPeriode(), p_periodesSuspension);
      totalJourAvecIntensite = null;
      for (iterProjectionEnPeriodeElementaire = projectionEnPeriodeElementaire.iterator(); iterProjectionEnPeriodeElementaire.hasNext();)
      {
        Periode periodeElementaireProjete = (Periode)iterProjectionEnPeriodeElementaire.next();
        
        periodeElementaire = proratiseAffiliationSurPeriode(periodeElementaireAvecIntensite, periodeElementaireProjete);
        Iterator iterperiodeSuspension;
        if ((p_periodesSuspension != null) && (!p_periodesSuspension.estVide())) {
          for (iterperiodeSuspension = p_periodesSuspension.iterer(); iterperiodeSuspension.hasNext();)
          {
            IncidentSpec suspension = (IncidentSpec)iterperiodeSuspension.next();
            if (suspension.estTempsPlein())
            {
              periodeElementaire = calculerAffiliationSuspensionTempsPlein(suspension, periodeElementaire, periodeElementaireAvecIntensite);
            }
            else
            {
              if (totalJourAvecIntensite == null) {
                totalJourAvecIntensite = determinerTotalIntensite(suspension, projectionEnPeriodeElementaire);
              }
              Quantite qteHeures = periodeElementaireAvecIntensite.getQuantiteAffiliation(UniteAffiliation.HEURE_TRAVAIL);
              if (qteHeures == null)
              {
                Quantite qteJours = periodeElementaireAvecIntensite.getQuantiteAffiliation(UniteAffiliation.JOUR);
                qteHeures = determinerAffiliationSuspensionTempsPlein(qteJours, periodeElementaireAvecIntensite.getInstensite().getHorairesSalarie());
              }
              periodeElementaire.setEstPresenceSuspension(true);
              Quantite quantiteHeuresActivite = periodeElementaire.getQuantiteAffiliation(UniteAffiliation.HEURE_TRAVAIL);
              if (quantiteHeuresActivite == null) {
                quantiteHeuresActivite = QUANTITE_ZERO_HEURE;
              }
              periodeElementaire.setQuantiteHeuresActivite(quantiteHeuresActivite);
              
              Quantite quantiteHeuresAffiliationAvecSuspensionTempsPartiel = calculerAffiliationSuspensionTempsPartiel(qteHeures.getValeur(), periodeElementaire.getDuree(), totalJourAvecIntensite, periodeElementaireAvecIntensite.getInstensite().getHorairesEntreprise());
              
              Quantite quantiteHeuresSuspension = quantiteHeuresAffiliationAvecSuspensionTempsPartiel.moins(quantiteHeuresActivite);
              quantiteHeuresSuspension = quantiteHeuresSuspension.max(QUANTITE_ZERO_HEURE);
              periodeElementaire.setQuantiteHeuresSuspension(quantiteHeuresSuspension);
              
              periodeElementaire.ajouterQuantiteAffiliation(quantiteHeuresAffiliationAvecSuspensionTempsPartiel);
            }
          }
        }
        periodeElementaire = proratiseAffiliationSurPeriode(periodeElementaire, p_periode);
        periodeElementaire.setReglementAppartenance(p_pas.getReglement());
        Iterator iterperiodeSanction;
        if ((p_pnds != null) && (!p_pnds.estVide()))
        {
          List projectionPeriodeElementaireSanction = ProjectionChronologie.decouper(periodeElementaire.getPeriode(), p_pnds);
          for (iterperiodeSanction = projectionPeriodeElementaireSanction.iterator(); iterperiodeSanction.hasNext();)
          {
            Periode periodeSanction = (Periode)iterperiodeSanction.next();
            PeriodeElementaire periodeElementaireSanctonne = proratiseAffiliationSurPeriode(periodeElementaire, periodeSanction);
            periodeElementaireSanctonne = sanctionnerPeriodeElementaireSurPnds(periodeElementaireSanctonne, p_pnds);
            
            periodeElementaireSanctonne.setPeriodeActiviteOrigine(p_pas);
            periodeElementaireSanctonne.setReglementAppartenance(p_pas.getReglement());
            periodesResultantes.ajouter(periodeElementaireSanctonne);
          }
        }
        else
        {
          periodeElementaire.setPeriodeActiviteOrigine(p_pas);
          
          periodesResultantes.ajouter(periodeElementaire);
        }
      }
    }
    PeriodeElementaire periodeElementaireAvecIntensite;
    PeriodeElementaire periodeElementaire;
    List projectionEnPeriodeElementaire;
    BigDecimal totalJourAvecIntensite;
    Iterator iterProjectionEnPeriodeElementaire;
    return periodesResultantes;
  }
  
  public static PeriodeElementaire proratiseAffiliationSurPeriode(PeriodeElementaire p_periodeElementaire, Periode p_periode)
  {
    PeriodeElementaire periodeElementaireProratise = null;
    
    Periode periodeIntersection = p_periode.periodeIntersection(p_periodeElementaire.getPeriode());
    if ((periodeIntersection != null) && (periodeIntersection.getDuree() < p_periodeElementaire.getDuree()))
    {
      periodeElementaireProratise = new PeriodeElementaire(periodeIntersection.getDebut(), periodeIntersection.getFin());
      
      BigDecimal dureePeriodeElementaire = new BigDecimal(p_periodeElementaire.getDuree());
      BigDecimal dureePeriodeIntersection = new BigDecimal(periodeIntersection.getDuree());
      UniteAffiliation uniteAffiliation = null;
      Quantite quantiteAffiliationParUnite = null;
      BigDecimal valeurProratisee = null;
      Hashtable listeQuantite = p_periodeElementaire.getListeQuantitesAppartenance();
      for (Iterator iter = listeQuantite.keySet().iterator(); iter.hasNext();)
      {
        uniteAffiliation = (UniteAffiliation)iter.next();
        quantiteAffiliationParUnite = (Quantite)listeQuantite.get(uniteAffiliation);
        valeurProratisee = Mathematiques.proratiser(quantiteAffiliationParUnite.getValeur(), dureePeriodeIntersection, dureePeriodeElementaire);
        
        valeurProratisee = valeurProratisee.setScale(2, 1);
        quantiteAffiliationParUnite = new Quantite(valeurProratisee, quantiteAffiliationParUnite.getUnite());
        periodeElementaireProratise.ajouterQuantiteAffiliation(quantiteAffiliationParUnite);
      }
      Quantite quantiteHeures = p_periodeElementaire.getQuantiteHeuresActivite();
      if ((quantiteHeures != null) && (quantiteHeures.getValeur().compareTo(ZERO) > 0))
      {
        valeurProratisee = Mathematiques.proratiser(quantiteHeures.getValeur(), dureePeriodeIntersection, dureePeriodeElementaire);
        valeurProratisee = valeurProratisee.setScale(2, 1);
        quantiteHeures = new Quantite(valeurProratisee, quantiteHeures.getUnite());
        periodeElementaireProratise.setQuantiteHeuresActivite(quantiteHeures);
      }
      quantiteHeures = p_periodeElementaire.getQuantiteHeuresSuspension();
      if ((quantiteHeures != null) && (quantiteHeures.getValeur().compareTo(ZERO) > 0))
      {
        valeurProratisee = Mathematiques.proratiser(quantiteHeures.getValeur(), dureePeriodeIntersection, dureePeriodeElementaire);
        valeurProratisee = valeurProratisee.setScale(2, 1);
        quantiteHeures = new Quantite(valeurProratisee, quantiteHeures.getUnite());
        periodeElementaireProratise.setQuantiteHeuresSuspension(quantiteHeures);
      }
      periodeElementaireProratise.setEstPresenceSuspension(p_periodeElementaire.estPresenceSuspension());
      periodeElementaireProratise.setEstSanctionne(p_periodeElementaire.estSanctionne());
      periodeElementaireProratise.getInstensite().setHorairesEntreprise(p_periodeElementaire.getInstensite().getHorairesEntreprise());
      periodeElementaireProratise.getInstensite().setHorairesSalarie(p_periodeElementaire.getInstensite().getHorairesSalarie());
      periodeElementaireProratise.getInstensite().setUniteHoraire(p_periodeElementaire.getInstensite().getUniteHoraire());
      periodeElementaireProratise.setPeriodeActiviteOrigine(p_periodeElementaire.getPeriodeActiviteOrigine());
      periodeElementaireProratise.setPriorite(p_periodeElementaire.getPriorite());
      periodeElementaireProratise.setReglementAppartenance(p_periodeElementaire.getReglementAppartenance());
    }
    else
    {
      periodeElementaireProratise = p_periodeElementaire;
    }
    return periodeElementaireProratise;
  }
  
  private static PeriodeElementaire proratiseAffiliationSurPMA(PeriodeElementaire p_periodeElementaire, Periode p_periode)
  {
    Hashtable listeQuantite = p_periodeElementaire.getListeQuantitesAppartenance();
    PeriodeElementaire periodeElementaireProratise = null;
    
    Periode intersection = p_periode.periodeIntersection(p_periodeElementaire.getPeriode());
    Iterator iter;
    if (intersection != null)
    {
      periodeElementaireProratise = new PeriodeElementaire(intersection.getDebut(), intersection.getFin());
      for (iter = listeQuantite.keySet().iterator(); iter.hasNext();)
      {
        UniteAffiliation uniteAffiliation = (UniteAffiliation)iter.next();
        Quantite quantiteAffiliationParUnite = (Quantite)listeQuantite.get(uniteAffiliation);
        BigDecimal valeurProratisee = Mathematiques.proratiser(quantiteAffiliationParUnite.getValeur(), new BigDecimal(intersection.getDuree()), new BigDecimal(p_periode.getDuree()));
        
        valeurProratisee = valeurProratisee.setScale(2, 1);
        quantiteAffiliationParUnite = new Quantite(valeurProratisee, quantiteAffiliationParUnite.getUnite());
        periodeElementaireProratise.ajouterQuantiteAffiliation(quantiteAffiliationParUnite);
      }
    }
    else
    {
      periodeElementaireProratise = p_periodeElementaire;
    }
    return periodeElementaireProratise;
  }
  
  private static PeriodeElementaire sanctionnerPeriodeElementaireSurPnds(PeriodeElementaire p_periodeElementaire, Chronologie p_pnds)
  {
    PeriodeElementaire periodeElementaireSanctionne = p_periodeElementaire;
    for (Iterator itPnds = p_pnds.iterer(); itPnds.hasNext();)
    {
      ObjetChronoPeriode periodeSanctionne = (ObjetChronoPeriode)itPnds.next();
      int nombreDeJourCommun = periodeSanctionne.inter(p_periodeElementaire.getPeriode());
      if (nombreDeJourCommun != 0) {
        periodeElementaireSanctionne.setEstSanctionne(true);
      }
    }
    return periodeElementaireSanctionne;
  }
  
  public static PeriodeElementaire calculerAffiliationSuspensionTempsPlein(IncidentSpec p_suspension, PeriodeElementaire p_periodeElementaire, PeriodeElementaire p_periodeElementaireAvecIntensite)
  {
    if (p_suspension.inter(p_periodeElementaire.getPeriode()) != 0)
    {
      Quantite quantiteJoursSuspension = new Quantite(p_periodeElementaire.getDuree(), UniteAffiliation.JOUR_SUSPENSION);
      
      Quantite quantiteHeuresActivite = p_periodeElementaire.getQuantiteAffiliation(UniteAffiliation.HEURE_TRAVAIL);
      if (quantiteHeuresActivite == null) {
        quantiteHeuresActivite = QUANTITE_ZERO_HEURE;
      }
      p_periodeElementaire.setEstPresenceSuspension(true);
      p_periodeElementaire.setQuantiteHeuresActivite(quantiteHeuresActivite);
      Quantite quantiteHeuresSuspension = determinerAffiliationSuspensionTempsPlein(quantiteJoursSuspension, p_periodeElementaireAvecIntensite.getInstensite().getHorairesSalarie());
      
      p_periodeElementaire.setQuantiteHeuresSuspension(quantiteHeuresSuspension);
      
      Quantite quantiteHeuresAffiliation = quantiteHeuresActivite.ajouter(quantiteHeuresSuspension);
      
      p_periodeElementaire.getListeQuantitesAppartenance().clear();
      p_periodeElementaire.ajouterQuantiteAffiliation(quantiteHeuresAffiliation);
      p_periodeElementaire.ajouterQuantiteAffiliation(quantiteJoursSuspension);
    }
    return p_periodeElementaire;
  }
  
  private static Quantite determinerAffiliationSuspensionTempsPlein(Quantite p_jourSuspendu, BigDecimal p_horaireSalarie)
  {
    float suspension = p_jourSuspendu.getValeur().floatValue() * (p_horaireSalarie.floatValue() / 7.0F);
    
    Quantite affiliationSuspension = new Quantite(new BigDecimal(suspension), UniteAffiliation.HEURE_TRAVAIL);
    
    return affiliationSuspension;
  }
  
  private static Quantite calculerAffiliationSuspensionTempsPartiel(BigDecimal p_totalHeure, int p_intensiteSuspensionJour, BigDecimal p_totalIntensiteJour, BigDecimal p_horaireContractuel)
  {
    BigDecimal intensiteSuspensionJour = new BigDecimal(p_intensiteSuspensionJour);
    BigDecimal suspension = p_totalHeure.multiply(intensiteSuspensionJour.divide(p_totalIntensiteJour, 5, 0));
    
    suspension = suspension.max(p_horaireContractuel);
    Quantite affiliationSuspension = new Quantite(suspension, UniteAffiliation.HEURE_TRAVAIL);
    return affiliationSuspension;
  }
  
  private static Chronologie determinerActiviteAvecIntensite(ActiviteSalarie p_pas)
  {
    Chronologie periodesActivteAvecIntensite = new ChronologiePeriodes();
    Chronologie periodesMesuresActivite = p_pas.getListePeriodesMesureActivite();
    Chronologie periodesIntensite = p_pas.getListePeriodeIntensite();
    for (Iterator iterPeriodeActivite = periodesMesuresActivite.iterer(); iterPeriodeActivite.hasNext();)
    {
      periodeMesureActivite = (PeriodeMesureActivite)iterPeriodeActivite.next();
      
      List projectionEnPeriodeElementaire = ProjectionChronologie.decouper(periodeMesureActivite.getPeriode(), periodesIntensite);
      for (iterProjectionEnPeriodeElementaire = projectionEnPeriodeElementaire.iterator(); iterProjectionEnPeriodeElementaire.hasNext();)
      {
        Periode periodeElementaireProjete = (Periode)iterProjectionEnPeriodeElementaire.next();
        PeriodeElementaire periodeElementaire = new PeriodeElementaire(periodeElementaireProjete.getDebut(), periodeElementaireProjete.getFin());
        
        periodeMesureActivite = (PeriodeMesureActivite)periodeMesureActivite.copie();
        periodeMesureActivite.initQuantiteAffiliation();
        for (Enumeration interQuantiteAffiliation = periodeMesureActivite.getListeQuantitesAffiliation().elements(); interQuantiteAffiliation.hasMoreElements();)
        {
          Quantite quantiteAppartenance = (Quantite)interQuantiteAffiliation.nextElement();
          periodeElementaire.ajouterQuantiteAffiliation(quantiteAppartenance);
        }
        for (Iterator interPeriodeIntensite = periodesIntensite.iterer(); interPeriodeIntensite.hasNext();)
        {
          PeriodeIntensite intensite = (PeriodeIntensite)interPeriodeIntensite.next();
          if (intensite.inter(periodeElementaire.getPeriode()) != 0) {
            periodeElementaire.setInstensite(intensite);
          }
        }
        periodeElementaire = proratiseAffiliationSurPMA(periodeElementaire, periodeMesureActivite.getPeriode());
        periodesActivteAvecIntensite.ajouter(periodeElementaire);
      }
    }
    PeriodeMesureActivite periodeMesureActivite;
    Iterator iterProjectionEnPeriodeElementaire;
    return periodesActivteAvecIntensite;
  }
  
  private static BigDecimal determinerTotalIntensite(IncidentSpec p_suspension, List p_periodeElementaire)
  {
    BigDecimal totalJourAvecIntensite = new BigDecimal("0");
    for (Iterator iterProjectionEnPeriodeElementaire = p_periodeElementaire.iterator(); iterProjectionEnPeriodeElementaire.hasNext();)
    {
      Periode periodeElementaireProjete = (Periode)iterProjectionEnPeriodeElementaire.next();
      if (p_suspension.getPeriode().coincideAvec(periodeElementaireProjete)) {
        totalJourAvecIntensite = new BigDecimal(periodeElementaireProjete.getDuree()).multiply(p_suspension.getIntensite()).add(totalJourAvecIntensite);
      } else {
        totalJourAvecIntensite = totalJourAvecIntensite.add(new BigDecimal(periodeElementaireProjete.getDuree()));
      }
    }
    return totalJourAvecIntensite;
  }
}

/* Location:
 * Qualified Name:     ConstitutionPeriodesElementaires
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */