package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.DelaiRechercheProduit;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.EreDemandeExpresse;
import fr.unedic.cali.asu.dom.EreFinDroitSuiteRepriseNonSaisonniere;
import fr.unedic.cali.asu.outilsaffiliation.OutilPeriodeAffiliation;
import fr.unedic.cali.asu.parcours.ParcoursRechercheAlertesNonBloquantes;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.OdSpec;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.services.PasAssezInformationException;
import fr.unedic.util.temps.CalculDelais;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.util.Map;

public class DelaiRechercheSinistres
  implements OutilFonctionnel
{
  public static DelaiRechercheProduit determinerDelaiRechercheSinistre(DossierAffectationSpec dossierAffectation, DureeCalendaire delaiAllongement)
    throws CoucheLogiqueException
  {
    Demande demande = (Demande)dossierAffectation.getDemande();
    
    TravailSpec sinistre = ((DossierAffectation)dossierAffectation).getSinistre();
    
    DelaiRechercheProduit delaiRetourne = delaiRechercheProduitRetourne(dossierAffectation, demande, sinistre);
    if (delaiAllongement != null) {
      delaiRetourne = allongerDelaiRechercheSinistre(delaiRetourne, delaiAllongement);
    } else {
      delaiRetourne = automatiserAllongementDelaiForclusion(delaiRetourne, demande);
    }
    Damj dateFgOdPrecedente = demande.getDateFaitGenerateurOdPrecedente();
    if ((dateFgOdPrecedente != null) && (delaiRetourne.getDebut().estAvantOuCoincideAvec(dateFgOdPrecedente))) {
      delaiRetourne.setDebut(dateFgOdPrecedente.lendemain());
    }
    return delaiRetourne;
  }
  
  private static DelaiRechercheProduit delaiRechercheProduitRetourne(DossierAffectationSpec dossierAffectation, Demande demande, TravailSpec sinistre)
  {
    int douzeMois = 12;
    
    DelaiRechercheProduit delaiRetourne = null;
    Damj debutDelaiRetourne = null;
    Damj finDelaiRetourne = null;
    
    Damj termeDelai = demande.getDateExamen().veille();
    if (((demande.getEvenementReferenceExamen() instanceof EreFinDroitSuiteRepriseNonSaisonniere)) || (demande.getEvenementReferenceExamen().getTypeExamen().equals("ASU_08")))
    {
      OdSpec odPrecedente = demande.rechercherOuvertureDroitPrecedenteDuMemeType();
      debutDelaiRetourne = odPrecedente.getDateAttribution();
      finDelaiRetourne = termeDelai;
    }
    else if (((demande.getEvenementReferenceExamen() instanceof EreDemandeExpresse)) && (sinistre != null) && (demande.getDonneesTemporaires() != null) && ((demande.getDonneesTemporaires().getMotifExamen() == 1) || (demande.getDonneesTemporaires().getMotifExamen() == 2)))
    {
      debutDelaiRetourne = ((DossierAffectation)dossierAffectation).getSinistre().getDateFin();
      finDelaiRetourne = termeDelai;
    }
    else
    {
      Periode delai = CalculDelais.determinerDelaiCalendaire(termeDelai, new DureeCalendaire(0, 12));
      debutDelaiRetourne = delai.getDebut();
      finDelaiRetourne = delai.getFin();
    }
    delaiRetourne = new DelaiRechercheProduit(debutDelaiRetourne, finDelaiRetourne);
    return delaiRetourne;
  }
  
  public static DelaiRechercheProduit allongerDelaiRechercheSinistre(DelaiRechercheProduit delaiRecherche, DureeCalendaire delaiAllongement)
    throws PasAssezInformationException
  {
    Damj dateDebut = delaiRecherche.getDebut().deplacerVersArriere(delaiAllongement);
    
    DelaiRechercheProduit delaiRetourne = new DelaiRechercheProduit(dateDebut, delaiRecherche.getFin());
    
    return delaiRetourne;
  }
  
  public static DelaiRechercheProduit automatiserAllongementDelaiForclusion(DelaiRechercheProduit delaiRecherche, Demande demande)
    throws CoucheLogiqueException
  {
    int allongementCourant = 0;
    DelaiRechercheProduit retour = delaiRecherche;
    int allongementTotal;
    do
    {
      allongementTotal = allongementCourant;
      Map chronologies = ConstructionChronologie.determinerChronologiesAllongementDelaiForclusion(demande, retour);
      
      Chronologie chronoSituation2 = ((Chronologie)chronologies.get("AllongementDFChevaucheCTPourAlerte")).copier();
      chronoSituation2.ajouter((Chronologie)chronologies.get("AllongementDFSansConditionPourAlerte"));
      if (!chronoSituation2.estVide())
      {
        ParcoursRechercheAlertesNonBloquantes.getInstance().presencePeriodeAllongementDelaiForclusion(demande, chronoSituation2);
        
        return delaiRecherche;
      }
      Chronologie chronoSituation1 = ((Chronologie)chronologies.get("AllongementDelaiForclusionSi1JourIndemnise")).copier();
      chronoSituation1.ajouter((Chronologie)chronologies.get("AllongementDFSansChevauchementCT"));
      chronoSituation1.ajouter((Chronologie)chronologies.get("AllongementDFSansCondition"));
      
      allongementCourant = OutilPeriodeAffiliation.determinerNombreJoursChronoApresFusionPeriode(chronoSituation1, new Periode(Damj.NUIT_DES_TEMPS, delaiRecherche.getFin()));
      
      retour = new DelaiRechercheProduit(delaiRecherche.getDebut().deplacerVersArriere(new DureeCalendaire(0, 0, allongementCourant)), delaiRecherche.getFin());
    } while (allongementCourant != allongementTotal);
    return retour;
  }
}

/* Location:
 * Qualified Name:     DelaiRechercheSinistres
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */