package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.dom.ResultatDeterminationDuree;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.OutilCalculAffiliation;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.OutilCalculAppartenance;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.dom.ParametresAffiliation;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.EreRechargement;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.JustificationAffiliationSpec;
import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.dom.Reliquat;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.liquidation.outilsfonctionnels.DeterminationMontant;
import fr.unedic.cali.asu.liquidation.outilsfonctionnels.OutilAdhesionVolontaire;
import fr.unedic.cali.asu.outilsfonctionnels.ConstitutionDuree;
import fr.unedic.cali.asu.outilsfonctionnels.DetectionContexteParticulierLiquidation;
import fr.unedic.cali.asu.outilsfonctionnels.OutilAsp;
import fr.unedic.cali.asu.outilsfonctionnels.OutilAsr;
import fr.unedic.cali.asu.outilsfonctionnels.OutilAtp;
import fr.unedic.cali.asu.outilsfonctionnels.OutilDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilFinDroit;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilTranchesExecutables;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionQuantiteAffiliation;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeDroitPourPRA;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeReglementaire;
import fr.unedic.cali.asu.produits.liquidation.dom.Od;
import fr.unedic.cali.asu.produits.liquidation.dom.Pra;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ConstitutionElementsSpec;
import fr.unedic.cali.asu.produits.liquidation.parametres.CleAccesDureeDroit;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeMesureActivite;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculSpec;
import fr.unedic.cali.calcul.dom.EtatAuDji;
import fr.unedic.cali.dom.DecisionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.NaturesDecisions;
import fr.unedic.cali.dom.affectation.GammeAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.conteneurs.DonneesEntreesRecuperationMontant;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourTypeContexteDemande;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.Convertisseur;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.UniteAffiliation;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import fr.unedic.util.temps.Temporel;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Map;

public class DeterminationDureeReglementaire
  implements OutilFonctionnel
{
  public static final int AGE_50_ANS = 50;
  public static final int AGE_57_ANS = 57;
  public static final int INF_50ANS = 1;
  public static final int SUP_EGAL_50ANS = 2;
  public static final int SUP_EGAL_57ANS = 3;
  public static final BigDecimal DUREE_MAXIMALE_ARE2009_730_JOURS = new BigDecimal(730);
  public static final BigDecimal DUREE_MAXIMALE_ARE2009_1095_JOURS = new BigDecimal(1095);
  public static final BigDecimal DUREE_THEORIQUE_INITIALE_MIMIMALE = new BigDecimal(122);
  public static final BigDecimal DUREE_THEORIQUE_MINIMALE_APRES_IMPUTATION_FORMATION = new BigDecimal(30);
  public static final BigDecimal DUREE_THEORIQUE_MINIMALE_RECHARGEMENT = new BigDecimal(30);
  private static final int PRECISION_ARRONDI_CONVERTION = 0;
  private static final int NB_CHIFFRE_APRES_VIRGULE = 10;
  private static final BigDecimal POURCENTAGE_PLAFOND_CAPITAL = new BigDecimal(0.75D);
  
  public static DeterminationDureeReglementaire getInstance()
  {
    return new DeterminationDureeReglementaire();
  }
  
  public void mapperResultatSurDom(ResultatDeterminationDuree resultat, DureeIndemnisation dureeIndemnisation)
  {
    dureeIndemnisation.setDateMaxiIndemnisationCsr(resultat.getDateMaxiIndemnisationCsr());
    dureeIndemnisation.setDureeImputation(resultat.getDureeImputation());
    dureeIndemnisation.setDureeTheorique(resultat.getDureeTheorique());
    dureeIndemnisation.setQuantiteJourImputationForce(resultat.getQuantiteJourImputationForce());
    dureeIndemnisation.setQuantiteTotalJourImputation(resultat.getQuantiteTotalJourImputation());
    dureeIndemnisation.setDureeEffective(resultat.getDureeEffective());
    dureeIndemnisation.setEstAccordPlusDe182jCsr(resultat.isEstAccordPlusDe182jCsr());
    dureeIndemnisation.setEstDureeTheoriquePlafonnee(resultat.isEstDureeTheoriquePlafonnee());
    dureeIndemnisation.setDureeServieSurAsr(resultat.getDureeServieSurAsr());
    dureeIndemnisation.setDureeRestantAImputer(resultat.getDureeRestantAImputer());
    dureeIndemnisation.setDureeAllongementAREF(resultat.getDureeAllongementAref());
    dureeIndemnisation.setEligibleAllongementAREF(resultat.isEligibleAllongementAref());
  }
  
  private BigDecimal determinerDureeMin(Demande demande)
  {
    BigDecimal dureeMini = DUREE_THEORIQUE_INITIALE_MIMIMALE;
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "RECHARGE")) {
      dureeMini = DUREE_THEORIQUE_MINIMALE_RECHARGEMENT;
    }
    return dureeMini;
  }
  
  public ResultatDeterminationDuree determinerDureeReglementaire(Demande demande, boolean appliquerPlafond, boolean appliquerPlancherImputationFormation)
    throws ApplicativeException
  {
    ConstitutionDurees constitutionDurees = ((DossierExamen)demande.getDossierExamen()).getConstitutionElementsActifs().getConstitutionDurees();
    
    ResultatDeterminationDuree resultat = new ResultatDeterminationDuree();
    
    Quantite dureeForcee = null;
    if (demande.getDonneesTemporaires() != null) {
      dureeForcee = demande.getDonneesTemporaires().getDureeTheoriqueForcee();
    }
    if ((dureeForcee != null) && (dureeForcee.getValeur() != null))
    {
      dureeForcee = new Quantite(new BigDecimal(plafonnerDuree(demande, dureeForcee.getValeur())), DureeReglementaire.UNITE_DEFAUT);
      resultat.setDureeTheorique(dureeForcee);
      resultat.setDureeImputation(new Quantite(0, DureeReglementaire.UNITE_DEFAUT));
      resultat.setQuantiteTotalJourImputation(new Quantite(0, DureeReglementaire.UNITE_DEFAUT));
      resultat.setQuantiteJourImputationForce(new Quantite(0, DureeReglementaire.UNITE_DEFAUT));
    }
    else
    {
      int dureeTheoriqueDroitCourant = determinerDureeReglementaireDroitCourant(demande);
      if (appliquerPlafond)
      {
        int dureeTheoriqueDroitCourantInitiale = dureeTheoriqueDroitCourant;
        dureeTheoriqueDroitCourant = appliquerPlafonnementDuree(dureeTheoriqueDroitCourant, demande, resultat);
        if (dureeTheoriqueDroitCourantInitiale > dureeTheoriqueDroitCourant) {
          constitutionDurees.setJoursEcretementSurPlafonnementDuree(dureeTheoriqueDroitCourantInitiale - dureeTheoriqueDroitCourant);
        }
      }
      dureeTheoriqueDroitCourant = determinerDureeMin(demande).max(new BigDecimal(dureeTheoriqueDroitCourant)).intValue();
      
      Quantite qteDureeTheorique = new Quantite(dureeTheoriqueDroitCourant, DureeReglementaire.UNITE_DEFAUT);
      
      Quantite qteDureeImputationDroitCourant = OutilTraitementReliquat.determinerDureeImputationFormationDroitCourant(demande.getDossierAffectation().getProduit(), demande, qteDureeTheorique, OutilTraitementReliquat.determinerPeriodeImputationFormationDroitCourant(demande, demande.getDateExamen().veille()), dureeTheoriqueDroitCourant);
      
      qteDureeTheorique = qteDureeTheorique.soustraire(qteDureeImputationDroitCourant);
      if (appliquerPlancherImputationFormation) {
        qteDureeTheorique = new Quantite(DUREE_THEORIQUE_MINIMALE_APRES_IMPUTATION_FORMATION.max(qteDureeTheorique.getValeur()), DureeReglementaire.UNITE_DEFAUT);
      }
      int dureeImputationDroitCourant = 0;
      Quantite qteDureeImputation = new Quantite(dureeImputationDroitCourant, DureeReglementaire.UNITE_DEFAUT);
      if (demande.getDonneesTemporaires().getNbJourImputer() != null)
      {
        qteDureeImputation = new Quantite(demande.getDonneesTemporaires().getNbJourImputer().intValue(), DureeReglementaire.UNITE_DEFAUT);
        qteDureeTheorique = qteDureeTheorique.soustraire(qteDureeImputation);
      }
      Quantite qteTotalJourImputation = qteDureeImputationDroitCourant.ajouter(qteDureeImputation);
      
      resultat.setDureeTheorique(qteDureeTheorique);
      resultat.setDureeImputation(qteDureeImputationDroitCourant);
      
      resultat.setQuantiteTotalJourImputation(qteTotalJourImputation);
      resultat.setQuantiteJourImputationForce(qteDureeImputation);
    }
    return resultat;
  }
  
  private Quantite recupererDureeRestantAimputer(Demande demande)
    throws ApplicativeException
  {
    Quantite quantiteRetour = new Quantite(0, DureeReglementaire.UNITE_DEFAUT);
    if ((demande != null) && (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "ACTIMPREL")) && (NaturesDecisions.estdeTypeReprise(demande.getObjectifDecisionne().getSousType())))
    {
      Quantite quantiteRestantAImputerSauvegardee = ((DossierExamenAssuranceSpec)demande.getDossierExamen()).getDureeRestanteAImputerFinCSP();
      if (quantiteRestantAImputerSauvegardee == null)
      {
        ResultatDeterminationDuree resultatDeterminationDuree = DeterminationDureeReglementaireAdhesionVolontaire.getInstanceAdhesionVolontaire().determinerDureeReglementairePourRepriseRevision(demande);
        quantiteRetour = resultatDeterminationDuree.getDureeRestantAImputer();
      }
      else
      {
        quantiteRetour = quantiteRestantAImputerSauvegardee;
      }
    }
    return quantiteRetour;
  }
  
  public ResultatDeterminationDuree imputerReliquatImputation(Demande demande, ResultatDeterminationDuree resultat)
    throws ApplicativeException
  {
    DecisionSpec decisionAvecReliquatImputationPossible = null;
    
    EvenementReferenceExamenSpec ere = demande.getEvenementReferenceExamen();
    String typeExamen = ere.getTypeExamen();
    if ("ASU_29".equals(typeExamen)) {
      decisionAvecReliquatImputationPossible = ((EreRechargement)ere).getAttributionAssurancePrecedente();
    }
    if (decisionAvecReliquatImputationPossible != null)
    {
      Quantite quantiteAImputer = recupererDureeRestantAimputer((Demande)decisionAvecReliquatImputationPossible.getDemande());
      Quantite dureeTheorique = resultat.getDureeTheorique();
      Quantite nouvelleDureeTheorique = OutilAdhesionVolontaire.imputerQuantite(dureeTheorique, quantiteAImputer);
      resultat.setDureeTheorique(nouvelleDureeTheorique);
    }
    return resultat;
  }
  
  public ResultatDeterminationDuree determinerDureeReglementairePourRepriseRevision(Demande demande)
    throws ApplicativeException
  {
    ResultatDeterminationDuree resultat = new ResultatDeterminationDuree();
    
    AttributionAssuranceSpec dossierExamen = (AttributionAssuranceSpec)demande.getDossierExamen();
    
    Quantite qteNbJourImputer = new Quantite(0, DureeReglementaire.UNITE_DEFAUT);
    Reliquat reliquat = demande.getReliquat();
    Quantite quantiteReliquat = new Quantite(reliquat.getQuantiteReliquat().getValeurEntiere(), DureeReglementaire.UNITE_DEFAUT);
    if (demande.getDonneesTemporaires().getNbJourImputer() != null)
    {
      qteNbJourImputer = new Quantite(demande.getDonneesTemporaires().getNbJourImputer().intValue(), DureeReglementaire.UNITE_DEFAUT);
      quantiteReliquat = quantiteReliquat.soustraire(qteNbJourImputer);
    }
    if (demande.estEnContexteDemande("PREPOSTCSP"))
    {
      DecisionSpec attribution = OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande.getDateExamen(), new FiltreDemandePourTypeContexteDemande("AREENTRCSP"));
      if ((attribution instanceof Attribution))
      {
        int dureeAllongement = ((Attribution)attribution).getConstitutionDurees().getDureeIndemnisation().getDureeAllongementAREF();
        if (dureeAllongement != 0)
        {
          resultat.setEligibleAllongementAref(true);
          resultat.setDureeAllongementAref(dureeAllongement);
        }
      }
    }
    else
    {
      resultat.setDureeAllongementAref(reliquat.getReliquatAllongementArefPossible());
      if (reliquat.getReliquatAllongementArefPossible() > 0) {
        resultat.setEligibleAllongementAref(true);
      } else {
        resultat.setEligibleAllongementAref(false);
      }
    }
    Quantite qteTotalJourImputation = reliquat.getQuantiteImputee().ajouter(qteNbJourImputer);
    resultat.setQuantiteJourImputationForce(qteNbJourImputer);
    resultat.setQuantiteTotalJourImputation(qteTotalJourImputation);
    resultat.setDureeTheorique(quantiteReliquat);
    resultat.setDureeImputation(qteTotalJourImputation);
    
    resultat.setDureeEffective(ConstitutionDuree.calculerDureeEffectivePourReprise(demande.getDemandeur(), dossierExamen.getDateAttribution(), quantiteReliquat, DureeReglementaire.UNITE_DEFAUT, true));
    
    return resultat;
  }
  
  public ResultatDeterminationDuree determinerDureeReglementaireFinAsr(Demande demande, int contexteExamen)
    throws ApplicativeException
  {
    int nbJoursIndemnises = 0;
    
    Attribution attributionAsr = (Attribution)OutilAsr.rechercherDernierDroitAsr(demande);
    while ((attributionAsr != null) && (!(attributionAsr instanceof Od)) && (!attributionAsr.getDemande().getEvenementReferenceExamen().getTypeExamen().equals("ASU_16")))
    {
      nbJoursIndemnises += attributionAsr.getCalendrierExecutionCalcul().getEtatAuDJI().getCumulJoursIndemnise();
      attributionAsr = (Attribution)attributionAsr.getAttributionPrecedente();
    }
    nbJoursIndemnises += attributionAsr.getCalendrierExecutionCalcul().getEtatAuDJI().getCumulJoursIndemnise();
    
    Quantite qteJoursIndemnises = new Quantite(nbJoursIndemnises, Unite.getParCode("4"));
    ResultatDeterminationDuree dureeIndemnisation = determinerDureeReglementaire(demande, false, false);
    dureeIndemnisation.setDureeServieSurAsr(qteJoursIndemnises);
    Quantite qteResult;
    Quantite qteResult;
    if (demande.estContexteAsrPrecSuiteCsr())
    {
      Demande demandeAsr = (Demande)attributionAsr.getDemande();
      AttributionAssuranceSpec attributionArePrecedente = OutilDemande.getArePrecedentCsr(demandeAsr);
      
      Quantite reliquat = OutilAsr.calculerReliquatArePrecedentAsr(demandeAsr, attributionArePrecedente);
      qteResult = reliquat;
    }
    else
    {
      qteResult = dureeIndemnisation.getDureeTheorique();
    }
    if ((attributionAsr.getProduit().getCode() == 36) || (contexteExamen == 1) || (contexteExamen == 2)) {
      qteResult = qteResult.soustraire(qteJoursIndemnises);
    }
    if (qteResult.getValeurEntiere() < 0) {
      qteResult = new Quantite(0, qteResult.getUnite());
    }
    dureeIndemnisation.setDureeTheorique(qteResult);
    
    return dureeIndemnisation;
  }
  
  public ResultatDeterminationDuree determinerDureeReglementaireFinAtp(Demande demande)
    throws ApplicativeException
  {
    Attribution attributionAtp = (Attribution)OutilAtp.rechercherAttributionAtpPrecedent(demande);
    
    Quantite nbJoursIndemnisesAtp = OutilFinDroit.trouverQuantiteAImputer(demande, attributionAtp);
    
    ResultatDeterminationDuree dureeIndemnisation = determinerDureeReglementaire(demande, false, false);
    
    Quantite qteResult = dureeIndemnisation.getDureeTheorique();
    
    qteResult = qteResult.soustraire(nbJoursIndemnisesAtp);
    if (qteResult.getValeurEntiere() < 0) {
      qteResult = new Quantite(0, qteResult.getUnite());
    }
    dureeIndemnisation.setDureeTheorique(qteResult);
    
    return dureeIndemnisation;
  }
  
  public ResultatDeterminationDuree determinerDureeReglementaireFinAsp(Demande demande, int contexteExamen, boolean appliquerPlafond, boolean appliquerPlancherImputationFormation)
    throws ApplicativeException
  {
    Attribution attributionAsp = (Attribution)OutilAsp.getInstance().rechercherAttributionAspPrecedent(demande, demande.getDateDeclenchementExamen());
    
    Quantite nbJoursIndemnisesAsr = OutilFinDroit.trouverQuantiteAImputer(demande, attributionAsp);
    ResultatDeterminationDuree dureeIndemnisation = determinerDureeReglementaire(demande, appliquerPlafond, appliquerPlancherImputationFormation);
    dureeIndemnisation.setDureeServieSurAsr(nbJoursIndemnisesAsr);
    Quantite qteResult;
    Quantite qteResult;
    if (demande.estContexteAsrPrecSuiteCsr())
    {
      Demande demandeAsp = (Demande)attributionAsp.getDemande();
      AttributionAssuranceSpec attributionArePrecedente = OutilDemande.getArePrecedentCsr(demandeAsp);
      
      Quantite reliquat = OutilAsr.calculerReliquatArePrecedentAsr(demandeAsp, attributionArePrecedente);
      qteResult = reliquat;
    }
    else
    {
      qteResult = dureeIndemnisation.getDureeTheorique();
    }
    if ((contexteExamen == 1) || (contexteExamen == 2))
    {
      qteResult = qteResult.soustraire(nbJoursIndemnisesAsr);
      if ((dureeIndemnisation.getQuantiteTotalJourImputation() != null) && (nbJoursIndemnisesAsr != null)) {
        dureeIndemnisation.setQuantiteTotalJourImputation(dureeIndemnisation.getQuantiteTotalJourImputation().ajouter(nbJoursIndemnisesAsr));
      }
    }
    if (qteResult.getValeurEntiere() < 0) {
      qteResult = new Quantite(0, qteResult.getUnite());
    }
    dureeIndemnisation.setDureeTheorique(qteResult);
    
    return dureeIndemnisation;
  }
  
  public ResultatDeterminationDuree determinerDureeReglementaireFinAtpBasculeCrpCtp(Demande demande)
    throws ApplicativeException
  {
    Attribution attributionAtp = (Attribution)OutilAtp.rechercherAttributionAtpPrecedent(demande);
    
    Attribution attributionAsr = (Attribution)OutilAsr.rechercherAttributionAsrPrecedent(demande);
    
    Quantite nbJoursIndemnisesAtp = OutilFinDroit.trouverQuantiteAImputer(demande, attributionAtp);
    
    Quantite nbJoursIndemnisesAsr = OutilFinDroit.trouverQuantiteAImputer(demande, attributionAsr);
    
    Quantite qteJoursIndemnises = nbJoursIndemnisesAtp.ajouter(nbJoursIndemnisesAsr);
    ResultatDeterminationDuree dureeIndemnisation = determinerDureeReglementaire(demande, false, false);
    
    Quantite qteResult = dureeIndemnisation.getDureeTheorique();
    
    qteResult = qteResult.soustraire(qteJoursIndemnises);
    if (qteResult.getValeurEntiere() < 0) {
      qteResult = new Quantite(0, qteResult.getUnite());
    }
    dureeIndemnisation.setDureeTheorique(qteResult);
    
    return dureeIndemnisation;
  }
  
  private static BigDecimal determinerQuantiteJourAffiliation(Quantite quantiteAcquise, Convertisseur convertisseurUniteAffiliation)
  {
    if (quantiteAcquise != null)
    {
      if (!quantiteAcquise.getUnite().equals(UniteAffiliation.JOUR))
      {
        BigDecimal resultat = convertisseurUniteAffiliation.convertir(quantiteAcquise, UniteAffiliation.JOUR).getValeur();
        return Mathematiques.arrondiASup(resultat, 0);
      }
      return Mathematiques.arrondiASup(quantiteAcquise.getValeur(), 0);
    }
    return null;
  }
  
  private static BigDecimal determinerPlafondDureeAre2009SelonCodeAge(Demande demande)
  {
    FaitGenerateurSpec faitGenerateur = demande.getFaitGenerateur();
    DureeCalendaire ageFG = demande.getDemandeur().getAgeALaDate(faitGenerateur.getDateFaitGenerateur());
    if (determinerCodeAge(ageFG.getAnnees()) > 1) {
      return DUREE_MAXIMALE_ARE2009_1095_JOURS;
    }
    return DUREE_MAXIMALE_ARE2009_730_JOURS;
  }
  
  private static int determinerCodeAge(int ageDemandeurAuFg)
  {
    if (ageDemandeurAuFg < 50) {
      return 1;
    }
    if (ageDemandeurAuFg >= 57) {
      return 3;
    }
    return 2;
  }
  
  private int determinerDureeReglementaireDroitCourant(Demande demande)
  {
    IndividuSpec individu = demande.getDemandeur();
    
    FaitGenerateurSpec faitGenerateur = demande.getFaitGenerateur();
    Damj dateFG = faitGenerateur.getDateFaitGenerateur();
    DossierExamen dossierExamen = (DossierExamen)demande.getDossierExamen();
    
    JustificationAffiliationSpec justification = dossierExamen.getJustificationAffiliation();
    Pra pra;
    Pra pra;
    if ("justifCGENouveauModele".equals(justification.getTypeJustificationAffiliation())) {
      pra = (Pra)((fr.unedic.cali.asu.dom.JustificationAffiliation)justification).getPeriodeRechercheAffiliation();
    } else {
      pra = ((fr.unedic.cali.asu.produits.liquidation.dom.JustificationAffiliation)justification).getPeriodePraRetenue();
    }
    ConstitutionQuantiteAffiliation cepQuantiteAffiliation = ((DossierExamen)demande.getDossierExamen()).getConstitutionQuantiteAffiliation();
    
    DureeCalendaire ageFG = individu.getAgeALaDate(dateFG);
    int codeAge = determinerCodeAge(ageFG.getAnnees());
    
    int codeCentTrimestres = 0;
    if ((demande.getDemandeur().getDateCentTrimestres() != null) && (demande.getDemandeur().getDateCentTrimestres().estAvantOuCoincideAvec(dateFG))) {
      codeCentTrimestres = 1;
    }
    CleAccesDureeDroit cle = new CleAccesDureeDroit(codeAge, codeCentTrimestres);
    
    DureeDroitPourPRA duree = pra.getDureeDroit(cle);
    int dureeTheoriqueDroitCourant;
    int dureeTheoriqueDroitCourant;
    if (duree != null)
    {
      dureeTheoriqueDroitCourant = duree.getDuree();
    }
    else
    {
      ProduitAsuSpec produitAffecte = (ProduitAsuSpec)dossierExamen.getDossierAffecte().getProduit();
      Convertisseur convertisseurUniteAffiliation = produitAffecte.determinerConvertisseurUniteAffiliation();
      
      BigDecimal quantiteAffiliationEnJours = determinerQuantiteJourAffiliation(cepQuantiteAffiliation.getQuantiteAcquise(), convertisseurUniteAffiliation);
      
      BigDecimal quantiteAffiliationEnJoursSecondaire = determinerQuantiteJourAffiliation(cepQuantiteAffiliation.getQuantiteAcquiseSecondaire(), convertisseurUniteAffiliation);
      
      BigDecimal quantiteARetenir = quantiteAffiliationEnJours;
      if (quantiteAffiliationEnJoursSecondaire != null) {
        quantiteARetenir = quantiteAffiliationEnJours.max(quantiteAffiliationEnJoursSecondaire);
      }
      if ((cepQuantiteAffiliation.getQuantiteAcquise() != null) && (quantiteAffiliationEnJoursSecondaire != null) && (cepQuantiteAffiliation.getQuantiteAcquise().getValeur().compareTo(quantiteAffiliationEnJoursSecondaire) == -1))
      {
        JustificationAffiliationSpec justif = cepQuantiteAffiliation.getJustificationAffiliation(cepQuantiteAffiliation.getQuantiteAcquiseSecondaire().getUnite());
        if ("justifCGENouveauModele".equals(justif.getTypeJustificationAffiliation()))
        {
          fr.unedic.cali.asu.dom.JustificationAffiliation justificationNouveauModele = (fr.unedic.cali.asu.dom.JustificationAffiliation)justif;
          
          ((DossierAffecte)dossierExamen.getDossierAffecte()).getValidationProduit().setJustificationCalculAffiliation(justificationNouveauModele);
        }
        else
        {
          fr.unedic.cali.asu.produits.liquidation.dom.JustificationAffiliation justificationAncienModele = (fr.unedic.cali.asu.produits.liquidation.dom.JustificationAffiliation)justif;
          justificationAncienModele.setAppartenanceCalculee(cepQuantiteAffiliation.getQuantiteAcquiseSecondaire());
        }
        Quantite qteTemp = cepQuantiteAffiliation.getQuantiteAffiliationAcquise();
        Quantite qteTemp1 = cepQuantiteAffiliation.getQuantiteAssimilationAcquise();
        Quantite qteTemp2 = cepQuantiteAffiliation.getQuantiteAffiliationAcquiseSecondaire();
        Quantite qteTemp3 = cepQuantiteAffiliation.getQuantiteAssimilationAcquiseSecondaire();
        qteTemp2 = new Quantite(qteTemp2.getValeur().setScale(10, 1), qteTemp2.getUnite());
        
        qteTemp3 = new Quantite(qteTemp3.getValeur().setScale(10, 1), qteTemp3.getUnite());
        
        qteTemp = new Quantite(qteTemp.getValeur().setScale(10, 1), qteTemp.getUnite());
        
        qteTemp1 = new Quantite(qteTemp1.getValeur().setScale(10, 1), qteTemp1.getUnite());
        
        cepQuantiteAffiliation.setQuantiteAffiliationAcquise(qteTemp2);
        cepQuantiteAffiliation.setQuantiteAssimilationAcquise(qteTemp3);
        cepQuantiteAffiliation.setQuantiteAffiliationAcquiseSecondaire(qteTemp);
        cepQuantiteAffiliation.setQuantiteAssimilationAcquiseSecondaire(qteTemp1);
      }
      dureeTheoriqueDroitCourant = plafonnerDuree(demande, quantiteARetenir);
    }
    return dureeTheoriqueDroitCourant;
  }
  
  protected int plafonnerDuree(Demande demande, BigDecimal quantiteARetenir)
  {
    BigDecimal plafondDuree = determinerPlafondDureeAre2009SelonCodeAge(demande);
    
    int dureeTheoriqueDroitCourant = plafondDuree.min(quantiteARetenir).intValue();
    return dureeTheoriqueDroitCourant;
  }
  
  public ResultatDeterminationDuree determinerDureeReglementaireFinancementAtpBasculeCrpCtp(Demande demande)
    throws ApplicativeException
  {
    ResultatDeterminationDuree dureeIndemnisation;
    if (demande.getDonneesTemporaires().getDureeFinancement() != null)
    {
      ResultatDeterminationDuree dureeIndemnisation = new ResultatDeterminationDuree();
      Quantite qteDureeTheorique = new Quantite(demande.getDonneesTemporaires().getDureeFinancement(), DureeReglementaire.UNITE_DEFAUT);
      if (demande.getDonneesTemporaires().getNbJourImputer() != null)
      {
        Quantite qteDureeImputation = new Quantite(demande.getDonneesTemporaires().getNbJourImputer().intValue(), DureeReglementaire.UNITE_DEFAUT);
        qteDureeTheorique = qteDureeTheorique.soustraire(qteDureeImputation);
        dureeIndemnisation.setDureeImputation(qteDureeImputation);
      }
      dureeIndemnisation.setDureeTheorique(qteDureeTheorique);
    }
    else
    {
      dureeIndemnisation = determinerDureeReglementaire(demande, false, false);
      if (demande.getDonneesTemporaires().getNbJourImputer() == null)
      {
        Attribution attributionAsr = (Attribution)OutilAsr.rechercherAttributionAsrPrecedent(demande);
        
        Quantite nbJoursIndemnisesAsr = OutilFinDroit.trouverQuantiteAImputer(demande, attributionAsr);
        
        dureeIndemnisation.setDureeServieSurAsr(nbJoursIndemnisesAsr);
        
        Quantite qteResult = dureeIndemnisation.getDureeTheorique();
        qteResult = qteResult.soustraire(nbJoursIndemnisesAsr);
        if (qteResult.getValeurEntiere() < 0) {
          qteResult = new Quantite(0, qteResult.getUnite());
        }
        dureeIndemnisation.setDureeTheorique(qteResult);
      }
    }
    return dureeIndemnisation;
  }
  
  public ResultatDeterminationDuree determinerDureeReglementaireFinancementAtp(Demande demande)
    throws ApplicativeException
  {
    ResultatDeterminationDuree dureeIndemnisation;
    if (demande.getDonneesTemporaires().getDureeFinancement() != null)
    {
      ResultatDeterminationDuree dureeIndemnisation = new ResultatDeterminationDuree();
      Quantite qteDureeTheorique = new Quantite(demande.getDonneesTemporaires().getDureeFinancement(), DureeReglementaire.UNITE_DEFAUT);
      if (demande.getDonneesTemporaires().getNbJourImputer() != null)
      {
        Quantite qteDureeImputation = new Quantite(demande.getDonneesTemporaires().getNbJourImputer().intValue(), DureeReglementaire.UNITE_DEFAUT);
        qteDureeTheorique = qteDureeTheorique.soustraire(qteDureeImputation);
        dureeIndemnisation.setDureeImputation(qteDureeImputation);
      }
      dureeIndemnisation.setDureeTheorique(qteDureeTheorique);
    }
    else
    {
      dureeIndemnisation = determinerDureeReglementaire(demande, false, false);
    }
    return dureeIndemnisation;
  }
  
  private int appliquerPlafonnementDuree(int dureeTheoriqueInitiale, Demande demande, ResultatDeterminationDuree dureeIndemnisation)
    throws ApplicativeException
  {
    int dureePlafonne = dureeTheoriqueInitiale;
    
    BigDecimal capitalDroit = calculerCapitalTheorique(dureeTheoriqueInitiale, demande);
    
    BigDecimal plafondCapital = calculerPlafondCapital(demande);
    if (capitalDroit.compareTo(plafondCapital) > 0)
    {
      BigDecimal duree = Mathematiques.diviseParDefaut(plafondCapital, recupererMontantAllocation(demande));
      duree = duree.setScale(0, 0);
      dureePlafonne = duree.intValue();
      dureeIndemnisation.setEstDureeTheoriquePlafonnee(true);
    }
    return dureePlafonne;
  }
  
  private BigDecimal calculerCapitalTheorique(int duree, Demande demande)
    throws CoucheLogiqueException
  {
    BigDecimal montantBrutPrecompte = recupererMontantAllocation(demande);
    
    return montantBrutPrecompte.multiply(new BigDecimal(duree));
  }
  
  private BigDecimal recupererMontantAllocation(Demande demande)
    throws CoucheLogiqueException
  {
    Attribution attribution = (Attribution)demande.getDossierExamen();
    
    OutilTranchesExecutables.alimenterTrancheExecutable(attribution);
    
    DonneesEntreesRecuperationMontant donneesEntrees = ((GammeAsuSpec)attribution.getGamme()).mapperDonneesEntreesRecuperationMontant(attribution);
    
    donneesEntrees.setDateCalculMontant(attribution.getDateAttribution());
    
    MontantAsuSpec montantAAttribution = DeterminationMontant.determinerMontant(donneesEntrees);
    
    return montantAAttribution.getMontantPrecompteEffectif().getValeur();
  }
  
  private BigDecimal calculerPlafondCapital(Demande demande)
    throws ApplicativeException
  {
    BigDecimal sjrrp = ((Attribution)demande.getDossierExamen()).getConstitutionSjr().getSjrrp().getSalaire();
    BigDecimal dureeAppartenance = calculerDureeAppartenance(demande);
    return POURCENTAGE_PLAFOND_CAPITAL.multiply(sjrrp.multiply(dureeAppartenance));
  }
  
  private BigDecimal calculerDureeAppartenance(Demande demande)
    throws ApplicativeException
  {
    Attribution attribution = (Attribution)demande.getDossierExamen();
    ConstitutionQuantiteAffiliation cepaAffiliation = attribution.getConstitutionQuantiteAffiliation();
    Pra pra = (Pra)cepaAffiliation.getJustificationAffiliation(cepaAffiliation.getQuantiteAffiliationAcquise().getUnite()).getPeriodeRechercheAffiliation();
    
    OutilCalculAppartenance outilCalculAppartenance = (OutilCalculAppartenance)((ProduitAsuSpec)attribution.getProduit()).getOutilCalculAppartenance(demande, false);
    OutilCalculAffiliation outilCalculAffiliation = (OutilCalculAffiliation)outilCalculAppartenance.getOutilCalculAffiliation();
    fr.unedic.cali.asu.dom.JustificationAffiliation justifAffi = new fr.unedic.cali.asu.dom.JustificationAffiliation();
    
    Chronologie chronosAttributionsEnCoursPmvsDansPra = DetectionContexteParticulierLiquidation.getInstance().detectionContexteSuiteOdPmvs(demande, pra, demande.getDateExamen());
    
    ParametresAffiliation parametres = new ParametresAffiliation();
    parametres.setListeContexte(demande.getListContexteDemande());
    parametres.setEffectuerImputationAffiliationPmvs(true);
    parametres.setChronologieAttributionEnCoursPmvsDansPra(chronosAttributionsEnCoursPmvsDansPra);
    parametres.setComptabiliserAffiliationDernierJourFevrier(true);
    parametres.setDateExamen(demande.getDateExamen());
    parametres.setIndividu(demande.getDemandeur());
    parametres.setPra(pra);
    parametres.setProduit((ProduitAsuSpec)attribution.getProduit());
    parametres.setUniteCalcul(UniteAffiliation.JOUR);
    parametres.setContexteAppel("cepAffi");
    if (2 == demande.getObjectifCourant().getType()) {
      parametres.setDateFaitGenerateur(demande.getDateFaitGenerateurOdPrecedente());
    } else {
      parametres.setDateFaitGenerateur(demande.getDateFaitGenerateurOuDernierSinistre());
    }
    Map<String, Chronologie> chronologies = outilCalculAffiliation.determinerChronologieActivitesParticipantes(demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation(), parametres, justifAffi);
    
    Chronologie activitesParticipantes = (Chronologie)chronologies.get("ChronologieAffiliation");
    
    Reglement annexe1 = Reglement.getInstance("A1", demande.getDossierAffectationAdmission().getProduit());
    
    activitesParticipantes.iterer();
    while (activitesParticipantes.encoreSuivant())
    {
      Temporel periodeCourante = activitesParticipantes.elementSuivant();
      if ((periodeCourante instanceof ActiviteSalarie))
      {
        ActiviteSalarie activite = (ActiviteSalarie)periodeCourante;
        activite.initialiserReglementForce(annexe1);
        if (activite.chevauche(pra))
        {
          ArrayList<Periode> moisCivil = activite.getPeriode().periodeIntersection(pra).decouperEnMoisCivils();
          for (int i = 0; i < moisCivil.size(); i++)
          {
            Periode mois = (Periode)moisCivil.get(i);
            PeriodeMesureActivite pma = new PeriodeMesureActivite(mois.getDebut(), mois.getFin());
            pma.ajouterQuantiteAffiliation(new Quantite(mois.getDuree(), UniteAffiliation.JOUR));
            activite.ajouterPeriodeMesureActiviteForcee(pma);
          }
        }
        activite.setListePeriodeElementaire(null);
      }
    }
    justifAffi = outilCalculAffiliation.calculerAffiliation(activitesParticipantes, parametres);
    
    activitesParticipantes.iterer();
    while (activitesParticipantes.encoreSuivant())
    {
      Temporel periodeCourante = activitesParticipantes.elementSuivant();
      if ((periodeCourante instanceof ActiviteSalarie))
      {
        ActiviteSalarie activite = (ActiviteSalarie)periodeCourante;
        activite.supprimerReglementForce();
        activite.supprimerPeriodesMesureActiviteForcees();
        activite.setListePeriodeElementaire(null);
      }
    }
    BigDecimal quantiteAssimiliation = null;
    if (cepaAffiliation.getQuantiteAssimilationAcquise() != null) {
      quantiteAssimiliation = determinerQuantiteJourAffiliation(cepaAffiliation.getQuantiteAssimilationAcquise(), ((ProduitAsuSpec)demande.getDossierAffectationAdmission().getProduit()).determinerConvertisseurUniteAffiliation());
    }
    BigDecimal dureeAppartenance = justifAffi.getQuantiteAffiliation().getValeur();
    if (quantiteAssimiliation != null) {
      dureeAppartenance = dureeAppartenance.add(quantiteAssimiliation);
    }
    return dureeAppartenance;
  }
}

/* Location:
 * Qualified Name:     DeterminationDureeReglementaire
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */