package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.fabriques.FabriqueStrategieDeterminationDiviseurSjr;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.FabriqueOutilFonctionnelDeterminationSjrSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.FabriqueStrategieDeterminationDiviseurSjrSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.OutilDeterminationSrPrcSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.OutilDeterminationSrPrceSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.OutilJustificationSjrSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.CriteresStrategieDeterminationDiviseurSjr;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieDeterminationDiviseurSjrCasGeneralSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieDeterminationDiviseurSjrSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationDiviseur;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationPrc;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationSr;
import fr.unedic.cali.asu.produits.liquidation.dom.Prc;
import fr.unedic.cali.asu.produits.liquidation.dom.PrcSjc;
import fr.unedic.cali.asu.produits.liquidation.dom.PrcSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.Prce;
import fr.unedic.cali.asu.produits.liquidation.dom.conteneurs.DonneesResultatDeterminationSjr;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.DelaiRecherche;
import fr.unedic.cali.dom.conteneurs.DonneeEntreeParametre;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeComplementairesDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeComportementSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDemandeDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeProduitDeterminationSjrSpec;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreContratRemunereBaseSmic;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.CalculDelais;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;

public class OutilDeterminationSrPrc
  implements OutilDeterminationSrPrcSpec
{
  private static final BigDecimal ZERO = new BigDecimal("0");
  private static OutilDeterminationSrPrc s_instance = new OutilDeterminationSrPrc();
  
  public static OutilDeterminationSrPrc getInstance()
  {
    return s_instance;
  }
  
  public OutilJustificationSjrSpec recupererOutilJustificationSjr(DonneesEntreeComportementSpec p_donneesEntreeComportement)
  {
    FabriqueOutilFonctionnelDeterminationSjrSpec fabriqueOutilFonctionnel = (FabriqueOutilFonctionnelDeterminationSjrSpec)p_donneesEntreeComportement.getFabriqueOutilFonctionnel();
    
    return fabriqueOutilFonctionnel.getOutilJustificationSjr(p_donneesEntreeComportement);
  }
  
  public DonneesResultatDeterminationSjr determinerSrip(DonneesEntreeDeterminationSjrSpec p_donneesEntree)
    throws CoucheLogiqueException
  {
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Début de la détermination du SRIP." });
    
    Prc resultatPrc = determinerPrcResultat(p_donneesEntree);
    
    DonneesResultatDeterminationSjr resultatDeterminationSjr = OutilDonneesDeterminationSjr.getInstance().initialiserDonneesResultatSjrAvecJustification(resultatPrc);
    
    determinerDiviseur(p_donneesEntree, resultatDeterminationSjr);
    
    determinerPrip(resultatPrc.getDateFin(), p_donneesEntree, resultatDeterminationSjr);
    
    ArrayList listePrce = determinerListePrce(resultatPrc);
    
    DonneesEntreeComportementSpec donneesEntreeComportement = p_donneesEntree.getDonneesEntreeComportement();
    FabriqueOutilFonctionnelDeterminationSjrSpec fabriqueOutilFonctionnel = (FabriqueOutilFonctionnelDeterminationSjrSpec)donneesEntreeComportement.getFabriqueOutilFonctionnel();
    
    BigDecimal cumulSrpe = ZERO;
    for (int boucle = 0; boucle < listePrce.size(); boucle++) {
      cumulSrpe = cumulSrpe.add(fabriqueOutilFonctionnel.getOutilDeterminationSrPrce().determinerSrpe((Prce)listePrce.get(boucle), p_donneesEntree, resultatDeterminationSjr));
    }
    BigDecimal resultatSrip = Mathematiques.arrondiASup(cumulSrpe, 2);
    if (donneesEntreeComportement.isAppliquerPlafondSrPrc()) {
      resultatSrip = appliquerPlafondSrPrc(resultatSrip, p_donneesEntree.getDonneesEntreeProduit(), resultatPrc.getDateFin());
    }
    resultatPrc.setSrip(resultatSrip);
    
    OutilJustificationSjrSpec outilJustificationSjr = recupererOutilJustificationSjr(donneesEntreeComportement);
    if (outilJustificationSjr != null)
    {
      JustificationSr resultatJustificationSr = resultatDeterminationSjr.getJustificationSjr().getJustificationSr();
      
      outilJustificationSjr.justifierSrMontant(resultatJustificationSr, 1, resultatSrip);
      
      BigDecimal resultatSri = resultatJustificationSr.getSalaireReferenceNonPlafonne();
      outilJustificationSjr.justifierSrMontant(resultatJustificationSr, 2, Mathematiques.arrondiASup(resultatSri, 2));
      
      BigDecimal resultatTotalSalaires = resultatJustificationSr.getTotalSalairesRetenus();
      outilJustificationSjr.justifierSrMontant(resultatJustificationSr, 3, Mathematiques.arrondiASup(resultatTotalSalaires, 2));
      
      BigDecimal resultatTotalPrimesNormales = resultatJustificationSr.getTotalPrimesNormalesRetenues();
      outilJustificationSjr.justifierSrMontant(resultatJustificationSr, 4, Mathematiques.arrondiASup(resultatTotalPrimesNormales, 2));
      
      BigDecimal resultatTotalPrimesExceptionnelles = resultatJustificationSr.getTotalPrimesExceptionnellesRetenues();
      outilJustificationSjr.justifierSrMontant(resultatJustificationSr, 5, Mathematiques.arrondiASup(resultatTotalPrimesExceptionnelles, 2));
    }
    Chronologie resultatChronoActiviteSalarieParticipantSr = resultatPrc.getChronoActiviteSalarieParticipantSr();
    resultatPrc.setTopContratsDeTypeParticulier(determinerTopContratsRemuneresBaseSmic(resultatChronoActiviteSalarieParticipantSr));
    
    return resultatDeterminationSjr;
  }
  
  private Prc determinerPrcResultat(DonneesEntreeDeterminationSjrSpec p_donneesEntree)
  {
    Prc prcRetournee = null;
    
    Periode periodePrcInitiale = p_donneesEntree.getDonneesEntreeComplementaires().getPeriodePrcInitiale();
    JustificationPrc justificationPrcRetournee = new JustificationPrc(periodePrcInitiale);
    Periode periodePrcBornee = p_donneesEntree.getDonneesEntreeComplementaires().getPeriodePrcBornee();
    justificationPrcRetournee.setPeriodePrcBornee(periodePrcBornee);
    int typeBornagePrc = p_donneesEntree.getDonneesEntreeComplementaires().getTypeBornagePrc();
    justificationPrcRetournee.setTypeBornagePrc(typeBornagePrc);
    
    Periode periodePrcEffective = justificationPrcRetournee.getPeriodePrcEffective();
    int typeTraitementAppelant = p_donneesEntree.getDonneesEntreeComportement().getTypeTraitementAppelant();
    switch (typeTraitementAppelant)
    {
    case 1: 
      prcRetournee = new PrcSjr(periodePrcEffective);
      break;
    case 2: 
      prcRetournee = new PrcSjc(periodePrcEffective);
      break;
    }
    prcRetournee.setJustification(justificationPrcRetournee);
    
    return prcRetournee;
  }
  
  public void determinerDiviseur(DonneesEntreeDeterminationSjrSpec p_donneesEntree, DonneesResultatDeterminationSjr p_donneesResultat)
    throws CoucheLogiqueException
  {
    StrategieDeterminationDiviseurSjrCasGeneralSpec strategieCasGeneral = recupererFabriqueStrategieDeterminationDiviseurSjr().getStrategieCasGeneral();
    
    strategieCasGeneral.determinerDiviseurCasGeneral(p_donneesEntree, p_donneesResultat);
    
    CriteresStrategieDeterminationDiviseurSjr criteresStrategie = new CriteresStrategieDeterminationDiviseurSjr();
    criteresStrategie.setDonneesEntreeDeterminationSjr(p_donneesEntree);
    StrategieDeterminationDiviseurSjrSpec strategie = (StrategieDeterminationDiviseurSjrSpec)recupererFabriqueStrategieDeterminationDiviseurSjr().getStrategie(criteresStrategie);
    
    strategie.determinerDiviseur(p_donneesEntree, p_donneesResultat);
    
    OutilJustificationSjrSpec outilJustificationSjr = recupererOutilJustificationSjr(p_donneesEntree.getDonneesEntreeComportement());
    if (outilJustificationSjr != null)
    {
      JustificationDiviseur resultatJustificationDiviseur = p_donneesResultat.getJustificationSjr().getJustificationDiviseur();
      outilJustificationSjr.justifierDiviseurDonneePrimoDemandeurA3A4A5(resultatJustificationDiviseur, p_donneesEntree.getDonneesEntreeDemande().isPrimoDemandeurA3A4A5());
    }
  }
  
  protected FabriqueStrategieDeterminationDiviseurSjrSpec recupererFabriqueStrategieDeterminationDiviseurSjr()
  {
    return FabriqueStrategieDeterminationDiviseurSjr.getInstance();
  }
  
  private void determinerPrip(Damj p_termePrc, DonneesEntreeDeterminationSjrSpec p_donneesEntree, DonneesResultatDeterminationSjr p_donneesResultat)
    throws CoucheLogiqueException
  {
    Periode resultatPeriodePrip = null;
    
    Damj termePrip = p_donneesEntree.getDonneesEntreeDemande().getDateFaitGenerateurDroitCourant();
    
    DureeCalendaire dureeMaximale = new DureeCalendaire(0, 12, 0);
    Periode periodeReference = CalculDelais.determinerDelai(p_termePrc, dureeMaximale);
    periodeReference.setDebut(periodeReference.getDebut().lendemain());
    
    Damj borneDebutPrip = p_donneesEntree.getDonneesEntreeDemande().getDateFaitGenerateurDroitPrecedent();
    if (borneDebutPrip != null) {
      periodeReference = DelaiRecherche.getInstance().deplacerDepartDelai(borneDebutPrip, periodeReference);
    }
    Damj debutPrip = periodeReference.getDebut();
    
    resultatPeriodePrip = new Periode(debutPrip, termePrip);
    
    p_donneesResultat.getPrc().setPrip(resultatPeriodePrip);
  }
  
  private ArrayList determinerListePrce(Prc p_resultatPrc)
  {
    ArrayList listePrceRetournee = new ArrayList();
    
    Prce prceCourante = new Prce(p_resultatPrc.getPeriode());
    prceCourante.setPrc(p_resultatPrc);
    listePrceRetournee.add(prceCourante);
    
    return listePrceRetournee;
  }
  
  private boolean determinerTopContratsRemuneresBaseSmic(Chronologie p_chronoActiviteSalarieParticipantSr)
  {
    boolean topContratsRemuneresBaseSmicRetourne = false;
    if (p_chronoActiviteSalarieParticipantSr != null)
    {
      Chronologie chronoFiltree = p_chronoActiviteSalarieParticipantSr.copier(new FiltreContratRemunereBaseSmic());
      
      topContratsRemuneresBaseSmicRetourne = p_chronoActiviteSalarieParticipantSr.getTaille() == chronoFiltree.getTaille();
    }
    return topContratsRemuneresBaseSmicRetourne;
  }
  
  private BigDecimal appliquerPlafondSrPrc(BigDecimal p_montantSr, DonneesEntreeProduitDeterminationSjrSpec p_donneesEntreeProduit, Damj p_termePrc)
  {
    BigDecimal montantSrPlafonneRetourne = p_montantSr;
    
    DonneeEntreeParametre parametreActif = p_donneesEntreeProduit.getParametreActif("FACULTATIF PLAFOND PRC SR", p_termePrc);
    if (parametreActif != null)
    {
      BigDecimal plafondSrPrcApplicable = parametreActif.getValeurParametre();
      
      OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Plafonnement du SRIP sur la PRC." });
      montantSrPlafonneRetourne = p_montantSr.min(plafondSrPrcApplicable);
    }
    return montantSrPlafonneRetourne;
  }
}

/* Location:
 * Qualified Name:     OutilDeterminationSrPrc
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */