package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.affectation.parametres.AccesDecorReglementaire;
import fr.unedic.cali.affectation.parametres.CriteresQualification;
import fr.unedic.cali.asu.cge01.liquidation.dom.DomSimulationSjrEtSjc;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.FabriqueOutilFonctionnelDeterminationSjrSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.OutilSimulationSjrEtSjcSpec;
import fr.unedic.cali.asu.cge01.parametres.Parametres;
import fr.unedic.cali.asu.outilsfonctionnels.ConstitutionDecorReglementaire;
import fr.unedic.cali.asu.parametres.AccesPlafond;
import fr.unedic.cali.asu.parametres.AccesPlafondMayotte;
import fr.unedic.cali.asu.parametres.AccesSalaireForfaitaireJournalierCategorieA2B;
import fr.unedic.cali.asu.parametres.EvenementCategorieA2B;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationPrc;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.autresdoms.ga.dom.spec.PeriodeGaecSpec;
import fr.unedic.cali.dom.ConteneurAccesDecorReglementaire;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ContexteDemandeSpec;
import fr.unedic.cali.dom.affectation.DecorReglementaire;
import fr.unedic.cali.dom.affectation.ProduitAsuCge01P05;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.conteneurs.DonneeEntreeParametre;
import fr.unedic.cali.dom.conteneurs.DonneesEntreeComplementairesDeterminationSjr;
import fr.unedic.cali.dom.conteneurs.DonneesEntreeComportement;
import fr.unedic.cali.dom.conteneurs.DonneesEntreeConstructionChronologie;
import fr.unedic.cali.dom.conteneurs.DonneesEntreeDemandeDeterminationSjr;
import fr.unedic.cali.dom.conteneurs.DonneesEntreeDeterminationSjr;
import fr.unedic.cali.dom.conteneurs.DonneesEntreePRC;
import fr.unedic.cali.dom.conteneurs.DonneesEntreeProduitDeterminationSjr;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeComplementairesDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeComportementSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDemandeDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeProduitDeterminationSjrSpec;
import fr.unedic.cali.liquidation.pnds.StrategieDeterminationPNDSSpec;
import fr.unedic.cali.liquidation.pnds.outilsfonctionnels.FabriqueStrategieDeterminationPNDS;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.parametres.AccesSmicMensuelBase35h;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public class OutilSimulationSjrEtSjc
  implements OutilSimulationSjrEtSjcSpec
{
  private static OutilSimulationSjrEtSjc instance = new OutilSimulationSjrEtSjc();
  private static final Damj DATE_PIVOT_FG_MAYOTTE = new Damj(2013, 1, 1);
  
  public static OutilSimulationSjrEtSjc getInstance()
  {
    return instance;
  }
  
  public void controleDesDonnees(DomSimulationSjrEtSjc domSimulationSjrEtSjc)
    throws ApplicativeException
  {
    controleDonneesObligatoires(domSimulationSjrEtSjc);
    controleDonneesOptionnelles(domSimulationSjrEtSjc);
  }
  
  private void controleDonneesObligatoires(DomSimulationSjrEtSjc domSimulationSjrEtSjc)
    throws CoucheLogiqueException
  {
    if (domSimulationSjrEtSjc.getTypeSimulation() == 0) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_TYPE_SIMULATION_OBLIGATOIRE");
    }
    if (domSimulationSjrEtSjc.getDateExamen() == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_DATE_EXAMEN_OBLIGATOIRE");
    }
    if (domSimulationSjrEtSjc.getPeriodeFgd() == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_FGD_OBLIGATOIRE");
    }
    if (domSimulationSjrEtSjc.getPeriodeFct() == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_FCT_OBLIGATOIRE");
    }
    PeriodeGaecSpec periodeFctRetenue = domSimulationSjrEtSjc.getIndividu().rechercherPeriodePasseProfessionnel(domSimulationSjrEtSjc.getPeriodeFct());
    PeriodeGaecSpec periodeFgd = domSimulationSjrEtSjc.getIndividu().rechercherPeriodePasseProfessionnel(domSimulationSjrEtSjc.getPeriodeFgd());
    
    domSimulationSjrEtSjc.setDateFct(periodeFctRetenue.getDateFin());
    domSimulationSjrEtSjc.setDateFgd(periodeFgd.getDateFin());
    
    ActiviteSalarie contratTravail = (ActiviteSalarie)periodeFctRetenue;
    
    domSimulationSjrEtSjc.setActiviteSalarieFgd((ActiviteSalarie)periodeFgd);
    domSimulationSjrEtSjc.setActiviteSalarieRetenue(contratTravail);
    if (domSimulationSjrEtSjc.getDateFgd().estAvant(domSimulationSjrEtSjc.getDateFct())) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_FCT_AVANT_FGD");
    }
    if (domSimulationSjrEtSjc.getDateExamen().estAvantOuCoincideAvec(domSimulationSjrEtSjc.getDateFgd())) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_DATE_EXAMEN_APRES_FGD");
    }
    if (domSimulationSjrEtSjc.getActiviteSalarieFgd().estEnConflit()) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_SIMU_FGD_CONFLIT");
    }
    if (contratTravail.estEnConflit()) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_FCT_CONFLIT");
    }
    if ((domSimulationSjrEtSjc.getActiviteSalarieFgd().getCollectionOrigineInformationPAS().contains(Integer.valueOf(10))) && (domSimulationSjrEtSjc.getActiviteSalarieFgd().getContrat().getPohf() == 9)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_FGD_HORS_FRANCE");
    }
    if (((periodeFgd instanceof ActiviteSalarie)) && (((ActiviteSalarie)periodeFgd).isEstPeriodeMayotte()) && (periodeFgd.getDateFin().estAvant(DATE_PIVOT_FG_MAYOTTE))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_DONNEES_FORCEES_SIMU_AFFI_FG_MAYOTTE");
    }
  }
  
  private void controleDonneesOptionnelles(DomSimulationSjrEtSjc domSimulationSjrEtSjc)
    throws CoucheLogiqueException
  {
    if ((domSimulationSjrEtSjc.getDateTermePRC() != null) && (domSimulationSjrEtSjc.getDateTermePRC().estApres(domSimulationSjrEtSjc.getDateFct()))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_PRC_INCLUSE_PERIODE_FCT");
    }
    if ((domSimulationSjrEtSjc.getDateFgdOdPrecedente() != null) && (domSimulationSjrEtSjc.getDateFgdOdPrecedente().estApresOuCoincideAvec(domSimulationSjrEtSjc.getDateFgd()))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_FCT_APRES_OD_PRECEDENTE");
    }
    if ((domSimulationSjrEtSjc.getTypeCoordinationEuropeenne() != 0) && (!domSimulationSjrEtSjc.getDateFct().coincideAvec(domSimulationSjrEtSjc.getDateFgd()))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_COORDINATION_EUROPENNE_IDENTIQUE");
    }
  }
  
  public void chargementListePNDSIndividu(Damj dateFaitGenerateur, Damj dateExamen, IndividuSpec individu)
    throws CoucheLogiqueException
  {
    Damj dateDebutRecherche = dateFaitGenerateur;
    if (dateFaitGenerateur == null) {
      dateDebutRecherche = Damj.NUIT_DES_TEMPS;
    }
    CritereStrategie critere = new CritereStrategie();
    critere.setDatePivot(dateExamen);
    StrategieDeterminationPNDSSpec strategie = FabriqueStrategieDeterminationPNDS.determinerStrategieDeterminationPNDS(critere);
    strategie.determinationPNDSPourIndividuSurPeriode(individu, dateDebutRecherche, dateExamen, individu.getChronoPeriodePasseProfessionnelLiquidation(), false);
  }
  
  public DecorReglementaire getDecorReglementaire(DomSimulationSjrEtSjc domSimulationSjrEtSjc)
    throws CoucheLogiqueException
  {
    ConteneurAccesDecorReglementaire conteneur = new ConteneurAccesDecorReglementaire();
    conteneur.setDateRecherche(domSimulationSjrEtSjc.getDateFgd());
    DecorReglementaire decor = AccesDecorReglementaire.getInstance().getDecor(conteneur);
    CriteresQualification criteresQualification = new CriteresQualification(decor, domSimulationSjrEtSjc.getActiviteSalarieFgd(), domSimulationSjrEtSjc.isEstCoordCee());
    
    AccesDecorReglementaire.getInstance().positionnerCriteresQualifSurPas(criteresQualification, (Individu)domSimulationSjrEtSjc.getIndividu());
    
    return decor;
  }
  
  public ProduitAsuSpec determinerProduitRelatifAuSinistre(DomSimulationSjrEtSjc domSimulationSjrEtSjc)
    throws CoucheLogiqueException
  {
    PeriodeGaecSpec periodeFctRetenue = domSimulationSjrEtSjc.getIndividu().rechercherPeriodePasseProfessionnel(domSimulationSjrEtSjc.getPeriodeFct());
    
    ActiviteSalarie contratTravail = (ActiviteSalarie)periodeFctRetenue;
    ProduitAsuSpec produitRelatifSinistre = null;
    if ((contratTravail instanceof ActiviteSalarie)) {
      produitRelatifSinistre = ConstitutionDecorReglementaire.determinerProduitSinistre(contratTravail, domSimulationSjrEtSjc.getDecor());
    }
    return produitRelatifSinistre;
  }
  
  public void controleCoherenceDonneesAvecReglement(DomSimulationSjrEtSjc domSimulationSjrEtSjc)
    throws CoucheLogiqueException
  {
    Reglement reglementApplicable = domSimulationSjrEtSjc.getActiviteSalarieRetenue().getReglement();
    if ("A4".equals(reglementApplicable.getNomReglement()))
    {
      if (domSimulationSjrEtSjc.getTypeSimulation() == 2) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_SJC_A4_IMPOSSIBLE");
      }
      if (domSimulationSjrEtSjc.isEstRevision()) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_REVISION_A4_IMPOSSIBLE");
      }
    }
  }
  
  public void controlerProduit(ProduitAsuSpec produit)
    throws CoucheLogiqueException
  {
    ProduitAsuCge01P05 produitAre = ProduitAsuCge01P05.getInstance();
    if ((produit == null) || (!produitAre.getLigne().equals(produit.getLigne())) || (produitAre.getPeriodeValidite().getDebut().estApres(produit.getPeriodeValidite().getDebut()))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_PRODUIT_NON_GERE");
    }
  }
  
  public DonneesEntreeDeterminationSjrSpec initialiserDonneesEntreeSimulation(DomSimulationSjrEtSjc domSimulationSjrEtSjc, int typeTraitementAppelant, FabriqueOutilFonctionnelDeterminationSjrSpec fabriqueOutilFonctionnel, boolean justifierSjr)
  {
    DonneesEntreeDeterminationSjrSpec donneesEntreeDeterminationSjr = new DonneesEntreeDeterminationSjr();
    alimenterDonneesEntreeComportement(donneesEntreeDeterminationSjr, typeTraitementAppelant, fabriqueOutilFonctionnel, justifierSjr);
    alimenterDonneesEntreeProduit(donneesEntreeDeterminationSjr);
    alimenterDonneesEntreeDemande(donneesEntreeDeterminationSjr, domSimulationSjrEtSjc);
    
    return donneesEntreeDeterminationSjr;
  }
  
  private void alimenterDonneesEntreeComportement(DonneesEntreeDeterminationSjrSpec donneesEntree, int typeTraitementAppelant, FabriqueOutilFonctionnelDeterminationSjrSpec fabriqueOutilFonctionnel, boolean justifierSjr)
  {
    DonneesEntreeComportementSpec donneesEntreeComportement = new DonneesEntreeComportement();
    donneesEntreeComportement.setTypeTraitementAppelant(typeTraitementAppelant);
    donneesEntreeComportement.setFabriqueOutilFonctionnel(fabriqueOutilFonctionnel);
    donneesEntreeComportement.setJustifierSjr(justifierSjr);
    
    donneesEntree.setDonneesEntreeComportement(donneesEntreeComportement);
  }
  
  private void alimenterDonneesEntreeProduit(DonneesEntreeDeterminationSjrSpec donneesEntree)
  {
    DonneesEntreeProduitDeterminationSjrSpec donneesEntreeProduit = new DonneesEntreeProduitDeterminationSjr();
    
    chargerParametresPlafondSecuMensuel(donneesEntreeProduit);
    
    chargerParametresSmicMensuelBase35h(donneesEntreeProduit);
    
    chargerParametresSfjA2b(donneesEntreeProduit);
    
    donneesEntreeProduit.setParametrePlafondDiviseurPrc(Parametres.PLAFOND_DIVISEUR_PRC);
    
    donneesEntree.setDonneesEntreeProduit(donneesEntreeProduit);
  }
  
  private void chargerParametresPlafondSecuMensuel(DonneesEntreeProduitDeterminationSjrSpec donneesEntreeProduit)
  {
    Chronologie chronoParametresPlafondSecuMensuel = determinerChronoParametresPlafondSecuMensuel();
    Chronologie chronoParametresPlafondSecuMensuelMayotte = determinerChronoParametresPlafondSecuMensuelMayotte();
    
    alimenterParametrePlafondSecuMensuel(donneesEntreeProduit, "PLAFOND MENSUEL SR SJR", chronoParametresPlafondSecuMensuel);
    
    alimenterParametrePlafondSecuMensuel(donneesEntreeProduit, "PLAFOND MENSUEL SR SJR MAYOTTE", chronoParametresPlafondSecuMensuelMayotte);
  }
  
  public Chronologie determinerChronoParametresPlafondSecuMensuelMayotte()
  {
    return new AccesPlafondMayotte().getChronoValeursParametre();
  }
  
  private void alimenterParametrePlafondSecuMensuel(DonneesEntreeProduitDeterminationSjrSpec donneesEntreeProduit, String identifiantParam, Chronologie chronoParametrePlafondSecuMensuel)
  {
    boolean recupererPlafondMayotte = false;
    if ("PLAFOND MENSUEL SR SJR MAYOTTE".equals(identifiantParam)) {
      recupererPlafondMayotte = true;
    }
    fr.unedic.cali.asu.parametres.EvenementParametre parametrePlafondSecuMensuelCourant = null;
    Iterator it = chronoParametrePlafondSecuMensuel.iterer();
    while (it.hasNext())
    {
      parametrePlafondSecuMensuelCourant = (fr.unedic.cali.asu.parametres.EvenementParametre)it.next();
      BigDecimal plafond = recupererPlafondMayotte ? parametrePlafondSecuMensuelCourant.getPlafondMayotte() : parametrePlafondSecuMensuelCourant.getPlafond();
      
      donneesEntreeProduit.ajouterParametre(identifiantParam, new DonneeEntreeParametre(parametrePlafondSecuMensuelCourant.getDateEffet(), plafond));
    }
  }
  
  private Chronologie determinerChronoParametresPlafondSecuMensuel()
  {
    return new AccesPlafond().getChronoValeursParametre();
  }
  
  private void chargerParametresSmicMensuelBase35h(DonneesEntreeProduitDeterminationSjrSpec donneesEntreeProduit)
  {
    Chronologie chronoParametresSmicMensuelBase35h = determinerChronoParametresSmicMensuelBase35h();
    fr.unedic.cali.parametres.EvenementParametre parametreSmicMensuelBase35hCourant = null;
    Iterator it = chronoParametresSmicMensuelBase35h.iterer();
    while (it.hasNext())
    {
      parametreSmicMensuelBase35hCourant = (fr.unedic.cali.parametres.EvenementParametre)it.next();
      donneesEntreeProduit.ajouterParametre("SMIC MENSUEL BASE 35H", new DonneeEntreeParametre(parametreSmicMensuelBase35hCourant.getDateEffet(), parametreSmicMensuelBase35hCourant.getSmicMensuelBase35h()));
    }
  }
  
  private Chronologie determinerChronoParametresSmicMensuelBase35h()
  {
    return new AccesSmicMensuelBase35h().getChronoValeursParametre();
  }
  
  private void chargerParametresSfjA2b(DonneesEntreeProduitDeterminationSjrSpec donneesEntreeProduit)
  {
    Chronologie chronoParametresSfjA2b = determinerChronoParametresSfjA2b();
    EvenementCategorieA2B parametreSfjA2bCourant = null;
    int indexCategorieCourant = 0;
    ArrayList listeSfjParCategorieCourante = null;
    String nomParametreCourant = null;
    Iterator it = chronoParametresSfjA2b.iterer();
    while (it.hasNext())
    {
      parametreSfjA2bCourant = (EvenementCategorieA2B)it.next();
      listeSfjParCategorieCourante = parametreSfjA2bCourant.getValeurs();
      for (indexCategorieCourant = 0; indexCategorieCourant < listeSfjParCategorieCourante.size(); indexCategorieCourant++)
      {
        nomParametreCourant = "SFJ A2B CATEGORIE " + (indexCategorieCourant + 1);
        donneesEntreeProduit.ajouterParametre(nomParametreCourant, new DonneeEntreeParametre(parametreSfjA2bCourant.getDateEffet(), (BigDecimal)listeSfjParCategorieCourante.get(indexCategorieCourant)));
      }
    }
  }
  
  private Chronologie determinerChronoParametresSfjA2b()
  {
    return AccesSalaireForfaitaireJournalierCategorieA2B.getInstance().getChronoValeursParametre();
  }
  
  private void alimenterDonneesEntreeDemande(DonneesEntreeDeterminationSjrSpec donneesEntree, DomSimulationSjrEtSjc domSimulationSjrEtSjc)
  {
    PeriodeGaecSpec periodeFgd = domSimulationSjrEtSjc.getIndividu().rechercherPeriodePasseProfessionnel(domSimulationSjrEtSjc.getPeriodeFgd());
    
    DonneesEntreeDemandeDeterminationSjrSpec donneesEntreeDemande = new DonneesEntreeDemandeDeterminationSjr();
    donneesEntreeDemande.setDateAttribution(domSimulationSjrEtSjc.getDateExamen());
    donneesEntreeDemande.setDateExamen(domSimulationSjrEtSjc.getDateExamen());
    donneesEntreeDemande.setDateFaitGenerateurDroitCourant(domSimulationSjrEtSjc.getDateFgd());
    donneesEntreeDemande.setDateFaitGenerateurDroitPrecedent(domSimulationSjrEtSjc.getDateFgdOdPrecedente());
    donneesEntreeDemande.setIndividu(domSimulationSjrEtSjc.getIndividu());
    donneesEntreeDemande.setReglementApplicable(domSimulationSjrEtSjc.getActiviteSalarieRetenue().getReglement());
    donneesEntreeDemande.setCategorieA2bForcee(null);
    donneesEntreeDemande.setListePlafonnementAffiliation(new ArrayList());
    donneesEntreeDemande.setProduit(domSimulationSjrEtSjc.getActiviteSalarieRetenue().getReglement().getProduit());
    
    donneesEntreeDemande.setPrimoDemandeurA3A4A5(domSimulationSjrEtSjc.isEstPrimoA3A4A5());
    if (((periodeFgd instanceof ActiviteSalarie)) && (((ActiviteSalarie)periodeFgd).isEstPeriodeMayotte())) {
      donneesEntreeDemande.setContexteDemande("AREMAYOTTE");
    }
    donneesEntree.setDonneesEntreeDemande(donneesEntreeDemande);
  }
  
  public DonneesEntreePRC alimenterDonneesEntreePrc(DomSimulationSjrEtSjc domSimulationSjrEtSjc)
  {
    Damj dateFgd = domSimulationSjrEtSjc.getDateFgd();
    Damj dateDebut = domSimulationSjrEtSjc.getActiviteSalarieRetenue().getDateDebut();
    Damj dateFin = domSimulationSjrEtSjc.getActiviteSalarieRetenue().getDateFin();
    int typeCoordinationEuropeenne = domSimulationSjrEtSjc.getTypeCoordinationEuropeenne();
    Damj dateFgdOdPrecedente = domSimulationSjrEtSjc.getDateFgdOdPrecedente();
    Reglement reglementApplicableCourant = domSimulationSjrEtSjc.getActiviteSalarieRetenue().getReglement();
    Individu individu = (Individu)domSimulationSjrEtSjc.getIndividu();
    PeriodeGaecSpec periodeFgd = domSimulationSjrEtSjc.getIndividu().rechercherPeriodePasseProfessionnel(domSimulationSjrEtSjc.getPeriodeFgd());
    DonneesEntreePRC donneesEntreePRC = new DonneesEntreePRC();
    donneesEntreePRC.setDateFgd(dateFgd);
    donneesEntreePRC.setDateDebut(dateDebut);
    donneesEntreePRC.setDateFin(dateFin);
    donneesEntreePRC.setTypeCoordinationEuropeenne(typeCoordinationEuropeenne);
    donneesEntreePRC.setDateFgdOdPrecedente(dateFgdOdPrecedente);
    donneesEntreePRC.setIndividu(individu);
    donneesEntreePRC.setReglementApplicableCourant(reglementApplicableCourant);
    donneesEntreePRC.setPeriodeActiviteSalarieFgd(domSimulationSjrEtSjc.getActiviteSalarieFgd());
    donneesEntreePRC.setPeriodeActiviteSalarieRa(domSimulationSjrEtSjc.getActiviteSalarieRetenue());
    donneesEntreePRC.setValidationProduit(null);
    donneesEntreePRC.setTermePrcSaisi(domSimulationSjrEtSjc.getDateTermePRC());
    if (((periodeFgd instanceof ActiviteSalarie)) && (((ActiviteSalarie)periodeFgd).isEstPeriodeMayotte()))
    {
      List<ContexteDemandeSpec> contextes = new ArrayList();
      ContexteDemande contexte = new ContexteDemande();
      contexte.setTypeContexteDemande("AREMAYOTTE");
      contextes.add(contexte);
      donneesEntreePRC.setContexteParticulier(contextes);
    }
    return donneesEntreePRC;
  }
  
  public DonneesEntreeConstructionChronologie alimenterDonneesEntreeConstructionChronologie(DomSimulationSjrEtSjc domSimulationSjrEtSjc, Periode prc)
  {
    DonneesEntreeConstructionChronologie donneesEntree = new DonneesEntreeConstructionChronologie();
    
    donneesEntree.setDateExamen(domSimulationSjrEtSjc.getDateExamen());
    donneesEntree.setDateDeclenchementExamen(donneesEntree.getDateExamen());
    donneesEntree.setDateFgd(domSimulationSjrEtSjc.getDateFgd());
    donneesEntree.setDateFgdOdPrecedente(domSimulationSjrEtSjc.getDateFgdOdPrecedente());
    donneesEntree.setEstUneDemandeRevision(domSimulationSjrEtSjc.isEstRevision());
    donneesEntree.setIndividu((Individu)domSimulationSjrEtSjc.getIndividu());
    Reglement reglementApplicableCourant = domSimulationSjrEtSjc.getActiviteSalarieRetenue().getReglement();
    donneesEntree.setReglement(reglementApplicableCourant);
    donneesEntree.setPeriodePrc(prc);
    donneesEntree.setActiviteSalarie(domSimulationSjrEtSjc.getActiviteSalarieRetenue());
    
    return donneesEntree;
  }
  
  public void alimenterDonneesEntreeComplementaires(DonneesEntreeDeterminationSjrSpec donneesEntree, JustificationPrc justificationPrc, Chronologie chronoActiviteSalariePrc, Chronologie chronoActivitePourInappartenancePrc, Chronologie chronoPeriodeDeductiblePrc)
  {
    DonneesEntreeComplementairesDeterminationSjrSpec donneesEntreeComplementaires = new DonneesEntreeComplementairesDeterminationSjr();
    donneesEntreeComplementaires.setPeriodePrcInitiale(justificationPrc.getPeriodePrcInitiale());
    donneesEntreeComplementaires.setPeriodePrcBornee(justificationPrc.getPeriodePrcBornee());
    donneesEntreeComplementaires.setTypeBornagePrc(justificationPrc.getTypeBornagePrc());
    donneesEntreeComplementaires.setChronologieActiviteSalariePrc(chronoActiviteSalariePrc);
    donneesEntreeComplementaires.setChronologieActivitePourInappartenancePrc(chronoActivitePourInappartenancePrc);
    donneesEntreeComplementaires.setChronologiePeriodeDeductiblePrc(chronoPeriodeDeductiblePrc);
    
    donneesEntree.setDonneesEntreeComplementaires(donneesEntreeComplementaires);
  }
}

/* Location:
 * Qualified Name:     OutilSimulationSjrEtSjc
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */