package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.fabriques.FabriqueConditionFaitGenerateurDemandeExpresse;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.fabriques.FabriqueStrategieConditionFaitGenerateurDemandeIDE;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.StrategieConditionFaitGenerateurDemandeClassique;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.StrategieConditionFaitGenerateurPourDemandeDv122eJour;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.RechercheConditionFaitGenerateurSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieConditionFaitGenerateurDemandeExpresseSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.EreDemandeExpresse;
import fr.unedic.cali.asu.dom.EreInscriptionDemandeurEmploi;
import fr.unedic.cali.asu.dom.ErePassageCPSuiteRejetDV;
import fr.unedic.cali.asu.fabriques.FabriqueStrategieFCTRetenueDemandeExpresse;
import fr.unedic.cali.asu.outilsfonctionnels.OutilFinDroit;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsChomageSansRCT;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionFaitGenerateur;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnChargeSansFiltre;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.ResultatElementDroit;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;

public class RechercheConditionFaitGenerateur
  implements OutilFonctionnel
{
  private static final int NB_JOURS = 42;
  
  public static RechercheConditionFaitGenerateur getInstance()
  {
    return new RechercheConditionFaitGenerateur();
  }
  
  public ConditionFaitGenerateur rechercheConditionFaitGenerateur(Demande p_demande)
    throws CoucheLogiqueException
  {
    controleReintegrationDemandee(p_demande);
    
    RechercheConditionFaitGenerateurSpec strategieConditionFaitGenerateur = getStrategieConditionFaitGenerateur(p_demande);
    
    return strategieConditionFaitGenerateur.rechercherConditionFaitGenerateur(p_demande);
  }
  
  public ResultatElementDroit rechercheConditionFaitGenerateurCsr(Demande p_demande)
    throws CoucheLogiqueException
  {
    DonneesTemporaires donneesTemporaires = p_demande.getDonneesTemporaires();
    ResultatElementDroit resultatElementDroit = new ResultatElementDroit();
    resultatElementDroit.setEtatSatisfait(true);
    
    boolean isLeveeCondition28JoursSuspension = donneesTemporaires.isLeveeCondition28JoursChomageTotalSansRupture();
    if (!isLeveeCondition28JoursSuspension)
    {
      Periode periodeSuspension = OutilsChomageSansRCT.trouverPeriodeDeSuspension(p_demande).getPeriode();
      if (periodeSuspension.getDuree() < getNombreJoursSuspension())
      {
        resultatElementDroit.setCodeMotifEchec(202);
        resultatElementDroit.setEtatSatisfait(false);
      }
      else
      {
        Damj dateIde = p_demande.getDateExamen();
        if (!dateIde.estContenueDans(periodeSuspension))
        {
          resultatElementDroit.setCodeMotifEchec(202);
          resultatElementDroit.setEtatSatisfait(false);
        }
        else
        {
          ObjetChronoPeriodePriseEnChargeSansFiltre periodePEC = OutillagePEC.getPeriodePECContenant(p_demande.getDemandeur(), dateIde);
          if (periodeSuspension.getDebut().joursEntre(periodePEC.getDateFin()) < getNombreJoursSuspension())
          {
            resultatElementDroit.setCodeMotifEchec(202);
            resultatElementDroit.setEtatSatisfait(false);
          }
        }
      }
    }
    return resultatElementDroit;
  }
  
  private int getNombreJoursSuspension()
  {
    return 42;
  }
  
  public RechercheConditionFaitGenerateurSpec getStrategieConditionFaitGenerateur(Demande p_demande)
    throws CoucheLogiqueException
  {
    EvenementReferenceExamenSpec ere = p_demande.getEvenementReferenceExamen();
    if ((ere instanceof ErePassageCPSuiteRejetDV)) {
      return new StrategieConditionFaitGenerateurPourDemandeDv122eJour();
    }
    if ((ere instanceof EreDemandeExpresse))
    {
      CritereStrategie critere = new CritereStrategie();
      critere.setDemande(p_demande);
      FabriqueStrategieFCTRetenueDemandeExpresse fabrique = FabriqueStrategieFCTRetenueDemandeExpresse.getInstance();
      if (fabrique.appliquerStrategieApres(critere)) {
        return new StrategieConditionFaitGenerateurDemandeClassique();
      }
      CritereStrategie critereDemandeExpresse = new CritereStrategie();
      critereDemandeExpresse.setDatePivot(p_demande.getDateExamen());
      StrategieConditionFaitGenerateurDemandeExpresseSpec strategieDemandeExpresse = (StrategieConditionFaitGenerateurDemandeExpresseSpec)FabriqueConditionFaitGenerateurDemandeExpresse.getInstance().getStrategie(critereDemandeExpresse);
      
      return strategieDemandeExpresse.getOutilFonctionnel();
    }
    if ((ere instanceof EreInscriptionDemandeurEmploi))
    {
      CritereStrategie critere = new CritereStrategie();
      critere.setDatePivot(p_demande.getDateExamen());
      RechercheConditionFaitGenerateurSpec strategie = (RechercheConditionFaitGenerateurSpec)FabriqueStrategieConditionFaitGenerateurDemandeIDE.getInstance().getStrategie(critere);
      
      return strategie;
    }
    return new StrategieConditionFaitGenerateurDemandeClassique();
  }
  
  public ConditionFaitGenerateur rechercheConditionFaitGenerateurPourFinDroit(Demande p_demande)
    throws CoucheLogiqueException
  {
    ConditionFaitGenerateur faitGenerateur = ((DossierExamen)p_demande.getDossierExamen()).createConditionFaitGenerateur();
    controleReintegrationDemandee(p_demande);
    Attribution attributionPrecedente = (Attribution)OutilFinDroit.rechercherAttributionOrigineCorrespondante(p_demande);
    if (attributionPrecedente != null)
    {
      ConditionFaitGenerateur faitGenerateurPrec = (ConditionFaitGenerateur)attributionPrecedente.getConditionFaitGenerateur();
      faitGenerateurPrec.copieElements(faitGenerateur);
    }
    return faitGenerateur;
  }
  
  private static void controleReintegrationDemandee(Demande p_demande)
    throws CoucheLogiqueException
  {
    if ((!p_demande.getDonneesTemporaires().isEstDemarcheReintegrationEffectuee()) && (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(p_demande, "CRSPMVS"))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A8MB15");
    }
  }
}

/* Location:
 * Qualified Name:     RechercheConditionFaitGenerateur
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */