package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.dom.ParametresCalculAppartenance;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.EreRechargement;
import fr.unedic.cali.asu.dom.JustificationAffiliation;
import fr.unedic.cali.asu.dom.JustificationAffiliationSpec;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.parametres.OutilAccesListeUnitesReglement;
import fr.unedic.cali.asu.produits.liquidation.dom.Pra;
import fr.unedic.cali.asu.produits.liquidation.dom.QuantitesAppartenance;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DonneesEntreeDeterminationListePra;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.spec.CalculAppartenanceSpec;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologieStandard;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public class RechercheReglementApplicable
  implements OutilFonctionnel
{
  private static final int NB_CHIFFRE_APRES_VIRGULE = 10;
  private static RechercheReglementApplicable instance = null;
  
  public static RechercheReglementApplicable getInstance()
  {
    if (instance == null) {
      instance = new RechercheReglementApplicable();
    }
    return instance;
  }
  
  public ValidationProduit rechercher(Demande demande, ActiviteSalarie pas, boolean avecPeriodeNonAttestee, ProduitAsuSpec produit)
    throws ApplicativeException
  {
    if ((demande == null) || (demande.getDemandeur() == null)) {
      return null;
    }
    Reglement reglementPropose = pas.getReglement();
    boolean estEnContexteDeRechargement = OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "RECHARGE");
    if (estEnContexteDeRechargement)
    {
      EreRechargement ereRechargement = (EreRechargement)demande.getEvenementReferenceExamen();
      reglementPropose = ereRechargement.getReglementForcePourRechargement();
    }
    DonneesEntreeDeterminationListePra donneesEntreeDeterminationListePra = new DonneesEntreeDeterminationListePra();
    donneesEntreeDeterminationListePra.setDemande(demande);
    donneesEntreeDeterminationListePra.setActiviteSalarie(pas);
    donneesEntreeDeterminationListePra.setForcerReglementRecharge(estEnContexteDeRechargement);
    donneesEntreeDeterminationListePra.setUtiliserParametreAffiRechargement(estEnContexteDeRechargement);
    donneesEntreeDeterminationListePra.setOrdreTriListe(ConstructionPra.ORDRE_REGLEMENT_APPLICABLE);
    Collection<Pra> listePra = ConstructionPra.determinerListePra(donneesEntreeDeterminationListePra);
    if ((listePra == null) || (listePra.isEmpty())) {
      return null;
    }
    ValidationProduit validationProduit;
    ValidationProduit validationProduit;
    if (estEnContexteDeRechargement)
    {
      validationProduit = deuxiemeExamen(demande, listePra, reglementPropose, avecPeriodeNonAttestee, produit);
    }
    else
    {
      validationProduit = premierExamen(demande, listePra, reglementPropose, avecPeriodeNonAttestee, produit, false);
      if ((validationProduit == null) && (determineConditionPram(demande, pas, reglementPropose, avecPeriodeNonAttestee, produit))) {
        validationProduit = deuxiemeExamen(demande, listePra, reglementPropose, avecPeriodeNonAttestee, produit);
      }
    }
    if (validationProduit != null) {
      validationProduit.setPeriodeValidationProduit(pas);
    }
    return validationProduit;
  }
  
  protected ValidationProduit premierExamen(Demande demande, Collection listePra, Reglement reglement, boolean avecPeriodeNonAttestee, ProduitAsuSpec produit, boolean estSimulation)
    throws ApplicativeException
  {
    for (Iterator iter = listePra.iterator(); iter.hasNext();)
    {
      Pra pra = (Pra)iter.next();
      ValidationProduit validationProduit = premierExamen(demande, pra, reglement, avecPeriodeNonAttestee, produit, estSimulation);
      if (validationProduit != null)
      {
        validationProduit.setPeriodePra(new Periode(pra.getDebut(), pra.getFin()));
        return validationProduit;
      }
    }
    return null;
  }
  
  private ValidationProduit premierExamen(Demande demande, Pra pra, Reglement reglement, boolean avecPeriodeNonAttestee, ProduitAsuSpec produit, boolean estSimulation)
    throws ApplicativeException
  {
    Chronologie chronoPAS = determinerActivitesParticipantes(demande, pra, reglement, avecPeriodeNonAttestee, true);
    
    ValidationProduit validationProduit = null;
    
    QuantitesAppartenance qtesAcquises = verifierConditionAffiliation(demande, pra, chronoPAS, reglement, produit, true, "rechercheReglementApplicable");
    if (qtesAcquises != null)
    {
      validationProduit = new ValidationProduit();
      validationProduit.setReglementApplicable(reglement);
      validationProduit.setQuantiteAcquise(new Quantite(Mathematiques.arrondiASup(qtesAcquises.getQuantiteAppartenance(qtesAcquises.getUniteAppartenancePrincipale()).getValeur(), 10), qtesAcquises.getUniteAppartenancePrincipale()));
      if (qtesAcquises.getUniteAppartenanceSecondaire() != null) {
        validationProduit.setQuantiteAcquiseSecondaire(new Quantite(Mathematiques.arrondiASup(qtesAcquises.getQuantiteAppartenance(qtesAcquises.getUniteAppartenanceSecondaire()).getValeur(), 10), qtesAcquises.getUniteAppartenanceSecondaire()));
      }
      if (estSimulation)
      {
        JustificationAffiliationSpec justification = qtesAcquises.getJustificationAffiliation(qtesAcquises.getUniteAppartenancePrincipale());
        if ((justification != null) && ("justifCGENouveauModele".equals(justification.getTypeJustificationAffiliation())) && (!produit.getNomUnique().equals("ASU_CGE01_07"))) {
          validationProduit.setJustificationCalculAffiliation((JustificationAffiliation)justification);
        }
      }
      renseignerQuantiteAssimilation(validationProduit, qtesAcquises);
    }
    return validationProduit;
  }
  
  protected ValidationProduit deuxiemeExamen(Demande demande, Collection listePra, Reglement reglement, boolean avecPeriodeNonAttestee, ProduitAsuSpec produit)
    throws ApplicativeException
  {
    for (Iterator iter = listePra.iterator(); iter.hasNext();)
    {
      Pra pra = (Pra)iter.next();
      ValidationProduit validationProduit = deuxiemeExamen(demande, pra, reglement, avecPeriodeNonAttestee, produit);
      if (validationProduit != null)
      {
        validationProduit.setPeriodePra(new Periode(pra.getDebut(), pra.getFin()));
        return validationProduit;
      }
    }
    return null;
  }
  
  private ValidationProduit deuxiemeExamen(Demande demande, Pra pra, Reglement reglement, boolean avecPeriodeNonAttestee, ProduitAsuSpec produit)
    throws ApplicativeException
  {
    Chronologie chronoPAS = determinerActivitesParticipantes(demande, pra, avecPeriodeNonAttestee);
    
    ValidationProduit validationProduit = null;
    
    QuantitesAppartenance qtesAcquises = verifierConditionAffiliation(demande, pra, chronoPAS, reglement, produit, true, "rechercheReglementApplicable");
    if (qtesAcquises != null)
    {
      validationProduit = new ValidationProduit();
      validationProduit.setReglementApplicable(reglement);
      validationProduit.setQuantiteAcquise(new Quantite(Mathematiques.arrondiASup(qtesAcquises.getQuantiteAppartenance(qtesAcquises.getUniteAppartenancePrincipale()).getValeur(), 10), qtesAcquises.getUniteAppartenancePrincipale()));
      if (qtesAcquises.getUniteAppartenanceSecondaire() != null) {
        validationProduit.setQuantiteAcquiseSecondaire(new Quantite(Mathematiques.arrondiASup(qtesAcquises.getQuantiteAppartenance(qtesAcquises.getUniteAppartenanceSecondaire()).getValeur(), 10), qtesAcquises.getUniteAppartenanceSecondaire()));
      }
      renseignerQuantiteAssimilation(validationProduit, qtesAcquises);
    }
    return validationProduit;
  }
  
  protected QuantitesAppartenance verifierConditionAffiliation(Demande demande, Pra pra, Chronologie chronoPAS, Reglement reglementAppartenance, ProduitAsuSpec produit, boolean effectuerImputationAffiliationPmvs, String contexteAppel)
    throws ApplicativeException
  {
    Quantite qteAcquise = null;
    
    CalculAppartenanceSpec outilCalculAppartenance = recupererOutilCalculAppartenance(demande, produit);
    
    ParametresCalculAppartenance parametres = new ParametresCalculAppartenance();
    parametres.setEffectuerImputationAffiliationPmvs(effectuerImputationAffiliationPmvs);
    parametres.setPrendreEnCompteDernierJourFevrier(true);
    parametres.setPrendreEnCompteDonneesForcees(true);
    parametres.setActiverSpecificitesRechargement(true);
    parametres.setContexteAppel(contexteAppel);
    List<Unite> listeUnites = OutilAccesListeUnitesReglement.getInstance().recupererListeUniteRechercheReglementApplicable(reglementAppartenance.getNomReglement(), demande.estEnContexteDemande("RECHARGE"), produit);
    
    parametres.setListeUnitesReglement(listeUnites);
    QuantitesAppartenance quantitesAppartenance = (QuantitesAppartenance)outilCalculAppartenance.calculer(demande, pra, chronoPAS, reglementAppartenance, parametres);
    
    boolean bAffiliationOk = false;
    
    Iterator<Unite> iter = listeUnites.iterator();
    while ((!bAffiliationOk) && (iter.hasNext()))
    {
      Unite unite = (Unite)iter.next();
      
      Quantite qteAffiliation = quantitesAppartenance.getQuantiteAffiliation(unite);
      if (qteAffiliation == null) {
        qteAffiliation = new Quantite("0", unite);
      }
      Quantite qteAssimilation = quantitesAppartenance.getQuantiteAssimilation(unite);
      if (qteAssimilation == null) {
        qteAssimilation = new Quantite("0", unite);
      }
      BigDecimal valAcquise = qteAffiliation.getValeur().add(qteAssimilation.getValeur());
      if (pra.getQuantiteAffiliationRequise(unite) != null)
      {
        BigDecimal valRequise = pra.getQuantiteAffiliationRequise(unite).getValeur();
        
        bAffiliationOk = valAcquise.compareTo(valRequise) >= 0;
        if (bAffiliationOk) {
          qteAcquise = new Quantite(valAcquise, unite);
        }
      }
    }
    if (qteAcquise != null)
    {
      quantitesAppartenance.setUniteAppartenancePrincipale(qteAcquise.getUnite());
      
      iter = listeUnites.iterator();
      Unite unite;
      do
      {
        if (!iter.hasNext()) {
          break;
        }
        unite = (Unite)iter.next();
      } while (unite.equals(qteAcquise.getUnite()));
      quantitesAppartenance.setUniteAppartenanceSecondaire(unite);
    }
    else
    {
      quantitesAppartenance = null;
    }
    return quantitesAppartenance;
  }
  
  protected CalculAppartenanceSpec recupererOutilCalculAppartenance(DemandeSpec demande, ProduitAsuSpec produit)
  {
    return produit.getOutilCalculAppartenance(demande, false);
  }
  
  protected Chronologie determinerActivitesParticipantes(Demande demande, Periode periodeReference, Reglement reglement, boolean avecPeriodeNonAttestee, boolean assimilationIncluse)
  {
    Chronologie passeProfessionnel = demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation();
    
    Chronologie chronoActivitesSalariees = ConstructionChronologie.determinerChronoActiviteSalarieMemeReglement(passeProfessionnel, reglement.getNomReglement(), periodeReference, demande);
    
    return determinerActivitesParticipantes(demande, chronoActivitesSalariees, passeProfessionnel, periodeReference, avecPeriodeNonAttestee, assimilationIncluse);
  }
  
  public Chronologie determinerActivitesParticipantes(Demande demande, Periode periodeReference, boolean avecPeriodeNonAttestee)
  {
    Chronologie passeProfessionnel = demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation();
    
    Chronologie chronoActivitesSalariees = ConstructionChronologie.determinerChronoActiviteSalarieTousReglements(demande, passeProfessionnel, periodeReference);
    
    return determinerActivitesParticipantes(demande, chronoActivitesSalariees, passeProfessionnel, periodeReference, avecPeriodeNonAttestee, true);
  }
  
  private Chronologie determinerActivitesParticipantes(Demande demande, Chronologie chronoActivitesSalariees, Chronologie passeProfessionnel, Periode periodeReference, boolean avecPeriodeNonAttestee, boolean assimilationIncluse)
  {
    ChronologieStandard chronoActivitesSalarieesEtAssimilables = new ChronologieStandard();
    
    Chronologie chronoPeriodesParticipantes = fr.unedic.cali.asu.outilsfonctionnels.ConstructionChronologie.determinerPeriodesParticipantesAffiliationRegle13Mois(demande.getListContexteDemande(), periodeReference, chronoActivitesSalariees, avecPeriodeNonAttestee);
    if (assimilationIncluse)
    {
      Chronologie chronoActivitesAssimilables = ConstructionChronologie.determinerChronoAssimilablePra(demande, periodeReference, passeProfessionnel);
      
      chronoActivitesSalarieesEtAssimilables.ajouter(chronoActivitesAssimilables);
    }
    chronoActivitesSalarieesEtAssimilables.ajouter(chronoPeriodesParticipantes);
    
    return chronoActivitesSalarieesEtAssimilables;
  }
  
  public boolean determineConditionPram(Demande demande, ActiviteSalarie pas, Reglement reglement, boolean avecPeriodeNonAttestee, ProduitAsuSpec produit)
    throws ApplicativeException
  {
    boolean conditionremplie = false;
    
    Pra praMinimale = ConstructionPra.determinerPram(pas, demande);
    
    Chronologie chronoPAS = getInstance().determinerActivitesParticipantes(demande, praMinimale, reglement, avecPeriodeNonAttestee, false);
    
    QuantitesAppartenance qtesAcquises = verifierConditionAffiliation(demande, praMinimale, chronoPAS, reglement, produit, false, "rechercheReglementApplicablePram");
    if (qtesAcquises != null) {
      conditionremplie = true;
    }
    return conditionremplie;
  }
  
  private void renseignerQuantiteAssimilation(ValidationProduit validationProduit, QuantitesAppartenance quantiteAppartenance)
  {
    if (quantiteAppartenance != null)
    {
      if (quantiteAppartenance.getUniteAppartenancePrincipale() != null)
      {
        Quantite quantiteAssimilationPrincipale = quantiteAppartenance.getQuantiteAssimilation(quantiteAppartenance.getUniteAppartenancePrincipale());
        if (quantiteAssimilationPrincipale != null) {
          validationProduit.setQuantiteAssimilationAcquise(quantiteAssimilationPrincipale);
        }
      }
      if (quantiteAppartenance.getUniteAppartenanceSecondaire() != null)
      {
        Quantite quantiteAssimilationSecondaire = quantiteAppartenance.getQuantiteAssimilation(quantiteAppartenance.getUniteAppartenanceSecondaire());
        if (quantiteAssimilationSecondaire != null) {
          validationProduit.setQuantiteAssimilationAcquise(quantiteAssimilationSecondaire);
        }
      }
    }
  }
}

/* Location:
 * Qualified Name:     RechercheReglementApplicable
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */