package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.competence;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.dom.ResultatDeterminationCompetence;
import fr.unedic.cali.asu.dom.SaisieAntecedent;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.produits.liquidation.dom.Antecedent;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Entreprise;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.OdSpec;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourClassement;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourERE;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourTypeContexteDemande;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;

public class DeterminationCompetencePourReprise
{
  public static DeterminationCompetencePourReprise getInstance()
  {
    return new DeterminationCompetencePourReprise();
  }
  
  public void alimenterCompetencePourReprise(int contexteExamen, Demande demandeCourante, CompetenceSpec competence, CompetenceSpec competenceSousJacente)
    throws CoucheLogiqueException
  {
    DossierExamenAssuranceSpec dossierExamenCourant = (DossierExamenAssuranceSpec)demandeCourante.getDossierExamen();
    AttributionAssuranceSpec attributionPrecedente = dossierExamenCourant.getAttributionPrecedente();
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeCourante, "AREENTRCSP"))
    {
      ResultatDeterminationCompetence resultatDeterminationCompetence = DeterminationCompetenceAsp.getInstance().determinationCompetencesProduitCourant(demandeCourante);
      
      controleEntreCspSpEtReliquatAre(demandeCourante, resultatDeterminationCompetence.getChargeIndemnisationDroitCourant(), contexteExamen);
      
      OutilDeterminationCompetence.mapperResultatSurCompetence(resultatDeterminationCompetence, competence);
      if (attributionPrecedente != null) {
        alimenterCompetenceSousJacenteEntreeCSP(attributionPrecedente, competenceSousJacente);
      }
    }
    else if (attributionPrecedente != null)
    {
      boolean estNovationSortieCSp = demandeCourante.getObjectifDecisionne().getSousType() == 48;
      if (estNovationSortieCSp)
      {
        gererNovationPourSortieCSP(attributionPrecedente, demandeCourante, competence);
      }
      else
      {
        attributionPrecedente.getCompetence().copieElements(competence);
        controleDroitSpAReprendre(demandeCourante);
      }
    }
    if ((OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeCourante, "ARECOURCSP")) && (attributionPrecedente != null)) {
      gestionRevisionCspHorsPec(attributionPrecedente).getCompetenceSousJacente().copieElements(competenceSousJacente);
    }
  }
  
  private AttributionAssuranceSpec gestionRevisionCspHorsPec(AttributionAssuranceSpec attributionPrecedente)
  {
    AttributionAssuranceSpec attributionPrecedentePourCompetenceSousJacente = attributionPrecedente;
    if (("ASU_28".equals(attributionPrecedente.getDemandeAssurance().getEvenementReferenceExamen().getTypeExamen())) && (!OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)attributionPrecedente.getDemandeAssurance(), 6))) {
      attributionPrecedentePourCompetenceSousJacente = (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(attributionPrecedente.getDemande().getChronologieDemandesAssuranceSansCourante(), attributionPrecedente.getDemande(), new FiltreDemandePourTypeContexteDemande(6));
    }
    return attributionPrecedentePourCompetenceSousJacente;
  }
  
  private void gererNovationPourSortieCSP(AttributionAssuranceSpec attributionPrecedente, Demande demandeCourante, CompetenceSpec competence)
    throws CoucheLogiqueException
  {
    if ("ASU_23".equals(attributionPrecedente.getDemandeAssurance().getEvenementReferenceExamen().getTypeExamen()))
    {
      AttributionAssuranceSpec rechargementEnCoursCSP = rechercherRechargementEnCoursASP(demandeCourante);
      if ((rechargementEnCoursCSP != null) && (rechargementEnCoursCSP.getCompetenceSousJacente() != null) && (rechargementEnCoursCSP.getCompetenceSousJacente().getCompetenceFinanciere() == 1)) {
        rechargementEnCoursCSP.getCompetenceSousJacente().copieElements(competence);
      } else {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A8MB12");
      }
    }
    else
    {
      alimenterCompetencePourNovationSortieCsp(demandeCourante, competence);
    }
  }
  
  private void alimenterCompetenceSousJacenteEntreeCSP(AttributionAssuranceSpec attributionPrecedente, CompetenceSpec competenceSousJacente)
  {
    boolean attributionPrecedenteAntecedentConversion = false;
    if ("ASU_23".equals(attributionPrecedente.getDemandeAssurance().getEvenementReferenceExamen().getTypeExamen()))
    {
      SaisieAntecedent saisie = ((Demande)attributionPrecedente.getDemandeAssurance()).getSaisieAntecedent();
      attributionPrecedenteAntecedentConversion = 9 == saisie.getContexteDemande().intValue();
    }
    if (attributionPrecedenteAntecedentConversion)
    {
      competenceSousJacente.setCompetenceAdministrative(2);
      competenceSousJacente.setCompetenceFinanciere(2);
      competenceSousJacente.setChargeIndemnisationDroitCourant(2);
      SaisieAntecedent saisieAntecedent = ((Demande)attributionPrecedente.getDemandeAssurance()).getSaisieAntecedent();
      if (saisieAntecedent.getIdentifiantCompetence() != null)
      {
        ActiviteSalarie fctCompetence = (ActiviteSalarie)attributionPrecedente.getDemande().getDemandeur().rechercherPeriodePasseProfessionnel(saisieAntecedent.getIdentifiantCompetence());
        
        competenceSousJacente.setLibelleEmployeurCompetent(fctCompetence.getEntreprise().getLibelleEntreprise());
      }
    }
    else
    {
      attributionPrecedente.getCompetence().copieElements(competenceSousJacente);
    }
  }
  
  private AttributionAssuranceSpec rechercherRechargementEnCoursASP(Demande demandeCourante)
  {
    FiltreET filtreRechargement = new FiltreET();
    filtreRechargement.ajouterFiltre(new FiltreDemandePourERE("ASU_29"));
    filtreRechargement.ajouterFiltre(new FiltreDemandePourTypeContexteDemande("ARECOURCSP"));
    
    AttributionAssuranceSpec dernierRechargement = (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demandeCourante.getChronologieDemandesAssuranceSansCourante(), demandeCourante, filtreRechargement);
    if (dernierRechargement != null)
    {
      FiltreET filtreDemandeEntreeCSP = new FiltreET();
      filtreDemandeEntreeCSP.ajouterFiltre(new FiltreDemandePourTypeContexteDemande("AREENTRCSP"));
      filtreDemandeEntreeCSP.ajouterFiltre(new FiltreNegation(new FiltreDemandePourClassement("SO")));
      
      AttributionAssuranceSpec attributionEntreeCSP = (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demandeCourante.getChronologieDemandesAssuranceSansCourante(), demandeCourante, filtreDemandeEntreeCSP);
      if ((attributionEntreeCSP != null) && (attributionEntreeCSP.getDateAttribution().estApres(dernierRechargement.getDateAttribution()))) {
        dernierRechargement = null;
      }
    }
    return dernierRechargement;
  }
  
  private void alimenterCompetencePourNovationSortieCsp(Demande demandeCourante, CompetenceSpec competence)
    throws CoucheLogiqueException
  {
    DossierExamenAssuranceSpec dossierExamenCourant = (DossierExamenAssuranceSpec)demandeCourante.getDossierExamen();
    AttributionAssuranceSpec attributionPrecedente = gestionRevisionCspHorsPec(dossierExamenCourant.getAttributionPrecedente());
    if ((attributionPrecedente != null) && (attributionPrecedente.getCompetenceSousJacente() != null))
    {
      if (attributionPrecedente.getCompetenceSousJacente().getCompetenceAdministrative() == 2) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A8MB12");
      }
      attributionPrecedente.getCompetenceSousJacente().copieElements(competence);
    }
  }
  
  public void controleEntreCspSpEtReliquatAre(Demande demande, int competence, int contexteExamen)
    throws CoucheLogiqueException
  {
    if ((OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "AREENTRCSP")) && (competence == 2) && (contexteExamen == 3)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A8MB12");
    }
  }
  
  public void controleDroitSpAReprendre(Demande demande)
    throws CoucheLogiqueException
  {
    if (!OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, 6))
    {
      OdSpec od = demande.rechercherOuvertureDroitPrecedenteDuMemeType();
      if (((od instanceof Antecedent)) && (((Demande)((Antecedent)od).getDemande()).getSaisieAntecedent().getContexteDemande().intValue() == 9)) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A8MB12");
      }
    }
  }
}

/* Location:
 * Qualified Name:     DeterminationCompetencePourReprise
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */