package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.novation.asp;

import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.StrategieConditionFaitGenerateurDemandeClassique;
import fr.unedic.cali.asu.dom.DelaiRechercheProduit;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.CertifieSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.DeclareSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.autresdoms.ga.outilsfonctionnels.OutilPasseProfessionel;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteNonSalariee;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteSalarieeHorsChamp;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesCertifiees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesDeclarees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesSurFiltresExclusifs;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreTravailSpec;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreFinAvantOuCoincideAvecDate;
import fr.unedic.util.temps.FiltreFinDansBornes;
import fr.unedic.util.temps.FiltreTemporel;
import fr.unedic.util.temps.FiltresTemporel;

public class OutilDeterminationConditionFaitGenerateur
  implements OutilFonctionnel
{
  public void rechercheConditionFaitGenerateur(Demande demande)
    throws CoucheLogiqueException
  {
    controleReintegrationDemandee(demande);
    DossierAffecte dossierAffecte = (DossierAffecte)demande.getDossierAffectationAdmission();
    TravailSpec dernierSinistre = dossierAffecte.getSinistre();
    verifierPresenceAe(dernierSinistre);
    if (seulementChronoActivitesHorsChampDansDelai(demande))
    {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_ERR_CAP_FAIT_GENERATEUR_ASP_NOVATION");
    }
    else
    {
      boolean estDernierSinistre = dernierSinistre != null;
      verifierExistanceDernierAu(estDernierSinistre, demande);
      verifierDateExamenLendemainDernierAu(dossierAffecte, dernierSinistre);
      
      boolean estContextePap = OutilGestionContexteDemande.estContextePresentDansRegroupement(demande.getListContexteDemande(), 10);
      
      verifierMotifRuptureDernierAu(dernierSinistre, estContextePap);
    }
  }
  
  protected void verifierMotifRuptureDernierAu(TravailSpec dernierSinistre, boolean estContextePap)
    throws CoucheLogiqueException
  {
    int motifFin = Integer.parseInt(((ActiviteSalarie)dernierSinistre).getMotifFin());
    if (estContextePap) {
      controlerMotifRupturePAP(motifFin);
    } else {
      controlerMotifRuptureCSP(motifFin);
    }
  }
  
  private void controlerMotifRupturePAP(int motifFin)
    throws CoucheLogiqueException
  {
    if ((motifFin != 48) && (motifFin != 49)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A8MB10", new String[] { "entrée en PAP" });
    }
  }
  
  private void controlerMotifRuptureCSP(int motifFin)
    throws CoucheLogiqueException
  {
    if ((motifFin != 44) && (motifFin != 45)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A8MB10", new String[] { "entrée en CSP" });
    }
  }
  
  protected void verifierPresenceAe(TravailSpec dernierSinistre)
    throws CoucheLogiqueException
  {
    if ((estActiviteSalarieNonAtteste(dernierSinistre)) || (estCertifieNonAtteste(dernierSinistre)) || (estDeclareNonJustifie(dernierSinistre))) {
      StrategieConditionFaitGenerateurDemandeClassique.lancerAlerteA11MB1(dernierSinistre);
    }
  }
  
  private boolean estActiviteSalarieNonAtteste(TravailSpec dernierSinistre)
  {
    return ((dernierSinistre instanceof ActiviteSalarie)) && (!((ActiviteSalarie)dernierSinistre).estAtteste());
  }
  
  private boolean estCertifieNonAtteste(TravailSpec dernierSinistre)
  {
    return ((dernierSinistre instanceof CertifieSpec)) && (!((CertifieSpec)dernierSinistre).estAtteste());
  }
  
  private boolean estDeclareNonJustifie(TravailSpec dernierSinistre)
  {
    return ((dernierSinistre instanceof DeclareSpec)) && (!((DeclareSpec)dernierSinistre).estJustifie());
  }
  
  protected void verifierDateExamenLendemainDernierAu(DossierAffectation dossierAffectation, TravailSpec dernierSinistre)
    throws CoucheLogiqueException
  {
    Demande demande = (Demande)dossierAffectation.getDemande();
    int motifFin = Integer.parseInt(((ActiviteSalarie)dernierSinistre).getMotifFin());
    boolean estMotifEntreeCSPOuPAP = (motifFin == 44) || (motifFin == 48);
    if ((estMotifEntreeCSPOuPAP) && (demande.getDonneesTemporaires().getMotifExamen() == 0) && (!demande.getDateExamen().coincideAvec(dernierSinistre.getDateFin().lendemain()))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A8MB8", new String[] { demande.getDateExamen().toString(), dernierSinistre.getDateFin().toString() });
    }
  }
  
  protected void verifierExistanceDernierAu(boolean estDernierSinistre, Demande demande)
    throws CoucheLogiqueException
  {
    if (!estDernierSinistre) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A6MB5", new String[] { demande.getDateExamen().toString() });
    }
  }
  
  protected boolean seulementChronoActivitesHorsChampDansDelai(Demande demande)
  {
    FiltrePeriodesSurFiltresExclusifs filtresExclusifs = new FiltrePeriodesSurFiltresExclusifs();
    
    FiltresTemporel filtresTravailSalarieNonSalarie = new FiltresTemporel();
    filtresTravailSalarieNonSalarie.ajouterFiltre(new FiltrePeriodesCertifiees());
    filtresExclusifs.ajouterFiltre(filtresTravailSalarieNonSalarie);
    
    FiltresTemporel filtresDeclareTravail = new FiltresTemporel();
    filtresDeclareTravail.ajouterFiltre(new FiltrePeriodesDeclarees());
    filtresDeclareTravail.ajouterFiltre(new FiltreTravailSpec());
    filtresExclusifs.ajouterFiltre(filtresDeclareTravail);
    
    Chronologie chronoActivitesParticipantes = OutilPasseProfessionel.trouverChronoPasseProfessionelAvecFiltrageDNJ(demande.getDemandeur()).copier(filtresExclusifs);
    
    chronoActivitesParticipantes = chronoActivitesParticipantes.copier(new FiltreFinAvantOuCoincideAvecDate(demande.getDateExamen()));
    
    Chronologie chronoActivitesParticipantesDansDelai = null;
    
    DelaiRechercheProduit periodeDelaiForclusion = ((DossierAffectation)demande.getDossierAffectation()).getDelaiRecherche();
    if (periodeDelaiForclusion != null) {
      chronoActivitesParticipantesDansDelai = chronoActivitesParticipantes.copier(new FiltreFinDansBornes(periodeDelaiForclusion));
    }
    Chronologie chronoActivitesHorsChampDansDelai = null;
    
    filtresExclusifs = new FiltrePeriodesSurFiltresExclusifs();
    FiltreTemporel filtreActiviteSalarieHorsChamp = new FiltrePeriodeActiviteSalarieeHorsChamp();
    filtresExclusifs.ajouterFiltre(filtreActiviteSalarieHorsChamp);
    FiltreTemporel filtreActiviteNonSalarie = new FiltrePeriodeActiviteNonSalariee();
    filtresExclusifs.ajouterFiltre(filtreActiviteNonSalarie);
    if (chronoActivitesParticipantesDansDelai != null) {
      chronoActivitesHorsChampDansDelai = chronoActivitesParticipantesDansDelai.copier(filtresExclusifs);
    }
    return (chronoActivitesParticipantesDansDelai != null) && (chronoActivitesHorsChampDansDelai != null) && (chronoActivitesParticipantesDansDelai.getTaille() > 0) && (chronoActivitesParticipantesDansDelai.getTaille() == chronoActivitesHorsChampDansDelai.getTaille());
  }
  
  protected void controleReintegrationDemandee(Demande demande)
    throws CoucheLogiqueException
  {
    if ((!demande.getDonneesTemporaires().isEstDemarcheReintegrationEffectuee()) && (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "CRSPMVS"))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A8MB15");
    }
  }
}

/* Location:
 * Qualified Name:     OutilDeterminationConditionFaitGenerateur
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */