package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies;

import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.OutilJustificationSjrSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationDiviseur;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.Prc;
import fr.unedic.cali.asu.produits.liquidation.dom.conteneurs.DonneesResultatDeterminationSjr;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeComplementairesDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeComportementSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDemandeDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDeterminationSjrSpec;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;

public class StrategieDeterminationDiviseurSjrA4
  extends StrategieDeterminationDiviseurSjrA3A4A5Abstrait
{
  private static final String FORMULE_CALCUL_DIVISEUR = "Maximum de (N - (n + j); H / 10; D0)";
  
  protected BigDecimal determinerDiviseurSpecifique(DonneesEntreeDeterminationSjrSpec p_donneesEntree, DonneesResultatDeterminationSjr p_donneesResultat, BigDecimal p_resultatDureePrcPlafonnee)
    throws CoucheLogiqueException
  {
    BigDecimal resultatDiviseur = null;
    
    Prc resultatPrc = p_donneesResultat.getPrc();
    BigDecimal resultatNombreJourDeductible = new BigDecimal(String.valueOf(resultatPrc.getNombreJourDeductible()));
    BigDecimal resultatDiviseurCasGeneral = resultatPrc.getNombreJourTravailEffectif();
    
    OutilJustificationSjrSpec outilJustificationSjr = recupererOutilJustificationSjr(p_donneesEntree.getDonneesEntreeComportement());
    JustificationDiviseur resultatJustificationDiviseur = p_donneesResultat.getJustificationSjr().getJustificationDiviseur();
    
    calculerNombreHeuresTotal(p_donneesEntree, p_donneesResultat);
    
    calculerDroitCongesA4ouA5(p_donneesEntree, p_donneesResultat);
    
    BigDecimal premiereValeurFormule = p_resultatDureePrcPlafonnee.subtract(resultatNombreJourDeductible.add(resultatPrc.getDroitCongesA4ouA5()));
    
    BigDecimal diviseurMinimal = Mathematiques.diviseEntier(resultatPrc.getNombreHeuresTotal(), new BigDecimal("10"));
    
    BigDecimal valeurMaximaleIntermediaire = premiereValeurFormule.max(diviseurMinimal);
    resultatDiviseur = valeurMaximaleIntermediaire.max(resultatDiviseurCasGeneral);
    if (outilJustificationSjr != null)
    {
      outilJustificationSjr.justifierDiviseurDonneePremiereValeurFormule(resultatJustificationDiviseur, premiereValeurFormule.intValue());
      outilJustificationSjr.justifierDiviseurDonneeDiviseurMinimal(resultatJustificationDiviseur, diviseurMinimal.intValue());
    }
    if (resultatDiviseur.signum() < 1)
    {
      boolean estTraitementDeterminationSjr = p_donneesEntree.getDonneesEntreeComportement().getTypeTraitementAppelant() == 1;
      
      String libelleReglementApplicable = p_donneesEntree.getDonneesEntreeDemande().getReglementApplicable().getLibelleCourt();
      
      Damj dateFGD = p_donneesEntree.getDonneesEntreeDemande().getDateFaitGenerateurDroitCourant();
      
      genererAlerteBloquanteDiviseurNegatif(3, "Maximum de (N - (n + j); H / 10; D0)", estTraitementDeterminationSjr, resultatPrc, p_resultatDureePrcPlafonnee, libelleReglementApplicable, dateFGD);
    }
    return resultatDiviseur;
  }
  
  private void calculerNombreHeuresTotal(DonneesEntreeDeterminationSjrSpec p_donneesEntree, DonneesResultatDeterminationSjr p_donneesResultat)
  {
    OutilJustificationSjrSpec outilJustificationSjr = recupererOutilJustificationSjr(p_donneesEntree.getDonneesEntreeComportement());
    JustificationDiviseur resultatJustificationDiviseur = p_donneesResultat.getJustificationSjr().getJustificationDiviseur();
    
    Prc resultatPrc = p_donneesResultat.getPrc();
    Chronologie chronoActiviteSalariePrc = p_donneesEntree.getDonneesEntreeComplementaires().getChronologieActiviteSalariePrc();
    Reglement reglementApplicable = p_donneesEntree.getDonneesEntreeDemande().getReglementApplicable();
    BigDecimal resultatNombreHeuresTotal = calculerNombreHeuresActiviteDansPrc(chronoActiviteSalariePrc, resultatPrc, reglementApplicable, outilJustificationSjr, resultatJustificationDiviseur, true);
    
    resultatPrc.setNombreHeuresTotal(resultatNombreHeuresTotal);
  }
}

/* Location:
 * Qualified Name:     StrategieDeterminationDiviseurSjrA4
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */