package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.OutilDeterminationMontantICCP;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieMontantICCPSpec;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Salaire;
import fr.unedic.cali.outilsfonctionnels.ComparateurTemporelSurDateFinDecroissante;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Iterator;

public abstract class StrategieMontantICCP
  implements StrategieMontantICCPSpec
{
  private static final int MOIS_JUIN = 6;
  private static final int PREMIER_JOUR_MOIS = 1;
  
  public QuantiteEuro determinerMontantICCP(DemandeAssuranceSpec demande, ActiviteSalarie activiteSalarie, ChronologiePeriodes chronoPeriodesIndemnisation)
    throws ApplicativeException
  {
    throw new UnsupportedOperationException("Cette méthode ne doit pas être appelée (concerne les règlements applicables du cas général).");
  }
  
  public QuantiteEuro determinerMontantICCPRuptureA4(ActiviteSalarie activiteSalarie, ChronologiePeriodes chronoPeriodesIndemnisation)
  {
    throw new UnsupportedOperationException("Cette méthode ne doit pas être appelée (concerne le règlement applicable A4).");
  }
  
  protected QuantiteEuro recupererQuantiteEuroICCPSurFCT(ActiviteSalarie activiteSalarie)
  {
    return activiteSalarie.getQuantiteEuroIccp();
  }
  
  protected BigDecimal determinerMontantRuptureICCPProratiseHorsPeriodesIndemnisation(BigDecimal montantICCPRupture, ActiviteSalarie activiteSalarie, ChronologiePeriodes chronoPeriodesIndemnisation)
  {
    BigDecimal montantRuptureICCPProratiseRetour = montantICCPRupture;
    
    Salaire salaireChevauchantFCT = recupererSalaireChevauchantFCT(activiteSalarie);
    if ((montantICCPRupture != null) && (montantICCPRupture.compareTo(BigDecimal.ZERO) > 0)) {
      activiteSalarie.setPresenceMontantICCPAvantProratisation(true);
    }
    BigDecimal montantICCPRuptureProratise = OutilDeterminationMontantICCP.proratiserMontantRuptureICCPSurActivite(activiteSalarie, montantICCPRupture, salaireChevauchantFCT, chronoPeriodesIndemnisation);
    
    mettreAJourInfoProratisation(activiteSalarie, montantICCPRupture, montantICCPRuptureProratise);
    if (montantICCPRuptureProratise != null) {
      montantRuptureICCPProratiseRetour = montantICCPRuptureProratise;
    }
    return montantRuptureICCPProratiseRetour;
  }
  
  protected Salaire recupererSalaireChevauchantFCT(ActiviteSalarie activiteSalarie)
  {
    Salaire salaireChevauchantFCT = null;
    
    Chronologie chronoPeriodesSalaireCourante = activiteSalarie.getListeSalaires();
    if ((chronoPeriodesSalaireCourante != null) && (!chronoPeriodesSalaireCourante.estVide()))
    {
      chronoPeriodesSalaireCourante.setComparateur(new ComparateurTemporelSurDateFinDecroissante());
      
      Salaire periodeSalaireRecuperee = (Salaire)chronoPeriodesSalaireCourante.premierElement();
      if (activiteSalarie.getDateFin().estContenueDans(new Periode(periodeSalaireRecuperee.getDateDebut(), periodeSalaireRecuperee.getDateFin()))) {
        salaireChevauchantFCT = periodeSalaireRecuperee;
      }
    }
    return salaireChevauchantFCT;
  }
  
  protected BigDecimal determinerMontantICCPMajorationRemuneration(ActiviteSalarie activiteSalarie, Damj dateFg, ChronologiePeriodes chronoPeriodesIndemnisation)
  {
    BigDecimal montantICCPRetour = null;
    
    Periode periodeReference = determinerPeriodeReferenceMajorationRemuneration(dateFg);
    
    Chronologie chronologieResultante = activiteSalarie.getListeSalaires().copier(new FiltreChevauchePeriode(periodeReference));
    Iterator iter = chronologieResultante.iterer();
    BigDecimal txICCP = null;
    BigDecimal txIPE = null;
    BigDecimal cumulMontantsICCP = null;
    BigDecimal montantHorsPeriodeIndemnisation = null;
    while (iter.hasNext())
    {
      Salaire salaire = (Salaire)iter.next();
      
      QuantiteEuro montantICCPSalaire = (QuantiteEuro)salaire.getMontantIccp();
      if (montantICCPSalaire != null)
      {
        if (cumulMontantsICCP == null) {
          cumulMontantsICCP = BigDecimal.ZERO;
        }
        if (montantICCPSalaire.getValeur().compareTo(BigDecimal.ZERO) > 0) {
          activiteSalarie.setPresenceMontantICCPAvantProratisation(true);
        }
        montantHorsPeriodeIndemnisation = OutilDeterminationMontantICCP.proratiserMontantSurPeriodeHorsChronologie(salaire.getMontantIccp().getValeur(), salaire.getPeriode(), chronoPeriodesIndemnisation);
        
        cumulMontantsICCP = cumulMontantsICCP.add(montantHorsPeriodeIndemnisation);
        mettreAJourInfoProratisation(activiteSalarie, salaire.getMontantIccp().getValeur(), montantHorsPeriodeIndemnisation);
      }
      else
      {
        txICCP = salaire.getTauxIccp();
        txIPE = salaire.getTauxIndemnisationPrecarite();
      }
      if (txICCP != null)
      {
        if (txICCP.compareTo(BigDecimal.ZERO) > 0) {
          activiteSalarie.setPresenceMontantICCPAvantProratisation(true);
        }
        if (cumulMontantsICCP == null) {
          cumulMontantsICCP = BigDecimal.ZERO;
        }
        montantHorsPeriodeIndemnisation = OutilDeterminationMontantICCP.proratiserMontantSurPeriodeHorsChronologie(salaire.getMontantBrutBase().getValeur(), salaire.getPeriode(), chronoPeriodesIndemnisation);
        
        cumulMontantsICCP = cumulMontantsICCP.add(montantHorsPeriodeIndemnisation);
        if (txICCP.compareTo(BigDecimal.ZERO) > 0) {
          mettreAJourInfoProratisation(activiteSalarie, salaire.getMontantBrutBase().getValeur(), montantHorsPeriodeIndemnisation);
        }
      }
    }
    if (txICCP != null) {
      montantICCPRetour = determinerMontantDepuisTauxICCPMajorationRemuneration(cumulMontantsICCP, txICCP, txIPE);
    } else if (cumulMontantsICCP != null) {
      montantICCPRetour = cumulMontantsICCP;
    }
    return montantICCPRetour;
  }
  
  private Periode determinerPeriodeReferenceMajorationRemuneration(Damj dateFg)
  {
    Damj datePivot = new Damj(dateFg.getAnnee(), 6, 1);
    
    Damj dateDebutPeriode = null;
    if (dateFg.estApresOuCoincideAvec(datePivot)) {
      dateDebutPeriode = new Damj(dateFg.getAnnee() - 1, 6, 1);
    } else {
      dateDebutPeriode = new Damj(dateFg.getAnnee() - 2, 6, 1);
    }
    return new Periode(dateDebutPeriode, dateFg);
  }
  
  private BigDecimal determinerMontantDepuisTauxICCPMajorationRemuneration(BigDecimal cumulSalaires, BigDecimal txICCP, BigDecimal txIPE)
  {
    BigDecimal montantICCPRetour = null;
    BigDecimal denominateur;
    BigDecimal nominateur;
    BigDecimal denominateur;
    if (txIPE == null)
    {
      BigDecimal nominateur = txICCP;
      denominateur = txICCP.add(BigDecimal.ONE);
    }
    else
    {
      nominateur = txICCP;
      denominateur = txICCP.add(BigDecimal.ONE).multiply(txIPE.add(BigDecimal.ONE));
    }
    montantICCPRetour = Mathematiques.proratiser(cumulSalaires, nominateur, denominateur);
    montantICCPRetour = Mathematiques.arrondiASup(montantICCPRetour, 2);
    
    return montantICCPRetour;
  }
  
  protected boolean estMontantDifferent(BigDecimal montantAvant, BigDecimal montantApres)
  {
    BigDecimal avant = montantAvant;
    if (avant == null) {
      avant = BigDecimal.ZERO;
    }
    BigDecimal apres = montantApres;
    if (apres == null) {
      apres = BigDecimal.ZERO;
    }
    return avant.compareTo(apres) != 0;
  }
  
  protected void mettreAJourInfoProratisation(ActiviteSalarie activite, BigDecimal montantAvant, BigDecimal montantApres)
  {
    boolean montantProratise = activite.estMontantIccpProratise();
    activite.setMontantIccpProratise((montantProratise) || (estMontantDifferent(montantAvant, montantApres)));
  }
}

/* Location:
 * Qualified Name:     StrategieMontantICCP
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */