package fr.unedic.cali.asu.cge01.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.ConstructionChronologie;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.OutilDonneesDeterminationSjr;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.FabriqueOutilFonctionnelDeterminationSjrSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.OutilDeterminationSjrSpec;
import fr.unedic.cali.asu.cge01.outilsfonctionnels.RevalorisationSalaire;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.outilsfonctionnels.OutilMappingSjmSjr;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationDiviseur;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationPlafonds;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationPrc;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationSr;
import fr.unedic.cali.asu.produits.liquidation.dom.Prc;
import fr.unedic.cali.asu.produits.liquidation.dom.PrcSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.Sjrip;
import fr.unedic.cali.asu.produits.liquidation.dom.conteneurs.DonneesResultatDeterminationSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ConstitutionElementsSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.ObjetAlertesNonBloquantes;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeComportementSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDemandeDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDeterminationSjrSpec;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.cali.util.OutillageChronologiePeriodes;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.ObjetChronoPeriodeConcrete;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.Map;

public abstract class ParcoursConstitutionSjrAbstrait
  extends ParcoursCali
{
  private static final int DUREE_VINGT_HUIT_JOURS = 28;
  private static final Damj DATE_PIVOT_CONTROLE_JOURS_CEE = new Damj(2010, 5, 1);
  
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    Resultat resultatCEPA07 = new Resultat(0);
    
    Demande demandeCourante = DomLiquidationAssurance.getDemande(contexte);
    DossierExamen dossierExamenCourant = (DossierExamen)demandeCourante.getDossierExamen();
    
    ConstitutionSjr constitutionSjr = dossierExamenCourant.getConstitutionElementsActifs().createConstitutionSjr();
    
    Sjrip sjripCourant = determinerSjrip(demandeCourante);
    
    alimenterCEPSjrip(constitutionSjr, sjripCourant);
    
    Sjr sjrrpCourant = determinerSjrrp(dossierExamenCourant);
    
    alimenterCEPSjrrp(constitutionSjr, sjrrpCourant);
    
    OutilTrace.tracerFinParcours();
    
    return resultatCEPA07;
  }
  
  protected abstract void alimenterCEPCodeEmploiA2B(ConstitutionSjr paramConstitutionSjr, DonneesEntreeDeterminationSjrSpec paramDonneesEntreeDeterminationSjrSpec);
  
  protected abstract Chronologie determinerChronoActiviteSalariePrc(Demande paramDemande, Periode paramPeriode);
  
  protected Prc determinerPrc(Demande demande)
    throws ApplicativeException
  {
    JustificationPrc justificationPrc = determinerEtJustifierPeriodePrc(demande);
    
    Periode periodeReferenceCalcul = justificationPrc.getPeriodePrcEffective();
    Prc prcRetourne = new PrcSjr(periodeReferenceCalcul);
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Prc : ", periodeReferenceCalcul });
    
    prcRetourne.setJustification(justificationPrc);
    
    return prcRetourne;
  }
  
  protected abstract JustificationPrc determinerEtJustifierPeriodePrc(Demande paramDemande)
    throws ApplicativeException;
  
  protected abstract Sjrip verifierSjripForce(Demande paramDemande, DonneesEntreeDeterminationSjrSpec paramDonneesEntreeDeterminationSjrSpec)
    throws ApplicativeException;
  
  private void alimenterCEPJustificationSjr(ConstitutionSjr constitutionSjr, DonneesResultatDeterminationSjr donneesResultatDeterminationSjr)
  {
    JustificationSr justificationSrResultat = donneesResultatDeterminationSjr.getJustificationSjr().getJustificationSr();
    JustificationDiviseur justificationDiviseurResultat = donneesResultatDeterminationSjr.getJustificationSjr().getJustificationDiviseur();
    JustificationPlafonds justificationPlafondsResultat = donneesResultatDeterminationSjr.getJustificationSjr().getJustificationPlafonds();
    
    JustificationSjr justificationSjr = constitutionSjr.createJustificationSjr();
    
    JustificationSr justificationSr = justificationSjr.createJustificationSr();
    justificationSr.setListeActivitesSalarieesRetenues(justificationSrResultat.getListeActivitesSalarieesRetenues());
    justificationSr.setSalaireReferenceNonPlafonne(justificationSrResultat.getSalaireReferenceNonPlafonne());
    justificationSr.setSalaireReferencePlafonnne(justificationSrResultat.getSalaireReferencePlafonnne());
    justificationSr.setTotalSalairesRetenus(justificationSrResultat.getTotalSalairesRetenus());
    justificationSr.setTotalPrimesNormalesRetenues(justificationSrResultat.getTotalPrimesNormalesRetenues());
    justificationSr.setTotalPrimesExceptionnellesRetenues(justificationSrResultat.getTotalPrimesExceptionnellesRetenues());
    
    justificationSjr.setJustificationDiviseur(justificationDiviseurResultat);
    
    justificationSjr.setJustificationPlafonds(justificationPlafondsResultat);
    
    constitutionSjr.setCoeffReducteurSjr(donneesResultatDeterminationSjr.getCoefficientReducteurSjr());
    constitutionSjr.setSjrTheorique(donneesResultatDeterminationSjr.getSjrTheorique());
    constitutionSjr.setPlancherCoefficientSjr(donneesResultatDeterminationSjr.getPlancherCoefficientReducteur());
  }
  
  private void alimenterCEPListeAlertesNonBloquantes(Demande demande, Hashtable listeAlertesNonBloquantesResultat)
  {
    String codeAlerteNonBloquanteResultat = null;
    Collection listePeriodeTravailResultat = null;
    Iterator itListePeriodeTravailResultat = null;
    ObjetAlertesNonBloquantes objetAlertesNonBloquantesResultat = null;
    Collection listePeriodeTravail = null;
    for (Enumeration enumeration = listeAlertesNonBloquantesResultat.keys(); enumeration.hasMoreElements();)
    {
      codeAlerteNonBloquanteResultat = (String)enumeration.nextElement();
      listePeriodeTravailResultat = (Collection)listeAlertesNonBloquantesResultat.get(codeAlerteNonBloquanteResultat);
      if (demande.getAlertesNonBloquantes().containsKey(codeAlerteNonBloquanteResultat))
      {
        listePeriodeTravail = (Collection)demande.getAlertesNonBloquantes().get(codeAlerteNonBloquanteResultat);
        
        itListePeriodeTravailResultat = listePeriodeTravailResultat.iterator();
        while (itListePeriodeTravailResultat.hasNext())
        {
          objetAlertesNonBloquantesResultat = (ObjetAlertesNonBloquantes)itListePeriodeTravailResultat.next();
          if (!listePeriodeTravail.contains(objetAlertesNonBloquantesResultat)) {
            listePeriodeTravail.add(objetAlertesNonBloquantesResultat);
          }
        }
      }
      else
      {
        demande.getAlertesNonBloquantes().put(codeAlerteNonBloquanteResultat, listePeriodeTravailResultat);
      }
    }
  }
  
  private void alimenterCEPSjrip(ConstitutionSjr constitutionSjr, Sjrip sjrip)
  {
    Sjrip sjripCourant = constitutionSjr.createSjrip(sjrip.getDateEffet(), sjrip.getPlafondSjr(), sjrip.getSjrInitial());
    sjripCourant.setPrc(sjrip.getPrc());
  }
  
  private void alimenterCEPSjrrp(ConstitutionSjr constitutionSjr, Sjr sjrrp)
  {
    constitutionSjr.setSjrrp(sjrrp);
  }
  
  private void controle28JoursSituationCoordEuropeenne(Demande demande, Prc prc, Chronologie chronoActiviteSalariePrc)
    throws CoucheLogiqueException
  {
    Periode periodePrc = prc.getPeriode();
    
    boolean coordCee = demande.getDonneesTemporaires().isEstCoordCee();
    if ((coordCee) && ((demande.getDonneesTemporaires().getTypeCoordinationEuropeenne() == 2) || ((demande.getDonneesTemporaires().getTypeCoordinationEuropeenne() == 1) && (demande.getFaitGenerateur().getDateFaitGenerateur().estAvant(DATE_PIVOT_CONTROLE_JOURS_CEE)))))
    {
      Chronologie chronoActivitePostE301PourControle = determinerChronoActivitePourConditionCoordEuropeenne(prc, chronoActiviteSalariePrc);
      if (chronoActivitePostE301PourControle != null)
      {
        ChronologiePeriodes chronoPeriodesActiviteEnFranceSurPrc = new ChronologiePeriodes();
        ActiviteSalarie periodeActiviteSalarieEnFrancePostE301 = null;
        Periode periodeAAjouter = null;
        chronoActivitePostE301PourControle.iterer();
        while (chronoActivitePostE301PourControle.encoreSuivant())
        {
          periodeActiviteSalarieEnFrancePostE301 = (ActiviteSalarie)chronoActivitePostE301PourControle.elementSuivant();
          if (periodeActiviteSalarieEnFrancePostE301.getContrat().getPohf() == 0)
          {
            periodeAAjouter = periodeActiviteSalarieEnFrancePostE301.periodeIntersection(periodePrc);
            chronoPeriodesActiviteEnFranceSurPrc.ajouter(new ObjetChronoPeriodeConcrete(periodeAAjouter));
          }
        }
        boolean conditionRemplie = false;
        if (!chronoPeriodesActiviteEnFranceSurPrc.estVide())
        {
          chronoPeriodesActiviteEnFranceSurPrc = chronoPeriodesActiviteEnFranceSurPrc.fusionnerChevauchementPeriodes();
          chronoPeriodesActiviteEnFranceSurPrc = OutillageChronologiePeriodes.fusionnerPeriodesAccolees(chronoPeriodesActiviteEnFranceSurPrc);
          
          chronoPeriodesActiviteEnFranceSurPrc.iterer();
          ObjetChronoPeriode periodeCourante = null;
          while ((chronoPeriodesActiviteEnFranceSurPrc.encoreSuivant()) && (!conditionRemplie))
          {
            periodeCourante = (ObjetChronoPeriode)chronoPeriodesActiviteEnFranceSurPrc.elementSuivant();
            if (periodeCourante.getDuree() >= 28) {
              conditionRemplie = true;
            }
          }
        }
        if (!conditionRemplie) {
          leverAlerteA11MB13();
        }
      }
    }
  }
  
  protected abstract Chronologie determinerChronoActivitePourConditionCoordEuropeenne(Prc paramPrc, Chronologie paramChronologie);
  
  private Chronologie determinerChronoActiviteInappartenancePrc(Demande demande, Periode periodePrc)
  {
    Chronologie chronologieActivitePourInappartenance = ConstructionChronologie.determinerChronoActivitesPrcPourInappartenance(demande, periodePrc);
    
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Chronologie des activités, pour déterminer l'inappartenance, chevauchant la Prc : ", chronologieActivitePourInappartenance });
    
    return chronologieActivitePourInappartenance;
  }
  
  private Chronologie determinerChronoPeriodeDeductiblePrc(Demande demande, Periode periodePrc)
    throws CoucheLogiqueException
  {
    Chronologie chronologiePeriodesDeductibles = ConstructionChronologie.determinerChronoPeriodesDeductiblesPrc(demande, periodePrc);
    
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Chronologie des Périodes Déductibles chevauchant la Prc : ", chronologiePeriodesDeductibles });
    
    return chronologiePeriodesDeductibles;
  }
  
  private void leverAlerteA11MB13()
    throws CoucheLogiqueException
  {
    fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB13");
  }
  
  private void leverAlerteA11MNB10(Demande demande, Chronologie pnds)
  {
    String codeAlerteNonBloquante = "A11MNB10";
    
    Collection listePnds = new ArrayList();
    ObjetChronoPeriode pndsCourante = null;
    for (Iterator iterPnds = pnds.iterer(); iterPnds.hasNext();)
    {
      pndsCourante = (ObjetChronoPeriode)iterPnds.next();
      ObjetAlertesNonBloquantes objetAlerteNonBloquante = new ObjetAlertesNonBloquantes(pndsCourante.getDateDebut(), pndsCourante.getDateFin(), 7);
      
      listePnds.add(objetAlerteNonBloquante);
    }
    demande.getAlertesNonBloquantes().put(codeAlerteNonBloquante, listePnds);
  }
  
  private Sjr determinerSjrrp(DossierExamen dossierExamen)
  {
    Sjr sjrrpRetourne = null;
    
    ConstitutionSjr cepConstitutionSjr = dossierExamen.getConstitutionSjr();
    Reglement reglementApplicableCourant = dossierExamen.getReglementApplicable().getReglement();
    if (reglementApplicableCourant.estNomReglementIdentique("A2b")) {
      sjrrpRetourne = cepConstitutionSjr.getSjri();
    } else {
      sjrrpRetourne = RevalorisationSalaire.revaloriserSjr(OutilMappingSjmSjr.creerElementBaseIndeminisationSjrip(dossierExamen.getConstitutionSjr().getSjrip()), (ProduitAsuSpec)dossierExamen.getDossierAffecte().getProduit(), dossierExamen.getDateAttribution());
    }
    return sjrrpRetourne;
  }
  
  private Sjrip calculerSjrip(Demande demande, DonneesEntreeDeterminationSjrSpec donneesEntree)
    throws ApplicativeException
  {
    Sjrip sjripRetourne = null;
    
    ConstitutionSjr cepConstitutionSjr = ((DossierExamen)demande.getDossierExamen()).getConstitutionSjr();
    
    sjripRetourne = verifierSjripA2b(cepConstitutionSjr, donneesEntree);
    if (sjripRetourne == null)
    {
      Prc prcCourante = determinerPrc(demande);
      Periode periodePrc = prcCourante.getPeriode();
      
      verifierPresencePnds(demande, periodePrc);
      
      Chronologie chronoActiviteSalariePrc = determinerChronoActiviteSalariePrc(demande, periodePrc);
      Chronologie chronoActiviteInappartenancePrc = determinerChronoActiviteInappartenancePrc(demande, periodePrc);
      Chronologie chronoPeriodeDeductiblePrc = determinerChronoPeriodeDeductiblePrc(demande, periodePrc);
      
      controle28JoursSituationCoordEuropeenne(demande, prcCourante, chronoActiviteSalariePrc);
      
      OutilDonneesDeterminationSjr.getInstance().alimenterDonneesEntreeComplementaires(donneesEntree, prcCourante.getJustification(), chronoActiviteSalariePrc, chronoActiviteInappartenancePrc, chronoPeriodeDeductiblePrc);
      
      FabriqueOutilFonctionnelDeterminationSjrSpec fabriqueOutilFonctionnel = (FabriqueOutilFonctionnelDeterminationSjrSpec)donneesEntree.getDonneesEntreeComportement().getFabriqueOutilFonctionnel();
      
      DonneesResultatDeterminationSjr resultatDeterminationSjr = fabriqueOutilFonctionnel.getOutilDeterminationSjr().determinerSjrip(donneesEntree);
      
      verifierIncoherenceSalaire(demande.getAlertesNonBloquantes(), chronoActiviteSalariePrc);
      
      alimenterCEPJustificationSjr(cepConstitutionSjr, resultatDeterminationSjr);
      alimenterCEPListeAlertesNonBloquantes(demande, resultatDeterminationSjr.getListeAlertesNonBloquantes());
      
      sjripRetourne = construireSjrip(resultatDeterminationSjr.getPrc(), resultatDeterminationSjr.getPlafondSjr(), resultatDeterminationSjr.getSjri(), donneesEntree.getDonneesEntreeDemande().getContexteDemande());
    }
    return sjripRetourne;
  }
  
  protected Sjrip determinerSjrip(Demande demande)
    throws ApplicativeException
  {
    Sjrip sjripRetourne = null;
    
    ProduitAsuSpec produitCourant = (ProduitAsuSpec)demande.getDossierAffectation().getProduit();
    DonneesEntreeDeterminationSjrSpec donneesEntreeDeterminationSjr = OutilDonneesDeterminationSjr.getInstance().initialiserDonneesEntree(demande, 1, (FabriqueOutilFonctionnelDeterminationSjrSpec)produitCourant.determinerFabriqueOutilFonctionnelDeterminationSjr(demande.getDateFaitGenerateurOuDernierSinistre()), true);
    
    sjripRetourne = verifierSjripForce(demande, donneesEntreeDeterminationSjr);
    if (sjripRetourne == null) {
      sjripRetourne = calculerSjrip(demande, donneesEntreeDeterminationSjr);
    }
    return sjripRetourne;
  }
  
  private Sjrip verifierSjripA2b(ConstitutionSjr constitutionSjr, DonneesEntreeDeterminationSjrSpec donneesEntree)
  {
    Sjrip sjripRetourne = null;
    
    Reglement reglementApplicable = donneesEntree.getDonneesEntreeDemande().getReglementApplicable();
    if ((reglementApplicable != null) && (reglementApplicable.estNomReglementIdentique("A2b")))
    {
      FabriqueOutilFonctionnelDeterminationSjrSpec fabriqueOutilFonctionnel = (FabriqueOutilFonctionnelDeterminationSjrSpec)donneesEntree.getDonneesEntreeComportement().getFabriqueOutilFonctionnel();
      
      DonneesResultatDeterminationSjr resultatDeterminationSjr = fabriqueOutilFonctionnel.getOutilDeterminationSjr().determinerSjripPourA2B(donneesEntree);
      
      sjripRetourne = construireSjrip(donneesEntree.getDonneesEntreeDemande().getDateExamen(), resultatDeterminationSjr.getPlafondSjr(), resultatDeterminationSjr.getSjri());
      
      alimenterCEPCodeEmploiA2B(constitutionSjr, donneesEntree);
    }
    return sjripRetourne;
  }
  
  private void verifierPresencePnds(Demande demande, Periode periodePrc)
    throws CoucheLogiqueException
  {
    try
    {
      Chronologie pnds = demande.getChronologiePNDS(periodePrc);
      if ((pnds != null) && (!pnds.estVide())) {
        leverAlerteA11MNB10(demande, pnds);
      }
    }
    catch (ApplicativeException e)
    {
      throw new CoucheLogiqueException(e.getCode(), e.getLibelle(), e);
    }
  }
  
  protected Sjrip construireSjrip(Prc prc, BigDecimal plafondSjr, BigDecimal sjr, String contexteParticulier)
  {
    Sjrip sjripRetourne = Sjrip.createNonPersistent();
    sjripRetourne.setDateEvenement(prc.getDateFin());
    sjripRetourne.setPrc(prc);
    sjripRetourne.setPlafondSjr(new QuantiteEuro(plafondSjr));
    sjripRetourne.setSjrInitial(new QuantiteEuro(sjr));
    sjripRetourne.setContexteParticulierSjr(contexteParticulier);
    
    return sjripRetourne;
  }
  
  protected Sjrip construireSjrip(Damj dateEffetSjr, BigDecimal plafondSjr, BigDecimal sjr)
  {
    Sjrip sjripRetourne = Sjrip.createNonPersistent();
    sjripRetourne.setDateEvenement(dateEffetSjr);
    sjripRetourne.setPlafondSjr(new QuantiteEuro(plafondSjr));
    sjripRetourne.setSjrInitial(new QuantiteEuro(sjr));
    
    return sjripRetourne;
  }
  
  private void verifierIncoherenceSalaire(Map<String, Collection<ObjetAlertesNonBloquantes>> tableAlerteNonBloquante, Chronologie chronoActiviteSalariePrc)
  {
    Collection<ObjetAlertesNonBloquantes> listePeriodes = new ArrayList();
    String codeAlerteNonBloquante = "SALAIRE_CT_INCOHERENT";
    for (Iterator iterActivite = chronoActiviteSalariePrc.iterer(); iterActivite.hasNext();)
    {
      ActiviteSalarie activiteCourante = (ActiviteSalarie)iterActivite.next();
      if ("02".equals(activiteCourante.getIncoherencePeriode()))
      {
        ObjetAlertesNonBloquantes objetAlerteNonBloquante = new ObjetAlertesNonBloquantes(activiteCourante.getDateDebut(), activiteCourante.getDateFin(), 10);
        
        listePeriodes.add(objetAlerteNonBloquante);
      }
    }
    if (!listePeriodes.isEmpty()) {
      tableAlerteNonBloquante.put(codeAlerteNonBloquante, listePeriodes);
    }
  }
}

/* Location:
 * Qualified Name:     ParcoursConstitutionSjrAbstrait
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */