package fr.unedic.cali.asu.cge01.liquidation.parcours.asp;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.spec.ObjectifExamenAssuranceSpec;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilObjectifExamen;
import fr.unedic.cali.asu.parcours.ParcoursObjectifAdmission;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.Resultat;

public class ParcoursObjectifCSPSousJacent
  extends ParcoursObjectifAdmission
{
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    Resultat resultatObjectifAdmission = new Resultat();
    resultatObjectifAdmission.setEtat(1);
    
    DemandeAssuranceSpec demandeCourante = getDemande(contexte);
    ObjectifExamenAssuranceSpec objectifExamenCourant = OutilObjectifExamen.recupererObjectifCourant(contexte);
    boolean capaSatisfaites = false;
    
    capaSatisfaites = ((ProduitAsuSpec)demandeCourante.getDossierAffectation().getProduit()).verifierCapasPreliminaires(contexte);
    
    capaSatisfaites = (capaSatisfaites) && (verifierCapa(contexte));
    if (capaSatisfaites)
    {
      executerCepa(contexte, objectifExamenCourant);
      if (!OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)demandeCourante, "ARESJASPDC")) {
        capaSatisfaites = (capaSatisfaites) && (verifierCapaSupplementaires(contexte));
      }
      if (capaSatisfaites) {
        resultatObjectifAdmission.setEtat(0);
      } else {
        demandeCourante.getDossierExamen().changerEtat(16);
      }
    }
    else
    {
      demandeCourante.getDossierExamen().changerEtat(16);
    }
    OutilTrace.tracerFinParcours();
    
    return resultatObjectifAdmission;
  }
  
  protected boolean verifierCapa(Contexte p_contexte)
    throws ApplicativeException
  {
    boolean capaSatisfaites = false;
    
    Resultat resultatCapa04 = null;
    
    ProduitAsuSpec produitCourant = getProduit(p_contexte);
    
    resultatCapa04 = produitCourant.verifierConditionFaitGenerateur(p_contexte);
    if (resultatCapa04.estSatisfait()) {
      capaSatisfaites = true;
    }
    return capaSatisfaites;
  }
  
  protected void executerCepa(Contexte contexte, ObjectifExamenAssuranceSpec objectifExamenCourant)
    throws ApplicativeException
  {
    Demande demandeCourante = (Demande)getDemande(contexte);
    IndividuSpec individu = demandeCourante.getDemandeur();
    ProduitAsuSpec produitCourant = getProduit(contexte);
    
    changerEtatDossierExamenEnAttribution(demandeCourante);
    
    produitCourant.constituerDateAttribution(contexte);
    
    produitCourant.constituerReglementApplicable(contexte);
    
    activerExclusionChronoPasseProPourLiquidationFCTRevision(demandeCourante, individu);
    produitCourant.constituerQuantiteAffiliation(contexte);
    desactiverExclusionChronoPasseProPourLiquidationFCTRevision(demandeCourante, individu);
    
    activerExclusionChronoPasseProPourLiquidationFCTRevision(demandeCourante, individu);
    produitCourant.constituerSalaireJournalierDeReference(contexte);
    desactiverExclusionChronoPasseProPourLiquidationFCTRevision(demandeCourante, individu);
    
    activerExclusionChronoPasseProPourLiquidationFCTRevision(demandeCourante, individu);
    produitCourant.constituerCoefficientTempsPartiel(contexte);
    desactiverExclusionChronoPasseProPourLiquidationFCTRevision(demandeCourante, individu);
    
    activerExclusionChronoPasseProPourLiquidationFCTRevision(demandeCourante, individu);
    produitCourant.determinerCompetencesDroitCourant(contexte);
    desactiverExclusionChronoPasseProPourLiquidationFCTRevision(demandeCourante, individu);
    
    produitCourant.constituerMontantsBruts(contexte);
  }
  
  private boolean verifierCapaSupplementaires(Contexte contexte)
    throws ApplicativeException
  {
    boolean capaSupplementairesSatisfaites = true;
    
    return capaSupplementairesSatisfaites;
  }
}

/* Location:
 * Qualified Name:     ParcoursObjectifCSPSousJacent
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */