package fr.unedic.cali.asu.cge01.p02.calcul.outilsfonctionnels;

import fr.unedic.cali.asu.cge01.p02.calcul.outilsfonctionnels.fabriques.FabriqueStrategieActiviteReduitePansConservee;
import fr.unedic.cali.asu.cge01.p02.calcul.outilsfonctionnels.strategies.StrategieActiviteReduitePansConserveeSpec;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.Attribution;
import fr.unedic.cali.calcul.dom.periode.Pans;
import fr.unedic.cali.calcul.dom.periode.PansNonInstallee;
import fr.unedic.cali.calcul.dom.periode.PeriodeActiviteEmploiCalcul;
import fr.unedic.cali.calcul.dom.periode.PeriodeNonDeclareeSanction;
import fr.unedic.cali.calcul.dom.periode.PeriodePrime;
import fr.unedic.cali.calcul.dom.periode.PeriodeTravail;
import fr.unedic.cali.calcul.dom.periode.PeriodeTravailJustifiee;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.ResultatActiviteReduite;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodePrimeCalcul;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodeTravailCalcul;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodeTravailCalculCESCAE;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodeTravailCalculCUI;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodeTravailCalculHorsPANSNonInstallee;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import java.math.BigDecimal;
import java.util.ListIterator;

public class ActiviteReduite
  extends fr.unedic.cali.asu.calcul.outilsfonctionnels.ActiviteReduite
{
  private static final BigDecimal COEF_AVANTAGE_VIEILLESSE_AR = new BigDecimal("0.8");
  private static final int AGE_CINQUANTE_ANS = 50;
  public static final BigDecimal SEUIL_HORAIRE_BIG = new BigDecimal("136");
  public static final int CUMUL_AR_DUREE_INDEMNISATION_MAX = 18;
  public static final int CUMUL_AR_SEIZIEME_MOIS = 16;
  
  public static BigDecimal calculerGainRetenu(Chronologie p_periodesEmploi)
  {
    BigDecimal gainRetenu = BigDecimal.ZERO;
    
    Chronologie chronoFiltree = p_periodesEmploi.copier(new FiltrePeriodeTravailCalcul());
    
    PeriodeTravail periodeCourante = null;
    chronoFiltree.iterer();
    while (chronoFiltree.encoreSuivant())
    {
      periodeCourante = (PeriodeTravail)chronoFiltree.elementSuivant();
      if (!(periodeCourante instanceof PansNonInstallee)) {
        gainRetenu = gainRetenu.add(periodeCourante.getGain());
      }
    }
    return gainRetenu;
  }
  
  public static BigDecimal calculerSeuilMensuel(Damj p_mois, BigDecimal p_sjr, BigDecimal p_sjc, boolean p_estApprenti, boolean p_avecSjc, BigDecimal p_cumulGainPansConservee)
    throws CoucheLogiqueException
  {
    BigDecimal montantJournalierRetenu;
    BigDecimal montantJournalierRetenu;
    if (p_avecSjc) {
      montantJournalierRetenu = p_sjr.add(p_sjc);
    } else {
      montantJournalierRetenu = p_sjr;
    }
    BigDecimal sommeSjrSjc = p_sjr.add(p_sjc);
    BigDecimal montantMoyenMensuelRetenu = null;
    BigDecimal smicJournalier = getSmicJournalier(p_mois.getDebutMois());
    if (p_estApprenti) {
      if (!p_avecSjc)
      {
        if (smicJournalier.compareTo(p_sjr) > 0) {
          montantJournalierRetenu = smicJournalier;
        }
      }
      else if (smicJournalier.compareTo(sommeSjrSjc) > 0) {
        montantJournalierRetenu = smicJournalier;
      }
    }
    montantMoyenMensuelRetenu = montantJournalierRetenu.multiply(new BigDecimal("30")).add(p_cumulGainPansConservee);
    
    return Mathematiques.tronque(montantMoyenMensuelRetenu.multiply(new BigDecimal("0.7")), 2);
  }
  
  private static boolean estMoisNeutraliseOdRgActiviteReprise(ResultatActiviteReduite p_resultatRetour, boolean p_contientPasCESEtCAE, boolean p_contintPasCUI, boolean p_contientPeriodeHorsPansNonInstallees, boolean p_contientUnePeriodeARRepriseChezUnMemeEmployeur, boolean p_commissionParitaire, DureeCalendaire p_age, Damj p_mois, BigDecimal p_nbreHeuresCumulees, BigDecimal p_gainCumule, BigDecimal p_sjr, BigDecimal p_sjc, int p_cumulMois, boolean p_apprenti, boolean p_debutActiviteConserveAvantPrc, BigDecimal p_cumulGainPansConservee)
    throws CoucheLogiqueException
  {
    boolean retour = false;
    BigDecimal montantMoyenMensuelCumul = calculerSeuilMensuel(p_mois, p_sjr, p_sjc, p_apprenti, p_debutActiviteConserveAvantPrc, p_cumulGainPansConservee);
    if ((p_contientUnePeriodeARRepriseChezUnMemeEmployeur) && (!p_commissionParitaire))
    {
      p_resultatRetour.setTypeNeutralisation(6);
      retour = true;
    }
    else if ((p_contientPasCESEtCAE) && (p_contintPasCUI) && (p_contientPeriodeHorsPansNonInstallees) && (p_age.getAnnees() < 50) && (p_cumulMois >= 18))
    {
      p_resultatRetour.setTypeNeutralisation(3);
      retour = true;
    }
    else if ((p_nbreHeuresCumulees.compareTo(SEUIL_HORAIRE_BIG) > 0) && (p_gainCumule.compareTo(montantMoyenMensuelCumul) > 0))
    {
      p_resultatRetour.setTypeNeutralisation(2);
      retour = true;
    }
    else if (p_nbreHeuresCumulees.compareTo(SEUIL_HORAIRE_BIG) > 0)
    {
      p_resultatRetour.setTypeNeutralisation(0);
      retour = true;
    }
    else if (p_gainCumule.compareTo(montantMoyenMensuelCumul) > 0)
    {
      p_resultatRetour.setTypeNeutralisation(1);
      retour = true;
    }
    return retour;
  }
  
  public static ResultatActiviteReduite genererEvenementActiviteReduite(Damj p_dateDebutPeriodeActiviteReduite, Chronologie p_periodeEmploi, DureeCalendaire p_age, boolean p_apprenti, int p_cumulMois, String p_identifiantEmployeur, int p_periodeARRepriseChezUnMemeEmployeurForcee, boolean p_commissionParitaire, String p_reglementAttribution, BigDecimal p_sjr, BigDecimal p_sjc, boolean p_estPNDS, Attribution p_attribution)
    throws CoucheLogiqueException
  {
    ResultatActiviteReduite evtRetour = new ResultatActiviteReduite();
    BigDecimal cumulNbHeures = BigDecimal.ZERO;
    BigDecimal cumulGain = BigDecimal.ZERO;
    BigDecimal cumulGainPrimes = BigDecimal.ZERO;
    BigDecimal cumulGainActiviteNonSalarieeNonInstallee = BigDecimal.ZERO;
    BigDecimal cumulGainJustifie = BigDecimal.ZERO;
    BigDecimal cumulNbHeuresJustifiees = BigDecimal.ZERO;
    BigDecimal cumulGainPNDS = BigDecimal.ZERO;
    BigDecimal cumulNbJourTravail = BigDecimal.ZERO;
    BigDecimal cumulGainICCPConserve = BigDecimal.ZERO;
    BigDecimal cumulGainICCPRepris = BigDecimal.ZERO;
    BigDecimal cumulGainConserve = BigDecimal.ZERO;
    BigDecimal cumulGainPrimesConservees = BigDecimal.ZERO;
    BigDecimal cumulGainPansConservee = BigDecimal.ZERO;
    BigDecimal cumulGainReprise = BigDecimal.ZERO;
    BigDecimal cumulNbHeuresReprise = BigDecimal.ZERO;
    BigDecimal cumulGainEstNeutralise = BigDecimal.ZERO;
    BigDecimal cumulNbHeuresConservees = BigDecimal.ZERO;
    BigDecimal cumulMontantPANS = BigDecimal.ZERO;
    
    Chronologie periodesEmploiCourantes = p_periodeEmploi.copier(new FiltrePeriodeTravailCalcul());
    Chronologie periodesPrime = p_periodeEmploi.copier(new FiltrePeriodePrimeCalcul());
    
    PeriodeTravail periodeCourante = null;
    boolean neutralisation = false;
    boolean contientUnePeriodeARRepriseChezUnMemeEmployeur = false;
    PeriodePrime prime = null;
    boolean calculSeuilAvecSjc = false;
    
    Chronologie chronoPeriodesConserveesLiq = p_attribution.getListeActiviteConservee();
    if ((chronoPeriodesConserveesLiq != null) && (!chronoPeriodesConserveesLiq.estVide())) {
      calculSeuilAvecSjc = true;
    }
    periodesPrime.iterer();
    while (periodesPrime.encoreSuivant())
    {
      prime = (PeriodePrime)periodesPrime.elementSuivant();
      if (prime.getTypeActivite() == 1) {
        cumulGainPrimesConservees = cumulGainPrimesConservees.add(prime.getMontant().getValeur());
      }
      cumulGainPrimes = cumulGainPrimes.add(prime.getMontant().getValeur());
    }
    ListIterator iterateur = periodesEmploiCourantes.iterer();
    while (iterateur.hasNext())
    {
      periodeCourante = (PeriodeTravail)iterateur.next();
      if ((periodeCourante instanceof PeriodeNonDeclareeSanction)) {
        cumulGainPNDS = cumulGainPNDS.add(((PeriodeNonDeclareeSanction)periodeCourante).getGain());
      }
      if ((periodeCourante instanceof PeriodeTravailJustifiee))
      {
        cumulGainJustifie = cumulGainJustifie.add(periodeCourante.getGain());
        cumulNbHeuresJustifiees = cumulNbHeuresJustifiees.add(periodeCourante.getNombreHeures());
      }
      if ((!contientUnePeriodeARRepriseChezUnMemeEmployeur) && ((periodeCourante instanceof PeriodeActiviteEmploiCalcul)) && (((PeriodeActiviteEmploiCalcul)periodeCourante).getIdentifiantEmployeur() != null) && (p_identifiantEmployeur != null)) {
        contientUnePeriodeARRepriseChezUnMemeEmployeur = ((PeriodeActiviteEmploiCalcul)periodeCourante).getIdentifiantEmployeur().equals(p_identifiantEmployeur);
      }
      if ((periodeCourante instanceof PansNonInstallee))
      {
        cumulGainActiviteNonSalarieeNonInstallee = cumulGainActiviteNonSalarieeNonInstallee.add(periodeCourante.getGain());
      }
      else
      {
        cumulNbJourTravail = cumulNbJourTravail.add(new BigDecimal(periodeCourante.getDuree()));
        if ((periodeCourante instanceof PeriodeActiviteEmploiCalcul))
        {
          if (!estCategorieEmploiAnnexe1((PeriodeActiviteEmploiCalcul)periodeCourante)) {
            cumulNbHeures = cumulNbHeures.add(periodeCourante.getNombreHeures());
          }
          cumulGain = cumulGain.add(((PeriodeActiviteEmploiCalcul)periodeCourante).getGainHorsIccp());
          if (((PeriodeActiviteEmploiCalcul)periodeCourante).getTypeActivite() == 1)
          {
            cumulGainConserve = cumulGainConserve.add(((PeriodeActiviteEmploiCalcul)periodeCourante).getGain());
            
            cumulGainICCPConserve = cumulGainICCPConserve.add(((PeriodeActiviteEmploiCalcul)periodeCourante).getIccp());
            if (!estCategorieEmploiAnnexe1((PeriodeActiviteEmploiCalcul)periodeCourante)) {
              cumulNbHeuresConservees = cumulNbHeuresConservees.add(((PeriodeActiviteEmploiCalcul)periodeCourante).getNombreHeures());
            }
          }
          else
          {
            if (!estCategorieEmploiAnnexe1((PeriodeActiviteEmploiCalcul)periodeCourante)) {
              cumulNbHeuresReprise = cumulNbHeuresReprise.add(((PeriodeActiviteEmploiCalcul)periodeCourante).getNombreHeures());
            }
            cumulGainICCPRepris = cumulGainICCPRepris.add(((PeriodeActiviteEmploiCalcul)periodeCourante).getIccp());
          }
        }
        else
        {
          cumulNbHeures = cumulNbHeures.add(periodeCourante.getNombreHeures());
          
          cumulGain = cumulGain.add(periodeCourante.getGain());
          if ((periodeCourante instanceof Pans))
          {
            evtRetour.setEstForfaitPans(((Pans)periodeCourante).getTypeRevenu() == 1 ? "1" : "0");
            cumulMontantPANS = cumulMontantPANS.add(((Pans)periodeCourante).getGain());
            if (((Pans)periodeCourante).getTypeActivite() == 1)
            {
              cumulGainConserve = cumulGainConserve.add(((Pans)periodeCourante).getGain());
              cumulGainPansConservee = cumulGainPansConservee.add(((Pans)periodeCourante).getGain());
              cumulNbHeuresConservees = cumulNbHeuresConservees.add(((Pans)periodeCourante).getNombreHeures());
            }
            else
            {
              cumulNbHeuresReprise = cumulNbHeuresReprise.add(((Pans)periodeCourante).getNombreHeures());
            }
          }
        }
      }
    }
    CritereStrategie critere = new CritereStrategie();
    critere.setDatePivot(p_dateDebutPeriodeActiviteReduite);
    FabriqueStrategieActiviteReduitePansConservee fabrique = new FabriqueStrategieActiviteReduitePansConservee();
    StrategieActiviteReduitePansConserveeSpec strategie = (StrategieActiviteReduitePansConserveeSpec)fabrique.getStrategie(critere);
    
    BigDecimal gainPansConserveeALaLiquidation = strategie.getGainPansConserveeALaLiquidation(p_attribution);
    
    BigDecimal gainPansConserveeAPrendreenComptePourNeutralisation = gainPansConserveeALaLiquidation;
    if (gainPansConserveeAPrendreenComptePourNeutralisation.compareTo(new BigDecimal(0)) == 0) {
      gainPansConserveeAPrendreenComptePourNeutralisation = cumulGainPansConservee;
    }
    cumulGain = cumulGain.add(cumulGainPrimes);
    cumulGainConserve = cumulGainConserve.add(cumulGainPrimesConservees);
    cumulGainEstNeutralise = cumulGain;
    cumulGain = calculerGainRetenu(periodesEmploiCourantes);
    cumulGain = cumulGain.add(cumulGainPrimes);
    cumulGainReprise = cumulGain.subtract(cumulGainConserve).add(cumulGainActiviteNonSalarieeNonInstallee);
    cumulNbHeuresReprise = cumulNbHeures.subtract(cumulNbHeuresConservees);
    if (TraitementActiviteReduite.estAvantConventionARE14(p_dateDebutPeriodeActiviteReduite))
    {
      if (!p_reglementAttribution.equalsIgnoreCase("A4"))
      {
        boolean contientPasCESEtCAE = periodesEmploiCourantes.copier(new FiltrePeriodeTravailCalculCESCAE()).estVide();
        
        boolean contientPasCUI = periodesEmploiCourantes.copier(new FiltrePeriodeTravailCalculCUI()).estVide();
        
        boolean contientUneActiviteHorsPansNonInstallee = !periodesEmploiCourantes.copier(new FiltrePeriodeTravailCalculHorsPANSNonInstallee()).estVide();
        if (p_periodeARRepriseChezUnMemeEmployeurForcee == 1) {
          contientUnePeriodeARRepriseChezUnMemeEmployeur = true;
        } else if (p_periodeARRepriseChezUnMemeEmployeurForcee == 2) {
          contientUnePeriodeARRepriseChezUnMemeEmployeur = false;
        }
        neutralisation = estMoisNeutraliseOdRgActiviteReprise(evtRetour, contientPasCESEtCAE, contientPasCUI, contientUneActiviteHorsPansNonInstallee, contientUnePeriodeARRepriseChezUnMemeEmployeur, p_commissionParitaire, p_age, p_dateDebutPeriodeActiviteReduite, cumulNbHeures, cumulGainEstNeutralise, p_sjr, p_sjc, p_cumulMois, p_apprenti, calculSeuilAvecSjc, gainPansConserveeAPrendreenComptePourNeutralisation);
        if (calculSeuilAvecSjc)
        {
          evtRetour.setSeuilRemuneration(null);
          evtRetour.setSeuilRemunerationAvecActConservee(calculerSeuilMensuel(p_dateDebutPeriodeActiviteReduite, p_sjr, p_sjc, p_apprenti, true, gainPansConserveeAPrendreenComptePourNeutralisation));
        }
        else
        {
          evtRetour.setSeuilRemuneration(calculerSeuilMensuel(p_dateDebutPeriodeActiviteReduite, p_sjr, p_sjc, p_apprenti, false, new BigDecimal(0)));
          evtRetour.setSeuilRemunerationAvecActConservee(null);
        }
      }
      BigDecimal smicJournalier = getSmicJournalier(p_dateDebutPeriodeActiviteReduite.getDebutMois());
      if (cumulGainActiviteNonSalarieeNonInstallee.compareTo(BigDecimal.ZERO) > 0)
      {
        BigDecimal nbJoursDecalage = null;
        BigDecimal montantJournalierRetenu = p_sjr;
        if ((p_apprenti) && (smicJournalier.compareTo(p_sjr) > 0)) {
          montantJournalierRetenu = smicJournalier;
        }
        if (p_age.getAnnees() >= 50)
        {
          nbJoursDecalage = Mathematiques.diviseEntier(cumulGainActiviteNonSalarieeNonInstallee, montantJournalierRetenu);
          nbJoursDecalage = nbJoursDecalage.multiply(COEF_AVANTAGE_VIEILLESSE_AR).setScale(0, 1);
        }
        else
        {
          nbJoursDecalage = Mathematiques.diviseEntier(cumulGainActiviteNonSalarieeNonInstallee, montantJournalierRetenu);
        }
        evtRetour.setDecalageDuree(nbJoursDecalage);
      }
      if ((!neutralisation) || (p_estPNDS))
      {
        BigDecimal nbJoursDecalage = null;
        BigDecimal montantJournalierRetenu = p_sjr;
        BigDecimal cumulGainPrDecalage = cumulGain.subtract(cumulGainConserve);
        if ((p_apprenti) && (smicJournalier.compareTo(p_sjr) > 0)) {
          montantJournalierRetenu = smicJournalier;
        }
        if (p_age.getAnnees() >= 50)
        {
          nbJoursDecalage = Mathematiques.diviseEntier(cumulGainPrDecalage, montantJournalierRetenu);
          nbJoursDecalage = nbJoursDecalage.multiply(COEF_AVANTAGE_VIEILLESSE_AR).setScale(0, 1);
        }
        else
        {
          nbJoursDecalage = Mathematiques.diviseEntier(cumulGainPrDecalage, montantJournalierRetenu);
        }
        evtRetour.setCreditDecalage(nbJoursDecalage);
      }
      evtRetour.setNeutralise(neutralisation);
    }
    evtRetour.setNbHeuresPrisesEnCompte(cumulNbHeures);
    evtRetour.setGainPrisEnCompte(cumulGain.add(cumulGainActiviteNonSalarieeNonInstallee));
    
    evtRetour.setCumulGainJustifie(cumulGainJustifie);
    evtRetour.setCumulNbHeuresJustifiees(cumulNbHeuresJustifiees);
    
    evtRetour.setCumulGainReprise(cumulGainReprise);
    evtRetour.setCumulNbHeuresReprise(cumulNbHeuresReprise);
    
    evtRetour.setCumulJourDeTravail(cumulNbJourTravail);
    
    evtRetour.setCumulGainPNDS(cumulGainPNDS);
    
    evtRetour.setRepriseMemeEmployeur(contientUnePeriodeARRepriseChezUnMemeEmployeur);
    
    evtRetour.setCumulGainICCPConserves(cumulGainICCPConserve);
    
    evtRetour.setCumulGainICCPRepris(cumulGainICCPRepris);
    
    evtRetour.setRacAns(gainPansConserveeAPrendreenComptePourNeutralisation);
    
    return evtRetour;
  }
}

/* Location:
 * Qualified Name:     ActiviteReduite
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */