package fr.unedic.cali.asu.cge01.p02.liquidation.dom;

import fr.unedic.cali.asu.cge01.p02.liquidation.dom.gen.ConditionChomageInvolontaireGen;
import fr.unedic.cali.asu.dom.ConditionChomageInvolontaireSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.PeriodeGaecSpec;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.ResultatElementDroit;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.cali.parcours.ContexteParcoursCali;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.temps.Damj;

public class ConditionChomageInvolontaire
  extends ConditionChomageInvolontaireGen
  implements ConditionChomageInvolontaireSpec
{
  private static final long serialVersionUID = 4070896845544034991L;
  public static final int SITUATION_MOTIF_FG_DV = 1;
  public static final int SITUATION_AUCUN_DV = 2;
  public static final int SITUATION_DV_AFFI_SUFFISANTE = 3;
  public static final int SITUATION_DV_AFFI_INSUFFISANTE = 4;
  public static final int SITUATION_MOTIF_FG_DV_LEGITIME = 5;
  private PeriodeGaecSpec activiteDv = null;
  
  public ConditionChomageInvolontaire() {}
  
  public ConditionChomageInvolontaire(DomPCSpec pc)
  {
    super(pc);
  }
  
  public ResultatElementDroit getResultatElementDroit()
  {
    if (super.getResultatElementDroit() == null) {
      super.setResultatElementDroit(new ResultatElementDroit());
    }
    return super.getResultatElementDroit();
  }
  
  public String toString()
  {
    StringBuffer sb = new StringBuffer();
    sb.append("ConditionChomageInvolontaire:");
    sb.append("\tEtat Condition Chomage Involontaire:");
    sb.append("\t");
    sb.append(getEtatConditionChomageInvolontaire());
    sb.append("\tSituation Condition Chomage Involontaire:");
    return sb.toString();
  }
  
  public boolean getEtatConditionChomageInvolontaire()
  {
    return estSatisfait();
  }
  
  public void setEtatConditionChomageInvolontaire(boolean etatConditionChomageInvolontaire)
  {
    setEtatSatisfait(etatConditionChomageInvolontaire);
  }
  
  public void marquerGraphePersistant() {}
  
  public boolean estSatisfait()
  {
    return getResultatElementDroit().estSatisfait();
  }
  
  public int getCodeMotifEchec()
  {
    return getResultatElementDroit().getCodeMotifEchec();
  }
  
  public void setCodeMotifEchec(int codeMotifEchec)
  {
    getResultatElementDroit().setCodeMotifEchec(codeMotifEchec);
  }
  
  public void setEtatSatisfait(boolean etatSatisfait)
  {
    getResultatElementDroit().setEtatSatisfait(etatSatisfait);
  }
  
  public ObjetMetierSpec copie()
  {
    ConditionChomageInvolontaire copie = new ConditionChomageInvolontaire();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec copie)
  {
    ConditionChomageInvolontaire copieCondition = (ConditionChomageInvolontaire)copie;
    copieCondition.setCodeMotifEchec(getCodeMotifEchec());
    copieCondition.setEtat(getEtat());
    copieCondition.setIdentifiantActivitePortantDV(getIdentifiantActivitePortantDV());
    copieCondition.setIntensiteHoraireSalarieAeDv(super.getIntensiteHoraireSalarieAeDv());
    copieCondition.setDureeAeDv(super.getDureeAeDv());
    copieCondition.setQuantiteAffiliationPrincipaleInopposabilite(super.getQuantiteAffiliationPrincipaleInopposabilite());
    copieCondition.setQuantiteAffiliationSecondaireInopposabilite(super.getQuantiteAffiliationSecondaireInopposabilite());
  }
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
  
  public void setEtat(int etat)
  {
    getResultatElementDroit().setEtat(etat);
  }
  
  public int getEtat()
  {
    return getResultatElementDroit().getEtat();
  }
  
  public Damj getDateFctAeDV()
  {
    Damj dateFCTDV = null;
    if (activiteDv == null)
    {
      if (getIdentifiantActivitePortantDV() != null)
      {
        Individu individuCourant = ContexteParcoursCali.getIndividuCourant();
        
        PeriodeGaecSpec activite = (ActiviteSalarie)individuCourant.rechercherPeriodePasseProfessionnel(getIdentifiantActivitePortantDV());
        activiteDv = activite;
        if (activite != null) {
          dateFCTDV = activite.getDateFin();
        }
      }
    }
    else {
      dateFCTDV = activiteDv.getDateFin();
    }
    return dateFCTDV;
  }
}

/* Location:
 * Qualified Name:     ConditionChomageInvolontaire
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */