package fr.unedic.cali.asu.cge01.p02.liquidation.dom;

import fr.unedic.cali.asu.cge01.p02.liquidation.dom.gen.ConditionFaitGenerateurGen;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.ResultatElementDroit;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.cali.parcours.ContexteParcoursCali;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.UniteAffiliation;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;

public class ConditionFaitGenerateur
  extends ConditionFaitGenerateurGen
  implements FaitGenerateurSpec
{
  private static final long serialVersionUID = 9087364812930778168L;
  private transient ActiviteSalarie m_periodeFaitGenerateur = null;
  
  public ConditionFaitGenerateur() {}
  
  public ConditionFaitGenerateur(DomPCSpec p_pc)
  {
    super(p_pc);
  }
  
  public ResultatElementDroit getResultatElementDroit()
  {
    if (super.getResultatElementDroit() == null) {
      super.setResultatElementDroit(new ResultatElementDroit());
    }
    return super.getResultatElementDroit();
  }
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
  
  public Damj getDateEffet()
  {
    return getDateFaitGenerateur();
  }
  
  public ActiviteSalarie getPeriodeFaitGenerateur()
  {
    if (m_periodeFaitGenerateur == null)
    {
      Individu individuCourant = ContexteParcoursCali.getIndividuCourant();
      
      m_periodeFaitGenerateur = ((ActiviteSalarie)individuCourant.rechercherPeriodePasseProfessionnel(getIdentifiantPeriodeFaitGenerateur()));
    }
    return m_periodeFaitGenerateur;
  }
  
  public void setPeriodeFaitGenerateur(ActiviteSalarie p_periodeFaitGenerateur)
  {
    m_periodeFaitGenerateur = p_periodeFaitGenerateur;
    if (p_periodeFaitGenerateur != null)
    {
      setIdentifiantPeriodeFaitGenerateur(p_periodeFaitGenerateur.getIdentifiant());
      setMotifFinPeriode(p_periodeFaitGenerateur.getMotifFin());
      setDateFaitGenerateur(p_periodeFaitGenerateur.getDateFin());
      setDateEngagementProcedure(p_periodeFaitGenerateur.getDateEngagementProcedureLicenciement());
    }
  }
  
  public String toString()
  {
    return m_periodeFaitGenerateur == null ? "null" : m_periodeFaitGenerateur.toString();
  }
  
  public boolean estSatisfait()
  {
    return getResultatElementDroit().estSatisfait();
  }
  
  public void setEtatSatisfait(boolean p_etatSatisfait)
  {
    getResultatElementDroit().setEtatSatisfait(p_etatSatisfait);
  }
  
  public int getCodeMotifEchec()
  {
    return getResultatElementDroit().getCodeMotifEchec();
  }
  
  public void setCodeMotifEchec(int p_codeMotifEchec)
  {
    getResultatElementDroit().setCodeMotifEchec(p_codeMotifEchec);
  }
  
  public void jdoPostLoad() {}
  
  public void jdoPreClear() {}
  
  public void jdoPreDelete() {}
  
  public void marquerGraphePersistant() {}
  
  public void jdoPreStore() {}
  
  public ObjetMetierSpec copie()
  {
    ConditionFaitGenerateur copie = new ConditionFaitGenerateur();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    ConditionFaitGenerateur copie = (ConditionFaitGenerateur)p_copie;
    
    copie.setDateEvenement(getDateEvenement());
    copie.setAgeIndividuDateFG(getAgeIndividuDateFG());
    copie.setDateFaitGenerateur(getDateFaitGenerateur());
    copie.setIdentifiantPeriodeFaitGenerateur(getIdentifiantPeriodeFaitGenerateur());
    copie.setMotifFinPeriode(getMotifFinPeriode());
    copie.setCodeMotifEchec(getCodeMotifEchec());
    copie.setEtat(getEtat());
    copie.setDateEngagementProcedure(getDateEngagementProcedure());
    copie.setRefusAdhesionFne(getRefusAdhesionFne());
  }
  
  public Damj getDateFaitGenerateur()
  {
    return super.getDateFG();
  }
  
  public void setDateFaitGenerateur(Damj p_dateFG)
  {
    super.setDateFG(p_dateFG);
  }
  
  public void setEtat(int p_etat)
  {
    getResultatElementDroit().setEtat(p_etat);
  }
  
  public int getEtat()
  {
    return getResultatElementDroit().getEtat();
  }
  
  public Quantite getNombreJoursFaitGenerateur()
  {
    if (getPeriodeFaitGenerateur() != null) {
      return new Quantite(getPeriodeFaitGenerateur().getDuree(), UniteAffiliation.JOUR);
    }
    return null;
  }
  
  public BigDecimal getRefusFne()
  {
    if ((getPeriodeFaitGenerateur() != null) && (getPeriodeFaitGenerateur().getContrat() != null)) {
      return getPeriodeFaitGenerateur().getContrat().getRefusFne();
    }
    return null;
  }
  
  public int getCodeBassinCtp()
  {
    return 0;
  }
}

/* Location:
 * Qualified Name:     ConditionFaitGenerateur
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */