package fr.unedic.cali.asu.cge01.p02.liquidation.dom;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.parametres.EvenementParametre;
import fr.unedic.cali.asu.parametres.ParametresIndemnisation;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Entreprise;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.List;

public class Prce
  extends ObjetChronoPeriode
  implements ObjetMetierSpec
{
  private static final long serialVersionUID = 1L;
  private Prc prc = null;
  private Hashtable<String, Chronologie> tableChronoPraeParEmployeur = null;
  
  public Prce() {}
  
  public Prce(Damj dateDebut, Damj dateFin)
  {
    super(dateDebut, dateFin);
  }
  
  public Prce(Periode periode)
  {
    super(periode);
  }
  
  protected void determinerChronoPraeParEmployeur()
  {
    Chronologie chronologiePraeParEmployeur = new ChronologiePeriodes();
    ActiviteSalarie periodeActiviteCourante = null;
    String identifiantEmployeurCourant = null;
    Periode periodePraeCourante = null;
    Prae praeCourante = null;
    
    tableChronoPraeParEmployeur = new Hashtable();
    
    Periode periodePrceCourante = new Periode(getDateDebut(), getDateFin());
    Chronologie chronoActivitesPrceCourante = getPrc().getChronoActiviteSalarie().copier(new FiltreChevauchePeriode(periodePrceCourante));
    
    chronoActivitesPrceCourante.iterer();
    while (chronoActivitesPrceCourante.encoreSuivant())
    {
      periodeActiviteCourante = (ActiviteSalarie)chronoActivitesPrceCourante.elementSuivant();
      
      identifiantEmployeurCourant = periodeActiviteCourante.getEntreprise().getIdentifiantBNE();
      
      periodePraeCourante = periodeIntersection(new Periode(periodeActiviteCourante.getDateDebut(), periodeActiviteCourante.getDateFin()));
      if (periodePraeCourante != null)
      {
        praeCourante = new Prae(periodePraeCourante);
        
        praeCourante.setPrce(this);
        
        praeCourante.setPeriodeActiviteSalarie(periodeActiviteCourante);
        if (tableChronoPraeParEmployeur.containsKey(identifiantEmployeurCourant))
        {
          chronologiePraeParEmployeur = (ChronologiePeriodes)tableChronoPraeParEmployeur.get(identifiantEmployeurCourant);
          chronologiePraeParEmployeur.ajouter(praeCourante);
        }
        else
        {
          chronologiePraeParEmployeur = new ChronologiePeriodes();
          chronologiePraeParEmployeur.ajouter(praeCourante);
          tableChronoPraeParEmployeur.put(identifiantEmployeurCourant, chronologiePraeParEmployeur);
        }
      }
    }
  }
  
  private ChronologiePeriodes determinerChronoPraeTousEmployeur()
  {
    ChronologiePeriodes chronoPraeTousEmployeurs = new ChronologiePeriodes();
    
    String identifiantEmployeurCourant = null;
    for (Enumeration<String> enumeration = tableChronoPraeParEmployeur.keys(); enumeration.hasMoreElements();)
    {
      identifiantEmployeurCourant = (String)enumeration.nextElement();
      chronoPraeTousEmployeurs.ajouter((ChronologiePeriodes)tableChronoPraeParEmployeur.get(identifiantEmployeurCourant));
    }
    return chronoPraeTousEmployeurs;
  }
  
  private BigDecimal getPpe(ChronologiePeriodes chronoPrae)
  {
    BigDecimal cumulPpe = BigDecimal.ZERO;
    ObjetChronoPeriode objetChronoPeriodeCourant = null;
    List<Periode> listePeriodesMoisCivils = null;
    Periode periodeMoisCivilCourant = null;
    Periode periodeMoisCivilEntier = null;
    BigDecimal plafondMensuelApplicable = BigDecimal.ZERO;
    
    Chronologie chronoPraeSansChevauchement = chronoPrae.fusionnerChevauchementPeriodes();
    
    ParametresIndemnisation parametresIndemnisation = ParametresIndemnisation.getParametresIndemnisation();
    
    chronoPraeSansChevauchement.iterer();
    while (chronoPraeSansChevauchement.encoreSuivant())
    {
      objetChronoPeriodeCourant = (ObjetChronoPeriode)chronoPraeSansChevauchement.elementSuivant();
      
      listePeriodesMoisCivils = objetChronoPeriodeCourant.decouperEnMoisCivils();
      for (int boucle = 0; boucle < listePeriodesMoisCivils.size(); boucle++)
      {
        periodeMoisCivilCourant = (Periode)listePeriodesMoisCivils.get(boucle);
        
        plafondMensuelApplicable = parametresIndemnisation.getElementActif(periodeMoisCivilCourant.getDebut()).getPlafond();
        if ((!periodeMoisCivilCourant.getDebut().estLeDebutDuMois()) || (!periodeMoisCivilCourant.getFin().estLaFinDuMois()))
        {
          BigDecimal nominateur1 = plafondMensuelApplicable;
          BigDecimal nominateur2 = new BigDecimal(String.valueOf(periodeMoisCivilCourant.getDuree()));
          periodeMoisCivilEntier = new Periode(periodeMoisCivilCourant.getDebut().getDebutMois(), periodeMoisCivilCourant.getDebut().getFinMois());
          
          BigDecimal denominateur = new BigDecimal(String.valueOf(periodeMoisCivilEntier.getDuree()));
          plafondMensuelApplicable = Mathematiques.proratiser(nominateur1, nominateur2, denominateur);
        }
        cumulPpe = cumulPpe.add(plafondMensuelApplicable);
      }
    }
    return Mathematiques.tronque(cumulPpe, 2);
  }
  
  public Prc getPrc()
  {
    return prc;
  }
  
  private BigDecimal getSre(Demande demande, Reglement reglementApplicable, JustificationPlafondsParExerciceEtEmployeur justificationPlafondsParExercice)
    throws CoucheLogiqueException
  {
    BigDecimal cumulSre = BigDecimal.ZERO;
    BigDecimal srpeeTheorique = null;
    BigDecimal cumulSraeParEmployeur = null;
    BigDecimal cumulPaeParEmployeur = null;
    
    String identifiantEmployeurCourant = null;
    ChronologiePeriodes chronoPraeParEmployeur = null;
    Prae praeCourante = null;
    JustificationPlafondsParEmployeur justificationPlafondsParEmployeurCourant = null;
    for (Enumeration<String> enumeration = tableChronoPraeParEmployeur.keys(); enumeration.hasMoreElements();)
    {
      identifiantEmployeurCourant = (String)enumeration.nextElement();
      chronoPraeParEmployeur = (ChronologiePeriodes)tableChronoPraeParEmployeur.get(identifiantEmployeurCourant);
      
      justificationPlafondsParEmployeurCourant = new JustificationPlafondsParEmployeur();
      justificationPlafondsParExercice.getListePlafondsParEmployeur().add(justificationPlafondsParEmployeurCourant);
      
      cumulSraeParEmployeur = BigDecimal.ZERO;
      cumulPaeParEmployeur = BigDecimal.ZERO;
      chronoPraeParEmployeur.iterer();
      while (chronoPraeParEmployeur.encoreSuivant())
      {
        praeCourante = (Prae)chronoPraeParEmployeur.elementSuivant();
        cumulSraeParEmployeur = cumulSraeParEmployeur.add(praeCourante.getSrae(demande, reglementApplicable));
        cumulPaeParEmployeur = cumulPaeParEmployeur.add(praeCourante.getPae(justificationPlafondsParEmployeurCourant));
      }
      if (cumulPaeParEmployeur.compareTo(BigDecimal.ZERO) == 0) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_SC_L_ES_ED_CDR09_CDR10_CUMUL_PAE_EMPLOYEUR", new Object[] { praeCourante.getPeriodeActiviteSalarie().getDateFin() }, 2);
      }
      srpeeTheorique = cumulSraeParEmployeur.min(cumulPaeParEmployeur);
      
      cumulSre = cumulSre.add(srpeeTheorique);
      
      justificationPlafondsParEmployeurCourant.setRaisonSociale(praeCourante.getPeriodeActiviteSalarie().getEntreprise().getLibelleEntreprise());
      justificationPlafondsParEmployeurCourant.setSrNonPlafonne(cumulSraeParEmployeur);
      justificationPlafondsParEmployeurCourant.setPlafond(cumulPaeParEmployeur);
      justificationPlafondsParEmployeurCourant.setSrPlafonne(srpeeTheorique);
    }
    return cumulSre;
  }
  
  public BigDecimal getSrpe(Demande demande, Reglement reglementApplicable)
    throws CoucheLogiqueException
  {
    BigDecimal valeurSrpe = BigDecimal.ZERO;
    
    JustificationPlafonds justificationPlafondsSjrCourant = getPrc().recupererJustificationSjr(demande).getJustificationPlafonds();
    
    JustificationPlafondsParExerciceEtEmployeur justificationPlafondsParExerciceCourant = new JustificationPlafondsParExerciceEtEmployeur();
    justificationPlafondsParExerciceCourant.setExercice(Integer.toString(getDateDebut().getAnnee()));
    justificationPlafondsSjrCourant.getListePlafondsParExerciceEtEmployeur().add(justificationPlafondsParExerciceCourant);
    
    determinerChronoPraeParEmployeur();
    
    BigDecimal sreCourant = getSre(demande, reglementApplicable, justificationPlafondsParExerciceCourant);
    
    justificationPlafondsParExerciceCourant.setSommeSrPlafonne(sreCourant);
    
    ChronologiePeriodes chronoPraeCourante = determinerChronoPraeTousEmployeur();
    if (chronoPraeCourante.contientChevauchementElements())
    {
      BigDecimal ppeCourant = getPpe(chronoPraeCourante);
      if (ppeCourant.compareTo(BigDecimal.ZERO) == 0) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_SC_L_ES_ED_CDR09_CDR10_INCOHERENCE_PPE", 2);
      }
      justificationPlafondsParExerciceCourant.setPlafondParExercice(ppeCourant);
      
      valeurSrpe = sreCourant.min(ppeCourant);
    }
    else
    {
      valeurSrpe = sreCourant;
    }
    justificationPlafondsParExerciceCourant.setSrPlafonneParExercice(valeurSrpe);
    
    return valeurSrpe;
  }
  
  public void setPrc(Prc pPrc)
  {
    prc = pPrc;
  }
  
  public ObjetMetierSpec copie()
  {
    Prce copie = new Prce();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec copieSpec)
  {
    Prce copie = (Prce)copieSpec;
    copie.setPrc((Prc)getPrc().copie());
    copie.setDateDebut(getDateDebut());
    copie.setDateFin(getDateFin());
    copie.determinerChronoPraeParEmployeur();
  }
}

/* Location:
 * Qualified Name:     Prce
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */