package fr.unedic.cali.asu.cge01.p02.liquidation.dom.gen;

import fr.unedic.archi.commun.exception.TechniqueException;
import fr.unedic.archi.commun.lang.ExceptionUtil;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DureeReglementaire;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.pc.ConstitutionDureesPC;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.transverse.dom.ContexteSuppressionEnProfondeur;
import fr.unedic.transverse.dom.spec.DomGenSpec;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;

public abstract class ConstitutionDureesGen
  implements DomGenSpec
{
  protected transient DomPCSpec m_constitutionDureesPC;
  private Collection m_listeDurees;
  
  public ConstitutionDureesGen(DomPCSpec p_pc)
  {
    setPC(p_pc);
  }
  
  public ConstitutionDureesGen()
  {
    setPC(createPC());
  }
  
  protected DomPCSpec createPC()
  {
    return new ConstitutionDureesPC();
  }
  
  public DomPCSpec getPC()
  {
    return m_constitutionDureesPC;
  }
  
  public Object getGenericPC()
  {
    return getPC();
  }
  
  public void setPC(DomPCSpec p_constitutionDureesPC)
  {
    m_constitutionDureesPC = p_constitutionDureesPC;
  }
  
  private final Collection getCollectionModifiableDuree()
  {
    Iterator itCollectionPC;
    if (m_listeDurees == null)
    {
      m_listeDurees = new ArrayList();
      for (itCollectionPC = ((ConstitutionDureesPC)getPC()).getCollectionDuree().iterator(); itCollectionPC.hasNext();)
      {
        DomPCSpec currentPC = (DomPCSpec)itCollectionPC.next();
        Object currentOM = currentPC.createOM();
        m_listeDurees.add(currentOM);
      }
    }
    return m_listeDurees;
  }
  
  public Collection getCollectionDuree()
  {
    return Collections.unmodifiableCollection(getCollectionModifiableDuree());
  }
  
  public List getListDuree()
  {
    return Collections.unmodifiableList((List)getCollectionModifiableDuree());
  }
  
  public void remplacerCollectionDuree(Collection p_collectionACopier)
  {
    clearCollectionDuree();
    for (Iterator i = p_collectionACopier.iterator(); i.hasNext();)
    {
      DureeReglementaire objet = (DureeReglementaire)i.next();
      ajouterDuree(objet);
    }
  }
  
  public void supprimerSousCollectionDuree(Collection p_collectionASupprimer)
  {
    for (Iterator i = p_collectionASupprimer.iterator(); i.hasNext();)
    {
      DureeReglementaire objet = (DureeReglementaire)i.next();
      supprimerDuree(objet);
    }
  }
  
  public void ajouterDuree(DureeReglementaire p_durees)
    throws NullPointerException
  {
    if (p_durees == null) {
      ExceptionUtil.assertInternalNotNull("Le paramètre p_durees ne devrait pas être nul.", p_durees);
    }
    getCollectionModifiableDuree().add(p_durees);
    ((ConstitutionDureesPC)getPC()).ajouterDuree(p_durees.getPC());
  }
  
  public void supprimerDuree(DureeReglementaire p_durees)
    throws NullPointerException
  {
    if (p_durees == null) {
      ExceptionUtil.assertInternalNotNull("Le paramètre p_durees ne devrait pas être nul.", p_durees);
    }
    getCollectionModifiableDuree().remove(p_durees);
    ((ConstitutionDureesPC)getPC()).supprimerDuree(p_durees.getPC());
  }
  
  public void recopierCollectionDureeVers(ObjetMetierSpec p_copie)
  {
    ConstitutionDureesGen copie = (ConstitutionDureesGen)p_copie;
    Collection listeACopier = getCollectionDuree();
    for (Iterator i = listeACopier.iterator(); i.hasNext();)
    {
      ObjetMetierSpec objet = ((ObjetMetierSpec)i.next()).copie();
      copie.ajouterDuree((DureeReglementaire)objet);
    }
  }
  
  public void clearCollectionDuree()
  {
    getCollectionModifiableDuree().clear();
    ((ConstitutionDureesPC)getPC()).getCollectionDuree().clear();
  }
  
  public void supprimerEnProfondeur(ContexteSuppressionEnProfondeur p_contexteSuppression)
    throws TechniqueException
  {
    p_contexteSuppression.addElementEnCoursDeSuppression(this);
    for (Iterator iter = getCollectionDuree().iterator(); iter.hasNext();)
    {
      DomGenSpec item = (DomGenSpec)iter.next();
      if ((item != null) && (!p_contexteSuppression.isAlreadyEnlistedForDeletion(item))) {
        DomManager.supprimer(item, p_contexteSuppression);
      }
    }
  }
  
  public void copieElements(ObjetMetierSpec p_copie) {}
}

/* Location:
 * Qualified Name:     ConstitutionDureesGen
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */