package fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels.strategies;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.dom.ResultatRechercheConditionChomageInvolontaire;
import fr.unedic.cali.asu.cge01.liquidation.outilsaffiliation.strategies.spec.StrategieConditionChomageInvolontaireAre14Spec;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.ErePassageCPSuiteRejetDV;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.ResultatElementDroit;
import fr.unedic.cali.dom.affectation.ProduitAsuCge01P02;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.ComparateurTemporelSurDateFinDecroissante;
import fr.unedic.cali.outilsfonctionnels.DetectionTypeChomage;
import fr.unedic.cali.outilsfonctionnels.OutilChronologie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieeMotifDvNonLegitime;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteNonSalarieePeriodique;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesAttestees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesAvecConflit;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesJustifiees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesLiquidables;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesSurFiltresExclusifs;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreTravailSpec;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreFinDansBornes;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import fr.unedic.util.temps.Temporel;
import java.util.ListIterator;

public class StrategieConditionChomageInvolontaireAre14Avant
  implements StrategieConditionChomageInvolontaireAre14Spec
{
  public ResultatRechercheConditionChomageInvolontaire rechercheConditionChomageInvolontairePourOd(Demande p_demande)
    throws ApplicativeException
  {
    boolean conditionForcee = false;
    ResultatRechercheConditionChomageInvolontaire resultat = initialiserResultat();
    if (p_demande.getDonneesTemporaires() != null) {
      conditionForcee = p_demande.getDonneesTemporaires().isConditionChomageInvolontaireSatistaite();
    }
    if (conditionForcee)
    {
      resultat.getResultatElementDroit().setEtatSatisfait(true);
      resultat.setSituationConditionChomageInvolontaire(3);
    }
    else if ((p_demande.getEvenementReferenceExamen() instanceof ErePassageCPSuiteRejetDV))
    {
      resultat = fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels.RechercheConditionChomageInvolontaire.verifierChomageInvolontaireExamen122Jour(p_demande);
    }
    else
    {
      DossierExamen dossierExamen = (DossierExamen)p_demande.getDossierExamen();
      FaitGenerateurSpec faitGenerateur = dossierExamen.getFaitGenerateur();
      
      int codeMotifFin = faitGenerateur.getPeriodeFaitGenerateur().getCodeMotifFin();
      int contexteDemisison = faitGenerateur.getPeriodeFaitGenerateur().getContrat().getContexteDemission();
      if (!DetectionTypeChomage.estChomageLegitime(codeMotifFin, contexteDemisison))
      {
        resultat.setSituationConditionChomageInvolontaire(1);
        resultat.getResultatElementDroit().setEtatSatisfait(false);
        resultat.getResultatElementDroit().setCodeMotifEchec(91);
      }
      else
      {
        Reglement reglementApplicableCourant = ((DossierAffectation)p_demande.getDossierAffectation()).getReglementPeriodeValidationProduit();
        
        reglementApplicableCourant = fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels.RechercheConditionChomageInvolontaire.verificationReglementNonNull(reglementApplicableCourant, p_demande.getDossierAffectationAdmission().getJustificationAffectation());
        if (reglementApplicableCourant != null) {
          if (reglementApplicableCourant.equals(ProduitAsuCge01P02.getInstance().getReglement("A3")))
          {
            resultat.setSituationConditionChomageInvolontaire(2);
            resultat.getResultatElementDroit().setEtatSatisfait(true);
          }
          else
          {
            Damj dateDebutRechercheDV = Damj.NUIT_DES_TEMPS;
            
            Damj dateFinRechercheDV = faitGenerateur.getDateFaitGenerateur();
            
            Damj dateFGOdPrec = p_demande.getDateFaitGenerateurOdPrecedente();
            if (dateFGOdPrec != null) {
              dateDebutRechercheDV = dateFGOdPrec.lendemain();
            }
            Chronologie chronoToutesPeriodes = p_demande.getDemandeur().getChronoPeriodePasseProfessionnelPourLiquidationSansFiltrageDNJ();
            
            FiltresTemporel filtreChevauchePeriodeEtActiviteSalarie = new FiltresTemporel();
            filtreChevauchePeriodeEtActiviteSalarie.ajouterFiltre(new FiltreFinDansBornes(new Periode(dateDebutRechercheDV, dateFinRechercheDV)));
            
            filtreChevauchePeriodeEtActiviteSalarie.ajouterFiltre(new FiltreTravailSpec());
            Chronologie chronoDansDelaiRecherche = chronoToutesPeriodes.copier(filtreChevauchePeriodeEtActiviteSalarie);
            
            OutilChronologie.supprimerPeriodeParIdentifiant(chronoDansDelaiRecherche, faitGenerateur.getPeriodeFaitGenerateur());
            
            FiltrePeriodesSurFiltresExclusifs listeFiltres = new FiltrePeriodesSurFiltresExclusifs();
            
            FiltrePeriodesSurFiltresExclusifs filtreASupprimer = new FiltrePeriodesSurFiltresExclusifs();
            filtreASupprimer.ajouterFiltre(new FiltrePeriodeActiviteNonSalarieePeriodique());
            filtreASupprimer.ajouterFiltre(new FiltrePeriodesLiquidables(false));
            Chronologie chronoPans = chronoDansDelaiRecherche.copier(filtreASupprimer);
            if (!chronoPans.estVide())
            {
              ListIterator pans = chronoPans.iterer();
              while (pans.hasNext()) {
                chronoDansDelaiRecherche.supprimer((Temporel)pans.next());
              }
            }
            listeFiltres.ajouterFiltre(new FiltrePeriodesAttestees(false));
            
            listeFiltres.ajouterFiltre(new FiltrePeriodesJustifiees(false));
            
            listeFiltres.ajouterFiltre(new FiltrePeriodesAvecConflit());
            
            listeFiltres.ajouterFiltre(new FiltreActiviteSalarieeMotifDvNonLegitime());
            
            Chronologie chronoFiltreeDansDelaiRecherche = chronoDansDelaiRecherche.copier(listeFiltres);
            if (chronoFiltreeDansDelaiRecherche.estVide())
            {
              resultat.setSituationConditionChomageInvolontaire(2);
              resultat.getResultatElementDroit().setEtatSatisfait(true);
            }
            else
            {
              chronoFiltreeDansDelaiRecherche.setComparateur(new ComparateurTemporelSurDateFinDecroissante());
              TravailSpec dernierePeriode = (TravailSpec)chronoFiltreeDansDelaiRecherche.premierElement();
              
              resultat = fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels.RechercheConditionChomageInvolontaire.rechercherConditionChomageInvolontaire(p_demande, dernierePeriode.getDateFin(), reglementApplicableCourant);
              
              boolean estContexteChomageNonLegitime = ((dernierePeriode instanceof ActiviteSalarie)) && (((ActiviteSalarie)dernierePeriode).getCodeMotifFin() == 19);
              if (estContexteChomageNonLegitime) {
                return resultat;
              }
              if (!resultat.getResultatElementDroit().estSatisfait()) {
                fr.unedic.cali.asu.liquidation.outilsfonctionnels.RechercheConditionChomageInvolontaire.getInstance().verifierConditionChomageInvolontaireVerifiable(dernierePeriode);
              }
            }
          }
        }
      }
    }
    return resultat;
  }
  
  public ResultatRechercheConditionChomageInvolontaire rechercheConditionChomageInvolontairePourReprise(Demande demande)
    throws ApplicativeException
  {
    ResultatRechercheConditionChomageInvolontaire resultat = initialiserResultat();
    if (demande.getFormulaire().getPresenceAe().equalsIgnoreCase("I"))
    {
      resultat.getResultatElementDroit().setEtatSatisfait(true);
      resultat.setSituationConditionChomageInvolontaire(2);
    }
    else
    {
      Reglement reglementApplicableCourant = ((DossierAffectation)demande.getDossierAffectation()).getReglementPeriodeValidationProduit();
      if (reglementApplicableCourant == null)
      {
        AttributionAssuranceSpec odAttributionPrecedente = demande.rechercherOuvertureDroitPrecedenteDuMemeType();
        reglementApplicableCourant = odAttributionPrecedente.getReglementApplicable().getReglement();
      }
      fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels.RechercheConditionChomageInvolontaire.traiterSituation1(demande, reglementApplicableCourant, resultat);
      if (!resultat.getResultatElementDroit().estSatisfait()) {
        fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels.RechercheConditionChomageInvolontaire.traiterSituation2(demande, reglementApplicableCourant, resultat);
      }
    }
    return resultat;
  }
  
  private ResultatRechercheConditionChomageInvolontaire initialiserResultat()
  {
    ResultatRechercheConditionChomageInvolontaire resultatRechercheConditionChomageInvolontaire = new ResultatRechercheConditionChomageInvolontaire();
    ResultatElementDroit resultatElementDroit = new ResultatElementDroit();
    resultatRechercheConditionChomageInvolontaire.setResultatElementDroit(resultatElementDroit);
    return resultatRechercheConditionChomageInvolontaire;
  }
}

/* Location:
 * Qualified Name:     StrategieConditionChomageInvolontaireAre14Avant
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */