package fr.unedic.cali.asu.cge01.p02.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionCaractereSaisonnier;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels.ConstructionChronologie;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.parametres.AccesListeUnitesReglement;
import fr.unedic.cali.asu.parametres.ValeurListeUnitesReglement;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.QuantitesAppartenance;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.DomLiquidationDemande;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.Convertisseur;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Iterator;

public class ConstitutionCoefficientSaisonnier
  extends ParcoursCali
  implements ParcoursAssurance
{
  private static final int UN_AN = 365;
  public static final Unite JOUR = Unite.get("jour d'affiliation");
  public static final Unite HEURE = Unite.get("heure de travail");
  private BigDecimal m_coefficientSaisonnier = new BigDecimal("1");
  private boolean m_coefficientSaisonnierDetermine = false;
  
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    if (getDemande(p_contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null pour la constitution du coefficient saisonnier.");
    }
  }
  
  public Resultat demarrer(Contexte p_contexte)
    throws ApplicativeException
  {
    OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "\t\t******** Début Parcours ConstitutionCoefficientSaisonnier ********" });
    Resultat resultatCEPA12 = new Resultat(0);
    
    Demande demande = DomLiquidationAssurance.getDemande(p_contexte);
    
    DossierExamen dossierExamenCourant = (DossierExamen)demande.getDossierExamen();
    Damj dateFCT = dossierExamenCourant.getFaitGenerateur().getDateFaitGenerateur();
    
    DonneesTemporaires donneestemporaires = demande.getDonneesTemporaires();
    
    Quantite affiEnJour = null;
    if (!dossierExamenCourant.getConstitutionCaractereSaisonnier().getCaractereSaisonnierRetenu()) {
      m_coefficientSaisonnierDetermine = true;
    }
    if ((!m_coefficientSaisonnierDetermine) && 
      (donneestemporaires.getCoefficientSaisonnier() != null))
    {
      m_coefficientSaisonnierDetermine = true;
      m_coefficientSaisonnier = donneestemporaires.getCoefficientSaisonnier();
    }
    if (!m_coefficientSaisonnierDetermine)
    {
      DureeCalendaire unAn = new DureeCalendaire(0, 0, 365);
      Damj departPrs = dateFCT.deplacerVersArriere(unAn);
      Periode prs = new Periode(departPrs, dateFCT);
      
      Chronologie chronoActivitesPrs = ConstructionChronologie.determinerChronoActivitesPrs(demande, prs);
      Reglement reglementApplicable = dossierExamenCourant.getReglementApplicable().getReglement();
      
      QuantitesAppartenance listeAffiSaisonniere = fr.unedic.cali.asu.cge01.p02.liquidation.outilsaffiliation.CalculAppartenance.getInstance().calculer(demande, null, prs, chronoActivitesPrs, reglementApplicable);
      
      ProduitAsuSpec produitAffecte = (ProduitAsuSpec)dossierExamenCourant.getDossierAffecte().getProduit();
      Convertisseur convertisseurUniteAffiliation = produitAffecte.determinerConvertisseurUniteAffiliation();
      
      affiEnJour = determinerAffiliationJour(listeAffiSaisonniere, reglementApplicable, convertisseurUniteAffiliation);
      
      int nbApresVirgule = 4;
      Quantite coefficientSaisonnier = affiEnJour.diviserPar(new Quantite(365, JOUR), 4);
      m_coefficientSaisonnier = coefficientSaisonnier.getValeur();
    }
    if (m_coefficientSaisonnier != null)
    {
      if (m_coefficientSaisonnier.compareTo(new BigDecimal("1")) == 1) {
        m_coefficientSaisonnier = new BigDecimal("1");
      }
      if (((m_coefficientSaisonnier.compareTo(new BigDecimal("0.005")) == 1) || (m_coefficientSaisonnier.compareTo(new BigDecimal("0.005")) == 0)) && (m_coefficientSaisonnier.compareTo(new BigDecimal("0.01")) == -1)) {
        m_coefficientSaisonnier = new BigDecimal("0.01");
      }
      if (((m_coefficientSaisonnier.compareTo(new BigDecimal("0")) == 1) || (m_coefficientSaisonnier.compareTo(new BigDecimal("0")) == 0)) && (m_coefficientSaisonnier.compareTo(new BigDecimal("0.005")) == -1)) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB19");
      }
    }
    m_coefficientSaisonnier = m_coefficientSaisonnier.setScale(2, 1);
    
    fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionCoefficientSaisonnier cepa12 = new fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionCoefficientSaisonnier();
    cepa12.setCoefficientSaisonnierRetenu(m_coefficientSaisonnier);
    cepa12.setJourActiviteDouzeDerniersMois(affiEnJour);
    
    dossierExamenCourant.setConstitutionCoefficientSaisonnier(cepa12);
    OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "\t\t******** Résultat Parcours ConstitutionCoefficientSaisonnier ********\n", resultatCEPA12 });
    OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "\t\t******** Fin Parcours ConstitutionCoefficientSaisonnier ********\n" });
    return resultatCEPA12;
  }
  
  private DemandeSpec getDemande(Contexte p_contexte)
  {
    return ((DomLiquidationDemande)p_contexte.getDonnees()).getDemandeSpec();
  }
  
  private Quantite determinerAffiliationJour(QuantitesAppartenance p_listeAffiSaisonniere, Reglement p_reglement, Convertisseur p_convertisseurUniteAffiliation)
  {
    Quantite affiSaisonnierJourTable = p_listeAffiSaisonniere.getQuantiteAffiliation(JOUR);
    if (affiSaisonnierJourTable == null)
    {
      Iterator iterUniteAffiliation = AccesListeUnitesReglement.get(p_reglement, null).getListeUnites().iterator();
      do
      {
        Unite unite = (Unite)iterUniteAffiliation.next();
        affiSaisonnierJourTable = p_listeAffiSaisonniere.getQuantiteAffiliation(unite);
        if (affiSaisonnierJourTable != null) {
          affiSaisonnierJourTable = p_convertisseurUniteAffiliation.convertir(affiSaisonnierJourTable, JOUR);
        }
      } while ((affiSaisonnierJourTable == null) && (iterUniteAffiliation.hasNext()));
    }
    Quantite affiSaisonnierJour = new Quantite(affiSaisonnierJourTable.getValeurEntiere(), affiSaisonnierJourTable.getUnite());
    return affiSaisonnierJour;
  }
}

/* Location:
 * Qualified Name:     ConstitutionCoefficientSaisonnier
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */