package fr.unedic.cali.asu.cge01.p02.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DureeReglementaire;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DureeRenouvellement;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.Reliquat;
import fr.unedic.cali.asu.outilsfonctionnels.ConstitutionDuree;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Damj;

public class ConstitutionDureePourReprise
  extends ParcoursCali
  implements ParcoursAssurance
{
  public void controlerContexte(Contexte contexte)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null: constitution du Sjc impossible.");
    }
    DossierExamen dossierExamenCourant = (DossierExamen)DomLiquidationAssurance.getDemande(contexte).getDossierExamen();
    if (dossierExamenCourant == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_OD", "L'attribution courante est null: constitution du Sjc impossible.");
    }
    if ((DomLiquidationAssurance.getDemande(contexte).getReliquat() == null) || (!DomLiquidationAssurance.getDemande(contexte).getReliquat().estReliquatValide()) || (((DomLiquidationAssurance)contexte.getDonnees()).getContexteExamen() != 3)) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CONTEXTE", "Pas de reliquat pour cette demande d'assurance.");
    }
  }
  
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    if (Log.isTraceActive(ConstitutionDureePourReprise.class, Niveau.DEBUG))
    {
      Log.ecritTrace(Niveau.DEBUG, ConstitutionDureePourReprise.class, "demarrer", "");
      Log.ecritTrace(Niveau.DEBUG, ConstitutionDureePourReprise.class, "demarrer", "\t\t******** Début Parcours ConstitutionDureePourReprise ********\n");
    }
    Demande demande = DomLiquidationAssurance.getDemande(contexte);
    
    DossierExamen dossierExamen = (DossierExamen)demande.getDossierExamen();
    
    ConstitutionDurees constitutionDurees = new ConstitutionDurees();
    dossierExamen.setConstitutionDurees(constitutionDurees);
    
    Quantite quantiteReliquat = demande.getReliquat().getQuantiteReliquat();
    DureeIndemnisation dureeIndemnisation = null;
    
    Quantite qteDureeImputationImposee = null;
    if (demande.getDonneesTemporaires().getNbJourImputer() != null) {
      qteDureeImputationImposee = new Quantite(demande.getDonneesTemporaires().getNbJourImputer(), DureeReglementaire.UNITE_DEFAUT);
    } else {
      qteDureeImputationImposee = new Quantite(0, DureeReglementaire.UNITE_DEFAUT);
    }
    int dureeTheoriqueDroitCourant = quantiteReliquat.getValeurEntiere();
    Quantite qteDureeTheorique = new Quantite(dureeTheoriqueDroitCourant - qteDureeImputationImposee.getValeurEntiere(), DureeReglementaire.UNITE_DEFAUT);
    
    Quantite qteDureeImputation = demande.getReliquat().getQuantiteImputee();
    
    dureeIndemnisation = getDureeIndemnisation();
    dureeIndemnisation.setDureeTheorique(qteDureeTheorique);
    dureeIndemnisation.setDureeImputation(qteDureeImputation);
    dureeIndemnisation.setDureeEffective(calculerDureeEffective(getIndividu(contexte), dossierExamen.getDateAttribution(), qteDureeTheorique, demande));
    
    dossierExamen.getConstitutionDurees().ajouterDuree(dureeIndemnisation);
    
    int dureeIndemnisationTheorique = dureeIndemnisation.getDureeTheorique().getValeurEntiere();
    if ((dureeIndemnisationTheorique > 213) && (demande.getReliquat().getQuantiteReliquatRenouvellement() != null))
    {
      DureeRenouvellement dureeRenouvellement = new DureeRenouvellement();
      dureeRenouvellement.setDureeEffective(demande.getReliquat().getQuantiteReliquatRenouvellement());
      dossierExamen.getConstitutionDurees().ajouterDuree(dureeRenouvellement);
    }
    if (Log.isTraceActive(ConstitutionDureePourReprise.class, Niveau.DEBUG))
    {
      Log.ecritTrace(Niveau.DEBUG, ConstitutionDureePourReprise.class, "demarrer", "");
      Log.ecritTrace(Niveau.DEBUG, ConstitutionDureePourReprise.class, "demarrer", "\t\t******** Fin Parcours ConstitutionDureePourReprise ********\n");
    }
    return new Resultat();
  }
  
  private static Quantite calculerDureeEffective(IndividuSpec individu, Damj pointDeDepart, Quantite qteTheorique, Demande demande)
    throws CoucheLogiqueException
  {
    return new Quantite(ConstitutionDuree.calculerDureeEffective(individu, pointDeDepart, qteTheorique, ConstitutionDuree.bornageALaRetraiteApplicablePourReprise(demande)), DureeReglementaire.UNITE_DEFAUT);
  }
  
  protected DureeIndemnisation getDureeIndemnisation()
  {
    return new DureeIndemnisation();
  }
}

/* Location:
 * Qualified Name:     ConstitutionDureePourReprise
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */