package fr.unedic.cali.asu.cge01.p02.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.ConstructionChronologie;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.OutilGestionActivitesConservees;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieActiviteConserveeConvention2014Spec;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConditionActiviteConservee;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionSjc;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.Prc;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.Sjcip;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.SjrActiviteConservee;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.Sjrip;
import fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels.RechercheConditionCumulActiviteConservee;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteNonSalariee;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesAttestees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesCertifiees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesJustifiees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesQualifiables;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesSurFiltresExclusifs;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import fr.unedic.util.temps.Temporel;

public class DeterminationConditionCumulActiviteConservee
  extends ParcoursCali
  implements ParcoursAssurance
{
  private static final QuantiteEuro QUANTITE_EURO_ZERO = new QuantiteEuro("0");
  
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(p_contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null: determination condition de cumul avec une activite conservee impossible.");
    }
    DossierExamen dossierExamenCourant = (DossierExamen)DomLiquidationAssurance.getDemande(p_contexte).getDossierExamen();
    if (dossierExamenCourant == null) {
      throw new ContexteException("ASU_PR_CALI_L_CONTEXTE_ABSENCE_DOSSIER_EXAMEN", "Le dossier examen courant est null: determination condition de cumul avec une activite conservee impossible.");
    }
    if ((dossierExamenCourant.getConstitutionSjr() == null) || (dossierExamenCourant.getConstitutionSjr().getSjrip() == null)) {
      throw new ContexteException("ASU_SC_L_ES_ED_CONTEXTE_ABSENCE_SJRIP", "Le Sjrip est null: determination condition de cumul avec une activite conservee impossible.");
    }
  }
  
  public Resultat demarrer(Contexte p_contexte)
    throws ApplicativeException
  {
    if (Log.isTraceActive(DeterminationConditionCumulActiviteConservee.class, Niveau.DEBUG))
    {
      Log.ecritTrace(Niveau.DEBUG, DeterminationConditionCumulActiviteConservee.class, "demarrer", "");
      Log.ecritTrace(Niveau.DEBUG, DeterminationConditionCumulActiviteConservee.class, "demarrer", "\t\t******** Début Parcours DeterminationConditionCumulActiviteConservee ********\n");
    }
    Resultat resultatCAPA12 = new Resultat(1);
    
    Demande demandeCourante = DomLiquidationAssurance.getDemande(p_contexte);
    DossierExamen dossierExamenCourant = (DossierExamen)demandeCourante.getDossierExamen();
    ProduitSpec produit = ((DossierAffectation)demandeCourante.getDossierAffectation()).getProduit();
    Reglement reglementApplicableCourant = dossierExamenCourant.getReglementApplicable().getReglement();
    boolean estReglementApplicableA4 = reglementApplicableCourant.equals(produit.getReglement("A4"));
    
    StrategieActiviteConserveeConvention2014Spec strategieActiviteConservee = OutilGestionActivitesConservees.getInstance().recupererStrategieActiviteConserveeConvention2014(demandeCourante);
    
    ConditionActiviteConservee conditionActiviteConservee = new ConditionActiviteConservee();
    if ((estReglementApplicableA4) && (!strategieActiviteConservee.traiterActivitesConserveesA4()))
    {
      conditionActiviteConservee.setEtatSatisfait(true);
    }
    else
    {
      Periode periodePrc = recupererPeriodePrc(demandeCourante);
      Chronologie chronoGlobaleActivitesConservees = strategieActiviteConservee.recupererChronoActivitesConservees(demandeCourante, periodePrc);
      if ((estReglementApplicableA4) || (strategieActiviteConservee.persisterListeActivitesConserveesCapa12())) {
        mettreAJourDomListeActivitesConservees(dossierExamenCourant, chronoGlobaleActivitesConservees, periodePrc.getFin());
      }
      leverAlerteA11MB7SurOriginePasConservee(chronoGlobaleActivitesConservees);
      
      Chronologie chronoActivitesSalarieesConservees = ConstructionChronologie.determinerChronoActivitesSalarieesConservees(demandeCourante);
      
      conditionActiviteConservee = RechercheConditionCumulActiviteConservee.rechercherConditionCumulActiviteConservee(demandeCourante, chronoActivitesSalarieesConservees);
      if (demandeCourante.getDonneesTemporaires().isConditionCumulActiviteConserveeRemplie()) {
        if (chronoGlobaleActivitesConservees.estVide()) {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_L_CAPA12_REMPLIE_FORCEE_A_TORT");
        }
      }
    }
    if (conditionActiviteConservee.estSatisfait())
    {
      resultatCAPA12.setEtat(0);
    }
    else
    {
      resultatCAPA12.setEtat(1);
      resultatCAPA12.setMessageErreur(Integer.toString(conditionActiviteConservee.getCodeMotifEchec()));
    }
    dossierExamenCourant.setConditionActiviteConservee(conditionActiviteConservee);
    if (Log.isTraceActive(DeterminationConditionCumulActiviteConservee.class, Niveau.DEBUG))
    {
      Log.ecritTrace(Niveau.DEBUG, DeterminationConditionCumulActiviteConservee.class, "demarrer", "");
      Log.ecritTrace(Niveau.DEBUG, DeterminationConditionCumulActiviteConservee.class, "demarrer", "\t\t******** Résultat Parcours DeterminationConditionCumulActiviteConservee ********\n" + resultatCAPA12);
      
      Log.ecritTrace(Niveau.DEBUG, DeterminationConditionCumulActiviteConservee.class, "demarrer", "");
      Log.ecritTrace(Niveau.DEBUG, DeterminationConditionCumulActiviteConservee.class, "demarrer", "\t\t******** Fin Parcours DeterminationConditionCumulActiviteConservee ********\n");
    }
    return resultatCAPA12;
  }
  
  public static void leverAlerteA11MB7SurOriginePasConservee(Chronologie p_chronoGlobaleActivitesConservees)
    throws CoucheLogiqueException
  {
    FiltrePeriodesSurFiltresExclusifs filtreExclusif = new FiltrePeriodesSurFiltresExclusifs();
    Chronologie chronoActivitesSalarieesConserveesFiltrees = null;
    Chronologie chronoActivitesNonSalarieesConserveesFiltrees = null;
    
    filtreExclusif.ajouterFiltre(new FiltrePeriodesJustifiees(false));
    
    FiltresTemporel filtreCertifieeNonQualifiee = new FiltresTemporel();
    filtreCertifieeNonQualifiee.ajouterFiltre(new FiltreActiviteSalarie());
    filtreCertifieeNonQualifiee.ajouterFiltre(new FiltrePeriodesCertifiees());
    filtreCertifieeNonQualifiee.ajouterFiltre(new FiltrePeriodesQualifiables(false));
    filtreExclusif.ajouterFiltre(filtreCertifieeNonQualifiee);
    
    chronoActivitesSalarieesConserveesFiltrees = p_chronoGlobaleActivitesConservees.copier(filtreExclusif);
    if (!chronoActivitesSalarieesConserveesFiltrees.estVide())
    {
      Damj dateFCTDamj = chronoActivitesSalarieesConserveesFiltrees.dernierElement().getDateDebut();
      String dateFCTString = dateFCTDamj.formater();
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB7_1", new String[] { dateFCTString });
    }
    FiltresTemporel filtreActiviteNonSalarieNonAtteste = new FiltresTemporel();
    filtreActiviteNonSalarieNonAtteste.ajouterFiltre(new FiltrePeriodeActiviteNonSalariee());
    filtreActiviteNonSalarieNonAtteste.ajouterFiltre(new FiltrePeriodesAttestees(false));
    
    chronoActivitesNonSalarieesConserveesFiltrees = p_chronoGlobaleActivitesConservees.copier(filtreActiviteNonSalarieNonAtteste);
    if (!chronoActivitesNonSalarieesConserveesFiltrees.estVide())
    {
      Damj dateFCTDamj = chronoActivitesNonSalarieesConserveesFiltrees.dernierElement().getDateDebut();
      String dateFCTString = dateFCTDamj.formater();
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB7_2", new String[] { dateFCTString });
    }
  }
  
  private Periode recupererPeriodePrc(DemandeAssuranceSpec p_demande)
    throws ApplicativeException
  {
    Periode periodePrc = null;
    
    DossierExamen dossierExamenCourant = (DossierExamen)p_demande.getDossierExamen();
    if ((dossierExamenCourant.getConstitutionSjr().getSjrip() != null) && (dossierExamenCourant.getConstitutionSjr().getSjrip().getPrc() != null)) {
      periodePrc = dossierExamenCourant.getConstitutionSjr().getSjrip().getPrc().getPeriode();
    } else {
      periodePrc = fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels.DelaiRecherche.getInstance().determinerPrcSjcipRaA2b((Demande)p_demande);
    }
    return periodePrc;
  }
  
  private void mettreAJourDomListeActivitesConservees(DossierExamen p_dossierExamen, Chronologie p_chronoActivitesConservees, Damj p_termePrc)
  {
    if ((p_chronoActivitesConservees != null) && (p_chronoActivitesConservees.getTaille() > 0))
    {
      ConstitutionSjc constitutionSjc = new ConstitutionSjc();
      Sjcip sjcipCourant = new Sjcip(p_termePrc, QUANTITE_EURO_ZERO, QUANTITE_EURO_ZERO);
      constitutionSjc.setSjcip(sjcipCourant);
      p_dossierExamen.setConstitutionSjc(constitutionSjc);
      
      p_chronoActivitesConservees.iterer();
      TravailSpec activiteConserveeCourante = null;
      SjrActiviteConservee sjrActiviteConserveCourant = null;
      while (p_chronoActivitesConservees.encoreSuivant())
      {
        activiteConserveeCourante = (TravailSpec)p_chronoActivitesConservees.elementSuivant();
        
        sjrActiviteConserveCourant = new SjrActiviteConservee(QUANTITE_EURO_ZERO);
        sjrActiviteConserveCourant.setPeriodeActiviteConservee(activiteConserveeCourante);
        
        OutilGestionActivitesConservees.getInstance().mettreAJourTypeActiviteConservee(sjrActiviteConserveCourant);
        sjcipCourant.ajouterSjrActiviteConservee(sjrActiviteConserveCourant);
      }
    }
  }
}

/* Location:
 * Qualified Name:     DeterminationConditionCumulActiviteConservee
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */