package fr.unedic.cali.asu.cge01.p02.liquidation.parcours;

import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConditionRechercheEmploi;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels.RechercheConditionRechercheEmploi;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.EreInscriptionDemandeurEmploi;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.ResultatConditionRechercheEmploi;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.asr.RechercheConditionRechercheEmploiAsp;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.asr.RechercheConditionRechercheEmploiPap;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnCharge;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.ResultatElementDroit;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Damj;

public class DeterminationConditionRechercheEmploiPourReprise
  extends ParcoursCali
  implements ParcoursAssurance
{
  public void controlerContexte(Contexte contexte)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "Une demande est obligatoire pour ce produit. : DeterminationConditionRechercheEmploiReprise impossible");
    }
    if (DomLiquidationAssurance.getDemande(contexte).getDemandeur() == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_DEMANDEUR", "Absence individu demandeur sur la demande : DeterminationConditionRechercheEmploiReprise impossible");
    }
  }
  
  public Resultat demarrer(Contexte contexte)
    throws CoucheLogiqueException
  {
    OutilTrace.tracerDebutParcours();
    
    Resultat resultatCapr01 = new Resultat(1);
    
    ConditionRechercheEmploi condition = new ConditionRechercheEmploi();
    
    Demande demandeCourante = DomLiquidationAssurance.getDemande(contexte);
    DossierExamen dossierExamenCourant = (DossierExamen)demandeCourante.getDossierExamen();
    boolean estSatisfait;
    boolean estSatisfait;
    if ((OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeCourante, "AREENTRCSP")) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeCourante, "ARECOURCSP"))) {
      estSatisfait = verifierConditionDispositifCSP(condition, demandeCourante);
    } else {
      estSatisfait = verifierConditionClassique(condition, demandeCourante);
    }
    dossierExamenCourant.setConditionRechercheEmploi(condition);
    if (estSatisfait)
    {
      resultatCapr01.setEtat(0);
    }
    else
    {
      resultatCapr01.setEtat(1);
      resultatCapr01.setMessageErreur(Integer.toString(condition.getCodeMotifEchec()));
    }
    OutilTrace.tracerFinParcours();
    
    return resultatCapr01;
  }
  
  private boolean verifierConditionClassique(ConditionRechercheEmploi condition, Demande demande)
    throws CoucheLogiqueException
  {
    Damj dateExamenDemandeCourante = demande.getDateExamen();
    
    ObjetChronoPeriodePriseEnCharge periodePEC = OutillagePEC.getPeriodePECIndemnisableContenant(demande.getDemandeur(), dateExamenDemandeCourante);
    if ((periodePEC == null) || (estPecIncorrectPourIDE(demande, periodePEC))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_ERR_DEMANDEUR_NON_INSCRIT");
    }
    boolean estSatisfait = RechercheConditionRechercheEmploi.rechercherConditionRechercheEmploi(demande);
    if (!estSatisfait) {
      condition.setCodeMotifEchec(11);
    }
    return estSatisfait;
  }
  
  private boolean estPecIncorrectPourIDE(Demande demande, ObjetChronoPeriodePriseEnCharge periodePEC)
  {
    return ((demande.getEvenementReferenceExamen() instanceof EreInscriptionDemandeurEmploi)) && (periodePEC.getIdentifiantPec() != demande.getFormulaire().getIdPec());
  }
  
  private boolean verifierConditionDispositifCSP(ConditionRechercheEmploi condition, Demande demande)
    throws CoucheLogiqueException
  {
    ResultatConditionRechercheEmploi resultatCondition;
    ResultatConditionRechercheEmploi resultatCondition;
    if (demande.estEnContexteDemande(10)) {
      resultatCondition = RechercheConditionRechercheEmploiPap.getInstance().rechercherConditionRechercheEmploi(demande);
    } else {
      resultatCondition = RechercheConditionRechercheEmploiAsp.getInstance().rechercherConditionRechercheEmploi(demande);
    }
    ResultatElementDroit resultatElementDroit = resultatCondition.getResultatElementDroit();
    condition.setEtat(0);
    if (!resultatElementDroit.estSatisfait())
    {
      condition.setEtat(resultatElementDroit.getEtat());
      condition.setCodeMotifEchec(resultatElementDroit.getCodeMotifEchec());
    }
    return resultatElementDroit.estSatisfait();
  }
}

/* Location:
 * Qualified Name:     DeterminationConditionRechercheEmploiPourReprise
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */