package fr.unedic.cali.asu.cge01.p02.migration.graphes;

import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionDateAttribution;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionDelais;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionElementsReprise;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionMontantsBruts;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionPointDepartIndemnisation;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.Decision;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.Prc;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.Reprise;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.Sjrip;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.autresdoms.cohab.dom.CodesErreursMigration;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.affectation.Parametres;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cohabitation.sigma.migration.dom.DecisionMigreeAsuV1;
import fr.unedic.cohabitation.sigma.migration.dom.DemandeMigreeAsuV1;
import fr.unedic.cohabitation.sigma.migration.dom.DemandeMigreeV1;
import fr.unedic.util.QuantiteEuro;
import java.math.BigDecimal;
import java.util.Collection;

public class GrapheReprise
  extends GrapheDecision
{
  protected void miseAJourDemandeOrigine(DemandeSpec p_demande)
  {
    AttributionSpec attributionPrecedente = ((DemandeAssuranceSpec)p_demande).rechercherAttributionPrecedenteDuMemeType();
    if (attributionPrecedente != null) {
      ((Demande)p_demande).setDemandeOrigine((DemandeAssuranceSpec)attributionPrecedente.getDemande());
    } else {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_DEM_ORIG_INCONNU"));
    }
  }
  
  protected void creerCaps(DossierExamen p_dossierExamen) {}
  
  protected void creerCeps(DossierExamen p_dossierExamen)
  {
    ConstitutionElementsReprise ceprs = new ConstitutionElementsReprise();
    
    ceprs.setConstitutionDurees(new ConstitutionDurees());
    ceprs.setConstitutionMontantsBruts(new ConstitutionMontantsBruts());
    ceprs.setConstitutionDelais(new ConstitutionDelais());
    ceprs.setConstitutionDateAttribution(new ConstitutionDateAttribution());
    ceprs.setConstitutionPointDepartIndemnisation(new ConstitutionPointDepartIndemnisation());
    
    p_dossierExamen.setConstitutionElementsReprise(ceprs);
  }
  
  protected Decision creerDecision(int p_natureDecision)
  {
    Decision nouvelleDecision = null;
    switch (p_natureDecision)
    {
    case 3: 
      nouvelleDecision = new Reprise();
      nouvelleDecision.setNatureDecision(3);
      break;
    case 13: 
      nouvelleDecision = new Reprise();
      nouvelleDecision.setNatureDecision(13);
      break;
    case 14: 
      nouvelleDecision = new Reprise();
      nouvelleDecision.setNatureDecision(14);
      break;
    case 15: 
      nouvelleDecision = new Reprise();
      nouvelleDecision.setNatureDecision(15);
      break;
    default: 
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_HG_OBJECT_DECIS"));
    }
    return nouvelleDecision;
  }
  
  protected DossierAffectation creerDossierAffectation()
  {
    DossierAffectation dossierAffectation = new DossierAffecte(2);
    ValidationProduit validation = new ValidationProduit();
    dossierAffectation.setValidationProduit(validation);
    
    return dossierAffectation;
  }
  
  protected ObjectifExamen creerObjectifDecision(DemandeMigreeAsuV1 p_demandeTemporaireSource)
  {
    ObjectifExamen objectifExamen = null;
    
    ProduitAsuSpec produitAsu = (ProduitAsuSpec)Parametres.getProduit(p_demandeTemporaireSource.getCodeProduit());
    switch (p_demandeTemporaireSource.getDecision().getNatureDecision())
    {
    case 3: 
      objectifExamen = (ObjectifExamen)produitAsu.creerObjectifExamen(13, null);
      objectifExamen.setEtat(23);
      break;
    case 13: 
      objectifExamen = (ObjectifExamen)produitAsu.creerObjectifExamen(13, null);
      objectifExamen.setEtat(23);
      break;
    case 14: 
      objectifExamen = (ObjectifExamen)produitAsu.creerObjectifExamen(14, null);
      objectifExamen.setEtat(23);
      break;
    case 15: 
      objectifExamen = (ObjectifExamen)produitAsu.creerObjectifExamen(15, null);
      objectifExamen.setEtat(23);
      break;
    default: 
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_HG_OBJECT_DECIS"));
    }
    return objectifExamen;
  }
  
  protected void alimenterIdentifiant(DecisionMigreeAsuV1 p_decisionTemporaireSource, Decision p_decisionInstallee)
  {
    BigDecimal idReprise = p_decisionTemporaireSource.getIdReprise();
    if (idReprise != null)
    {
      Reprise decisionReprise = (Reprise)p_decisionInstallee;
      decisionReprise.setReferenceExterne(idReprise.toString());
    }
    else
    {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_ID_ADMISSION"));
    }
  }
  
  protected void alimenterCaps(DecisionMigreeAsuV1 p_decisionTemporaireSource, DossierExamen p_dossierExamen) {}
  
  protected void alimenterCeps(DecisionMigreeAsuV1 p_decisionTemporaireSource, DossierExamen p_dossierExamen)
  {
    alimenterConstitutionDurees(p_decisionTemporaireSource, p_dossierExamen);
    alimenterConstitutionMontantsBruts(p_decisionTemporaireSource, p_dossierExamen);
    alimenterConstitutionDelaisReport(p_decisionTemporaireSource, p_dossierExamen);
    alimenterConstitutionDateAttribution(p_decisionTemporaireSource, p_dossierExamen);
    alimenterConstitutionPji(p_decisionTemporaireSource, p_dossierExamen);
  }
  
  protected void alimenterDonneesImposees(DemandeMigreeV1 p_demandeV1, DemandeSpec p_demande)
  {
    DossierExamen dossierExamen = (DossierExamen)p_demande.getDossierAffectation().getDossierExamen();
    DecisionMigreeAsuV1 decisionAsu = ((DemandeMigreeAsuV1)p_demandeV1).getDecision();
    
    alimenterConstitutionDateAttribution(decisionAsu, dossierExamen);
    
    reinitialiseConstitutionDurees(dossierExamen);
    alimenterConstitutionDurees(decisionAsu, dossierExamen);
    
    alimenterConstitutionDelaisReport(decisionAsu, dossierExamen);
  }
  
  protected void lireCaps(Decision p_decision, DecisionMigreeAsuV1 p_decisionLue) {}
  
  protected void lireCeps(Decision p_decision, DecisionMigreeAsuV1 p_decisionLue)
  {
    lireConstitutionDurees(p_decision, p_decisionLue);
    lireConstitutionMontantsBruts(p_decision, p_decisionLue);
    lireConstitutionSjr(p_decision, p_decisionLue);
    lireConstitutionSjc(p_decision, p_decisionLue);
    lireConstitutionDelaisReport(p_decision, p_decisionLue);
    lireConstitutionReglementApplicable(p_decision, p_decisionLue);
    lireConstitutionDateAttribution(p_decision, p_decisionLue);
    lireConstitutionPji(p_decision, p_decisionLue);
    lireConstitutionCaractereSaisonnier(p_decision, p_decisionLue);
    lireConstitutionCoefficientSaisonnier(p_decision, p_decisionLue);
    lireConstitutionCoefficientTempsPartiel(p_decision, p_decisionLue);
  }
  
  protected void lireIdentifiant(Decision p_decision, DecisionMigreeAsuV1 p_decisionLue)
  {
    p_decisionLue.setIdAdmission(new BigDecimal(((Reprise)p_decision).getRsod()));
    p_decisionLue.setIdReprise(new BigDecimal(((Reprise)p_decision).getRsrp()));
  }
  
  protected void lireConstitutionSjr(Decision p_decision, DecisionMigreeAsuV1 p_decisionLue)
  {
    Sjrip sjrip = p_decision.getConstitutionSjr().getSjrip();
    Sjr sjrrp = p_decision.getConstitutionSjr().getSjrrp();
    
    p_decisionLue.setMontantSjrInitialDroitCourant(sjrip.getSjrInitial().getValeur());
    
    p_decisionLue.setMontantSjrrpDroitCourant(sjrrp.getSalaire());
    
    p_decisionLue.setDateFinPrcSjrInitialDroitCourant(sjrip.getDateEffet());
    if (sjrip.getPrc() != null) {
      p_decisionLue.setEstApprenti(sjrip.getPrc().isTopContratsDeTypeParticulier());
    }
  }
}

/* Location:
 * Qualified Name:     GrapheReprise
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */