package fr.unedic.cali.asu.cge01.p02.parametres;

import fr.unedic.cali.asu.cge01.parametres.ParametrageListePRASpec;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeDroitPourPRA;
import fr.unedic.cali.asu.produits.liquidation.dom.Pra;
import fr.unedic.cali.asu.produits.liquidation.parametres.CleAccesDureeDroit;
import fr.unedic.cali.asu.produits.liquidation.parametres.CleAccesPRA;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.List;

public class ParametrageListePRA
  implements ParametrageListePRASpec
{
  public static final int PRA_72_MOIS = 72;
  public static final int PRA_48_MOIS = 48;
  public static final int PRA_36_MOIS = 36;
  public static final int PRA_26_MOIS = 26;
  public static final int PRA_24_MOIS = 24;
  public static final int PRA_22_MOIS = 22;
  public static final int PRA_20_MOIS = 20;
  public static final int INF_50ANS = 1;
  public static final int SUP_EGAL_50ANS = 2;
  public static final int SUP_EGAL_57ANS = 3;
  public static final int AGE_50_ANS = 50;
  public static final int AGE_57_ANS = 57;
  public static final int DUREE_DROIT_1277 = 1277;
  public static final int CENT_TRIMESTRES_ACQUIS = 1;
  private Collection m_listePRA;
  private static ParametrageListePRA s_instance;
  private static final int UN = 1;
  private static final int DEUX = 2;
  private static final int TROIS = 3;
  private static final int QUATRE = 4;
  private static final int CINQ = 5;
  private static final int SIX = 6;
  private static final int SEPT = 7;
  
  public static ParametrageListePRA getInstance()
  {
    if (s_instance == null) {
      s_instance = new ParametrageListePRA();
    }
    return s_instance;
  }
  
  private void initInstance(String p_nomReglement)
  {
    m_listePRA = new ArrayList();
    if ("RG".equals(p_nomReglement))
    {
      initInstanceRG();
      return;
    }
    if ("RGP".equals(p_nomReglement))
    {
      initInstanceRGP();
      return;
    }
    if ("OP".equals(p_nomReglement))
    {
      initInstanceRGOP();
      return;
    }
    if ("A1".equals(p_nomReglement))
    {
      initInstanceA1();
      return;
    }
    if ("A2a".equals(p_nomReglement))
    {
      initInstanceA2A();
      return;
    }
    if ("A2b".equals(p_nomReglement))
    {
      initInstanceA2B();
      return;
    }
    if ("A3".equals(p_nomReglement))
    {
      initInstanceA3();
      return;
    }
    if ("A4".equals(p_nomReglement))
    {
      initInstanceA4();
      return;
    }
    if ("A5".equals(p_nomReglement))
    {
      initInstanceA5();
      return;
    }
  }
  
  public List getListePra(CleAccesPRA p_cle)
  {
    List resultatListePRA = new ArrayList();
    
    initInstance(p_cle.getNomReglement());
    
    Iterator it = m_listePRA.iterator();
    while (it.hasNext())
    {
      Pra pra = (Pra)it.next();
      if (pra.estApplicable(p_cle)) {
        resultatListePRA.add(pra);
      }
    }
    return resultatListePRA;
  }
  
  private void initInstanceRG()
  {
    Pra pra = new Pra("RG", new int[] { 2, 3 }, 36, 3, 3);
    pra.setArticle3("c");
    positionnerQuantiteAffiliationRequise(pra, 821, "jour d'affiliation");
    positionnerQuantiteAffiliationRequise(pra, 4095, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 540, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 2700, "heure de travail");
    positionnerDureeDroit(pra, 1277, 4, 3, 1);
    positionnerDureeDroit(pra, 1095, 5);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("RG", 24, 2, 6);
    pra.setArticle3("b");
    positionnerQuantiteAffiliationRequise(pra, 426, "jour d'affiliation");
    positionnerQuantiteAffiliationRequise(pra, 2123, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 280, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 1400, "heure de travail");
    positionnerDureeDroit(pra, 700, 6);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("RG", 22, 1, 7);
    pra.setArticle3("a");
    positionnerQuantiteAffiliationRequise(pra, 182, "jour d'affiliation");
    positionnerQuantiteAffiliationRequise(pra, 910, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 120, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 600, "heure de travail");
    positionnerDureeDroit(pra, 213, 7);
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceRGP()
  {
    Pra pra = new Pra("RGP", new int[] { 2, 3 }, 36, 3, 3);
    pra.setArticle3("c");
    positionnerQuantiteAffiliationRequise(pra, 821, "jour d'affiliation");
    positionnerQuantiteAffiliationRequise(pra, 4095, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 540, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 2700, "heure de travail");
    positionnerDureeDroit(pra, 1277, 4, 3, 1);
    positionnerDureeDroit(pra, 1095, 5);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("RGP", 24, 2, 6);
    pra.setArticle3("b");
    positionnerQuantiteAffiliationRequise(pra, 426, "jour d'affiliation");
    positionnerQuantiteAffiliationRequise(pra, 2123, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 280, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 1400, "heure de travail");
    positionnerDureeDroit(pra, 700, 6);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("RGP", 22, 1, 7);
    pra.setArticle3("a");
    positionnerQuantiteAffiliationRequise(pra, 182, "jour d'affiliation");
    positionnerQuantiteAffiliationRequise(pra, 910, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 120, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 600, "heure de travail");
    positionnerDureeDroit(pra, 213, 7);
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceRGOP()
  {
    Pra pra = new Pra("OP", new int[] { 2, 3 }, 36, 3, 3);
    pra.setArticle3("c");
    positionnerQuantiteAffiliationRequise(pra, 821, "jour d'affiliation");
    positionnerQuantiteAffiliationRequise(pra, 3767, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 540, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 2700, "heure de travail");
    positionnerDureeDroit(pra, 1277, 4, 3, 1);
    positionnerDureeDroit(pra, 1095, 5);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("OP", 24, 2, 6);
    pra.setArticle3("b");
    positionnerQuantiteAffiliationRequise(pra, 426, "jour d'affiliation");
    positionnerQuantiteAffiliationRequise(pra, 1953, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 280, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 1400, "heure de travail");
    positionnerDureeDroit(pra, 700, 6);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("OP", 22, 1, 7);
    pra.setArticle3("a");
    positionnerQuantiteAffiliationRequise(pra, 182, "jour d'affiliation");
    positionnerQuantiteAffiliationRequise(pra, 837, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 120, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 600, "heure de travail");
    positionnerDureeDroit(pra, 213, 7);
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceA1()
  {
    Pra pra = new Pra("A1", new int[] { 2, 3 }, 36, 3, 3);
    pra.setArticle3("c");
    positionnerQuantiteAffiliationRequise(pra, 821, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 540, "jour d'affiliation");
    positionnerDureeDroit(pra, 1277, 4, 3, 1);
    positionnerDureeDroit(pra, 1095, 5);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A1", 24, 2, 6);
    pra.setArticle3("b");
    positionnerQuantiteAffiliationRequise(pra, 426, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 280, "jour d'affiliation");
    positionnerDureeDroit(pra, 700, 6);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A1", 22, 1, 7);
    pra.setArticle3("a");
    positionnerQuantiteAffiliationRequise(pra, 182, "jour d'affiliation");
    positionnerQuantiteAssimilationMax(pra, 120, "jour d'affiliation");
    positionnerDureeDroit(pra, 213, 7);
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceA2A()
  {
    Pra pra = new Pra("A2a", new int[] { 2, 3 }, 36, 3, 3);
    pra.setArticle3("c");
    positionnerQuantiteAffiliationRequise(pra, 821, "embarquement administratif");
    positionnerQuantiteAffiliationRequise(pra, 5670, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 540, "embarquement administratif");
    positionnerQuantiteAssimilationMax(pra, 3780, "heure de travail");
    positionnerDureeDroit(pra, 1277, 4, 3, 1);
    positionnerDureeDroit(pra, 1095, 5);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A2a", 24, 2, 6);
    pra.setArticle3("b");
    positionnerQuantiteAffiliationRequise(pra, 426, "embarquement administratif");
    positionnerQuantiteAffiliationRequise(pra, 2940, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 280, "embarquement administratif");
    positionnerQuantiteAssimilationMax(pra, 1960, "heure de travail");
    positionnerDureeDroit(pra, 700, 6);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A2a", 22, 1, 7);
    pra.setArticle3("a");
    positionnerQuantiteAffiliationRequise(pra, 182, "embarquement administratif");
    positionnerQuantiteAffiliationRequise(pra, 1260, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 120, "embarquement administratif");
    positionnerQuantiteAssimilationMax(pra, 840, "heure de travail");
    positionnerDureeDroit(pra, 213, 7);
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceA2B()
  {
    Pra pra = new Pra("A2b", new int[] { 2, 3 }, 36, 3, 3);
    pra.setArticle3("c");
    positionnerQuantiteAffiliationRequise(pra, 821, "embarquement administratif");
    positionnerQuantiteAssimilationMax(pra, 540, "embarquement administratif");
    positionnerDureeDroit(pra, 1277, 4, 3, 1);
    positionnerDureeDroit(pra, 1095, 5);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A2b", 24, 2, 6);
    pra.setArticle3("b");
    positionnerQuantiteAffiliationRequise(pra, 426, "embarquement administratif");
    positionnerQuantiteAssimilationMax(pra, 280, "embarquement administratif");
    positionnerDureeDroit(pra, 700, 6);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A2b", 22, 1, 7);
    pra.setArticle3("a");
    positionnerQuantiteAffiliationRequise(pra, 182, "embarquement administratif");
    positionnerQuantiteAssimilationMax(pra, 120, "embarquement administratif");
    positionnerDureeDroit(pra, 213, 7);
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceA3()
  {
    Pra pra = new Pra("A3", new int[] { 2, 3 }, 36, 3, 3);
    pra.setArticle3("c");
    positionnerQuantiteAffiliationRequise(pra, 1170, "vacation");
    positionnerQuantiteAssimilationMax(pra, 780, "vacation");
    positionnerDureeDroit(pra, 1277, 4, 3, 1);
    positionnerDureeDroit(pra, 1095, 5);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A3", 24, 2, 6);
    pra.setArticle3("b");
    positionnerQuantiteAffiliationRequise(pra, 606, "vacation");
    positionnerQuantiteAssimilationMax(pra, 400, "vacation");
    positionnerDureeDroit(pra, 700, 6);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A3", 22, 1, 7);
    pra.setArticle3("a");
    positionnerQuantiteAffiliationRequise(pra, 260, "vacation");
    positionnerQuantiteAssimilationMax(pra, 170, "vacation");
    positionnerDureeDroit(pra, 213, 7);
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceA4()
  {
    Pra pra = new Pra("A4", new int[] { 2, 3 }, 36, 3, 3);
    pra.setArticle3("c");
    positionnerQuantiteAffiliationRequise(pra, 4095, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 2700, "heure de travail");
    positionnerDureeDroit(pra, 1277, 4, 3, 1);
    positionnerDureeDroit(pra, 1095, 5);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A4", 24, 2, 6);
    pra.setArticle3("b");
    positionnerQuantiteAffiliationRequise(pra, 2123, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 1400, "heure de travail");
    positionnerDureeDroit(pra, 700, 6);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A4", 22, 1, 7);
    pra.setArticle3("a");
    positionnerQuantiteAffiliationRequise(pra, 910, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 600, "heure de travail");
    positionnerDureeDroit(pra, 213, 7);
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceA5()
  {
    Pra pra = new Pra("A5", new int[] { 2, 3 }, 36, 3, 3);
    pra.setArticle3("c");
    positionnerQuantiteAffiliationRequise(pra, 4095, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 2700, "heure de travail");
    positionnerDureeDroit(pra, 1277, 4, 3, 1);
    positionnerDureeDroit(pra, 1095, 5);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A5", 24, 2, 6);
    pra.setArticle3("b");
    positionnerQuantiteAffiliationRequise(pra, 2123, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 1400, "heure de travail");
    positionnerDureeDroit(pra, 700, 6);
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A5", 22, 1, 7);
    pra.setArticle3("a");
    positionnerQuantiteAffiliationRequise(pra, 910, "heure de travail");
    positionnerQuantiteAssimilationMax(pra, 600, "heure de travail");
    positionnerDureeDroit(pra, 213, 7);
    ajouterPRASurCollection(pra);
  }
  
  private void ajouterPRASurCollection(Pra p_pra)
  {
    m_listePRA.add(p_pra);
  }
  
  private void positionnerQuantiteAffiliationRequise(Pra p_pra, int p_quantite, String p_uniteAffiliation)
  {
    Unite unite = Unite.get(p_uniteAffiliation);
    Quantite quantite = new Quantite(p_quantite, unite);
    p_pra.getListeQuantitesAffiliationRequises().put(unite, quantite);
  }
  
  private void positionnerQuantiteAssimilationMax(Pra p_pra, int p_quantite, String p_uniteAffiliation)
  {
    Unite unite = Unite.get(p_uniteAffiliation);
    Quantite quantite = new Quantite(p_quantite, unite);
    p_pra.getListeQuantitesAssimilationMaximales().put(unite, quantite);
  }
  
  private void positionnerDureeDroit(Pra p_pra, int p_duree, int p_ordre)
  {
    positionnerDureeDroit(p_pra, p_duree, p_ordre, -1, -1);
  }
  
  private void positionnerDureeDroit(Pra p_pra, int p_duree, int p_ordre, int p_codeAge, int p_nombreTrimestre)
  {
    DureeDroitPourPRA duree = new DureeDroitPourPRA(p_duree, p_ordre);
    
    CleAccesDureeDroit cle = new CleAccesDureeDroit(p_codeAge, p_nombreTrimestre);
    
    duree.setCleAcces(cle);
    
    p_pra.ajouterDureeDroit(duree);
  }
}

/* Location:
 * Qualified Name:     ParametrageListePRA
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */