package fr.unedic.cali.asu.cge01.p03.calcul.dom;

import fr.unedic.cali.asu.cge01.p03.calcul.outilsfonctionnels.CotisationRetraiteComplementaire;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.parametres.EvenementParametre;
import fr.unedic.cali.asu.parametres.ParametresIndemnisation;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.dom.ElementBaseIndemnisationSpec;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.UniteMonaitaire;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;

public class FormuleMontantRegimeGeneral
  implements FormuleMontantSpec
{
  private static final BigDecimal FACTEUR_PLAFOND = new BigDecimal("0.75");
  private static final BigDecimal FACTEUR_BASE = new BigDecimal("0.404");
  private static final BigDecimal FACTEUR_PLANCHER = new BigDecimal("0.574");
  
  public static String getCode()
  {
    return "1";
  }
  
  public MontantBaseSpec calculer(ConstituantsIndemnisation p_constituantsIndemnisation, Damj p_dateCalcul)
    throws CoucheLogiqueException
  {
    Montant leMontant = new Montant();
    Quantite montantBrut = null;
    BigDecimal maxTmp = null;
    BigDecimal resultat = null;
    BigDecimal resultatSansAv = null;
    BigDecimal plafond = null;
    BigDecimal base = null;
    BigDecimal baseSansAv = null;
    BigDecimal plancher = null;
    BigDecimal plancherSansAv = null;
    BigDecimal mini = null;
    BigDecimal montantAVDeduit = null;
    
    ElementBaseIndemnisation coefficient = (ElementBaseIndemnisation)p_constituantsIndemnisation.getElementBaseIndemnisationCourant();
    EvenementParametre parametres = ParametresIndemnisation.getParametresIndemnisation().getElementActif(p_dateCalcul);
    
    BigDecimal coefficientParametre = coefficient.getCoefficientSaisonnier();
    if (coefficientParametre.intValue() == 1) {
      coefficientParametre = coefficient.getCoefficientTempsPartiel();
    }
    montantAVDeduit = coefficient.getTauxAvantageVieillesse().multiply(coefficient.getCoefficientAvantageVieillesse().multiply(coefficient.getSjr().getSalaire()));
    
    plafond = FACTEUR_PLAFOND.multiply(coefficient.getSjr().getSalaire()).multiply(coefficient.getCoefficientSaisonnier());
    
    baseSansAv = FACTEUR_BASE.multiply(coefficient.getSjr().getSalaire()).multiply(coefficient.getCoefficientSaisonnier()).add(parametres.getPartieFixe().multiply(coefficientParametre));
    
    plancherSansAv = FACTEUR_PLANCHER.multiply(coefficient.getSjr().getSalaire()).multiply(coefficient.getCoefficientSaisonnier());
    mini = parametres.getAllocationMinimale().multiply(coefficientParametre);
    resultatSansAv = baseSansAv.max(plancherSansAv).max(mini).min(plafond);
    
    base = baseSansAv.subtract(montantAVDeduit).max(new BigDecimal(0));
    plancher = plancherSansAv.subtract(montantAVDeduit).max(new BigDecimal(0));
    
    maxTmp = base.max(plancher);
    maxTmp = maxTmp.max(mini);
    resultat = maxTmp.min(plafond);
    if (resultat.equals(plafond)) {
      leMontant.setJustificationCalculMontant("03");
    } else if (resultat.equals(plancher)) {
      leMontant.setJustificationCalculMontant("01");
    } else if (resultat.equals(mini)) {
      leMontant.setJustificationCalculMontant("02");
    }
    leMontant.setMontantJournalierAvantageVieillesseDeduit(new QuantiteEuro(Mathematiques.arrondiASup(resultatSansAv.subtract(Mathematiques.arrondiASup(resultat, 2)), 2).max(new BigDecimal(0))));
    
    leMontant.setMontantBrutSansPensionInvaliditeADeduire(new Quantite(Mathematiques.arrondiASup(resultat, 2), UniteMonaitaire.EUROS));
    
    leMontant.setMontantBrutSansAvantageVieillesseDeduit(new Quantite(Mathematiques.arrondiASup(resultatSansAv, 2), UniteMonaitaire.EUROS));
    
    resultat = resultat.subtract(coefficient.getMontantPensionInvaliditeADeduire());
    
    resultat = resultat.max(new BigDecimal("0"));
    
    resultat = Mathematiques.arrondiASup(resultat, 2);
    
    montantBrut = new Quantite(resultat, UniteMonaitaire.EUROS);
    
    leMontant.setPensionInvaliditeADeduirePriseEnCompte(new Quantite(coefficient.getMontantPensionInvaliditeADeduire(), UniteMonaitaire.get("Euros")));
    
    leMontant.setMontantJournalierAvantageVieillesse(new QuantiteEuro(coefficient.getMontantAvantageVieillesse()));
    leMontant.setPlafond(new Quantite(Mathematiques.arrondiASup(plafond, 2), UniteMonaitaire.get("Euros")));
    leMontant.setPlancher(new Quantite(Mathematiques.arrondiASup(plancher, 2), UniteMonaitaire.get("Euros")));
    leMontant.setMini(new Quantite(Mathematiques.arrondiASup(mini, 2), UniteMonaitaire.get("Euros")));
    leMontant.setBase(new Quantite(Mathematiques.arrondiASup(base, 2), UniteMonaitaire.get("Euros")));
    leMontant.setMontantBrut(montantBrut);
    
    boolean estAvecCRC = coefficient.getAvecPrecompteCRC() != null ? coefficient.getAvecPrecompteCRC().booleanValue() : true;
    
    leMontant.setAvecPrecompteCRC(estAvecCRC);
    if (estAvecCRC)
    {
      leMontant.setCrc(CotisationRetraiteComplementaire.getCotisationEffective(leMontant, coefficient.getSjr().getSalaire(), coefficient.getCoefficientSaisonnier(), resultat, parametres.getAllocationMinimale(), parametres.getCotisationRetraiteComplementaire()));
    }
    else
    {
      leMontant.setCrc(new Quantite(0, UniteMonaitaire.get("Euros")));
      
      leMontant.setSjrNonReduit(coefficient.getSjr().getSalaire());
    }
    if ((coefficient.getCoefficientSanctionReduction() != null) && (!coefficient.getCoefficientSanctionReduction().equals(new BigDecimal("1.00"))))
    {
      BigDecimal mtApresPart = resultat.subtract(leMontant.getCrc().getValeur());
      mtApresPart = mtApresPart.multiply(coefficient.getCoefficientSanctionReduction());
      mtApresPart = mtApresPart.add(leMontant.getCrc().getValeur());
      mtApresPart = Mathematiques.arrondiASup(mtApresPart, 2);
      leMontant.setMontantBrut(new Quantite(mtApresPart, UniteMonaitaire.EUROS));
    }
    leMontant.setCoefficientSaisonnier(p_constituantsIndemnisation.getElementBaseIndemnisationCourant().getCoefficientSaisonnier());
    
    return leMontant;
  }
  
  public void setFormuleMontantDroitAssocie(FormuleMontantSpec p_formuleMontantDroitAssocie) {}
  
  public void setFormuleMontantApplicable(int p_formuleMontantApplicable) {}
}

/* Location:
 * Qualified Name:     FormuleMontantRegimeGeneral
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */