package fr.unedic.cali.asu.cge01.p03.liquidation.dom;

import fr.unedic.cali.asu.cge01.p03.liquidation.dom.gen.ConditionFaitGenerateurGen;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.cali.parcours.ContexteParcoursCali;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.UniteAffiliation;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;

public class ConditionFaitGenerateur
  extends ConditionFaitGenerateurGen
  implements FaitGenerateurSpec
{
  private static final long serialVersionUID = 1L;
  private transient ActiviteSalarie m_periodeFaitGenerateur = null;
  
  private ConditionFaitGenerateur()
  {
    if (getDateEvenement() != null) {
      setDateEvenement(new Damj());
    }
  }
  
  public ConditionFaitGenerateur(DomPCSpec p_conditionsAttributionPC)
  {
    super(p_conditionsAttributionPC);
  }
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
  
  public Damj getDateEffet()
  {
    return getDateFaitGenerateur();
  }
  
  public ActiviteSalarie getPeriodeFaitGenerateur()
  {
    if (m_periodeFaitGenerateur == null)
    {
      Individu individuCourant = ContexteParcoursCali.getIndividuCourant();
      
      m_periodeFaitGenerateur = ((ActiviteSalarie)individuCourant.rechercherPeriodePasseProfessionnel(getIdentifiantPeriodeFaitGenerateur()));
    }
    return m_periodeFaitGenerateur;
  }
  
  public void setPeriodeFaitGenerateur(ActiviteSalarie p_periodeFaitGenerateur)
  {
    m_periodeFaitGenerateur = p_periodeFaitGenerateur;
    if (p_periodeFaitGenerateur != null)
    {
      setIdentifiantPeriodeFaitGenerateur(p_periodeFaitGenerateur.getIdentifiant());
      setMotifFinPeriode(p_periodeFaitGenerateur.getMotifFin());
      setDateFaitGenerateur(p_periodeFaitGenerateur.getDateFin());
      setDateEngagementProcedure(p_periodeFaitGenerateur.getDateEngagementProcedureLicenciement());
    }
  }
  
  public String toString()
  {
    return m_periodeFaitGenerateur == null ? "null" : m_periodeFaitGenerateur.toString();
  }
  
  public boolean estSatisfait()
  {
    return getEtat() == 0;
  }
  
  public void setEtatSatisfait(boolean p_etatSatisfait)
  {
    if (p_etatSatisfait) {
      setEtat(0);
    } else {
      setEtat(1);
    }
  }
  
  public void marquerGraphePersistant() {}
  
  public ObjetMetierSpec copie()
  {
    throw new UnsupportedOperationException("Cette méthode ne doit pas être appelée! Appeller le méthode copieElements(ObjetMetierSpec).");
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    ConditionFaitGenerateur copie = (ConditionFaitGenerateur)p_copie;
    copie.setDateEvenement(getDateEvenement());
    copie.setAgeIndividuDateFG(getAgeIndividuDateFG());
    copie.setDateFaitGenerateur(getDateFaitGenerateur());
    copie.setIdentifiantPeriodeFaitGenerateur(getIdentifiantPeriodeFaitGenerateur());
    copie.setMotifFinPeriode(getMotifFinPeriode());
    copie.setCodeMotifEchec(getCodeMotifEchec());
    copie.setEtat(getEtat());
    copie.setDateEngagementProcedure(getDateEngagementProcedure());
    copie.setRefusAdhesionFne(getRefusAdhesionFne());
  }
  
  public Quantite getNombreJoursFaitGenerateur()
  {
    if (getPeriodeFaitGenerateur() != null) {
      return new Quantite(getPeriodeFaitGenerateur().getDuree(), UniteAffiliation.JOUR);
    }
    return null;
  }
  
  public BigDecimal getRefusFne()
  {
    if ((getPeriodeFaitGenerateur() != null) && (getPeriodeFaitGenerateur().getContrat() != null)) {
      return getPeriodeFaitGenerateur().getContrat().getRefusFne();
    }
    return null;
  }
  
  public int getCodeBassinCtp()
  {
    return 0;
  }
}

/* Location:
 * Qualified Name:     ConditionFaitGenerateur
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */