package fr.unedic.cali.asu.cge01.p03.liquidation.dom;

import fr.unedic.cali.asu.cge01.liquidation.dom.spec.ConstitutionDelaisSpec;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.gen.ConstitutionDelaisGen;
import fr.unedic.cali.dom.ConstitutionDroitSpec;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Iterator;

public class ConstitutionDelais
  extends ConstitutionDelaisGen
  implements ConstitutionDroitSpec, ConstitutionDelaisSpec
{
  private transient QuantiteEuro mMontantICCPOrigine;
  private transient QuantiteEuro mCumulMontantICCPA4Origine;
  private transient Damj dateDebutDernierDelaiAttente;
  
  private ConstitutionDelais() {}
  
  public ConstitutionDelais(DomPCSpec constitutionElementsAdmissionPC)
  {
    super(constitutionElementsAdmissionPC);
  }
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
  
  public Collection getListeCarences()
  {
    Collection toutesLesCarences = new ArrayList();
    Iterator iterEnsembles = getListeEnsembleCarences().iterator();
    while (iterEnsembles.hasNext())
    {
      EnsembleCarences ensembleCarences = (EnsembleCarences)iterEnsembles.next();
      toutesLesCarences.addAll(ensembleCarences.getListeCarences());
    }
    toutesLesCarences.addAll(super.getCollectionDelaisReports());
    return Collections.unmodifiableCollection(toutesLesCarences);
  }
  
  public Collection getListeEnsembleCarences()
  {
    return getCollectionEnsembleCarences();
  }
  
  public Collection getListeDelaisReports()
  {
    return getCollectionDelaisReports();
  }
  
  public void supprimerEnProfondeur() {}
  
  public void marquerGraphePersistant()
  {
    DomManager.persisterEnProfondeur(super.getCollectionEnsembleCarences());
    DomManager.persisterEnProfondeur(super.getCollectionDelaisReports());
  }
  
  public ObjetMetierSpec copie()
  {
    throw new UnsupportedOperationException("Cette méthode ne doit pas être appelée! Appeller le méthode copieElements(ObjetMetierSpec).");
  }
  
  public void copieElements(ObjetMetierSpec pCopie)
  {
    ConstitutionDelais copie = (ConstitutionDelais)pCopie;
    
    copie.setPeriodeReference91jours(getPeriodeReference91jours() != null ? new Periode(getPeriodeReference91jours().getDebut(), getPeriodeReference91jours().getFin()) : null);
    
    Collection listeEnsembleCarences = getListeEnsembleCarences();
    
    Iterator ensembleCarencesIterator = listeEnsembleCarences.iterator();
    while (ensembleCarencesIterator.hasNext())
    {
      EnsembleCarences element = (EnsembleCarences)ensembleCarencesIterator.next();
      if (element != null) {
        copie.ajouterEnsembleCarences((EnsembleCarences)element.copie());
      }
    }
    Collection listeDelaisReportsACloner = getListeDelaisReports();
    
    Iterator iter2 = listeDelaisReportsACloner.iterator();
    while (iter2.hasNext())
    {
      Differe element = (Differe)iter2.next();
      if (element != null) {
        copie.ajouterDelaisReports((Differe)element.copie());
      }
    }
    copie.setDebutCarenceDiffere(getDebutCarenceDiffere());
    copie.setDebutCarenceICCP(getDebutCarenceICCP());
    copie.setDebutCarenceISLR(getDebutCarenceISLR());
    copie.setNbJoursCarenceDiffere(getNbJoursCarenceDiffere());
    copie.setNbJoursCarenceICCP(getNbJoursCarenceICCP());
    copie.setNbJoursCarenceISLR(getNbJoursCarenceISLR());
    copie.setTermeCarenceDiffere(getTermeCarenceDiffere());
    copie.setTermeCarenceICCP(getTermeCarenceICCP());
    copie.setTermeCarenceISLR(getTermeCarenceISLR());
    copie.setDebutPMC(getDebutPMC());
    copie.setTermePMC(getTermePMC());
    copie.setNbJoursPMC(getNbJoursPMC());
    copie.setTypePmc(getTypePmc());
    copie.setMontantICCPOrigine(getMontantICCPOrigine());
    copie.setCumulMontantICCPA4Origine(getCumulMontantICCPA4Origine());
  }
  
  public Damj getDebutCarencePMC()
  {
    if (getTypePmc() == 1) {
      return getDebutPMC();
    }
    return null;
  }
  
  public Damj getDebutPmcIndemnisable()
  {
    if (getTypePmc() == 2) {
      return getDebutPMC();
    }
    return null;
  }
  
  public void setDebutCarencePMC(Damj debutPmc)
  {
    setTypePmc(1);
    setDebutPMC(debutPmc);
  }
  
  public void setDebutPmcIndemnisable(Damj debutPmc)
  {
    setTypePmc(2);
    setDebutPMC(debutPmc);
  }
  
  public int getNbJoursCarencePMC()
  {
    if (getTypePmc() == 1) {
      return getNbJoursPMC();
    }
    return 0;
  }
  
  public int getNbJoursPmcIndemnisable()
  {
    if (getTypePmc() == 2) {
      return getNbJoursPMC();
    }
    return 0;
  }
  
  public void setNbJoursCarencePMC(int nbJours)
  {
    setTypePmc(1);
    setNbJoursPMC(nbJours);
  }
  
  public void setNbJoursPmcIndemnisable(int nbJours)
  {
    setTypePmc(2);
    setNbJoursPMC(nbJours);
  }
  
  public Damj getTermeCarencePMC()
  {
    if (getTypePmc() == 1) {
      return getTermePMC();
    }
    return null;
  }
  
  public Damj getTermePmcIndemnisable()
  {
    if (getTypePmc() == 2) {
      return getTermePMC();
    }
    return null;
  }
  
  public void setTermeCarencePMC(Damj termePMC)
  {
    setTypePmc(1);
    setTermePMC(termePMC);
  }
  
  public void setTermePmcIndemnisable(Damj termePMC)
  {
    setTypePmc(2);
    setTermePMC(termePMC);
  }
  
  public QuantiteEuro getCumulMontantICCPA4Origine()
  {
    return mCumulMontantICCPA4Origine;
  }
  
  public void setCumulMontantICCPA4Origine(QuantiteEuro cumulMontantICCPA4Origine)
  {
    mCumulMontantICCPA4Origine = cumulMontantICCPA4Origine;
  }
  
  public QuantiteEuro getMontantICCPOrigine()
  {
    return mMontantICCPOrigine;
  }
  
  public void setMontantICCPOrigine(QuantiteEuro montantICCPOrigine)
  {
    mMontantICCPOrigine = montantICCPOrigine;
  }
  
  public void remplacerCollectionEnsembleCarences(Collection collectionACopier)
  {
    for (Iterator i = super.getCollectionEnsembleCarences().iterator(); i.hasNext();)
    {
      EnsembleCarences objet = (EnsembleCarences)i.next();
      DomManager.supprimer(objet);
    }
    super.remplacerCollectionEnsembleCarences(collectionACopier);
  }
  
  public void remplacerCollectionDelaisReports(Collection collectionACopier)
  {
    for (Iterator i = super.getCollectionDelaisReports().iterator(); i.hasNext();)
    {
      Differe objet = (Differe)i.next();
      DomManager.supprimer(objet);
    }
    super.remplacerCollectionDelaisReports(collectionACopier);
  }
  
  public void setDateDebutDernierDelaiAttente(Damj dateDebutDernierDelaiAttente)
  {
    this.dateDebutDernierDelaiAttente = dateDebutDernierDelaiAttente;
  }
  
  public Damj getDateDebutDernierDelaiAttente()
  {
    return dateDebutDernierDelaiAttente;
  }
}

/* Location:
 * Qualified Name:     ConstitutionDelais
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */