package fr.unedic.cali.asu.cge01.p03.liquidation.dom;

import fr.unedic.cali.asu.cge01.p03.liquidation.dom.gen.ConstitutionQuantiteAffiliationGen;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationAffiliation;
import fr.unedic.cali.dom.ConstitutionDroitSpec;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.UniteAffiliation;
import fr.unedic.util.temps.Periode;

public class ConstitutionQuantiteAffiliation
  extends ConstitutionQuantiteAffiliationGen
  implements ConstitutionDroitSpec
{
  private static final long serialVersionUID = 1L;
  public static final String ARTICLE3_A_2003 = "a";
  public static final String ARTICLE3_B_2003 = "b";
  public static final String ARTICLE3_C_2003 = "c";
  public static final String ARTICLE3_A_2006 = "1";
  public static final String ARTICLE3_B_2006 = "2";
  public static final String ARTICLE3_C_2006 = "3";
  public static final String ARTICLE3_D_2006 = "4";
  public static final String ARTICLE3_E_2006 = "5";
  public static final String ARTICLE3_F_2006 = "6";
  public static final String ARTICLE3_G_2006 = "7";
  public static final String ARTICLE3_A_2009 = "a";
  public static final String ARTICLE3_B_2009 = "b";
  private transient Quantite m_quantiteAffiliationAcquiseSecondaire;
  private transient Quantite m_quantiteAssimilationAcquiseSecondaire;
  private transient boolean m_estEnConflit;
  private transient JustificationAffiliation m_justificationAffi;
  
  protected ConstitutionQuantiteAffiliation()
  {
    setQuantiteAffiliationAcquise(new Quantite("0", UniteAffiliation.get("heure de travail")));
    setQuantiteAssimilationAcquise(new Quantite("0", UniteAffiliation.get("heure de travail")));
  }
  
  public ConstitutionQuantiteAffiliation(DomPCSpec p_cepAbstraitPC)
  {
    super(p_cepAbstraitPC);
    
    setQuantiteAffiliationAcquise(new Quantite("0", UniteAffiliation.get("heure de travail")));
    setQuantiteAssimilationAcquise(new Quantite("0", UniteAffiliation.get("heure de travail")));
  }
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
  
  public Quantite getQuantiteAcquise()
  {
    return getQuantiteAffiliationAcquise().ajouter(getQuantiteAssimilationAcquise());
  }
  
  public Quantite getQuantiteAcquiseSecondaire()
  {
    Quantite qte = m_quantiteAffiliationAcquiseSecondaire;
    if (m_quantiteAssimilationAcquiseSecondaire != null) {
      qte = m_quantiteAffiliationAcquiseSecondaire.ajouter(m_quantiteAssimilationAcquiseSecondaire);
    }
    return qte;
  }
  
  public String toString()
  {
    StringBuffer sb = new StringBuffer();
    if (getDureeInitiale() != null)
    {
      sb.append("Durée : ");
      sb.append(getDureeInitiale().getValeurEntiere());
    }
    sb.append(" - Affi. acquise : ");
    sb.append(getQuantiteAffiliationAcquise());
    sb.append(" - Assimi. acquise : ");
    sb.append(getQuantiteAssimilationAcquise());
    sb.append(" - Article : ");
    sb.append(getArticle3());
    return sb.toString();
  }
  
  public void marquerGraphePersistant() {}
  
  public ObjetMetierSpec copie()
  {
    throw new UnsupportedOperationException("Cette méthode ne doit pas être appelée! Appeller le méthode copieElements(ObjetMetierSpec).");
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    ConstitutionQuantiteAffiliation copie = (ConstitutionQuantiteAffiliation)p_copie;
    
    copie.setArticle3(getArticle3());
    copie.setDureeInitiale(getDureeInitiale());
    copie.setEnConflit(estEnConflit());
    copie.setPeriodePRA(getPeriodePRA() != null ? new Periode(getPeriodePRA().getDebut(), getPeriodePRA().getFin()) : null);
    copie.setQuantiteAffiliationAcquise(getQuantiteAffiliationAcquise());
    copie.setQuantiteAssimilationAcquise(getQuantiteAssimilationAcquise());
    
    copie.setJustificationAffiliation(getJustificationAffiliation());
    copie.setQuantiteAffiliationAcquiseSecondaire(getQuantiteAffiliationAcquiseSecondaire());
    copie.setQuantiteAssimilationAcquiseSecondaire(getQuantiteAssimilationAcquiseSecondaire());
  }
  
  public boolean estEnConflit()
  {
    return m_estEnConflit;
  }
  
  public void setEnConflit(boolean p_estEnConflit)
  {
    m_estEnConflit = p_estEnConflit;
  }
  
  public JustificationAffiliation getJustificationAffiliation()
  {
    return m_justificationAffi;
  }
  
  public void setJustificationAffiliation(JustificationAffiliation p_justificationAffi)
  {
    m_justificationAffi = p_justificationAffi;
  }
  
  public Quantite getQuantiteAffiliationAcquiseSecondaire()
  {
    return m_quantiteAffiliationAcquiseSecondaire;
  }
  
  public void setQuantiteAffiliationAcquiseSecondaire(Quantite p_quantiteAffiliationAcquiseSecondaire)
  {
    m_quantiteAffiliationAcquiseSecondaire = p_quantiteAffiliationAcquiseSecondaire;
  }
  
  public Quantite getQuantiteAssimilationAcquiseSecondaire()
  {
    return m_quantiteAssimilationAcquiseSecondaire;
  }
  
  public void setQuantiteAssimilationAcquiseSecondaire(Quantite p_quantiteAssimilationAcquiseSecondaire)
  {
    m_quantiteAssimilationAcquiseSecondaire = p_quantiteAssimilationAcquiseSecondaire;
  }
  
  public void jdoPreClear() {}
  
  public void jdoPreDelete() {}
  
  public void jdoPostLoad() {}
  
  public void jdoPreStore() {}
}

/* Location:
 * Qualified Name:     ConstitutionQuantiteAffiliation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */