package fr.unedic.cali.asu.cge01.p03.liquidation.dom;

import fr.unedic.cali.asu.cge01.p03.liquidation.dom.gen.EnsembleCarencesGen;
import fr.unedic.cali.asu.dom.ConteneurPMCSpec;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.PreavisMesureConservatoireIndemnisableSpec;
import fr.unedic.cali.asu.dom.PreavisMesureConservatoireNonIndemnisableSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.ObjetPersistantSpec;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.util.ArrayList;
import java.util.Collection;

public class EnsembleCarences
  extends EnsembleCarencesGen
  implements ObjetPersistantSpec, ConteneurPMCSpec
{
  private static final long serialVersionUID = 4989118601017456947L;
  private transient boolean m_presenceTransaction;
  private transient boolean m_autresIndemnitesLegales = false;
  private transient DemandeAssuranceSpec m_demande;
  
  public EnsembleCarences() {}
  
  public EnsembleCarences(DomPCSpec p_carencesPC)
  {
    super(p_carencesPC);
  }
  
  public Collection getListeCarences()
  {
    Collection coll = new ArrayList();
    if (getCarencePmc() != null) {
      coll.add(getCarencePmc());
    }
    if (getCarenceIccp() != null) {
      coll.add(getCarenceIccp());
    }
    if (getCarenceIslr() != null) {
      coll.add(getCarenceIslr());
    }
    return coll;
  }
  
  public void setCarenceIccp(CarenceIccp p_carenceIccp)
  {
    DomManager.supprimer(super.getCarenceIccp(), p_carenceIccp);
    
    super.setCarenceIccp(p_carenceIccp);
    if (super.getCarenceIccp() != null) {
      super.getCarenceIccp().setEnsembleCarences(this);
    }
  }
  
  public void setCarenceIslr(CarenceIslr p_carenceIslr)
  {
    DomManager.supprimer(super.getCarenceIslr(), p_carenceIslr);
    super.setCarenceIslr(p_carenceIslr);
    if (super.getCarenceIslr() != null) {
      super.getCarenceIslr().setEnsembleCarences(this);
    }
  }
  
  public void setPmcIndemnisable(PreavisMesureConservatoireIndemnisable p_pmcIndemnisable)
  {
    DomManager.supprimer(super.getPmcIndemnisable(), p_pmcIndemnisable);
    super.setPmcIndemnisable(p_pmcIndemnisable);
    if (super.getPmcIndemnisable() != null) {
      super.getPmcIndemnisable().setEnsembleCarences(this);
    }
  }
  
  public void setCarencePmc(PreavisMesureConservatoireNonIndemnisable p_carencePmc)
  {
    DomManager.supprimer(super.getCarencePmc(), p_carencePmc);
    super.setCarencePmc(p_carencePmc);
    if (super.getCarencePmc() != null) {
      super.getCarencePmc().setEnsembleCarences(this);
    }
  }
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
  
  public void supprimerEnProfondeur()
  {
    DomManager.supprimer(getCarencePmc().getPC());
    DomManager.supprimer(getCarenceIccp().getPC());
    DomManager.supprimer(getCarenceIslr().getPC());
    DomManager.supprimer(getPmcIndemnisable().getPC());
  }
  
  public void marquerGraphePersistant()
  {
    DomManager.persisterEnProfondeur(getCarencePmc());
    DomManager.persisterEnProfondeur(getCarenceIccp());
    DomManager.persisterEnProfondeur(getCarenceIslr());
    DomManager.persisterEnProfondeur(getPmcIndemnisable());
  }
  
  public ObjetMetierSpec copie()
  {
    EnsembleCarences copie = new EnsembleCarences();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    EnsembleCarences copie = (EnsembleCarences)p_copie;
    
    copie.setCarencePmc(getCarencePmc() != null ? (PreavisMesureConservatoireNonIndemnisable)getCarencePmc().copie() : null);
    copie.setCarenceIccp(getCarenceIccp() != null ? (CarenceIccp)getCarenceIccp().copie() : null);
    copie.setCarenceIslr(getCarenceIslr() != null ? (CarenceIslr)getCarenceIslr().copie() : null);
    copie.setPmcIndemnisable(getPmcIndemnisable() != null ? (PreavisMesureConservatoireIndemnisable)getPmcIndemnisable().copie() : null);
    copie.setAutresIndemnitesLegales(isAutresIndemnitesLegales());
    copie.setPresenceTransaction(isPresenceTransaction());
  }
  
  public String toString()
  {
    StringBuffer sb = new StringBuffer();
    sb.append("EnsembleCarences :\nCarence PMC : ");
    sb.append(getCarencePmc());
    sb.append("\nCarence ICCP : ");
    sb.append(getCarenceIccp());
    sb.append("\nCarence ISLR : ");
    sb.append(getCarenceIslr());
    sb.append("\nAutres Indemnites Legales : ");
    sb.append(isAutresIndemnitesLegales());
    sb.append("\nTransaction en cours : ");
    sb.append(isPresenceTransaction());
    return sb.toString();
  }
  
  public void setAutresIndemnitesLegales(boolean p_autresIndemnitesLegales)
  {
    m_autresIndemnitesLegales = p_autresIndemnitesLegales;
  }
  
  public boolean isAutresIndemnitesLegales()
  {
    return m_autresIndemnitesLegales;
  }
  
  public boolean isPresenceTransaction()
  {
    return m_presenceTransaction;
  }
  
  public void setPresenceTransaction(boolean p_presenceTransaction)
  {
    m_presenceTransaction = p_presenceTransaction;
  }
  
  public boolean estIdentiqueA(EnsembleCarences p_aComparer)
  {
    boolean identique = false;
    identique = p_aComparer.getCarenceIccp() == null ? true : getCarenceIccp() != null ? getCarenceIccp().estIdentiqueA(p_aComparer.getCarenceIccp()) : false;
    if (identique) {
      identique = p_aComparer.getCarenceIslr() == null ? true : getCarenceIslr() != null ? getCarenceIslr().estIdentiqueA(p_aComparer.getCarenceIslr()) : false;
    }
    if (identique) {
      identique = p_aComparer.getCarencePmc() == null ? true : getCarencePmc() != null ? getCarencePmc().estIdentiqueA(p_aComparer.getCarencePmc()) : false;
    }
    if (identique) {
      identique = p_aComparer.getPmcIndemnisable() == null ? true : getPmcIndemnisable() != null ? getPmcIndemnisable().estIdentiqueA(p_aComparer.getPmcIndemnisable()) : false;
    }
    return identique;
  }
  
  public PreavisMesureConservatoireIndemnisableSpec creerPMCIndemnisable(ActiviteSalarie p_periodeActivite, Periode p_periodeApplication)
  {
    return new PreavisMesureConservatoireIndemnisable(p_periodeActivite, p_periodeApplication);
  }
  
  public PreavisMesureConservatoireNonIndemnisableSpec creerPMCNonIndemnisable(ActiviteSalarie p_periodeActivite, Periode p_periodeApplication)
  {
    return new PreavisMesureConservatoireNonIndemnisable(p_periodeActivite, p_periodeApplication);
  }
  
  public void setCarencePmc(PreavisMesureConservatoireNonIndemnisableSpec p_carencePMC)
  {
    setCarencePmc((PreavisMesureConservatoireNonIndemnisable)p_carencePMC);
  }
  
  public void setPmcIndemnisable(PreavisMesureConservatoireIndemnisableSpec p_carencePMCIndemnisable)
  {
    setPmcIndemnisable((PreavisMesureConservatoireIndemnisable)p_carencePMCIndemnisable);
  }
  
  public PreavisMesureConservatoireNonIndemnisableSpec getCarencePmcNonIndemnisable()
  {
    return getCarencePmc();
  }
  
  public PreavisMesureConservatoireIndemnisableSpec getCarencePmcIndemnisable()
  {
    return getPmcIndemnisable();
  }
  
  public Damj getDateFinDerniereCarence()
  {
    Damj dateFinCarences = null;
    PreavisMesureConservatoireNonIndemnisable carencePmc = getCarencePmc();
    if (carencePmc != null) {
      dateFinCarences = carencePmc.getPeriodeApplicationCarence().getFin();
    }
    CarenceIslr carenceIslr = getCarenceIslr();
    if (carenceIslr != null)
    {
      Damj dateFinCrt = carenceIslr.getPeriodeApplicationCarence().getFin();
      if (dateFinCarences != null) {
        dateFinCarences = Damj.max(dateFinCrt, dateFinCarences);
      } else {
        dateFinCarences = dateFinCrt;
      }
    }
    CarenceIccp carenceIccp = getCarenceIccp();
    if (carenceIccp != null)
    {
      Damj dateFinCrt = carenceIccp.getPeriodeApplicationCarence().getFin();
      if (dateFinCarences != null) {
        dateFinCarences = Damj.max(dateFinCrt, dateFinCarences);
      } else {
        dateFinCarences = dateFinCrt;
      }
    }
    return dateFinCarences;
  }
  
  public DemandeAssuranceSpec getDemande()
  {
    return m_demande;
  }
  
  public void setDemande(DemandeAssuranceSpec p_demande)
  {
    m_demande = p_demande;
  }
}

/* Location:
 * Qualified Name:     EnsembleCarences
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */