package fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.dom.spec.ConstitutionDelaisSpec;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConditionActiviteConservee;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionMontantsBruts;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionProduitResultant;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Echec;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Reprise;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Revision;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Metier;
import fr.unedic.cali.autresdoms.ga.dom.RegimeRetraite;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.RejetSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.ObjetChronoPeriodeSpec;
import java.math.BigDecimal;
import java.util.List;

public class AlimenterBaseEchanges
{
  private static final BigDecimal COEFFICIENT_MENSUEL = new BigDecimal("30");
  
  public static void alimenterDonneesProduit(DossierExamenSpec pDossierExamen, fr.unedic.cali.dom.echange.Decision pDemandeEchange)
    throws ApplicativeException
  {
    if (pDemandeEchange == null) {
      pDemandeEchange = new fr.unedic.cali.dom.echange.Decision();
    }
    pDemandeEchange.setLigne("ASU_CGE01");
    if ((pDossierExamen.getDemande().estNotifieeCourrier()) && ((pDossierExamen instanceof fr.unedic.cali.asu.cge01.p03.liquidation.dom.Decision)))
    {
      alimenterDonneesCourrierECAX(pDossierExamen, pDemandeEchange);
      if ((pDossierExamen instanceof Reprise))
      {
        Reprise reprise = (Reprise)pDossierExamen;
        
        BigDecimal sjrrp = reprise.getConstitutionSjr().getSjrrp().getSalaire();
        pDemandeEchange.setMontantSJRSuiteRevision(sjrrp);
      }
      if ((pDossierExamen instanceof Revision))
      {
        alimenterDonneesCourrierECB7PourRevision(pDossierExamen, pDemandeEchange);
      }
      else if ((pDossierExamen instanceof Echec))
      {
        alimenterDonneesCourrierECB7PourEchecRevision(pDossierExamen, pDemandeEchange);
      }
      else if (!(pDossierExamen instanceof RejetSpec))
      {
        alimenterDonneesCourrier(pDossierExamen, pDemandeEchange);
        alimenterDonneesCourrierEcep(pDossierExamen, pDemandeEchange);
        alimenterDonneesRejetSP(pDossierExamen, pDemandeEchange);
      }
    }
  }
  
  protected static void alimenterDonneesCourrier(DossierExamenSpec pDossierExamen, fr.unedic.cali.dom.echange.Decision pDemandeEchange)
    throws ApplicativeException
  {
    fr.unedic.cali.asu.cge01.p03.liquidation.dom.Decision dossierExamen = (fr.unedic.cali.asu.cge01.p03.liquidation.dom.Decision)pDossierExamen;
    switch (dossierExamen.getNatureDecision())
    {
    case 11: 
    case 26: 
      alimenterDonneesCourrierReadAntecedent(dossierExamen, pDemandeEchange);
      break;
    default: 
      alimenterDonneesCourrierNonReadAntecedent(dossierExamen, pDemandeEchange);
    }
    pDemandeEchange.setLibelleEmployeur(dossierExamen.getCompetence().getLibelleEmployeurCompetent());
  }
  
  protected static void alimenterDonneesCourrierNonReadAntecedent(fr.unedic.cali.asu.cge01.p03.liquidation.dom.Decision pDossierExamen, fr.unedic.cali.dom.echange.Decision pDemandeEchange)
    throws ApplicativeException
  {
    ConstitutionMontantsBruts cepaMontantsBruts = pDossierExamen.getConstitutionMontantsBruts();
    if (cepaMontantsBruts != null)
    {
      if (cepaMontantsBruts.getMontantBrutSansDeduction() != null) {
        pDemandeEchange.setMontantAllocationJournalierBrutCourrier(cepaMontantsBruts.getMontantBrutSansDeduction().getValeur());
      }
      if (cepaMontantsBruts.getPensionInvaliditeADeduirePriseEnCompte() != null) {
        pDemandeEchange.setMontantPensionInvaliditeAreCourrier(cepaMontantsBruts.getPensionInvaliditeADeduirePriseEnCompte().getValeur());
      }
      if (cepaMontantsBruts.getCrc() != null) {
        pDemandeEchange.setMontantCrcCourrier(cepaMontantsBruts.getCrc().getValeur());
      }
      if (cepaMontantsBruts.getMontantJournalierAvantageVieillesseDeduit() != null) {
        pDemandeEchange.setMontantAllocation(cepaMontantsBruts.getMontantJournalierAvantageVieillesseDeduit().getValeur());
      }
    }
    ConstitutionDurees cepaDureesReglementaires = pDossierExamen.getConstitutionDurees();
    if ((cepaDureesReglementaires != null) && (cepaDureesReglementaires.getDureeIndemnisation() != null) && (cepaDureesReglementaires.getDureeIndemnisation().getDureeTheorique() != null))
    {
      pDemandeEchange.setDureeTheoriqueDroitServiCourrier(cepaDureesReglementaires.getDureeIndemnisation().getDureeTheorique().getValeurEntiere());
      
      pDemandeEchange.setDureeRenouvellementAreCourrier(cepaDureesReglementaires.getDureeIndemnisation().getDureeEffective().getValeurEntiere());
    }
  }
  
  protected static void alimenterDonneesCourrierReadAntecedent(fr.unedic.cali.asu.cge01.p03.liquidation.dom.Decision pDossierExamen, fr.unedic.cali.dom.echange.Decision pDemandeEchange)
    throws ApplicativeException
  {
    ConstitutionMontantsBruts cepaMontantsBruts = pDossierExamen.getConstitutionProduitResultant().getConstitutionMontantsBruts();
    if (cepaMontantsBruts != null)
    {
      if (cepaMontantsBruts.getMontantBrutSansDeduction() != null) {
        pDemandeEchange.setMontantAllocationJournalierBrutCourrier(cepaMontantsBruts.getMontantBrutSansDeduction().getValeur());
      }
      if (cepaMontantsBruts.getPensionInvaliditeADeduirePriseEnCompte() != null) {
        pDemandeEchange.setMontantPensionInvaliditeAreCourrier(cepaMontantsBruts.getPensionInvaliditeADeduirePriseEnCompte().getValeur());
      }
      if (cepaMontantsBruts.getCrc() != null) {
        pDemandeEchange.setMontantCrcCourrier(cepaMontantsBruts.getCrc().getValeur());
      }
      if (cepaMontantsBruts.getMontantJournalierAvantageVieillesseDeduit() != null) {
        pDemandeEchange.setMontantAllocation(cepaMontantsBruts.getMontantJournalierAvantageVieillesseDeduit().getValeur());
      }
    }
    ConstitutionDurees cepaDureesReglementaires = pDossierExamen.getConstitutionProduitResultant().getConstitutionDurees();
    if ((cepaDureesReglementaires != null) && (cepaDureesReglementaires.getDureeIndemnisation() != null))
    {
      pDemandeEchange.setDureeTheoriqueDroitServiCourrier(cepaDureesReglementaires.getDureeIndemnisation().getDureeTheorique().getValeurEntiere());
      
      pDemandeEchange.setDureeRenouvellementAreCourrier(cepaDureesReglementaires.getDureeIndemnisation().getDureeEffective().getValeurEntiere());
    }
  }
  
  protected static void alimenterDonneesCourrierECAX(DossierExamenSpec pDossierExamen, fr.unedic.cali.dom.echange.Decision pDemandeEchange)
  {
    fr.unedic.cali.asu.cge01.p03.liquidation.dom.Decision dossierExamen = (fr.unedic.cali.asu.cge01.p03.liquidation.dom.Decision)pDossierExamen;
    pDemandeEchange.setLibelleEmployeur(dossierExamen.getCompetence().getLibelleEmployeurCompetent());
    
    ConditionActiviteConservee capaConditionActiviteConservee = dossierExamen.getConditionActiviteConservee();
    if (capaConditionActiviteConservee != null)
    {
      BigDecimal montantSjc = capaConditionActiviteConservee.getMontantMensuelActiviteConservee();
      BigDecimal montantSjcMax = capaConditionActiviteConservee.getSeuilMontantMensuelActiviteConservee();
      if ((montantSjc != null) && (montantSjcMax != null) && (montantSjc.compareTo(montantSjcMax) == 1)) {
        pDemandeEchange.setMontantSJC(montantSjc.divide(COEFFICIENT_MENSUEL, 4));
      }
      if (montantSjcMax != null) {
        pDemandeEchange.setMontantSJCMax(montantSjcMax.divide(COEFFICIENT_MENSUEL, 4));
      }
      Chronologie listeActivitesConservee = dossierExamen.getListeActiviteConservee();
      Chronologie listeActivitesSalarieesConservees = listeActivitesConservee.copier(new FiltreActiviteSalarie());
      int autreActiviteConservee = 0;
      if ((listeActivitesSalarieesConservees != null) && (listeActivitesSalarieesConservees.getTaille() > 0)) {
        autreActiviteConservee = 1;
      }
      pDemandeEchange.setAuMoinsUneActiviteConservee(autreActiviteConservee);
    }
  }
  
  protected static void alimenterDonneesCourrierEcep(DossierExamenSpec pDossierExamen, fr.unedic.cali.dom.echange.Decision pDemandeEchange)
    throws CoucheLogiqueException
  {
    int topCaisseInconnue = 0;
    
    fr.unedic.cali.asu.cge01.p03.liquidation.dom.Decision dossierExamen = (fr.unedic.cali.asu.cge01.p03.liquidation.dom.Decision)pDossierExamen;
    if (dossierExamen.getConditionFaitGenerateur() != null)
    {
      List listeRegimeRetraite = dossierExamen.getConditionFaitGenerateur().getPeriodeFaitGenerateur().getMetier().getListeRegimeRetraite();
      if (listeRegimeRetraite != null)
      {
        int nbRegimeRetraite = listeRegimeRetraite.size();
        for (int i = 0; i < nbRegimeRetraite; i++)
        {
          RegimeRetraite regimeRetraiteGa = (RegimeRetraite)listeRegimeRetraite.get(i);
          if (regimeRetraiteGa.estCaisseRetraiteAbsente()) {
            topCaisseInconnue = 1;
          }
        }
      }
    }
    pDemandeEchange.setTopCaisseInconnue(topCaisseInconnue);
  }
  
  protected static void alimenterDonneesCourrierECB7PourRevision(DossierExamenSpec pDossierExamen, fr.unedic.cali.dom.echange.Decision pDemandeEchange)
    throws CoucheLogiqueException
  {
    Revision revision = (Revision)pDossierExamen;
    Demande demande = (Demande)pDossierExamen.getDemande();
    
    BigDecimal montantsNets = revision.getConstitutionMontantsBruts().getMontantAAttribution().getMontantPrecompte();
    
    Damj pji = revision.getPji();
    
    Damj dateEffetRevision = revision.getDateEffet();
    
    Damj dateBanalisee = dateEffetRevision;
    if (pji != null) {
      dateBanalisee = Damj.max(dateEffetRevision, pji);
    }
    BigDecimal seuilMontantMensuel = RechercheConditionCumulActiviteConservee.determinerPlafondMensuelRemuneration(demande, demande.getDateExamen());
    
    pDemandeEchange.setMontantAllocationJournalierNetCourrier(montantsNets);
    
    BigDecimal sjrrp = revision.getConstitutionSjr().getSjrrp().getSalaire();
    pDemandeEchange.setMontantSJRSuiteRevision(sjrrp);
    
    pDemandeEchange.setDateBanalisee(dateBanalisee);
    
    pDemandeEchange.setMontantSJCMax(seuilMontantMensuel);
  }
  
  protected static void alimenterDonneesCourrierECB7PourEchecRevision(DossierExamenSpec pDossierExamen, fr.unedic.cali.dom.echange.Decision pDemandeEchange)
    throws CoucheLogiqueException
  {
    Demande demande = (Demande)pDossierExamen.getDemande();
    
    Demande demandeOrigine = demande.getDemandeOrigine();
    
    BigDecimal seuilMontantMensuel = RechercheConditionCumulActiviteConservee.determinerPlafondMensuelRemuneration(demandeOrigine, demande.getDateExamen());
    
    pDemandeEchange.setMontantSJCMax(seuilMontantMensuel);
  }
  
  protected static void alimenterDonneesRejetSP(DossierExamenSpec dossierExamen, fr.unedic.cali.dom.echange.Decision demandeEchange)
  {
    fr.unedic.cali.asu.cge01.p03.liquidation.dom.Decision decision = (fr.unedic.cali.asu.cge01.p03.liquidation.dom.Decision)dossierExamen;
    
    ConstitutionDelaisSpec cepDelai = decision.getConstitutionDelais();
    if (cepDelai != null) {
      demandeEchange.setDateDebutDernierDelaiAttente(cepDelai.getDateDebutDernierDelaiAttente());
    }
    CompetenceSpec competence = decision.getCompetence();
    if (competence != null)
    {
      if (competence.isEstCoeffTPAppliqueRAC()) {
        demandeEchange.setCoeffTPAppliqueRAC(1);
      } else {
        demandeEchange.setCoeffTPAppliqueRAC(0);
      }
      if (competence.isEstCoeffTPAppliqueSP()) {
        demandeEchange.setCoeffTPAppliqueSP(1);
      } else {
        demandeEchange.setCoeffTPAppliqueSP(0);
      }
      demandeEchange.setDureeActiviteEmployeursRAC(competence.getDureeActiviteSecteurPrive() + competence.getDureeActiviteSecteurPublicAffilie() + competence.getDureeActiviteSecteurPriveCaCae());
      
      demandeEchange.setDureeActiviteEmployeursSP(competence.getDureeActiviteSecteurPublicAutoAssurance() + competence.getDureeActiviteSecteurPublicConventionGestion());
    }
    if (decision.getReglementApplicable() != null) {
      demandeEchange.setReglementApplicableDroit(decision.getReglementApplicable().getReglement().getLibelleCourt());
    }
    demandeEchange.setDateFaitGenerateurDroitPrecedent(decision.getDemandeAssurance().getDateFaitGenerateurOdPrecedente());
    
    ObjetChronoPeriodeSpec periode = OutillagePEC.getPeriodePECIndemnisableContenant(decision.getDemandeAssurance().getDemandeur(), decision.getDateAttribution());
    if (periode != null) {
      demandeEchange.setDateIDE(periode.getDateDebut());
    }
  }
}

/* Location:
 * Qualified Name:     AlimenterBaseEchanges
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */