package fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.cge01.liquidation.dom.ResultatDeterminationDuree;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.OutilTraitementReliquat;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionElementsSpec;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionQuantiteAffiliation;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DureeReglementaire;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.Reliquat;
import fr.unedic.cali.asu.outilsfonctionnels.ConstitutionDuree;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeDroitPourPRA;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationAffiliation;
import fr.unedic.cali.asu.produits.liquidation.dom.Pra;
import fr.unedic.cali.asu.produits.liquidation.parametres.CleAccesDureeDroit;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.services.PasAssezInformationException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import java.math.BigDecimal;

public class DeterminationDureeReglementaire
  implements OutilFonctionnel
{
  public static final int AGE_50_ANS = 50;
  public static final int AGE_57_ANS = 57;
  public static final int INF_50ANS = 1;
  public static final int SUP_EGAL_50ANS = 2;
  public static final int SUP_EGAL_57ANS = 3;
  static final int NB_JOURS_OUVRES = 5;
  static final Damj DATE_180106 = new Damj(2006, 1, 17);
  
  private static int determinerCodeAge(int ageDemandeurAuFg)
  {
    if (ageDemandeurAuFg < 50) {
      return 1;
    }
    if (ageDemandeurAuFg >= 57) {
      return 3;
    }
    return 2;
  }
  
  public static DureeIndemnisation determinerDureeReglementaire(Demande demande)
    throws PasAssezInformationException, CoucheLogiqueException
  {
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Début de la détermination des durées réglementaires." });
    
    ConstitutionDurees constitutionDurees = ((DossierExamen)demande.getDossierExamen()).getConstitutionElementsActifs().getConstitutionDurees();
    DureeIndemnisation dureeIndemnisation = constitutionDurees.createDureeIndemnisation();
    
    Quantite dureeForcee = null;
    if (demande.getDonneesTemporaires() != null) {
      dureeForcee = demande.getDonneesTemporaires().getDureeTheoriqueForcee();
    }
    if ((dureeForcee == null) && (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "RECHARGE"))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ASU_OBLIGATOIRE_DUREE_RECHARG", new Object[] { demande.getDossierAffectation().getProduit().getLibelleCourt() });
    }
    if ((dureeForcee != null) && (dureeForcee.getValeur() != null))
    {
      BigDecimal plafond = new BigDecimal(1277);
      BigDecimal duree = plafond.min(dureeForcee.getValeur());
      dureeIndemnisation.setDureeTheorique(new Quantite(duree, DureeReglementaire.UNITE_DEFAUT));
      dureeIndemnisation.setDureeImputation(new Quantite(0, DureeReglementaire.UNITE_DEFAUT));
      dureeIndemnisation.setQuantiteTotalJourImputation(new Quantite(0, DureeReglementaire.UNITE_DEFAUT));
      dureeIndemnisation.setQuantiteJourImputationForce(new Quantite(0, DureeReglementaire.UNITE_DEFAUT));
    }
    else
    {
      int dureeTheoriqueDroitCourant = determinerDureeTheoriqueDroitCourant(demande);
      
      Quantite qteDureeTheorique = new Quantite(dureeTheoriqueDroitCourant, DureeReglementaire.UNITE_DEFAUT);
      
      Quantite qteDureeImputationDroitCourant = OutilTraitementReliquat.determinerDureeImputationFormationDroitCourant(demande.getDossierAffectation().getProduit(), demande, qteDureeTheorique, OutilTraitementReliquat.determinerPeriodeImputationFormationDroitCourant(demande, demande.getDateExamen().veille()), dureeTheoriqueDroitCourant);
      
      qteDureeTheorique = qteDureeTheorique.soustraire(qteDureeImputationDroitCourant);
      
      int dureeImputationDroitCourant = 0;
      Quantite qteNbJourImputer = new Quantite(dureeImputationDroitCourant, DureeReglementaire.UNITE_DEFAUT);
      if (demande.getDonneesTemporaires().getNbJourImputer() != null)
      {
        qteNbJourImputer = new Quantite(demande.getDonneesTemporaires().getNbJourImputer().intValue(), DureeReglementaire.UNITE_DEFAUT);
        qteDureeTheorique = qteDureeTheorique.soustraire(qteNbJourImputer);
      }
      Quantite qteTotalJourImputation = qteDureeImputationDroitCourant.ajouter(qteNbJourImputer);
      dureeIndemnisation.setQuantiteJourImputationForce(qteNbJourImputer);
      dureeIndemnisation.setQuantiteTotalJourImputation(qteTotalJourImputation);
      dureeIndemnisation.setDureeTheorique(qteDureeTheorique);
      dureeIndemnisation.setDureeImputation(qteDureeImputationDroitCourant);
    }
    return dureeIndemnisation;
  }
  
  private static int determinerDureeTheoriqueDroitCourant(Demande demande)
    throws CoucheLogiqueException
  {
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Détermination de la durée théorique du droit courant." });
    
    IndividuSpec individu = demande.getDemandeur();
    FaitGenerateurSpec faitGenerateur = demande.getFaitGenerateur();
    Damj dateFG = faitGenerateur.getDateFaitGenerateur();
    DossierExamen dossierExamen = (DossierExamen)demande.getDossierExamen();
    
    Pra pra = dossierExamen.getConstitutionQuantiteAffiliation().getJustificationAffiliation().getPeriodePraRetenue();
    
    DureeCalendaire ageFG = individu.getAgeALaDate(dateFG);
    int codeAge = determinerCodeAge(ageFG.getAnnees());
    
    int codeCentTrimestres = 0;
    if ((demande.getDemandeur().getDateCentTrimestres() != null) && (demande.getDemandeur().getDateCentTrimestres().estAvantOuCoincideAvec(dateFG))) {
      codeCentTrimestres = 1;
    }
    CleAccesDureeDroit cle = new CleAccesDureeDroit(codeAge, codeCentTrimestres);
    
    DureeDroitPourPRA duree = pra.getDureeDroit(cle);
    int dureeTheorique = duree.getDuree();
    
    return dureeTheorique;
  }
  
  public ResultatDeterminationDuree determinerDureeReglementairePourRepriseRevision(Demande demande)
    throws ApplicativeException
  {
    ResultatDeterminationDuree resultat = new ResultatDeterminationDuree();
    
    DossierExamen dossierExamen = (DossierExamen)demande.getDossierExamen();
    
    Quantite qteNbJourImputer = new Quantite(0, DureeReglementaire.UNITE_DEFAUT);
    Reliquat reliquat = demande.getReliquat();
    Quantite quantiteReliquat = new Quantite(reliquat.getQuantiteReliquat().getValeurEntiere(), DureeReglementaire.UNITE_DEFAUT);
    if (demande.getDonneesTemporaires().getNbJourImputer() != null)
    {
      qteNbJourImputer = new Quantite(demande.getDonneesTemporaires().getNbJourImputer().intValue(), DureeReglementaire.UNITE_DEFAUT);
      quantiteReliquat = quantiteReliquat.soustraire(qteNbJourImputer);
    }
    Quantite qteTotalJourImputation = reliquat.getQuantiteImputee().ajouter(qteNbJourImputer);
    resultat.setQuantiteJourImputationForce(qteNbJourImputer);
    resultat.setQuantiteTotalJourImputation(qteTotalJourImputation);
    resultat.setDureeTheorique(quantiteReliquat);
    resultat.setDureeImputation(qteTotalJourImputation);
    if (((demande.estUneDemandeFinDroit()) || (demande.estUneDemandeFinancement())) && (quantiteReliquat.getValeurEntiere() == 0)) {
      resultat.setDureeEffective(new Quantite(0, DureeReglementaire.UNITE_DEFAUT));
    } else {
      resultat.setDureeEffective(ConstitutionDuree.calculerDureeEffectivePourReprise(demande.getDemandeur(), dossierExamen.getDateAttribution(), quantiteReliquat, DureeReglementaire.UNITE_DEFAUT, true));
    }
    return resultat;
  }
  
  public void mapperResultatSurDom(ResultatDeterminationDuree resultat, DureeIndemnisation dureeIndemnisation)
  {
    dureeIndemnisation.setDureeImputation(resultat.getDureeImputation());
    dureeIndemnisation.setDureeTheorique(resultat.getDureeTheorique());
    dureeIndemnisation.setQuantiteJourImputationForce(resultat.getQuantiteJourImputationForce());
    dureeIndemnisation.setQuantiteTotalJourImputation(resultat.getQuantiteTotalJourImputation());
    dureeIndemnisation.setDureeEffective(resultat.getDureeEffective());
    dureeIndemnisation.setDureeImputation(resultat.getDureeImputation());
  }
}

/* Location:
 * Qualified Name:     DeterminationDureeReglementaire
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */