package fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConditionFaitGenerateur;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p03.liquidation.fabriques.FabriqueStrategieFaitGenerateurDelaiValidite;
import fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels.strategies.StrategieFaitGenerateurDelaiValiditeSpec;
import fr.unedic.cali.asu.dom.DelaiRechercheProduit;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.EreDemandeExpresse;
import fr.unedic.cali.asu.dom.EreInscriptionDemandeurEmploi;
import fr.unedic.cali.asu.dom.ErePassageCPSuiteRejetDV;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.fabriques.FabriqueStrategieFCTRetenueDemandeExpresse;
import fr.unedic.cali.asu.outilsfonctionnels.GestionDemandeDv122eJour;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.CertifieSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.DeclareSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.autresdoms.ga.outilsfonctionnels.OutilPasseProfessionel;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteNonSalariee;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteSalarieeE301NonFrontalier;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteSalarieeHorsChamp;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesCertifiees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesDeclarees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesSurFiltresExclusifs;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreTravailSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreTravailSpec;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.FiltreFinAvantOuCoincideAvecDate;
import fr.unedic.util.temps.FiltreFinDansBornes;
import fr.unedic.util.temps.FiltreTemporel;
import fr.unedic.util.temps.FiltresTemporel;

public class RechercheConditionFaitGenerateur
  implements OutilFonctionnel
{
  public static ConditionFaitGenerateur rechercherConditionFaitGenerateur(Demande p_demande)
    throws CoucheLogiqueException
  {
    if ((p_demande.getEvenementReferenceExamen() instanceof ErePassageCPSuiteRejetDV)) {
      return rechercherConditionFaitGenerateurPourDemandeDv122eJour(p_demande);
    }
    if ((p_demande.getEvenementReferenceExamen() instanceof EreDemandeExpresse))
    {
      CritereStrategie critere = new CritereStrategie();
      critere.setDemande(p_demande);
      FabriqueStrategieFCTRetenueDemandeExpresse fabrique = FabriqueStrategieFCTRetenueDemandeExpresse.getInstance();
      if (fabrique.appliquerStrategieApres(critere)) {
        return rechercherConditionFaitGenerateurPourDemandeClassique(p_demande);
      }
      return rechercherConditionFaitGenerateurSurPeriodePec(p_demande);
    }
    return rechercherConditionFaitGenerateurPourDemandeClassique(p_demande);
  }
  
  private static ConditionFaitGenerateur rechercherConditionFaitGenerateurPourDemandeDv122eJour(Demande p_demande)
    throws CoucheLogiqueException
  {
    ConditionFaitGenerateur condition = ((DossierExamen)p_demande.getDossierExamen()).createConditionFaitGenerateur();
    
    GestionDemandeDv122eJour.rechercherConditionFaitGenerateur(p_demande).copieElements(condition);
    return condition;
  }
  
  private static ConditionFaitGenerateur rechercherConditionFaitGenerateurPourDemandeClassique(Demande p_demande)
    throws CoucheLogiqueException
  {
    ConditionFaitGenerateur faitGenerateur = ((DossierExamen)p_demande.getDossierExamen()).createConditionFaitGenerateur();
    
    boolean echecCondition = false;
    
    FiltrePeriodesSurFiltresExclusifs filtresExclusifs = new FiltrePeriodesSurFiltresExclusifs();
    
    FiltresTemporel filtresTravailSalarieNonSalarie = new FiltresTemporel();
    filtresTravailSalarieNonSalarie.ajouterFiltre(new FiltrePeriodesCertifiees());
    filtresExclusifs.ajouterFiltre(filtresTravailSalarieNonSalarie);
    
    FiltresTemporel filtresDeclareTravail = new FiltresTemporel();
    filtresDeclareTravail.ajouterFiltre(new FiltrePeriodesDeclarees());
    filtresDeclareTravail.ajouterFiltre(new FiltreTravailSpec());
    filtresExclusifs.ajouterFiltre(filtresDeclareTravail);
    
    Chronologie chronoActivitesParticipantes = OutilPasseProfessionel.trouverChronoPasseProfessionelAvecFiltrageDNJ(p_demande.getDemandeur()).copier(filtresExclusifs);
    
    chronoActivitesParticipantes = chronoActivitesParticipantes.copier(new FiltreFinAvantOuCoincideAvecDate(p_demande.getDateExamen()));
    
    Chronologie chronoActivitesParticipantesDansDelai = null;
    
    DelaiRechercheProduit periodeDelaiForclusion = ((DossierAffectation)p_demande.getDossierAffectation()).getDelaiRecherche();
    DelaiRechercheProduit periodeValiditeFgd = null;
    
    TravailSpec dernierSinistre = ((DossierAffectation)p_demande.getDossierAffectation()).getSinistre();
    if (dernierSinistre != null)
    {
      CritereStrategie critereStrategie = new CritereStrategie();
      if ((p_demande.getEvenementReferenceExamen() instanceof EreInscriptionDemandeurEmploi)) {
        critereStrategie.setDatePivot(dernierSinistre.getDateFin());
      } else {
        critereStrategie.setDatePivot(new Damj(Damj.NUIT_DES_TEMPS));
      }
      StrategieFaitGenerateurDelaiValiditeSpec strategieFgdDelaiValiditeCourante = (StrategieFaitGenerateurDelaiValiditeSpec)FabriqueStrategieFaitGenerateurDelaiValidite.getInstance().getStrategie(critereStrategie);
      
      periodeValiditeFgd = strategieFgdDelaiValiditeCourante.determinerDelaiValiditeFaitGenerateur(p_demande);
    }
    else
    {
      periodeValiditeFgd = ((DossierAffectation)p_demande.getDossierAffectation()).getDelaiRecherche();
    }
    if (periodeDelaiForclusion != null) {
      chronoActivitesParticipantesDansDelai = chronoActivitesParticipantes.copier(new FiltreFinDansBornes(periodeDelaiForclusion));
    }
    Chronologie chronoActivitesHorsChampDansDelai = null;
    
    filtresExclusifs = new FiltrePeriodesSurFiltresExclusifs();
    FiltreTemporel filtreActiviteSalarieHorsChamp = new FiltrePeriodeActiviteSalarieeHorsChamp();
    filtresExclusifs.ajouterFiltre(filtreActiviteSalarieHorsChamp);
    FiltreTemporel filtreActiviteNonSalarie = new FiltrePeriodeActiviteNonSalariee();
    filtresExclusifs.ajouterFiltre(filtreActiviteNonSalarie);
    if (chronoActivitesParticipantesDansDelai != null) {
      chronoActivitesHorsChampDansDelai = chronoActivitesParticipantesDansDelai.copier(filtresExclusifs);
    }
    FiltresTemporel filtreActiviteSalariee = new FiltresTemporel();
    filtreActiviteSalariee.ajouterFiltre(new FiltreTravailSalarie());
    Chronologie chronoActivitesSalariees = chronoActivitesParticipantes.copier(filtreActiviteSalariee);
    if ((chronoActivitesSalariees == null) || (chronoActivitesSalariees.estVide()))
    {
      faitGenerateur.setEtatSatisfait(false);
      faitGenerateur.setCodeMotifEchec(41);
      echecCondition = true;
    }
    if ((chronoActivitesParticipantesDansDelai != null) && (chronoActivitesHorsChampDansDelai != null) && (chronoActivitesParticipantesDansDelai.getTaille() > 0) && (chronoActivitesParticipantesDansDelai.getTaille() == chronoActivitesHorsChampDansDelai.getTaille()))
    {
      faitGenerateur.setEtatSatisfait(false);
      faitGenerateur.setCodeMotifEchec(42);
      echecCondition = true;
    }
    Chronologie chronoActivitesHorsDeFrance = null;
    
    filtresExclusifs = new FiltrePeriodesSurFiltresExclusifs();
    FiltreTemporel filtreActiviteHorsDeFrance = new FiltrePeriodeActiviteSalarieeE301NonFrontalier();
    filtresExclusifs.ajouterFiltre(filtreActiviteHorsDeFrance);
    if (chronoActivitesParticipantesDansDelai != null) {
      chronoActivitesHorsDeFrance = chronoActivitesParticipantesDansDelai.copier(filtresExclusifs);
    }
    if ((chronoActivitesParticipantesDansDelai != null) && (chronoActivitesHorsDeFrance != null) && (chronoActivitesParticipantesDansDelai.getTaille() > 0) && (chronoActivitesParticipantesDansDelai.getTaille() == chronoActivitesHorsDeFrance.getTaille()))
    {
      faitGenerateur.setEtatSatisfait(false);
      faitGenerateur.setCodeMotifEchec(47);
      echecCondition = true;
    }
    boolean delaiForclusionAllonge = (periodeDelaiForclusion != null) && (p_demande.getDonneesTemporaires() != null) && (p_demande.getDonneesTemporaires().getAllongementDelaiForclusion() != null) && (p_demande.getDonneesTemporaires().getAllongementDelaiForclusion().getJours() != 0);
    
    int codeMotifEchecDelaiForclusion = delaiForclusionAllonge ? 45 : 44;
    if (!echecCondition) {
      if ((dernierSinistre == null) || (periodeValiditeFgd == null) || (!dernierSinistre.getDateFin().estContenueDans(periodeValiditeFgd)))
      {
        faitGenerateur.setEtatSatisfait(false);
        
        faitGenerateur.setCodeMotifEchec(codeMotifEchecDelaiForclusion);
        echecCondition = true;
      }
      else if (((dernierSinistre instanceof ActiviteSalarie)) && (((ActiviteSalarie)dernierSinistre).estAtteste()))
      {
        faitGenerateur.setEtatSatisfait(true);
        faitGenerateur.setPeriodeFaitGenerateur((ActiviteSalarie)dernierSinistre);
        faitGenerateur.setAgeIndividuDateFG(p_demande.getDemandeur().getAgeALaDate(dernierSinistre.getDateFin()));
      }
      else if (p_demande.getFormulaire().getPresenceAe() != null)
      {
        if (p_demande.getFormulaire().getPresenceAe().equalsIgnoreCase("I"))
        {
          faitGenerateur.setEtatSatisfait(false);
          faitGenerateur.setCodeMotifEchec(46);
          echecCondition = true;
        }
        else if (p_demande.getFormulaire().getPresenceAe().equalsIgnoreCase("O"))
        {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB1", new String[] { dernierSinistre.getDateDebut().toString(), dernierSinistre.getDateFin().toString() });
        }
      }
      else
      {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB1", new String[] { dernierSinistre.getDateDebut().toString(), dernierSinistre.getDateFin().toString() });
      }
    }
    if (!echecCondition)
    {
      ActiviteSalarie fctRetenueValidationProduit = null;
      ValidationProduit validationProduit = ((DossierAffectation)p_demande.getDossierAffectation()).getValidationProduit();
      if ((validationProduit != null) && (validationProduit.isEstProduitValide())) {
        fctRetenueValidationProduit = validationProduit.getPeriodeValidationProduit();
      }
      boolean affectationProduitSecoursSurControleOriginePas = ((DossierAffectation)p_demande.getDossierAffectation()).getJustificationAffectation() == 6;
      if ((fctRetenueValidationProduit != null) && (periodeDelaiForclusion != null) && (!fctRetenueValidationProduit.getDateFin().estContenueDans(periodeDelaiForclusion)))
      {
        faitGenerateur.setEtatSatisfait(false);
        
        faitGenerateur.setCodeMotifEchec(codeMotifEchecDelaiForclusion);
        echecCondition = true;
      }
      else if ((affectationProduitSecoursSurControleOriginePas) || ((fctRetenueValidationProduit != null) && (!fctRetenueValidationProduit.estAtteste())))
      {
        if (p_demande.getFormulaire().getPresenceAe().equalsIgnoreCase("I"))
        {
          if (dernierSinistre != null) {
            faitGenerateur.setPeriodeFaitGenerateur((ActiviteSalarie)dernierSinistre);
          }
          faitGenerateur.setEtatSatisfait(false);
          faitGenerateur.setCodeMotifEchec(46);
          echecCondition = true;
        }
        else if (p_demande.getFormulaire().getPresenceAe().equalsIgnoreCase("O"))
        {
          TravailSpec derniereFctEtudiee = ((DossierAffectation)p_demande.getDossierAffectation()).getDerniereFctEtudiee();
          if ((derniereFctEtudiee != null) && ((((derniereFctEtudiee instanceof DeclareSpec)) && (!((DeclareSpec)derniereFctEtudiee).estJustifie())) || (((derniereFctEtudiee instanceof CertifieSpec)) && (!(derniereFctEtudiee instanceof ActiviteSalarie))) || (((derniereFctEtudiee instanceof ActiviteSalarie)) && (!((ActiviteSalarie)derniereFctEtudiee).estAtteste()) && (!((ActiviteSalarie)derniereFctEtudiee).estQualifiable())) || ((!((ActiviteSalarie)derniereFctEtudiee).estAtteste()) && (((ActiviteSalarie)derniereFctEtudiee).estQualifiable())))) {
            fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB2", new String[] { derniereFctEtudiee.getDateFin().toString() });
          }
        }
      }
    }
    if (!echecCondition) {
      verifierMotifRuptureASR(dernierSinistre);
    }
    return faitGenerateur;
  }
  
  private static ConditionFaitGenerateur rechercherConditionFaitGenerateurSurPeriodePec(Demande p_demande)
    throws CoucheLogiqueException
  {
    ConditionFaitGenerateur faitGenerateur = ((DossierExamen)p_demande.getDossierExamen()).createConditionFaitGenerateur();
    
    EreDemandeExpresse ere = (EreDemandeExpresse)p_demande.getEvenementReferenceExamen();
    ActiviteSalarie periodeFg = (ActiviteSalarie)ere.getPeriodeExamen();
    if (periodeFg != null)
    {
      faitGenerateur.setEtatSatisfait(true);
      faitGenerateur.setPeriodeFaitGenerateur(periodeFg);
    }
    else
    {
      faitGenerateur.setEtatSatisfait(false);
      faitGenerateur.setCodeMotifEchec(41);
    }
    return faitGenerateur;
  }
  
  private static void verifierMotifRuptureASR(TravailSpec p_dernierSinistre)
    throws CoucheLogiqueException
  {
    if (((p_dernierSinistre instanceof ActiviteSalarie)) && (Integer.parseInt(((ActiviteSalarie)p_dernierSinistre).getMotifFin()) == 42)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB24");
    }
  }
}

/* Location:
 * Qualified Name:     RechercheConditionFaitGenerateur
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */