package fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.ErePassageCPSuiteRejetDV;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.parametres.AccesListeUnitesReglement;
import fr.unedic.cali.asu.parametres.ValeurListeUnitesReglement;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.OdSpec;
import fr.unedic.cali.dom.RejetSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import java.util.ArrayList;

public class VerificationDonneesForcees
  extends fr.unedic.cali.asu.outilsfonctionnels.VerificationDonneesForcees
{
  private static VerificationDonneesForcees s_instance = new VerificationDonneesForcees();
  
  public static fr.unedic.cali.asu.outilsfonctionnels.VerificationDonneesForcees getInstance()
  {
    return s_instance;
  }
  
  private void verifierGARPExpatriesPostLiquidation(Demande p_demande)
    throws CoucheLogiqueException
  {
    DonneesTemporaires donneesForcees = p_demande.getDonneesTemporaires();
    DossierExamenSpec dossierExamen = p_demande.getDossierAffectation().getDossierExamen();
    if (((dossierExamen instanceof RejetSpec)) && (!p_demande.getEvenementReferenceExamen().getTypeExamen().equals("ASU_04")) && (((DossierExamenAssuranceSpec)dossierExamen).estRejetDV()) && (!donneesForcees.isRejetChomageVolontaireGARP())) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_CALI_L_REJET_DV", 1);
    }
  }
  
  protected void verifierFctForceeExpatriesPostLiquidation(Demande p_demande)
    throws CoucheLogiqueException
  {
    DonneesTemporaires donneesForcees = p_demande.getDonneesTemporaires();
    if ((p_demande.getEvenementReferenceExamen().getTypeExamen().equals("ASU_04")) && 
      (donneesForcees.getIdentifiantPeriodeFctARetenir() == null)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_CALI_L_ABSENCE_FCT_A_RETENIR2", 1);
    }
  }
  
  protected void verifierDonneesForceesExpatriesDecisionPostLiquidation(Demande p_demande)
    throws CoucheLogiqueException
  {
    DonneesTemporaires donneesForcees = p_demande.getDonneesTemporaires();
    DossierExamenSpec dossierExamen = p_demande.getDossierAffectation().getDossierExamen();
    ReglementApplicableSpec reglement = ((DossierExamenAssuranceSpec)dossierExamen).getReglementApplicable();
    if (reglement != null) {
      if ((reglement.getReglement().getLibelleCourt().equals("A9A")) || (reglement.getReglement().getLibelleCourt().equals("A9B")))
      {
        verifierGARPExpatriesPostLiquidation(p_demande);
        if (((dossierExamen instanceof OdSpec)) || (((p_demande.getEvenementReferenceExamen() instanceof ErePassageCPSuiteRejetDV)) && (donneesForcees.estAvisFavorableCommissionParitaire())))
        {
          if (donneesForcees.getSjr() == null) {
            fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_CALI_L_ABSENCE_SJRIP", 1);
          }
          if (!p_demande.estUneDemandeAtp())
          {
            if (donneesForcees.getQuantiteAffiliation() == null) {
              fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_CALI_L_ABSENCE_QTE_AFFILIATION", 1);
            }
            if (donneesForcees.getQuantiteAffiliation().getUnite() == null)
            {
              fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_CALI_L_ABSENCE_UNIT_AFFILIATION", 1);
            }
            else
            {
              ValeurListeUnitesReglement liste = AccesListeUnitesReglement.get(reglement.getReglement(), null);
              if (!liste.getListeUnites().contains(donneesForcees.getQuantiteAffiliation().getUnite())) {
                fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_CALI_L_IMPOSSIBLE_UNIT_AFFILIATION", 1);
              }
            }
            verifierFctForceeExpatriesPostLiquidation(p_demande);
            if (donneesForcees.getCoefficientTempsPartiel() == null) {
              fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_CALI_L_ABSENCE_CTP", 1);
            }
            if (!p_demande.estUneDemandeAsr())
            {
              if (donneesForcees.getQuantiteJourICCP() == null) {
                fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_CALI_L_ABSENCE_ICCP", 1);
              }
              if (donneesForcees.getQuantiteJourISLR() == null) {
                fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_CALI_L_ABSENCE_ISLR", 1);
              }
              if (donneesForcees.getIndentifiantFctPMC() == null) {
                fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_CALI_L_ABSENCE_FCT_CARENCE_EXPATRIE", 1);
              }
            }
          }
        }
      }
    }
  }
}

/* Location:
 * Qualified Name:     VerificationDonneesForcees
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */