package fr.unedic.cali.asu.cge01.p03.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Attribution;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.CarenceIccp;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.CarenceIslr;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.CarencePrefixeAFixer;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionDelais;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionElementsSpec;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Differe;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.EnsembleCarences;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.PreavisMesureConservatoireIndemnisable;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.PreavisMesureConservatoireNonIndemnisable;
import fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels.ConstructionChronologie;
import fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels.DelaiRecherche;
import fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels.DeterminationCarence;
import fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels.DeterminationCarenceRCT;
import fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels.DeterminationDiffere;
import fr.unedic.cali.asu.dom.CarenceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilCarence;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.ObjetAlertesNonBloquantes;
import fr.unedic.cali.outilsfonctionnels.AppelCalculParLiquidation;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.List;
import java.util.ListIterator;

public class ConstitutionDelaiReport
  extends ParcoursCali
  implements ParcoursAssurance
{
  public void controlerContexte(Contexte contexte)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null pour la constitution des délais reports.");
    }
    DossierExamen dossierExamenCourant = (DossierExamen)DomLiquidationAssurance.getDemande(contexte).getDossierExamen();
    if (dossierExamenCourant == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_OD", "Le dossier examen courant est null: constitution des délais reports impossible.");
    }
  }
  
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    Resultat resultatCEPA05 = new Resultat(0);
    
    Demande demande = DomLiquidationAssurance.getDemande(contexte);
    DossierExamen dossierExamenCourant = (DossierExamen)demande.getDossierExamen();
    
    ConstitutionDelais constitutionDelais = dossierExamenCourant.getConstitutionElementsActifs().createConstitutionDelais();
    
    List<EnsembleCarences> listeEnsembleCarences = null;
    ArrayList listeDelaisReports = null;
    Chronologie chronologieActiviteSalarie = new ChronologiePeriodes();
    Chronologie chronologieActiviteSalariePMC = new ChronologiePeriodes();
    
    Periode periodeReference = ((DelaiRecherche)DelaiRecherche.getInstance()).determinerDelaiRechercheCarences(demande);
    constitutionDelais.setPeriodeReference91jours(periodeReference);
    
    Periode periodeReferencePMC = ((DelaiRecherche)DelaiRecherche.getInstance()).determinerDelaiRechercheComplementairePMC(demande);
    if (periodeReference != null) {
      chronologieActiviteSalarie = ConstructionChronologie.determinerChronoActivitesParticipantCarences(periodeReference, demande);
    }
    if (periodeReferencePMC != null) {
      chronologieActiviteSalariePMC = ConstructionChronologie.determinerChronoActivitesParticipantPMC(periodeReferencePMC, demande, chronologieActiviteSalarie);
    }
    if (estDemandeEligibleCarences(demande)) {
      listeEnsembleCarences = DeterminationCarence.determinerCarences(chronologieActiviteSalarie, demande, chronologieActiviteSalariePMC);
    }
    listeDelaisReports = DeterminationDiffere.determinerDiffere(demande);
    
    Iterator iterateurC = listeEnsembleCarences.iterator();
    while (iterateurC.hasNext()) {
      constitutionDelais.ajouterEnsembleCarences((EnsembleCarences)iterateurC.next());
    }
    EnsembleCarences ensembleCarencesChomageSansRCT = DeterminationCarenceRCT.definirCarenceSupSiContexteChomageSansRCT(demande);
    if (ensembleCarencesChomageSansRCT != null) {
      constitutionDelais.ajouterEnsembleCarences(ensembleCarencesChomageSansRCT);
    }
    Iterator iterateurD = listeDelaisReports.iterator();
    while (iterateurD.hasNext()) {
      constitutionDelais.ajouterDelaisReports((Differe)iterateurD.next());
    }
    ResultatExecutionCalculSpec resultatCalcul = AppelCalculParLiquidation.executerCalculDeterminationEtatDroit((Attribution)dossierExamenCourant, null, false);
    
    alimenterResultatCepaDepuisResultatCalcul(resultatCalcul, constitutionDelais, demande);
    
    OutilTrace.tracerFinParcours();
    return resultatCEPA05;
  }
  
  private boolean estDemandeEligibleCarences(Demande demande)
  {
    return ((!OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "AREENTRCSP")) && (!OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "ARECOURCSP"))) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, 10));
  }
  
  protected static void alimenterResultatCepaDepuisResultatCalcul(ResultatExecutionCalculSpec resultat, ConstitutionDelais cepa, Demande demande)
    throws CoucheLogiqueException
  {
    boolean pmcIndemnisablePriseEnCompte;
    ListIterator iter;
    if ((resultat.getListeCarencesEffectives() != null) && (resultat.getListeCarencesEffectives().size() > 0))
    {
      pmcIndemnisablePriseEnCompte = false;
      for (iter = resultat.getListeCarencesEffectives().listIterator(); iter.hasNext();)
      {
        CarenceSpec carenceCourante = (CarenceSpec)iter.next();
        if (!OutilCarence.estCarenceDeType(carenceCourante, "Différé"))
        {
          CarencePrefixeAFixer carence = (CarencePrefixeAFixer)carenceCourante;
          if ((carence instanceof CarenceIccp))
          {
            CarenceIccp carenceIccp = (CarenceIccp)carence;
            if (carenceIccp.getPeriodeApplicationCarence() != null)
            {
              cepa.setDebutCarenceICCP(carenceIccp.getPeriodeApplicationCarence().getDebut());
              cepa.setTermeCarenceICCP(carenceIccp.getPeriodeApplicationCarence().getFin());
              cepa.setNbJoursCarenceICCP(carenceIccp.getPeriodeApplicationCarence().getDuree());
              if (((ActiviteSalarie)carenceIccp.getOrigine()).getQuantiteEuroIccp() == null) {
                cepa.setMontantICCPOrigine(new QuantiteEuro("0"));
              } else {
                cepa.setMontantICCPOrigine(((ActiviteSalarie)carenceIccp.getOrigine()).getQuantiteEuroIccp());
              }
            }
            if (cepa.getDebutPmcIndemnisable() == null)
            {
              PreavisMesureConservatoireIndemnisable pmci = carenceIccp.getEnsembleCarences().getPmcIndemnisable();
              if (pmci != null)
              {
                pmcIndemnisablePriseEnCompte = true;
                cepa.setDebutPmcIndemnisable(pmci.getPeriodeApplicationPMC().getDebut());
                cepa.setTermePmcIndemnisable(pmci.getPeriodeApplicationPMC().getFin());
                cepa.setNbJoursPmcIndemnisable(pmci.getPeriodeApplicationPMC().getDuree());
              }
            }
          }
          else if ((carence instanceof CarenceIslr))
          {
            CarenceIslr carenceIslr = (CarenceIslr)carence;
            if (carenceIslr.getPeriodeApplicationCarence() != null)
            {
              cepa.setDebutCarenceISLR(carenceIslr.getPeriodeApplicationCarence().getDebut());
              cepa.setTermeCarenceISLR(carenceIslr.getPeriodeApplicationCarence().getFin());
              cepa.setNbJoursCarenceISLR(carenceIslr.getPeriodeApplicationCarence().getDuree());
              if (carenceIslr.getEnsembleCarences().isPresenceTransaction()) {
                leverAlerteA11MNB4SurCarenceIslr(demande, (ActiviteSalarie)carenceIslr.getOrigine());
              }
            }
            if (cepa.getDebutPmcIndemnisable() == null)
            {
              PreavisMesureConservatoireIndemnisable pmci = carenceIslr.getEnsembleCarences().getPmcIndemnisable();
              if (pmci != null)
              {
                pmcIndemnisablePriseEnCompte = true;
                cepa.setDebutPmcIndemnisable(pmci.getPeriodeApplicationPMC().getDebut());
                cepa.setTermePmcIndemnisable(pmci.getPeriodeApplicationPMC().getFin());
                cepa.setNbJoursPmcIndemnisable(pmci.getPeriodeApplicationPMC().getDuree());
              }
            }
          }
          else if ((carence instanceof PreavisMesureConservatoireNonIndemnisable))
          {
            PreavisMesureConservatoireNonIndemnisable carencePmc = (PreavisMesureConservatoireNonIndemnisable)carence;
            if (carencePmc.getPeriodeApplicationCarence() != null)
            {
              cepa.setDebutCarencePMC(carencePmc.getPeriodeApplicationCarence().getDebut());
              cepa.setTermeCarencePMC(carencePmc.getPeriodeApplicationCarence().getFin());
              cepa.setNbJoursCarencePMC(carencePmc.getPeriodeApplicationCarence().getDuree());
            }
          }
        }
        if (!pmcIndemnisablePriseEnCompte)
        {
          PreavisMesureConservatoireIndemnisable pmci = retrouverPmcI(cepa.getListeEnsembleCarences());
          if (pmci != null)
          {
            cepa.setDebutPmcIndemnisable(pmci.getPeriodeApplicationPMC().getDebut());
            cepa.setTermePmcIndemnisable(pmci.getPeriodeApplicationPMC().getFin());
            cepa.setNbJoursPmcIndemnisable(pmci.getPeriodeApplicationPMC().getDuree());
          }
        }
      }
    }
    else
    {
      PreavisMesureConservatoireIndemnisable pmci = retrouverPmcI(cepa.getListeEnsembleCarences());
      if (pmci != null)
      {
        cepa.setDebutPmcIndemnisable(pmci.getPeriodeApplicationPMC().getDebut());
        cepa.setTermePmcIndemnisable(pmci.getPeriodeApplicationPMC().getFin());
        cepa.setNbJoursPmcIndemnisable(pmci.getPeriodeApplicationPMC().getDuree());
      }
    }
    Differe differe = (Differe)OutilCarence.trouverCarence(resultat.getListeCarencesEffectives(), "Différé");
    if (differe != null)
    {
      cepa.setDebutCarenceDiffere(differe.getPeriodeEffet().getDebut());
      cepa.setTermeCarenceDiffere(differe.getPeriodeEffet().getFin());
      cepa.setNbJoursCarenceDiffere(differe.getQuantiteInitialJour());
    }
  }
  
  private static PreavisMesureConservatoireIndemnisable retrouverPmcI(Collection collectionEnsembleCarences)
  {
    PreavisMesureConservatoireIndemnisable pmciCandidate = null;
    PreavisMesureConservatoireIndemnisable pmciEtudiee = null;
    Iterator iterE = collectionEnsembleCarences.iterator();
    while (iterE.hasNext())
    {
      EnsembleCarences ensembleCarences = (EnsembleCarences)iterE.next();
      pmciEtudiee = ensembleCarences.getPmcIndemnisable();
      if (pmciCandidate == null) {
        pmciCandidate = pmciEtudiee;
      }
      if ((pmciEtudiee != null) && 
        (pmciEtudiee.getPeriodeApplicationPMC().getFin().estApres(pmciCandidate.getPeriodeApplicationPMC().getFin()))) {
        pmciCandidate = pmciEtudiee;
      }
    }
    return pmciCandidate;
  }
  
  private static void leverAlerteA11MNB4SurCarenceIslr(Demande demande, ActiviteSalarie periodeActiviteSalarieCourante)
  {
    Collection listeActivitesSalariees = null;
    
    String codeAlerteNonBloquante = "A11MNB4";
    if (demande.getAlertesNonBloquantes().containsKey(codeAlerteNonBloquante))
    {
      listeActivitesSalariees = (Collection)demande.getAlertesNonBloquantes().get(codeAlerteNonBloquante);
      
      ObjetAlertesNonBloquantes objetAlertesNonBloquantes = new ObjetAlertesNonBloquantes(periodeActiviteSalarieCourante);
      if (!listeActivitesSalariees.contains(objetAlertesNonBloquantes)) {
        listeActivitesSalariees.add(objetAlertesNonBloquantes);
      }
    }
    else
    {
      listeActivitesSalariees = new ArrayList();
      
      listeActivitesSalariees.add(new ObjetAlertesNonBloquantes(periodeActiviteSalarieCourante));
      demande.getAlertesNonBloquantes().put(codeAlerteNonBloquante, listeActivitesSalariees);
    }
  }
}

/* Location:
 * Qualified Name:     ConstitutionDelaiReport
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */