package fr.unedic.cali.asu.cge01.p03.liquidation.parcours;

import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConditionChomageTotal;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.RechercherDernierSinistre;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesQualifiables;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;

public class DeterminationConditionChomageTotal
  extends ParcoursCali
  implements ParcoursAssurance
{
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(p_contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La DemandeAssurance est null pour une determination de chomage total");
    }
    Demande demandeCourante = DomLiquidationAssurance.getDemande(p_contexte);
    DossierExamen dossierExamenCourant = (DossierExamen)demandeCourante.getDossierExamen();
    if (dossierExamenCourant == null) {
      throw new ContexteException("ASU_PR_CALI_L_CONTEXTE_ABSENCE_DOSSIER_EXAMEN", "Le dossier examen est absent  pour une determination de chomage total");
    }
    Reglement reglementOdCourante = dossierExamenCourant.getReglementApplicable().getReglement();
    if (reglementOdCourante == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CONTEXTE", "Le réglement applicable est absent  pour une determination de chomage total");
    }
  }
  
  public Resultat demarrer(Contexte p_contexte)
    throws CoucheLogiqueException
  {
    if (Log.isTraceActive(DeterminationConditionChomageTotal.class, Niveau.DEBUG))
    {
      Log.ecritTrace(Niveau.DEBUG, DeterminationConditionChomageTotal.class, "demarrer", "");
      Log.ecritTrace(Niveau.DEBUG, DeterminationConditionChomageTotal.class, "demarrer", "\t\t******** Début Parcours DeterminationConditionChomageTotal ********\n");
    }
    Resultat resultatCapa05 = new Resultat(1);
    
    Demande demandeCourante = DomLiquidationAssurance.getDemande(p_contexte);
    DossierExamen dossierExamenCourant = (DossierExamen)demandeCourante.getDossierExamen();
    ConditionChomageTotal condition = dossierExamenCourant.createConditionChomageTotal();
    Reglement reglementOdCourante = dossierExamenCourant.getReglementApplicable().getReglement();
    
    ProduitSpec produit = ((DossierAffectation)demandeCourante.getDossierAffectation()).getProduit();
    if (!reglementOdCourante.equals(produit.getReglement("A4")))
    {
      condition.setEtatSatisfait(true);
    }
    else if (demandeCourante.getFaitGenerateur().getDateFaitGenerateur().estApresOuCoincideAvec(ConditionChomageTotal.DATE_FAIT_GENERATEUR))
    {
      condition.setEtatSatisfait(true);
    }
    else
    {
      Chronologie chronoPeriodesQualifiees = demandeCourante.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(new FiltrePeriodesQualifiables());
      
      TravailSpec dernierSinistre = RechercherDernierSinistre.rechercherDernierContratTravailRompu(demandeCourante.getDateExamen(), chronoPeriodesQualifiees);
      if ((dernierSinistre != null) && (!demandeCourante.getFaitGenerateur().getPeriodeFaitGenerateur().estLaMeme((ActiviteSalarie)dernierSinistre)))
      {
        condition.setEtatSatisfait(false);
        condition.setCodeMotifEchec(51);
      }
      else
      {
        condition.setEtatSatisfait(true);
      }
    }
    if (condition.estSatisfait())
    {
      resultatCapa05.setEtat(0);
    }
    else
    {
      resultatCapa05.setEtat(1);
      resultatCapa05.setMessageErreur(Integer.toString(condition.getCodeMotifEchec()));
    }
    if (Log.isTraceActive(DeterminationConditionChomageTotal.class, Niveau.DEBUG))
    {
      Log.ecritTrace(Niveau.DEBUG, DeterminationConditionChomageTotal.class, "demarrer", "");
      Log.ecritTrace(Niveau.DEBUG, DeterminationConditionChomageTotal.class, "demarrer", "\t\t******** Fin Parcours DeterminationConditionChomageTotal ********\n");
    }
    return resultatCapa05;
  }
}

/* Location:
 * Qualified Name:     DeterminationConditionChomageTotal
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */