package fr.unedic.cali.asu.cge01.p03.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.competence.OutilDeterminationCompetence;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Readmission;
import fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels.DeterminationCompetence;
import fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels.DeterminationDureeEffective;
import fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels.DeterminationProduitResultant;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.asu.dom.ResultatDeterminationCompetence;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;

public abstract class ParcoursConstitutionProduitResultant
  extends ParcoursCali
  implements ParcoursAssurance
{
  protected MontantAsuSpec m_montantPrecedent = null;
  protected MontantAsuSpec m_montantCourant = null;
  protected MontantAsuSpec m_montantPrecedentAvecCompetenceDuDroitAServir = null;
  protected MontantAsuSpec m_montantCourantAvecCompetenceDuDroitAServir = null;
  protected MontantAsuSpec m_montantProduitResultant = null;
  protected Quantite m_dureeProduitResultant = null;
  protected Quantite m_capitalComparatifDroitCourant = null;
  protected Quantite m_capitalProduitResultant = null;
  protected Quantite m_capitalComparatifDroitPrecedent = null;
  protected Quantite m_dureeIntermediaireDroitCourant = null;
  protected Quantite m_dureeIntermediaireDroitPrecedent = null;
  protected Damj m_pointDepartUnique = null;
  protected Readmission m_readmissionCourante = null;
  protected DeterminationProduitResultant m_determinationProduitResultant = null;
  
  public abstract Resultat demarrer(Contexte paramContexte)
    throws CoucheLogiqueException, ApplicativeException;
  
  public Resultat constitutionProduitResultant(Contexte p_contexte)
    throws CoucheLogiqueException, ApplicativeException
  {
    DomLiquidationAssurance dom = (DomLiquidationAssurance)p_contexte.getDonnees();
    Demande demandeCourante = dom.getDemande();
    DossierExamen dossierExamenCourant = (DossierExamen)demandeCourante.getDossierExamen();
    
    recuperationCapitaux(demandeCourante, dossierExamenCourant);
    
    recuperationMontants(demandeCourante, dossierExamenCourant);
    
    int typeReadmission = recuperationDuree(dossierExamenCourant, demandeCourante);
    
    miseAJourCepa15(demandeCourante, dom, typeReadmission);
    
    return new Resultat(0);
  }
  
  private void recuperationCapitaux(Demande p_demandeCourante, DossierExamen p_dossierExamenCourant)
    throws CoucheLogiqueException, ApplicativeException
  {
    m_montantPrecedent = m_determinationProduitResultant.obtenirMontantDroitPrecedent(p_dossierExamenCourant, p_demandeCourante);
    
    m_montantCourant = m_determinationProduitResultant.obtenirMontantDroitCourant(p_dossierExamenCourant);
    
    m_pointDepartUnique = m_determinationProduitResultant.determinerPointDepartUnique(p_demandeCourante, m_montantCourant, m_montantPrecedent);
    
    m_dureeIntermediaireDroitCourant = DeterminationDureeEffective.determinerDureeEffectivePourComparaisonCapitaux(p_demandeCourante, m_pointDepartUnique);
    
    m_capitalComparatifDroitCourant = m_determinationProduitResultant.obtenirCapitalPourComparaison(m_dureeIntermediaireDroitCourant, m_montantCourant, p_dossierExamenCourant, p_demandeCourante, true);
    
    m_dureeIntermediaireDroitPrecedent = m_determinationProduitResultant.determinerDureeDroitPrecedentPourCalculCapital(p_demandeCourante, m_pointDepartUnique, m_montantPrecedent);
    
    m_capitalComparatifDroitPrecedent = m_determinationProduitResultant.obtenirCapitalPourComparaison(m_dureeIntermediaireDroitPrecedent, m_montantPrecedent, p_dossierExamenCourant, p_demandeCourante, false);
    
    verifierCapitalPrecedentSP(m_dureeIntermediaireDroitPrecedent, m_montantPrecedent, m_capitalComparatifDroitPrecedent);
    if (m_capitalComparatifDroitPrecedent.compareTo(m_capitalComparatifDroitCourant) > 0) {
      m_capitalProduitResultant = m_capitalComparatifDroitPrecedent;
    } else {
      m_capitalProduitResultant = m_capitalComparatifDroitCourant;
    }
  }
  
  private void recuperationMontants(Demande p_demandeCourante, DossierExamen p_dossierExamenCourant)
    throws CoucheLogiqueException
  {
    DeterminationCompetence determinationCompetence = DeterminationCompetence.getInstance();
    ResultatDeterminationCompetence resultatDeterminationCompetence = new ResultatDeterminationCompetence();
    CompetenceSpec competence = p_dossierExamenCourant.getCompetence();
    OutilDeterminationCompetence.mapperCompetenceSurResultat(competence, resultatDeterminationCompetence);
    
    determinationCompetence.determinerCompetencesProduitResultant(p_demandeCourante, m_capitalComparatifDroitCourant.getValeur(), m_capitalComparatifDroitPrecedent.getValeur(), resultatDeterminationCompetence);
    
    OutilDeterminationCompetence.mapperResultatSurCompetence(resultatDeterminationCompetence, competence);
    
    m_montantPrecedentAvecCompetenceDuDroitAServir = m_determinationProduitResultant.obtenirMontantDroitPrecedentAvecCompetenceAServir(p_dossierExamenCourant, p_demandeCourante);
    
    m_montantCourantAvecCompetenceDuDroitAServir = m_determinationProduitResultant.obtenirMontantDroitCourantAvecCompetenceAServir(p_dossierExamenCourant);
    if (m_montantPrecedentAvecCompetenceDuDroitAServir.getMontantPrecompteEffectif().compareTo(m_montantCourantAvecCompetenceDuDroitAServir.getMontantPrecompteEffectif()) > 0) {
      m_montantProduitResultant = m_montantPrecedentAvecCompetenceDuDroitAServir;
    } else if (m_montantPrecedentAvecCompetenceDuDroitAServir.getMontantPrecompteEffectif().compareTo(m_montantCourantAvecCompetenceDuDroitAServir.getMontantPrecompteEffectif()) == 0)
    {
      if (m_montantPrecedentAvecCompetenceDuDroitAServir.getSjrNonReduit().compareTo(m_montantCourantAvecCompetenceDuDroitAServir.getSjrNonReduit()) > 0) {
        m_montantProduitResultant = m_montantPrecedentAvecCompetenceDuDroitAServir;
      } else {
        m_montantProduitResultant = m_montantCourantAvecCompetenceDuDroitAServir;
      }
    }
    else {
      m_montantProduitResultant = m_montantCourantAvecCompetenceDuDroitAServir;
    }
  }
  
  private int recuperationDuree(DossierExamen p_dossierExamenCourant, Demande p_demandeCourante)
    throws CoucheLogiqueException
  {
    int typeReadmission = m_determinationProduitResultant.determinerTypeReadmission(p_dossierExamenCourant.getConstitutionProduitResultant(), m_montantProduitResultant, m_capitalProduitResultant, m_montantPrecedentAvecCompetenceDuDroitAServir, m_montantCourantAvecCompetenceDuDroitAServir, m_capitalComparatifDroitPrecedent, m_capitalComparatifDroitCourant);
    switch (typeReadmission)
    {
    case 11: 
      m_readmissionCourante = ((Readmission)m_determinationProduitResultant.miseAJourReadmissionEnFonctionType(typeReadmission, p_demandeCourante));
      
      m_montantProduitResultant = m_montantPrecedentAvecCompetenceDuDroitAServir;
      m_capitalProduitResultant = m_capitalComparatifDroitPrecedent;
      m_dureeProduitResultant = m_dureeIntermediaireDroitPrecedent;
      
      break;
    case 26: 
      m_readmissionCourante = ((Readmission)m_determinationProduitResultant.miseAJourReadmissionEnFonctionType(typeReadmission, p_demandeCourante));
      
      m_dureeProduitResultant = m_determinationProduitResultant.determinationDureeProduitResultant(m_readmissionCourante, m_montantProduitResultant, m_pointDepartUnique, m_capitalProduitResultant);
      
      break;
    default: 
      m_montantProduitResultant = m_montantCourantAvecCompetenceDuDroitAServir;
      m_capitalProduitResultant = m_capitalComparatifDroitCourant;
      m_dureeProduitResultant = m_dureeIntermediaireDroitCourant;
    }
    return typeReadmission;
  }
  
  protected void miseAJourCepa15(Demande p_demandeCourante, DomLiquidationAssurance p_dom, int p_typeReadmission)
    throws CoucheLogiqueException
  {
    switch (p_typeReadmission)
    {
    case 11: 
      readmissionDroitPrecedent(p_demandeCourante, p_dom);
      break;
    case 26: 
      readmissionDroitResultant(p_demandeCourante, p_dom);
      break;
    default: 
      alimentationCepaDroitCourant(p_demandeCourante);
    }
  }
  
  protected void readmissionDroitPrecedent(Demande p_demandeCourante, DomLiquidationAssurance p_dom)
    throws CoucheLogiqueException
  {
    affectationDemandeOrigine(p_demandeCourante, p_dom);
    alimentationCepaDroitPrecedent(p_demandeCourante);
  }
  
  protected void readmissionDroitResultant(Demande p_demandeCourante, DomLiquidationAssurance p_dom)
    throws CoucheLogiqueException
  {
    affectationDemandeOrigine(p_demandeCourante, p_dom);
    alimentationCepaDroitResultant(p_demandeCourante);
  }
  
  protected void alimentationCepaDroitPrecedent(Demande p_demandeCourante)
    throws CoucheLogiqueException
  {
    m_determinationProduitResultant.affecterMontantPrecedentAvecCompetenceAServir(m_readmissionCourante, m_montantPrecedent);
    
    m_determinationProduitResultant.miseAJourCapitauxSurCepa15(m_readmissionCourante, m_capitalComparatifDroitPrecedent, m_capitalComparatifDroitCourant);
    
    m_determinationProduitResultant.affecterDureeDroitCourant(p_demandeCourante, m_dureeIntermediaireDroitCourant);
    
    m_determinationProduitResultant.affecterDureeDroitPrecedent(m_readmissionCourante, m_dureeIntermediaireDroitPrecedent);
    
    m_determinationProduitResultant.affecterDureeDroitResultant(m_dureeIntermediaireDroitPrecedent, m_readmissionCourante);
    
    m_determinationProduitResultant.constitutionMontantCepa15(m_montantPrecedentAvecCompetenceDuDroitAServir, m_readmissionCourante);
    
    m_determinationProduitResultant.reportElementsDroits(m_readmissionCourante, p_demandeCourante);
  }
  
  protected void alimentationCepaDroitResultant(Demande p_demandeCourante)
    throws CoucheLogiqueException
  {
    m_determinationProduitResultant.affecterMontantPrecedentAvecCompetenceAServir(m_readmissionCourante, m_montantPrecedent);
    
    m_determinationProduitResultant.miseAJourCapitauxSurCepa15(m_readmissionCourante, m_capitalComparatifDroitPrecedent, m_capitalComparatifDroitCourant);
    
    m_determinationProduitResultant.affecterDureeDroitCourant(p_demandeCourante, m_dureeIntermediaireDroitCourant);
    
    m_determinationProduitResultant.affecterDureeDroitPrecedent(m_readmissionCourante, m_dureeIntermediaireDroitPrecedent);
    
    m_determinationProduitResultant.affecterDureeDroitResultant(m_dureeProduitResultant, m_readmissionCourante);
    
    m_determinationProduitResultant.constitutionMontantCepa15(m_montantProduitResultant, m_readmissionCourante);
    
    m_determinationProduitResultant.reportElementsDroits(m_readmissionCourante, p_demandeCourante);
  }
  
  protected void alimentationCepaDroitCourant(Demande p_demandeCourante)
    throws CoucheLogiqueException
  {
    DossierExamen dossierExamenCourant = (DossierExamen)p_demandeCourante.getDossierExamen();
    
    m_determinationProduitResultant.affecterMontantPrecedentAvecCompetenceAServir(dossierExamenCourant, m_montantPrecedent);
    
    m_determinationProduitResultant.miseAJourCapitauxSurCepa15(dossierExamenCourant, m_capitalComparatifDroitPrecedent, m_capitalComparatifDroitCourant);
    
    m_determinationProduitResultant.affecterDureeDroitCourant(p_demandeCourante, m_dureeIntermediaireDroitCourant);
    
    m_determinationProduitResultant.affecterDureeDroitPrecedent(dossierExamenCourant, m_dureeIntermediaireDroitPrecedent);
  }
  
  protected abstract void affectationDemandeOrigine(Demande paramDemande, DomLiquidationAssurance paramDomLiquidationAssurance)
    throws CoucheLogiqueException;
  
  protected abstract void verifierCapitalPrecedentSP(Quantite paramQuantite1, MontantAsuSpec paramMontantAsuSpec, Quantite paramQuantite2)
    throws CoucheLogiqueException;
  
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    m_determinationProduitResultant = DeterminationProduitResultant.getInstance();
  }
}

/* Location:
 * Qualified Name:     ParcoursConstitutionProduitResultant
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */