package fr.unedic.cali.asu.cge01.p03.liquidation.parcours;

import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.OutilDeterminationOrdreObjectifs;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.fabriques.FabriqueStrategieContexteRepriseSystematique;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieContexteRepriseSystematiqueSpec;
import fr.unedic.cali.asu.cge01.p03.liquidation.fabriques.FabriqueStrategieFaitGenerateurDelaiValidite;
import fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels.strategies.StrategieFaitGenerateurDelaiValiditeSpec;
import fr.unedic.cali.asu.cge01.p03.parametres.Parametres;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.EreDemandeExpresse;
import fr.unedic.cali.asu.dom.ErePassageCPSuiteRejetDV;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.outilsfonctionnels.OutilDeterminationObjectifReprise;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsActiviteConserve;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsChomageSansRCT;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.LigneAsuCge01;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.outilsfonctionnels.OutilDemande;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import java.util.ArrayList;
import java.util.List;

public class ParcoursDeterminationOrdreObjectifs
  extends ParcoursCali
{
  private int numeroOrdre = 1;
  
  public Resultat demarrer(Contexte p_contexte)
    throws CoucheLogiqueException
  {
    Demande demandeCourante = getDemande(p_contexte);
    int contexteExamen = getDom(p_contexte).getContexteExamen();
    
    List listeTypesObjectifs = null;
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeCourante, "ASPSJACENT")) {
      listeTypesObjectifs = determinerObjectifsSansAntecedent();
    } else if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeCourante, "RECHARGE")) {
      listeTypesObjectifs = determinerObjectifsRechargement();
    } else if (OutilDemande.estUneDemandeFinDroitCasGeneral(demandeCourante)) {
      listeTypesObjectifs = determinerObjectifsDemandeRechargement();
    } else if (demandeCourante.estLiquideeAvecDroitOptionReprise()) {
      listeTypesObjectifs = determinerObjectifsDroitOptionReprise();
    } else if (demandeCourante.getDecisionAutomatique() == 2) {
      listeTypesObjectifs = determinerObjectifsRepriseAutomatique();
    } else if (demandeCourante.getDecisionAutomatique() == 1) {
      listeTypesObjectifs = determinerObjectifsRejetAutomatique(contexteExamen);
    } else if ((demandeCourante.getEvenementReferenceExamen() instanceof ErePassageCPSuiteRejetDV)) {
      listeTypesObjectifs = OutilDeterminationOrdreObjectifs.getInstance().determinerObjectifsExamenDv122Jour(demandeCourante, contexteExamen);
    } else if (OutilsActiviteConserve.estUneDemandeDeRevision(demandeCourante)) {
      listeTypesObjectifs = determinerObjectifsRevision(contexteExamen);
    } else {
      switch (getDom(p_contexte).getContexteExamen())
      {
      case 1: 
        listeTypesObjectifs = determinerObjectifsSansAntecedent();
        break;
      case 2: 
        listeTypesObjectifs = determinerObjectifsAvecAntecedentNonValide(demandeCourante);
        break;
      case 3: 
        listeTypesObjectifs = determinerObjectifsAvecAntecedentValide(p_contexte);
        break;
      case 4: 
        listeTypesObjectifs = determinerObjectifsAntecedentSecteurPublic(demandeCourante);
      }
    }
    demandeCourante.viderListeObjectifsExamen();
    for (int i = 0; i < listeTypesObjectifs.size(); i++)
    {
      int sousTypeObjectif = ((Integer)listeTypesObjectifs.get(i)).intValue();
      
      ObjectifExamen objectif = demandeCourante.creerObjectifExamen(sousTypeObjectif, getProduit(sousTypeObjectif, p_contexte));
      ajouteObjectifSurDemande(objectif, demandeCourante);
    }
    if ((demandeCourante.getDecisionAutomatique() == 2) && (demandeCourante.getListObjectifExamen() != null) && (demandeCourante.getListObjectifExamen().size() < 1)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ERR_PAS_OBJECTIF_POUR_REPRISE_AUTO");
    }
    return new Resultat();
  }
  
  protected List<Integer> determinerObjectifsRechargement()
  {
    List<Integer> listeTypesObjectifs = new ArrayList();
    
    listeTypesObjectifs.add(Integer.valueOf(44));
    
    return listeTypesObjectifs;
  }
  
  protected List<Integer> determinerObjectifsDemandeRechargement()
  {
    List<Integer> listeTypesObjectifs = new ArrayList();
    
    listeTypesObjectifs.add(Integer.valueOf(12));
    
    return listeTypesObjectifs;
  }
  
  private void ajouteObjectifSurDemande(ObjectifExamen objectif, Demande demandeCourante)
  {
    objectif.setNumeroOrdre(numeroOrdre);
    demandeCourante.ajouterObjectifExamen(objectif);
    numeroOrdre += 1;
  }
  
  private ProduitAsuSpec getProduit(int sousType, Contexte contexte)
  {
    ProduitAsuSpec produit = null;
    if ((sousType == 14) || (sousType == 15) || (sousType == 34) || (sousType == 13) || (sousType == 27)) {
      produit = getDom(contexte).getProduitPrecedent();
    }
    if ((sousType == 12) || (sousType == 11) || (sousType == 26) || (sousType == 10) || (sousType == 30) || (sousType == 44)) {
      produit = (ProduitAsuSpec)getDom(contexte).getDemande().getDossierAffectationAdmission().getProduit();
    }
    if (sousType == 50) {
      produit = (ProduitAsuSpec)LigneAsuCge01.getInstance().getProduitActif(getDom(contexte).getDemande().getDateExamen());
    }
    return produit;
  }
  
  protected List<Integer> determinerObjectifsRepriseAutomatique()
  {
    List<Integer> listeTypesObjectifs = new ArrayList();
    
    listeTypesObjectifs.add(Integer.valueOf(27));
    
    return listeTypesObjectifs;
  }
  
  protected List<Integer> determinerObjectifsRejetAutomatique(int contexteExamen)
  {
    List<Integer> listeTypesObjectifs = new ArrayList();
    
    listeTypesObjectifs.add(Integer.valueOf(10));
    if (contexteExamen == 3) {
      listeTypesObjectifs.add(Integer.valueOf(27));
    }
    return listeTypesObjectifs;
  }
  
  protected List<Integer> determinerObjectifsRevision(int contexteExamen)
  {
    List<Integer> listeTypesObjectifs = new ArrayList();
    if (contexteExamen == 3) {
      listeTypesObjectifs.add(Integer.valueOf(30));
    }
    return listeTypesObjectifs;
  }
  
  protected List<Integer> determinerObjectifsExamenDemandeExpresse()
  {
    List<Integer> listeTypesObjectifs = new ArrayList();
    
    listeTypesObjectifs.add(Integer.valueOf(12));
    
    return listeTypesObjectifs;
  }
  
  protected List<Integer> determinerObjectifsDroitOptionReprise()
  {
    List<Integer> listeTypesObjectifs = new ArrayList();
    
    listeTypesObjectifs.add(Integer.valueOf(13));
    
    return listeTypesObjectifs;
  }
  
  protected List<Integer> determinerObjectifsSansAntecedent()
  {
    List<Integer> listeTypesObjectifs = new ArrayList();
    
    listeTypesObjectifs.add(Integer.valueOf(10));
    
    return listeTypesObjectifs;
  }
  
  protected List<Integer> determinerObjectifsAvecAntecedentNonValide(Demande p_demande)
  {
    List<Integer> listeTypesObjectifs = new ArrayList();
    
    listeTypesObjectifs.add(Integer.valueOf(12));
    if (!p_demande.estEnContexteDroitAnterieurSecteurPublic()) {
      listeTypesObjectifs.add(Integer.valueOf(13));
    }
    return listeTypesObjectifs;
  }
  
  protected List<Integer> determinerObjectifsAvecAntecedentValide(Contexte contexte)
    throws CoucheLogiqueException
  {
    List<Integer> listeTypesObjectifs = new ArrayList();
    Demande demande = getDemande(contexte);
    EvenementReferenceExamenSpec ere = demande.getEvenementReferenceExamen();
    if (demande.estDroitOptionReadmission())
    {
      listeTypesObjectifs.add(Integer.valueOf(12));
    }
    else if (OutilDeterminationObjectifReprise.getInstance().determineDateExtinctionReliquatSurObjectifReprise(demande) != null)
    {
      listeTypesObjectifs.add(Integer.valueOf(12));
      ajouterObjectifReprise(demande, listeTypesObjectifs, 13);
    }
    else
    {
      Damj dateFgPrecedent = demande.getDateFaitGenerateurOdPrecedente();
      if (getIndividu(contexte).getAgeALaDate(dateFgPrecedent).compareTo(Parametres.AGE_57_ANS_6_MOIS) >= 0)
      {
        if ((ere instanceof EreDemandeExpresse))
        {
          listeTypesObjectifs.addAll(determinerObjectifDemandeExpresseAvecReliquatValide(demande));
        }
        else
        {
          StrategieContexteRepriseSystematiqueSpec strategie = recupererStrategieRepriseSystematique(demande);
          listeTypesObjectifs.addAll(strategie.determinerObjectifsExamenPourRepriseSystematique(demande));
        }
      }
      else if ((ere instanceof EreDemandeExpresse))
      {
        listeTypesObjectifs.addAll(determinerObjectifDemandeExpresseAvecReliquatValide(demande));
      }
      else
      {
        StrategieContexteRepriseSystematiqueSpec strategie = recupererStrategieRepriseSystematique(demande);
        if (strategie.determinerContexteRepriseSystematique(demande))
        {
          demande.setContexteDeRepriseSansFCT(true);
          
          TravailSpec dernierSinistre = ((DossierAffectation)demande.getDossierAffectation()).getSinistre();
          if (dernierSinistre != null)
          {
            CritereStrategie critereStrategie = new CritereStrategie();
            critereStrategie.setDatePivot(dernierSinistre.getDateFin());
            StrategieFaitGenerateurDelaiValiditeSpec strategieFgdDelaiValiditeCourante = (StrategieFaitGenerateurDelaiValiditeSpec)FabriqueStrategieFaitGenerateurDelaiValidite.getInstance().getStrategie(critereStrategie);
            
            ArrayList listeObjectifs = strategieFgdDelaiValiditeCourante.determinerOrdreObjectif(demande);
            for (int i = 0; i < listeObjectifs.size(); i++)
            {
              int objectif = ((Integer)listeObjectifs.get(i)).intValue();
              if ((objectif == 13) || (objectif == 15)) {
                ajouterObjectifReprise(demande, listeTypesObjectifs, objectif);
              } else {
                listeTypesObjectifs.add(Integer.valueOf(12));
              }
            }
          }
          else
          {
            listeTypesObjectifs.addAll(strategie.determinerObjectifsExamenPourRepriseSystematique(demande));
          }
        }
        else
        {
          listeTypesObjectifs.add(Integer.valueOf(12));
          ajouterObjectifReprise(demande, listeTypesObjectifs, 13);
          if (getDom(contexte).estEnRepriseContextuelle())
          {
            listeTypesObjectifs = new ArrayList();
            ajouterObjectifReprise(demande, listeTypesObjectifs, 14);
            listeTypesObjectifs.add(Integer.valueOf(12));
          }
        }
      }
    }
    return listeTypesObjectifs;
  }
  
  private StrategieContexteRepriseSystematiqueSpec recupererStrategieRepriseSystematique(Demande demande)
    throws CoucheLogiqueException
  {
    CritereStrategie critere = new CritereStrategie();
    critere.setDatePivot(demande.getDateExamen());
    return (StrategieContexteRepriseSystematiqueSpec)FabriqueStrategieContexteRepriseSystematique.getInstance().getStrategie(critere);
  }
  
  protected List<Integer> determinerObjectifDemandeExpresseAvecReliquatValide(Demande demande)
    throws CoucheLogiqueException
  {
    CritereStrategie critere = new CritereStrategie();
    critere.setDatePivot(demande.getDateExamen());
    
    StrategieContexteRepriseSystematiqueSpec strategie = (StrategieContexteRepriseSystematiqueSpec)FabriqueStrategieContexteRepriseSystematique.getInstance().getStrategie(critere);
    
    return strategie.determinerObjectifsExamenDemandeExpresseAvecReliquatValide(demande);
  }
  
  protected List<Integer> determinerObjectifsAntecedentSecteurPublic(Demande p_demande)
    throws CoucheLogiqueException
  {
    return recupererStrategieRepriseSystematique(p_demande).determinerObjectifsAntecedentSecteurPublic(p_demande);
  }
  
  protected Demande getDemande(Contexte p_contexte)
  {
    Demande demande = (Demande)((DomLiquidationAssurance)p_contexte.getDonnees()).getDemandeSpec();
    demande.setLiquideeAvecDroitOptionReprise(((DomLiquidationAssurance)p_contexte.getDonnees()).isLiquidationAvecDroitOptionReprise());
    
    return demande;
  }
  
  private void ajouterObjectifReprise(Demande p_demande, List<Integer> p_listeTypesObjectifs, int p_typeReprise)
  {
    boolean ajouterReprise = true;
    if ((OutilsChomageSansRCT.estDemandeEnContexteDeChomageEnCoursDeSuspension(p_demande)) && ((!p_demande.getDonneesTemporaires().isDecisionCPRenseigneeChomageTotalSansRupture()) || (!p_demande.getDonneesTemporaires().isAvisFavorableCPChomageTotalSansRupture()))) {
      ajouterReprise = false;
    }
    if (ajouterReprise) {
      if ("S".equalsIgnoreCase(p_demande.getModeLiquidation())) {
        p_listeTypesObjectifs.add(Integer.valueOf(34));
      } else {
        p_listeTypesObjectifs.add(Integer.valueOf(p_typeReprise));
      }
    }
  }
  
  protected DomLiquidationAssurance getDom(Contexte p_contexte)
  {
    return (DomLiquidationAssurance)p_contexte.getDonnees();
  }
}

/* Location:
 * Qualified Name:     ParcoursDeterminationOrdreObjectifs
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */