package fr.unedic.cali.asu.cge01.p03.migration.graphes;

import fr.unedic.cali.asu.cge01.outilsfonctionnels.RevalorisationSalaire;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Attribution;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionMontantsBruts;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionProduitResultant;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Decision;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Readmission;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.dom.Reliquat;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.autresdoms.cohab.dom.CodesErreursMigration;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.affectation.Parametres;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cohabitation.sigma.migration.dom.DecisionMigreeAsuV1;
import fr.unedic.cohabitation.sigma.migration.dom.DemandeMigreeAsuV1;
import fr.unedic.cohabitation.sigma.migration.dom.DemandeMigreeV1;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.QuantiteJour;
import java.math.BigDecimal;
import java.util.Collection;

public class GrapheReadmissionDroitCourant
  extends GrapheOd
{
  protected ObjectifExamen creerObjectifDecision(DemandeMigreeAsuV1 p_demandeTemporaireSource)
  {
    ObjectifExamen objectifExamen = null;
    
    ProduitAsuSpec produitAsu = (ProduitAsuSpec)Parametres.getProduit(p_demandeTemporaireSource.getCodeProduit());
    
    objectifExamen = (ObjectifExamen)produitAsu.creerObjectifExamen(12, null);
    objectifExamen.setEtat(23);
    
    return objectifExamen;
  }
  
  protected Decision creerDecision(int p_natureDecision)
  {
    Decision nouvelleDecision = null;
    
    nouvelleDecision = new Readmission();
    nouvelleDecision.setNatureDecision(12);
    
    return nouvelleDecision;
  }
  
  protected void creerCeps(DossierExamen p_dossierExamen)
  {
    super.creerCeps(p_dossierExamen);
    
    p_dossierExamen.createConstitutionProduitResultant();
  }
  
  protected void alimenterCeps(DecisionMigreeAsuV1 p_decisionTemporaireSource, DossierExamen p_dossierExamen)
  {
    super.alimenterCeps(p_decisionTemporaireSource, p_dossierExamen);
    
    alimenterProduitResultant(p_decisionTemporaireSource, p_dossierExamen);
  }
  
  protected void alimenterReliquat(DemandeMigreeAsuV1 p_demandeV1, Demande p_demande)
  {
    super.alimenterReliquat(p_demandeV1, p_demande);
    
    p_demande.getReliquat().setReliquatValide(true);
  }
  
  protected void alimenterProduitResultant(DecisionMigreeAsuV1 p_decisionTemporaireSource, DossierExamen p_dossierExamen)
  {
    alimenterTopProduitResultant(p_decisionTemporaireSource, p_dossierExamen);
    
    alimenterValeursDPProduitResultant(p_decisionTemporaireSource, p_dossierExamen);
    
    alimenterDureeProduitResultant(p_decisionTemporaireSource, p_dossierExamen);
  }
  
  protected void alimenterTopProduitResultant(DecisionMigreeAsuV1 p_decisionTemporaireSource, DossierExamen p_dossierExamen)
  {
    ConstitutionProduitResultant cepa15 = p_dossierExamen.getConstitutionProduitResultant();
    if (p_decisionTemporaireSource.isMontantRetenuEstLePrecedent()) {
      cepa15.setMontantRetenu(2);
    } else {
      cepa15.setMontantRetenu(1);
    }
    if (p_decisionTemporaireSource.isCapitalRetenuEstLePrecendent()) {
      cepa15.setCapitalRetenu(2);
    } else {
      cepa15.setCapitalRetenu(1);
    }
  }
  
  protected void alimenterValeursDPProduitResultant(DecisionMigreeAsuV1 p_decisionTemporaireSource, DossierExamen p_dossierExamen)
  {
    ConstitutionProduitResultant produitResultant = p_dossierExamen.getConstitutionProduitResultant();
    if (p_decisionTemporaireSource.getCapitalOdPrecedente() == null) {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_CAPITAL_DP"));
    } else {
      produitResultant.setCapitalDroitPrecedent(p_decisionTemporaireSource.getCapitalOdPrecedente());
    }
    if ((p_decisionTemporaireSource.getCapitalOdPrecedente() != null) && (p_decisionTemporaireSource.getMontantBrutDroitPrecedent() != null)) {
      produitResultant.setDureeDroitPrecedent(new QuantiteJour(Mathematiques.diviseEntier(p_decisionTemporaireSource.getCapitalOdPrecedente().getValeur(), p_decisionTemporaireSource.getMontantBrutDroitPrecedent().getValeur())));
    }
    if (p_decisionTemporaireSource.getMontantBrutDroitPrecedent() != null) {
      produitResultant.setMontantDroitPrecedent(p_decisionTemporaireSource.getMontantBrutDroitPrecedent());
    } else {
      produitResultant.setMontantDroitPrecedent(new QuantiteEuro(new BigDecimal("0")));
    }
    if ((p_decisionTemporaireSource.getMontantSjrInitialDroitRetenu() == null) || (p_decisionTemporaireSource.getDateFinPrcSjrInitialDroitRetenu() == null) || (p_decisionTemporaireSource.getDateAttribution() == null))
    {
      getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_SJRRP_DR"));
    }
    else
    {
      Sjr sjripDroitPrecedent = new Sjr(p_decisionTemporaireSource.getMontantSjrInitialDroitRetenu().getValeur(), p_decisionTemporaireSource.getDateFinPrcSjrInitialDroitRetenu(), null);
      
      Sjr sjrrpDroitPrecedent = RevalorisationSalaire.revaloriserSjr(sjripDroitPrecedent, p_decisionTemporaireSource.getDateAttribution());
      
      produitResultant.setSjrrpProduitPrecedent(sjrrpDroitPrecedent);
    }
  }
  
  protected void alimenterDureeProduitResultant(DecisionMigreeAsuV1 p_decisionTemporaireSource, DossierExamen p_dossierExamen)
  {
    ConstitutionProduitResultant constitutionProduitResultant = p_dossierExamen.getConstitutionProduitResultant();
    
    DureeIndemnisation dureeIndemnisationDC = p_dossierExamen.getConstitutionDurees().getDureeIndemnisation();
    
    ConstitutionDurees constitutionDureesPR = constitutionProduitResultant.createConstitutionDurees();
    
    constitutionDureesPR.createDureeIndemnisation();
    constitutionDureesPR.getDureeIndemnisation().setDureeTheorique(dureeIndemnisationDC.getDureeTheorique());
    constitutionDureesPR.getDureeIndemnisation().setDureeEffective(dureeIndemnisationDC.getDureeEffective());
  }
  
  protected void alimenterDonneesImposees(DemandeMigreeV1 p_demandeV1, DemandeSpec p_demande)
  {
    DossierExamen dossierExamen = (DossierExamen)p_demande.getDossierAffectation().getDossierExamen();
    DecisionMigreeAsuV1 decisionAsu = ((DemandeMigreeAsuV1)p_demandeV1).getDecision();
    
    super.alimenterDonneesImposees(p_demandeV1, p_demande);
    
    ConstitutionProduitResultant produitResultant = dossierExamen.getConstitutionProduitResultant();
    
    produitResultant.setDureeDroitPrecedent(new QuantiteJour(decisionAsu.getDureeEffectiveDroitPrecedent()));
  }
  
  protected Collection getListRecalcule()
  {
    return super.getListRecalcule();
  }
  
  protected void lireCeps(Decision p_decision, DecisionMigreeAsuV1 p_decisionLue)
  {
    super.lireCeps(p_decision, p_decisionLue);
    
    lireTopProduitResultant(p_decision, p_decisionLue);
    
    lireDonneesDroitPrecedent(p_decision, p_decisionLue);
    
    lireDonneesDroitRetenu(p_decision, p_decisionLue);
  }
  
  protected ElementBaseIndemnisation getEBIDroitRetenu(Decision p_decision)
  {
    return ((Attribution)p_decision).getElementBaseIndemnisation();
  }
  
  protected ElementBaseIndemnisation getEBIDroitPrecedent(Decision p_decision)
  {
    AttributionAssuranceSpec attributionPrecedente = p_decision.getAttributionPrecedente();
    if (attributionPrecedente == null)
    {
      attributionPrecedente = p_decision.getDemandeAssurance().rechercherAttributionPrecedenteDuMemeType();
      if (attributionPrecedente == null) {
        return null;
      }
    }
    return attributionPrecedente.getElementBaseIndemnisation();
  }
  
  protected void lireDonneesDroitPrecedent(Decision p_decision, DecisionMigreeAsuV1 p_decisionLue)
  {
    ElementBaseIndemnisation ebiDroitPrecedent = getEBIDroitPrecedent(p_decision);
    if (ebiDroitPrecedent != null)
    {
      if (ebiDroitPrecedent.getSjr().getSalaire() != null) {
        p_decisionLue.setMontantSjrInitialDroitPrecedent(ebiDroitPrecedent.getSjr().getSalaire());
      }
      if (ebiDroitPrecedent.getSjr().getDateDepart() != null) {
        p_decisionLue.setDateFinPrcSjrInitialDroitPrecedent(ebiDroitPrecedent.getSjr().getDateDepart());
      }
      if (ebiDroitPrecedent.getCoefficientTempsPartiel() != null) {
        p_decisionLue.setCoefTempsPartielDroitPrecedent(ebiDroitPrecedent.getCoefficientTempsPartiel());
      }
      if (ebiDroitPrecedent.getCoefficientSaisonnier() != null) {
        p_decisionLue.setCoefCaractereSaisonnierDroitPrecedent(ebiDroitPrecedent.getCoefficientSaisonnier());
      }
    }
    ConstitutionProduitResultant produitResultant = p_decision.getConstitutionProduitResultant();
    if (produitResultant != null)
    {
      if (produitResultant.getDureeDroitPrecedent() != null) {
        p_decisionLue.setDureeEffectiveDroitPrecedent(produitResultant.getDureeDroitPrecedent().getValeur());
      }
      if (produitResultant.getCapitalDroitPrecedent() != null) {
        p_decisionLue.setCapitalOdPrecedente(produitResultant.getCapitalDroitPrecedent().getValeur());
      }
      if ((produitResultant.getConstitutionMontantsBruts() != null) && (produitResultant.getConstitutionMontantsBruts().getMontantJournalierBrut() != null) && (produitResultant.getConstitutionMontantsBruts().getMontantJournalierBrut().getValeur() != null)) {
        p_decisionLue.setMontantBrutDroitPrecedent(produitResultant.getConstitutionMontantsBruts().getMontantJournalierBrut().getValeur());
      }
    }
  }
  
  protected void lireDonneesDroitRetenu(Decision p_decision, DecisionMigreeAsuV1 p_decisionLue)
  {
    ElementBaseIndemnisation ebiDroitRetenu = getEBIDroitRetenu(p_decision);
    if (ebiDroitRetenu != null)
    {
      if (ebiDroitRetenu.getSjr().getSalaire() != null) {
        p_decisionLue.setMontantSjrInitialDroitRetenu(ebiDroitRetenu.getSjr().getSalaire());
      }
      if (ebiDroitRetenu.getSjr().getDateDepart() != null) {
        p_decisionLue.setDateFinPrcSjrInitialDroitRetenu(ebiDroitRetenu.getSjr().getDateDepart());
      }
      if (ebiDroitRetenu.getCoefficientTempsPartiel() != null) {
        p_decisionLue.setCoefTempsPartielDroitRetenu(ebiDroitRetenu.getCoefficientTempsPartiel());
      }
      if (ebiDroitRetenu.getCoefficientSaisonnier() != null) {
        p_decisionLue.setCoefCaractereSaisonnierDroitRetenu(ebiDroitRetenu.getCoefficientSaisonnier());
      }
    }
    ConstitutionProduitResultant produitResultant = p_decision.getConstitutionProduitResultant();
    if (produitResultant != null)
    {
      if ((produitResultant.getConstitutionDurees() != null) && (produitResultant.getConstitutionDurees().getDureeIndemnisation() != null) && (produitResultant.getConstitutionDurees().getDureeIndemnisation().getDureeEffective() != null) && (produitResultant.getConstitutionDurees().getDureeIndemnisation().getDureeEffective().getValeur() != null)) {
        p_decisionLue.setDureeEffectiveDroitRetenu(produitResultant.getConstitutionDurees().getDureeIndemnisation().getDureeEffective().getValeur());
      }
      if ((produitResultant.getConstitutionDurees() != null) && (produitResultant.getConstitutionDurees().getDureeIndemnisation() != null) && (produitResultant.getConstitutionDurees().getDureeIndemnisation().getDureeTheorique() != null) && (produitResultant.getConstitutionDurees().getDureeIndemnisation().getDureeTheorique().getValeur() != null)) {
        p_decisionLue.setDureeTheoriqueDroitRetenu(produitResultant.getConstitutionDurees().getDureeIndemnisation().getDureeTheorique().getValeur());
      }
    }
    lireConstitutionMontantsBrutDroitRetenu(p_decision, p_decisionLue);
  }
  
  protected void lireConstitutionMontantsBrutDroitRetenu(Decision p_decision, DecisionMigreeAsuV1 p_decisionLue)
  {
    p_decisionLue.setMontantBrutRetenu(p_decision.getConstitutionMontantsBruts().getMontantJournalierBrut().getValeur());
    
    p_decisionLue.setCapitalOdRetenu(p_decision.getConstitutionMontantsBruts().getCapitalInitialBrut().getValeur());
  }
  
  protected void lireTopProduitResultant(Decision p_decision, DecisionMigreeAsuV1 p_decisionLue)
  {
    ConstitutionProduitResultant cepa15 = p_decision.getConstitutionProduitResultant();
    if (cepa15.getMontantRetenu() == 2) {
      p_decisionLue.setMontantRetenuEstLePrecedent(true);
    } else {
      p_decisionLue.setMontantRetenuEstLePrecedent(false);
    }
    if (cepa15.getCapitalRetenu() == 2) {
      p_decisionLue.setCapitalRetenuEstLePrecendent(true);
    } else {
      p_decisionLue.setCapitalRetenuEstLePrecendent(false);
    }
  }
  
  protected void miseAJourDemandeOrigine(DemandeSpec p_demande)
  {
    Demande demande = (Demande)p_demande;
    AttributionSpec attributionPrecedente = demande.rechercherAttributionPrecedenteDuMemeType();
    if (attributionPrecedente != null) {
      demande.setDemandeOrigine((DemandeAssuranceSpec)attributionPrecedente.getDemande());
    } else {
      getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_DEM_ORIG_INCONNU"));
    }
  }
}

/* Location:
 * Qualified Name:     GrapheReadmissionDroitCourant
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */