package fr.unedic.cali.asu.cge01.p07.liquidation.outilsfonctionnels.affiliation;

import fr.pe.cali.reglementaire.dom.impl.CriteresFabriqueReglementaire;
import fr.pe.cali.reglementaire.regles.assurance.affiliation.dom.DonneesEntreeCalculAffiliationJoursTravailles;
import fr.pe.cali.reglementaire.regles.assurance.affiliation.dom.ResultatCalculAffiliationJoursTravailles;
import fr.pe.cali.reglementaire.regles.assurance.affiliation.fabrique.FabriqueCorpsRegleCalculAffiliationJoursTravailles;
import fr.pe.cali.reglementaire.regles.assurance.affiliation.outils.spec.IOutilCalculAffiliationJoursTravailles;
import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.dom.ParametresCalculAppartenance;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.OutilAlerteAffiliation;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.OutilCalculAffiliation;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.dom.AlerteAffiliation;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.dom.ParametresAffiliation;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.spec.CalculAffiliationSpec;
import fr.unedic.cali.asu.cge01.p07.liquidation.dom.JustificationAffiliationJoursTravailles;
import fr.unedic.cali.asu.dom.AffiliationSupplementaire;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.JustificationAffiliation;
import fr.unedic.cali.asu.dom.JustificationAffiliationSpec;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.dom.PeriodeElementaire;
import fr.unedic.cali.asu.dom.PlafonnementAffiliation;
import fr.unedic.cali.asu.outilsfonctionnels.DetectionContexteParticulierLiquidation;
import fr.unedic.cali.asu.produits.liquidation.dom.Pra;
import fr.unedic.cali.asu.produits.liquidation.dom.QuantitesAppartenance;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.ObjetAlertesNonBloquantes;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.spec.CalculAppartenanceSpec;
import fr.unedic.cali.dom.spec.ParametresCalculAppartenanceSpec;
import fr.unedic.cali.dom.spec.QuantitesAppartenanceSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.UniteAffiliation;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.List;

public class OutilCalculAppartenance
  implements CalculAppartenanceSpec
{
  private static final int NOMBRE_DECIMAL_COEFFICIENT = 4;
  private static final int NOMBRE_DECIMAL_QUANTITE = 2;
  ProduitAsuSpec produit;
  
  public OutilCalculAppartenance(ProduitAsuSpec produit)
  {
    this.produit = produit;
  }
  
  public QuantitesAppartenanceSpec calculer(DemandeSpec demande, Periode periode, Chronologie passeProfessionnel, Reglement reglement, ParametresCalculAppartenanceSpec parametresCalculAppartenance)
    throws ApplicativeException
  {
    Demande demandeAsu = (Demande)demande;
    
    Chronologie chronosAttributionsEnCoursPmvsDansPra = detectionContexteSuiteOdPmvs(periode, demandeAsu);
    
    QuantitesAppartenance quantitesAppartenances = new QuantitesAppartenance();
    List<AlerteAffiliation> listeAlertesAffiliation = new ArrayList();
    
    ParametresCalculAppartenance parametresCalculAppartenanceImpl = (ParametresCalculAppartenance)parametresCalculAppartenance;
    
    DonneesTemporaires donneesTemporaires = demandeAsu.getDonneesTemporaires();
    Quantite quantiteAffiliationForcee = donneesTemporaires.getQuantiteAffiliation();
    Boolean conditionAffiliationSatisfaiteForcee = donneesTemporaires.isConditionAffiliationSatisfaiteForcee();
    if ((parametresCalculAppartenanceImpl.isPrendreEnCompteDonneesForcees()) && (conditionAffiliationSatisfaiteForcee != null) && (quantiteAffiliationForcee != null))
    {
      Quantite quantiteRequise = ((Pra)periode).getQuantiteAffiliationRequise((Unite)parametresCalculAppartenanceImpl.getListeUnitesReglement().get(0));
      if (conditionAffiliationSatisfaiteForcee.booleanValue())
      {
        if (parametresCalculAppartenanceImpl.getContexteAppel().equals("rechercheReglementApplicable")) {
          quantitesAppartenances = traiterAffiliationForcee(periode, quantiteRequise);
        } else if (parametresCalculAppartenanceImpl.getContexteAppel().equals("cepAffi")) {
          quantitesAppartenances = traiterAffiliationForcee(periode, quantiteAffiliationForcee);
        }
      }
      else
      {
        if ((parametresCalculAppartenanceImpl.getContexteAppel().equals("rechercheReglementApplicable")) && (quantiteAffiliationForcee.getValeur().compareTo(quantiteRequise.getValeur()) >= 0)) {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_REJET_CGE_DF_QUANTITE_AFFI", 1);
        }
        quantitesAppartenances = traiterAffiliationForcee(periode, quantiteAffiliationForcee);
      }
    }
    else
    {
      traiterAffiliationCalculee(periode, passeProfessionnel, demandeAsu, chronosAttributionsEnCoursPmvsDansPra, quantitesAppartenances, listeAlertesAffiliation, parametresCalculAppartenanceImpl);
    }
    if (!listeAlertesAffiliation.isEmpty())
    {
      demandeAsu.setListeAlertesAffiliation(listeAlertesAffiliation);
      
      Collection<ObjetAlertesNonBloquantes> listePeriodesAlerte = new ArrayList();
      ObjetAlertesNonBloquantes alerteNonBloquante = new ObjetAlertesNonBloquantes(periode.getDebut(), periode.getFin(), 9);
      
      listePeriodesAlerte.add(alerteNonBloquante);
      demandeAsu.getAlertesNonBloquantes().put("ALERTE_AFFILIATION", listePeriodesAlerte);
    }
    return quantitesAppartenances;
  }
  
  protected Chronologie detectionContexteSuiteOdPmvs(Periode periode, Demande demandeAsu)
  {
    return DetectionContexteParticulierLiquidation.getInstance().detectionContexteSuiteOdPmvs(demandeAsu, periode, demandeAsu.getDateExamen());
  }
  
  protected void traiterAffiliationCalculee(Periode periode, Chronologie passeProfessionnel, Demande demandeAsu, Chronologie chronosAttributionsEnCoursPmvsDansPra, QuantitesAppartenance quantitesAppartenances, List<AlerteAffiliation> listeAlertesAffiliation, ParametresCalculAppartenance parametresCalculAppartenanceImpl)
    throws ApplicativeException
  {
    ParametresAffiliation parametres = new ParametresAffiliation();
    parametres.setListeContexte(demandeAsu.getListContexteDemande());
    parametres.setEffectuerImputationAffiliationPmvs(parametresCalculAppartenanceImpl.isEffectuerImputationAffiliationPmvs());
    parametres.setChronologieAttributionEnCoursPmvsDansPra(chronosAttributionsEnCoursPmvsDansPra);
    
    parametres.setComptabiliserAffiliationDernierJourFevrier(false);
    parametres.setDateExamen(demandeAsu.getDateExamen());
    parametres.setIndividu(demandeAsu.getDemandeur());
    parametres.setPra((Pra)periode);
    parametres.setProduit(produit);
    parametres.setNePasSanctionnerPnds(parametresCalculAppartenanceImpl.isNePasSanctionnerPnds());
    parametres.setReinitialiserCalculPeriodeElementaires(parametresCalculAppartenanceImpl.isReinitialiserCalculPeriodesElementaires());
    parametres.setComptabiliserAssimilation(parametresCalculAppartenanceImpl.isComptabiliserAssimilation());
    parametres.setContexteAppel(parametresCalculAppartenanceImpl.getContexteAppel());
    
    boolean estContexteEtudeCapa09 = ("couvertureChomageInvolontaire".equals(parametres.getContexteAppel())) || ("inopposabiliteChomageInvolontaire".equals(parametres.getContexteAppel()));
    if ((estContexteEtudeCapa09) && (2 == demandeAsu.getObjectifCourant().getType())) {
      parametres.setDateFaitGenerateur(demandeAsu.getDateFaitGenerateurOdPrecedente());
    } else {
      parametres.setDateFaitGenerateur(demandeAsu.getDateFaitGenerateurOuDernierSinistre());
    }
    List<Unite> listeUniteEtude = parametresCalculAppartenanceImpl.getListeUnitesReglement();
    
    Iterator<Unite> itUnites = listeUniteEtude.iterator();
    while (itUnites.hasNext())
    {
      Unite uniteEtudeCourante = (Unite)itUnites.next();
      
      parametres.setUniteCalcul(uniteEtudeCourante);
      if ("23".equals(uniteEtudeCourante.getCode())) {
        calculerAffiliationPourUniteJourTravaille(passeProfessionnel, quantitesAppartenances, parametres, demandeAsu);
      } else {
        calculerAffiliationPourUniteAutres(passeProfessionnel, demandeAsu, quantitesAppartenances, listeAlertesAffiliation, parametres, uniteEtudeCourante);
      }
    }
    priseEnCompteAlertePNDS(demandeAsu, periode);
  }
  
  protected void calculerAffiliationPourUniteJourTravaille(Chronologie passeProfessionnel, QuantitesAppartenance quantitesAppartenances, ParametresAffiliation parametres, Demande demande)
    throws ApplicativeException
  {
    FabriqueCorpsRegleCalculAffiliationJoursTravailles fabrique = FabriqueCorpsRegleCalculAffiliationJoursTravailles.getInstance();
    CriteresFabriqueReglementaire criteres = new CriteresFabriqueReglementaire();
    criteres.setCodeProduit(parametres.getProduit().getNomUnique());
    criteres.setDate(parametres.getDateExamen());
    IOutilCalculAffiliationJoursTravailles outil = fabrique.recupererOutilCorpsRegle(criteres);
    DonneesEntreeCalculAffiliationJoursTravailles donneesEntree = new DonneesEntreeCalculAffiliationJoursTravailles();
    donneesEntree.setPasseProfessionnel(passeProfessionnel);
    donneesEntree.setAssimilerSuspensionNonAssimilables(false);
    donneesEntree.setIgnorerAssimiliation(!parametres.isComptabiliserAssimilation());
    donneesEntree.setIgnorerPNDS((parametres.isNePasSanctionnerPnds()) || (!parametres.getIndividu().estPndsActive()));
    donneesEntree.setPeriodeRecherche(parametres.getPra());
    donneesEntree.setPnds(parametres.getIndividu().getListePNDSIndividu());
    donneesEntree.setDateExamen(parametres.getDateExamen());
    donneesEntree.setListeContexte(parametres.getListeContexte());
    donneesEntree.setOutilFonctionnel(new OutilFonctionnelAffiliationJoursTravailles(demande.getDemandeur()));
    donneesEntree.setProduit(parametres.getProduit());
    donneesEntree.setDateFaitGenerateur(parametres.getDateFaitGenerateur());
    
    ResultatCalculAffiliationJoursTravailles resultat = outil.calculer(donneesEntree);
    
    parametres.setCalculerUniquementCoefficientPlafonnement(true);
    JustificationAffiliation justifPlafonnement = getOutilCalculAffiliation().calculerAffiliation(passeProfessionnel, parametres);
    parametres.setCalculerUniquementCoefficientPlafonnement(false);
    
    tronquerPlafonnement(justifPlafonnement);
    tronquerPeriodeElementaire(justifPlafonnement);
    tronquerAffiSup(justifPlafonnement);
    epurerPlafonnement(justifPlafonnement);
    
    JustificationAffiliationJoursTravailles justification = new JustificationAffiliationJoursTravailles();
    justification.setJustificationRepartitionJoursTravailles(resultat.getJustificationRepartitionJoursTravailles());
    justification.setJustificationSemaineCivile(resultat.getJustificationSemaineCivile());
    justification.setNombreJoursAffiliation(resultat.getNombreJoursAffiliation());
    justification.setNombreJoursAppartenance(resultat.getNombreJoursAppartenance());
    justification.setNombreJoursAssimilation(resultat.getNombreJoursAssimilation());
    justification.setPeriodeRechercheAffiliation(resultat.getPeriodeRecherche());
    justification.setPeriodesAssimilees(resultat.getPeriodesAssimilees());
    justification.setPlafondAssimilation(resultat.getPlafondAssimilation());
    justification.setListePlafonnementAffiliation(justifPlafonnement.getListPlafonnementAffiliation());
    justification.setListePeriodeElementaires(justifPlafonnement.getListPeriodeElementaire());
    justification.setListeAffiliationSupplementaire(justifPlafonnement.getListAffiliationSupplementaire());
    justification.setEstAffiliationPlafonne(justifPlafonnement.isEstAffiliationPlafonnee());
    quantitesAppartenances.putJustificationAffiliation(justification, Unite.get("jour travaillés"));
    quantitesAppartenances.putQuantiteAffiliation(transformerEnQuantiteJourTravaille(resultat.getNombreJoursAffiliation()));
    quantitesAppartenances.putQuantiteAssimilation(transformerEnQuantiteJourTravaille(resultat.getNombreJoursAssimilation()));
    
    demande.setPeriodesAffiliation(resultat.getActiviteParticipantes());
  }
  
  private void tronquerPlafonnement(JustificationAffiliation justifPlafonnement)
  {
    if ((justifPlafonnement != null) && (justifPlafonnement.getListPlafonnementAffiliation() != null))
    {
      Iterator<PlafonnementAffiliation> it = justifPlafonnement.getListPlafonnementAffiliation().iterator();
      while (it.hasNext())
      {
        PlafonnementAffiliation plafonnementAffiliation = (PlafonnementAffiliation)it.next();
        
        BigDecimal valeur = arrondirCoefficient(plafonnementAffiliation.getCoefficientReducteurAffiliation());
        plafonnementAffiliation.setCoefficientReducteurAffiliation(null);
        plafonnementAffiliation.setCoefficientReducteurAffiliation(valeur);
        
        valeur = arrondirCoefficient(plafonnementAffiliation.getCoefficientReducteurAffiliationSupplementaire());
        plafonnementAffiliation.setCoefficientReducteurAffiliationSupplementaire(null);
        plafonnementAffiliation.setCoefficientReducteurAffiliationSupplementaire(valeur);
      }
    }
  }
  
  private void epurerPlafonnement(JustificationAffiliation justifPlafonnement)
  {
    if ((justifPlafonnement != null) && (justifPlafonnement.getListPlafonnementAffiliation() != null))
    {
      Collection<PlafonnementAffiliation> listePlafonnementsASupprimer = new ArrayList();
      
      Iterator<PlafonnementAffiliation> it = justifPlafonnement.getListPlafonnementAffiliation().iterator();
      while (it.hasNext())
      {
        PlafonnementAffiliation plafonnementAffiliation = (PlafonnementAffiliation)it.next();
        if ((BigDecimal.ONE.compareTo(plafonnementAffiliation.getCoefficientReducteurAffiliationSupplementaire()) == 0) && (BigDecimal.ONE.compareTo(plafonnementAffiliation.getCoefficientReducteurAffiliation()) == 0)) {
          listePlafonnementsASupprimer.add(plafonnementAffiliation);
        }
      }
      it = listePlafonnementsASupprimer.iterator();
      while (it.hasNext()) {
        justifPlafonnement.supprimerPlafonnementAffiliation((PlafonnementAffiliation)it.next());
      }
    }
  }
  
  private void tronquerAffiSup(JustificationAffiliation justifPlafonnement)
  {
    if ((justifPlafonnement != null) && (justifPlafonnement.getListAffiliationSupplementaire() != null))
    {
      Iterator<AffiliationSupplementaire> it = justifPlafonnement.getListAffiliationSupplementaire().iterator();
      while (it.hasNext())
      {
        AffiliationSupplementaire periode = (AffiliationSupplementaire)it.next();
        
        Quantite valeur = arrondirQuantite(periode.getQuantiteInitiale());
        periode.setQuantiteInitiale(null);
        periode.setQuantiteInitiale(valeur);
        
        valeur = arrondirQuantite(periode.getQuantiteRetenue());
        periode.setQuantiteRetenue(null);
        periode.setQuantiteRetenue(valeur);
      }
    }
  }
  
  private void tronquerPeriodeElementaire(JustificationAffiliation justifPlafonnement)
  {
    if ((justifPlafonnement != null) && (justifPlafonnement.getListPeriodeElementaire() != null))
    {
      Iterator<PeriodeElementaire> it = justifPlafonnement.getListPeriodeElementaire().iterator();
      while (it.hasNext())
      {
        PeriodeElementaire periode = (PeriodeElementaire)it.next();
        
        Quantite valeur = arrondirQuantite(periode.getQuantiteInitialeHeure());
        periode.setQuantiteInitialeHeure(null);
        periode.setQuantiteInitialeHeure(valeur);
        
        valeur = arrondirQuantite(periode.getQuantitePlafonnee());
        periode.setQuantitePlafonnee(null);
        periode.setQuantitePlafonnee(valeur);
      }
    }
  }
  
  private Quantite arrondirQuantite(Quantite quantite)
  {
    if (quantite != null) {
      return new Quantite(quantite.getValeur().setScale(2, 5), quantite.getUnite());
    }
    return null;
  }
  
  protected BigDecimal arrondirCoefficient(BigDecimal valeur)
  {
    return valeur.setScale(4, 5);
  }
  
  protected Quantite transformerEnQuantiteJourTravaille(int nombre)
  {
    return new Quantite(BigDecimal.valueOf(nombre), Unite.get("jour travaillés"));
  }
  
  protected void calculerAffiliationPourUniteAutres(Chronologie passeProfessionnel, Demande demandeAsu, QuantitesAppartenance quantitesAppartenances, List<AlerteAffiliation> listeAlertesAffiliation, ParametresAffiliation parametres, Unite uniteEtudeCourante)
    throws ApplicativeException
  {
    CalculAffiliationSpec outilCalculAffiliation = getOutilCalculAffiliation();
    
    JustificationAffiliation justification = outilCalculAffiliation.calculerAffiliation(passeProfessionnel, parametres);
    
    priseEnCompteAlerteAffiliationPotentiellementManquante(listeAlertesAffiliation, justification);
    if (justification != null)
    {
      quantitesAppartenances.putJustificationAffiliation(justification, uniteEtudeCourante);
      quantitesAppartenances.putQuantiteAffiliation(justification.getQuantiteAffiliation());
      quantitesAppartenances.putQuantiteAssimilation(justification.getQuantiteAssimilation());
      
      demandeAsu.setPeriodesAffiliation(justification.getChronologieActivitesParticipantes());
    }
  }
  
  protected QuantitesAppartenance traiterAffiliationForcee(Periode periode, Quantite quantiteAffiliationForcee)
  {
    Quantite zero = new Quantite(new BigDecimal(0), quantiteAffiliationForcee.getUnite());
    
    QuantitesAppartenance quantitesAppartenances = new QuantitesAppartenance();
    JustificationAffiliationSpec justification;
    if ("23".equals(quantiteAffiliationForcee.getUnite().getCode()))
    {
      JustificationAffiliationSpec justification = new JustificationAffiliationJoursTravailles();
      ((JustificationAffiliationJoursTravailles)justification).setNombreJoursAffiliation(quantiteAffiliationForcee.getValeurEntiere());
      ((JustificationAffiliationJoursTravailles)justification).setNombreJoursAppartenance(quantiteAffiliationForcee.getValeurEntiere());
      ((JustificationAffiliationJoursTravailles)justification).setNombreJoursAssimilation(0);
      ((JustificationAffiliationJoursTravailles)justification).setPeriodeRechercheAffiliation(periode);
    }
    else
    {
      justification = new JustificationAffiliation();
      ((JustificationAffiliation)justification).setQuantiteAffiliation(quantiteAffiliationForcee);
      ((JustificationAffiliation)justification).setPeriodeRechercheAffiliation(periode);
      ((JustificationAffiliation)justification).setEstAffiliationPlafonnee(false);
      ((JustificationAffiliation)justification).setPlafondAssimilation(zero);
      ((JustificationAffiliation)justification).setQuantiteAssimilation(zero);
      ((JustificationAffiliation)justification).setQuantiteDernierJourFevrier(zero);
      ((JustificationAffiliation)justification).setTopConflits(false);
    }
    quantitesAppartenances.putQuantiteAffiliation(quantiteAffiliationForcee);
    quantitesAppartenances.putQuantiteAssimilation(zero);
    quantitesAppartenances.putJustificationAffiliation(justification, quantiteAffiliationForcee.getUnite());
    return quantitesAppartenances;
  }
  
  private void priseEnCompteAlerteAffiliationPotentiellementManquante(List<AlerteAffiliation> listeAlertes, JustificationAffiliation justification)
  {
    if ((justification != null) && (justification.getListPeriodeElementaire() != null))
    {
      Iterator<?> it = justification.getListPeriodeElementaire().iterator();
      while (it.hasNext())
      {
        PeriodeElementaire periodeElementaire = (PeriodeElementaire)it.next();
        if ((periodeElementaire.getIntensite().intValue() > 0) && (periodeElementaire.getQuantiteRetenue().getValeurEntiere() == 0))
        {
          AlerteAffiliation alerteAffiliation = OutilAlerteAffiliation.getInstance().genererAlerteAffiliation(periodeElementaire, "1", new String[] { justification.getUniteJustification().toString() });
          
          listeAlertes.add(alerteAffiliation);
        }
      }
    }
  }
  
  private void priseEnCompteAlertePNDS(DemandeSpec demande, Periode periode)
    throws ApplicativeException
  {
    Chronologie chronologiePnds = ((Demande)demande).getChronologiePNDS(periode);
    
    String codeAlerteNonBloquante = "A11MNB9";
    
    Collection<ObjetAlertesNonBloquantes> listePnds = new ArrayList();
    for (Iterator<?> iterPnds = chronologiePnds.iterer(); iterPnds.hasNext();)
    {
      ObjetChronoPeriode pnds = (ObjetChronoPeriode)iterPnds.next();
      ObjetAlertesNonBloquantes objetAlerteNonBloquante = new ObjetAlertesNonBloquantes(pnds.getDateDebut(), pnds.getDateFin(), 7);
      
      listePnds.add(objetAlerteNonBloquante);
    }
    demande.getAlertesNonBloquantes().put(codeAlerteNonBloquante, listePnds);
  }
  
  public CalculAffiliationSpec getOutilCalculAffiliation()
  {
    return new OutilCalculAffiliation();
  }
}

/* Location:
 * Qualified Name:     OutilCalculAppartenance
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */