package fr.unedic.cali.asu.cge01.p07.liquidation.outilsfonctionnels.affiliation;

import fr.pe.cali.reglementaire.regles.assurance.affiliation.dom.ResultatCalculAffiliationJoursTravailles;
import fr.pe.cali.reglementaire.regles.assurance.affiliation.outils.spec.IOutilFonctionnelAffiliationJoursTravailles;
import fr.unedic.cali.asu.outilsfonctionnels.ConstructionChronologie;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ContexteDemandeSpec;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieSuspensionChomageSansRCT;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreNegation;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteSalarieeHorsChamp;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeFormationAssimilable;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesLiquidables;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesQualifiables;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesSansConflit;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class OutilFonctionnelAffiliationJoursTravailles
  implements IOutilFonctionnelAffiliationJoursTravailles
{
  private IndividuSpec individu;
  ChronologiePeriodes chronologiePeriodesHorsChamp = null;
  
  public OutilFonctionnelAffiliationJoursTravailles(IndividuSpec individu)
  {
    this.individu = individu;
  }
  
  public Map<Integer, Chronologie> determinerChronologieActivitesParticipantes(Chronologie chronologiePeriodes, ResultatCalculAffiliationJoursTravailles resultatAffiliation, List<ContexteDemandeSpec> listeContexte, Periode periodeRecherche, Damj dateExamen)
  {
    Map<Integer, Chronologie> chronologieCalculAffiliation = new HashMap();
    
    FiltresTemporel filtreActivitesParticipantes = new FiltresTemporel();
    
    filtreActivitesParticipantes.ajouterFiltre(ConstructionChronologie.filtreChevauchePeriodeAvecPriseEnComptePmvs(listeContexte, periodeRecherche, true));
    
    filtreActivitesParticipantes.ajouterFiltre(ConstructionChronologie.filtreFinAvantDateAvecPriseEnComptePmvs(listeContexte, dateExamen, true));
    
    Chronologie chronologieActivitesParticipantesSurPra = chronologiePeriodes.copier(filtreActivitesParticipantes);
    
    Chronologie chronologieActiviteAffiliation = determinerChronologieActivitesPourAffiliation(chronologieActivitesParticipantesSurPra, resultatAffiliation);
    
    chronologieCalculAffiliation.put(Integer.valueOf(1), chronologieActiviteAffiliation);
    
    Chronologie chronologieActiviteAssimilation = determinerChronologieActivitesPourAssimilation(chronologieActivitesParticipantesSurPra);
    
    chronologieCalculAffiliation.put(Integer.valueOf(3), chronologieActiviteAssimilation);
    
    return chronologieCalculAffiliation;
  }
  
  protected Chronologie determinerChronologieActivitesPourAffiliation(Chronologie chronologiePeriodes, ResultatCalculAffiliationJoursTravailles resultatAffiliation)
  {
    FiltresTemporel filtreActivitesParticipantesPourAffiliation = new FiltresTemporel();
    filtreActivitesParticipantesPourAffiliation.ajouterFiltre(new FiltreActiviteSalarie());
    filtreActivitesParticipantesPourAffiliation.ajouterFiltre(new FiltrePeriodesQualifiables());
    filtreActivitesParticipantesPourAffiliation.ajouterFiltre(new FiltrePeriodesLiquidables());
    filtreActivitesParticipantesPourAffiliation.ajouterFiltre(new FiltreNegation(new FiltreActiviteSalarieSuspensionChomageSansRCT()));
    
    Chronologie chronologieActiviteSalarieLiquidables = chronologiePeriodes.copier(filtreActivitesParticipantesPourAffiliation);
    Chronologie chronologieActiviteSalarieLiquidablesSansConflit = chronologieActiviteSalarieLiquidables.copier(new FiltrePeriodesSansConflit());
    if (chronologieActiviteSalarieLiquidablesSansConflit.getTaille() != chronologieActiviteSalarieLiquidables.getTaille()) {
      resultatAffiliation.setTopConflits(true);
    }
    return chronologieActiviteSalarieLiquidablesSansConflit;
  }
  
  protected Chronologie determinerChronologieActivitesPourAssimilation(Chronologie chronologiePeriodes)
  {
    FiltresTemporel filtreActivitesParticipantesPourAssimilation = new FiltresTemporel();
    filtreActivitesParticipantesPourAssimilation.ajouterFiltre(new FiltrePeriodeFormationAssimilable());
    return chronologiePeriodes.copier(filtreActivitesParticipantesPourAssimilation);
  }
  
  public ChronologiePeriodes recupererPeriodesHorsChamp()
  {
    if (chronologiePeriodesHorsChamp == null) {
      chronologiePeriodesHorsChamp = ((ChronologiePeriodes)individu.getChronoPeriodePasseProfessionnel().copier(new FiltrePeriodeActiviteSalarieeHorsChamp()));
    }
    return chronologiePeriodesHorsChamp;
  }
}

/* Location:
 * Qualified Name:     OutilFonctionnelAffiliationJoursTravailles
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */