package fr.unedic.cali.asu.cge01.p07.liquidation.outilsfonctionnels.cep.sjr;

import fr.pe.cali.reglementaire.dom.impl.CriteresFabriqueReglementaire;
import fr.pe.cali.reglementaire.regles.assurance.affiliation.fabrique.FabriqueCorpsReglePeriodesSuspensionsNonAssimilables;
import fr.pe.cali.reglementaire.regles.assurance.affiliation.outils.spec.IOutilFonctionnelAffiliationJoursTravailles;
import fr.pe.cali.reglementaire.regles.assurance.affiliation.outils.spec.IOutilPeriodeNonAssimilable;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Salaire;
import fr.unedic.cali.autresdoms.ga.dom.spec.IncidentSpec;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import fr.unedic.util.temps.Temporel;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.ListIterator;
import java.util.Map;
import java.util.Set;

public class OutilComblageSuspensionAvecAbsence
{
  private Map<ActiviteSalarie, Collection<Salaire>> salairesAjoutesParActivite = new HashMap();
  private IOutilPeriodeNonAssimilable outilSuspensionsAssimilables;
  private IOutilFonctionnelAffiliationJoursTravailles outilFonctionnel;
  
  public OutilComblageSuspensionAvecAbsence(String nomProduit, Damj fgd, IOutilFonctionnelAffiliationJoursTravailles of)
  {
    FabriqueCorpsReglePeriodesSuspensionsNonAssimilables fabriquePeriodeAssimilable = FabriqueCorpsReglePeriodesSuspensionsNonAssimilables.getInstance();
    CriteresFabriqueReglementaire criteresFabriquePeriodeAssimilable = new CriteresFabriqueReglementaire();
    criteresFabriquePeriodeAssimilable.setCodeProduit(nomProduit);
    criteresFabriquePeriodeAssimilable.setDate(fgd);
    outilFonctionnel = of;
    outilSuspensionsAssimilables = fabriquePeriodeAssimilable.recupererOutilCorpsRegle(criteresFabriquePeriodeAssimilable);
  }
  
  public void comblerSuspensionsAvecAbsence(Chronologie activites)
  {
    ListIterator<?> iterateurActivites = activites.iterer();
    while (iterateurActivites.hasNext())
    {
      ActiviteSalarie activiteCourante = (ActiviteSalarie)iterateurActivites.next();
      comblerSuspensionsAvecAbsence(activiteCourante);
    }
  }
  
  public void comblerSuspensionsAvecAbsence(ActiviteSalarie activite)
  {
    Chronologie suspensions = getSuspensionsNonAssimilables(activite);
    
    Chronologie salaires = activite.getListeSalaires();
    if (!suspensions.estVide())
    {
      Collection<Periode> copieSuspensions = copierSuspensionVersListe(suspensions);
      Collection<Periode> exclusions = copierSalairesVersListe(salaires);
      exclure(copieSuspensions, exclusions);
      if (!copieSuspensions.isEmpty()) {
        ajouterSalairesAbsents(activite, copieSuspensions);
      }
    }
  }
  
  private void ajouterSalairesAbsents(ActiviteSalarie activite, Collection<Periode> periodesACombler)
  {
    Collection<Salaire> salairesAjoutes = new ArrayList();
    Iterator<Periode> iterateurPeriodesACombler = periodesACombler.iterator();
    while (iterateurPeriodesACombler.hasNext())
    {
      Periode periodeCourante = (Periode)iterateurPeriodesACombler.next();
      Salaire salaire = new Salaire(periodeCourante);
      salaire.setQuantiteAbsence(new QuantiteJour(BigDecimal.valueOf(periodeCourante.getDuree())));
      salaire.setMontantSoumisAContribution(new QuantiteEuro(BigDecimal.ZERO));
      salaire.setMontantBrutBase(new QuantiteEuro(BigDecimal.ZERO));
      activite.ajouterSalaire(salaire);
      salairesAjoutes.add(salaire);
    }
    salairesAjoutesParActivite.put(activite, salairesAjoutes);
  }
  
  private Collection<Periode> copierSuspensionVersListe(Chronologie suspensions)
  {
    Collection<Periode> retour = new ArrayList();
    
    ListIterator<?> iterateurSalaires = suspensions.iterer();
    while (iterateurSalaires.hasNext())
    {
      IncidentSpec suspensionCourante = (IncidentSpec)iterateurSalaires.next();
      retour.add(new Periode(suspensionCourante.getDateDebut(), suspensionCourante.getDateFin()));
    }
    return retour;
  }
  
  private Collection<Periode> copierSalairesVersListe(Chronologie suspensions)
  {
    Collection<Periode> retour = new ArrayList();
    
    ListIterator<?> iterateurSalaires = suspensions.iterer();
    while (iterateurSalaires.hasNext())
    {
      Salaire salaireCourant = (Salaire)iterateurSalaires.next();
      retour.add(new Periode(salaireCourant.getDateDebut(), salaireCourant.getDateFin()));
    }
    return retour;
  }
  
  private void exclure(Collection<Periode> listeInitiale, Collection<Periode> listeAExclure)
  {
    Iterator<Periode> iterateurExclusions = listeAExclure.iterator();
    while (iterateurExclusions.hasNext())
    {
      Periode exclusionCourante = (Periode)iterateurExclusions.next();
      
      exclure(listeInitiale, exclusionCourante);
    }
  }
  
  private void exclure(Collection<Periode> listeInitiale, Periode exclusionCourante)
  {
    List<Periode> periodesASupprimer = new ArrayList();
    List<Periode> periodesAAjouter = new ArrayList();
    Iterator<Periode> iterateurPeriodes = listeInitiale.iterator();
    while (iterateurPeriodes.hasNext())
    {
      Periode periodeCourante = (Periode)iterateurPeriodes.next();
      if (periodeCourante.chevauche(exclusionCourante)) {
        if (chevaucheLeDebutDe(exclusionCourante, periodeCourante))
        {
          periodeCourante.setDebut(exclusionCourante.getFin().lendemain());
        }
        else if (chevaucheLaFinDe(exclusionCourante, periodeCourante))
        {
          periodeCourante.setFin(exclusionCourante.getDebut().veille());
        }
        else if (estAuMilieuDe(exclusionCourante, periodeCourante))
        {
          periodesASupprimer.add(periodeCourante);
          Periode periodeDebut = new Periode(periodeCourante.getDebut(), exclusionCourante.getDebut().veille());
          Periode periodeFin = new Periode(exclusionCourante.getFin().lendemain(), periodeCourante.getFin());
          periodesAAjouter.add(periodeDebut);
          periodesAAjouter.add(periodeFin);
        }
        else
        {
          periodesASupprimer.add(periodeCourante);
        }
      }
    }
    supprimerPeriodes(listeInitiale, periodesASupprimer);
    ajouterPeriodes(listeInitiale, periodesAAjouter);
  }
  
  private void ajouterPeriodes(Collection<Periode> listeInitiale, List<Periode> periodesAAjouter)
  {
    Iterator<Periode> iteratorPeriodesAAjouter = periodesAAjouter.iterator();
    while (iteratorPeriodesAAjouter.hasNext()) {
      listeInitiale.add(iteratorPeriodesAAjouter.next());
    }
    periodesAAjouter.clear();
  }
  
  private void supprimerPeriodes(Collection<Periode> listeInitiale, List<Periode> periodesASupprimer)
  {
    Iterator<Periode> iteratorPeriodesAsupprimer = periodesASupprimer.iterator();
    while (iteratorPeriodesAsupprimer.hasNext()) {
      listeInitiale.remove(iteratorPeriodesAsupprimer.next());
    }
    periodesASupprimer.clear();
  }
  
  private boolean estAuMilieuDe(Periode periodeA, Periode periodeB)
  {
    return (periodeA.getDebut().estApres(periodeB.getDebut())) && (periodeA.getFin().estAvant(periodeB.getFin()));
  }
  
  private boolean chevaucheLeDebutDe(Periode periodeA, Periode periodeB)
  {
    return (periodeA.getDebut().estAvantOuCoincideAvec(periodeB.getDebut())) && (periodeA.getFin().estAvant(periodeB.getFin()));
  }
  
  private boolean chevaucheLaFinDe(Periode periodeA, Periode periodeB)
  {
    return (periodeA.getFin().estApresOuCoincideAvec(periodeB.getFin())) && (periodeA.getDebut().estApres(periodeB.getDebut()));
  }
  
  private Chronologie getSuspensionsNonAssimilables(ActiviteSalarie activite)
  {
    ChronologiePeriodes retour = new ChronologiePeriodes();
    Chronologie listeIncidents = activite.getListePeriodesIncident();
    ListIterator<?> iterateursIncidents = listeIncidents.iterer();
    while (iterateursIncidents.hasNext())
    {
      IncidentSpec incident = (IncidentSpec)iterateursIncidents.next();
      if (!outilSuspensionsAssimilables.estAssimilable(incident, outilFonctionnel)) {
        retour.ajouter(incident);
      }
    }
    return retour;
  }
  
  public void supprimerSalairesCrees()
  {
    Iterator<ActiviteSalarie> iterateurActivites = salairesAjoutesParActivite.keySet().iterator();
    while (iterateurActivites.hasNext())
    {
      ActiviteSalarie activite = (ActiviteSalarie)iterateurActivites.next();
      
      Collection<Salaire> salaires = (Collection)salairesAjoutesParActivite.get(activite);
      Iterator<Salaire> iterateurSalaires = salaires.iterator();
      while (iterateurSalaires.hasNext()) {
        activite.getListeSalaires().supprimer((Temporel)iterateurSalaires.next());
      }
    }
  }
}

/* Location:
 * Qualified Name:     OutilComblageSuspensionAvecAbsence
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */