package fr.unedic.cali.asu.cge01.p07.liquidation.outilsfonctionnels.cep.sjr;

import fr.pe.cali.reglementaire.regles.assurance.affiliation.outils.spec.IOutilFonctionnelAffiliationJoursTravailles;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.OutilJustificationSjrSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.StrategieDeterminationDiviseurSjrCasGeneral;
import fr.unedic.cali.asu.cge01.p07.liquidation.outilsfonctionnels.affiliation.OutilFonctionnelAffiliationJoursTravailles;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationDiviseur;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.Prc;
import fr.unedic.cali.asu.produits.liquidation.dom.conteneurs.DonneesResultatDeterminationSjr;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.autresdoms.ga.dom.Salaire;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeComplementairesDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDemandeDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDeterminationSjrSpec;
import fr.unedic.cali.util.OutillageChronologiePeriodes;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public class StrategieDeterminationDiviseurSjrCasGeneralConvention2017
  extends StrategieDeterminationDiviseurSjrCasGeneral
{
  public BigDecimal calculerNombreJourAbsence(DonneesEntreeDeterminationSjrSpec donneesEntree, DonneesResultatDeterminationSjr donneesResultat)
    throws CoucheLogiqueException
  {
    BigDecimal cumulJoursAbsenceRetourne = BigDecimal.ZERO;
    
    Periode periodeCourante = null;
    ActiviteSalarie periodeActiviteSalarieCourante = null;
    Salaire periodeSalaireCourante = null;
    Chronologie chronoPeriodesSalaireAvecAbsence = null;
    Periode periodeIntersectionPrcCourante = null;
    int nbJoursDeductiblesSurSalaireCourant = 0;
    int nbJoursAbsenceArrondi = 0;
    int nbJoursAbsenceDeductible = 0;
    ChronologiePeriodes chronoPeriodesComplementaires = null;
    ChronologiePeriodes chronoPeriodesNonRemunereesApresDjtp = null;
    ChronologiePeriodes chronoPeriodesSuspension = null;
    Chronologie chronoPeriodesSalairePnds = null;
    
    DonneesEntreeComplementairesDeterminationSjrSpec donneesEntreeComplementaires = donneesEntree.getDonneesEntreeComplementaires();
    DonneesEntreeDemandeDeterminationSjrSpec donneesEntreeDemande = donneesEntree.getDonneesEntreeDemande();
    
    OutilJustificationSjrSpec outilJustificationSjr = recupererOutilJustificationSjr(donneesEntree.getDonneesEntreeComportement());
    JustificationDiviseur resultatJustificationDiviseur = donneesResultat.getJustificationSjr().getJustificationDiviseur();
    
    Prc resultatPrc = donneesResultat.getPrc();
    Periode periodeReference = new Periode(resultatPrc.getDateDebut(), resultatPrc.getDateFin());
    
    boolean absenceDeductible = estAbsenceDeductible();
    
    Chronologie chronoActivites = determinerChronoActivitePourAbsence(donneesEntreeComplementaires);
    
    String nomProduit = donneesEntree.getDonneesEntreeDemande().getProduit().getNomUnique();
    Damj fgd = donneesEntree.getDonneesEntreeDemande().getDateFaitGenerateurDroitCourant();
    IndividuSpec individu = donneesEntreeDemande.getIndividu();
    IOutilFonctionnelAffiliationJoursTravailles of = new OutilFonctionnelAffiliationJoursTravailles(individu);
    OutilComblageSuspensionAvecAbsence outilComblage = new OutilComblageSuspensionAvecAbsence(nomProduit, fgd, of);
    outilComblage.comblerSuspensionsAvecAbsence(chronoActivites);
    
    ChronologiePeriodes chronoPeriodeSalaireSansAbsenceChevauchantPrc = new ChronologiePeriodes();
    ChronologiePeriodes chronoChevauchementsPeriodeSalaireAvecAbsence = null;
    if (chronoActivites.contientChevauchementElements())
    {
      chronoPeriodeSalaireSansAbsenceChevauchantPrc = determinerChronoPeriodesSalaireSansAbsenceChevauchantPrc(donneesEntree, donneesEntreeDemande.getIndividu(), periodeReference, donneesEntreeDemande.getDateFaitGenerateurDroitCourant(), donneesEntreeDemande.getDateExamen(), chronoActivites);
      
      chronoChevauchementsPeriodeSalaireAvecAbsence = determinerChronoChevauchementsPeriodeSalaireAvecAbsence(donneesEntreeDemande.getIndividu(), periodeReference, donneesEntreeDemande.getDateFaitGenerateurDroitCourant(), donneesEntreeDemande.getDateExamen(), chronoActivites);
    }
    boolean presenceChevauchementPeriodeSalaireAvecAbsence = (chronoChevauchementsPeriodeSalaireAvecAbsence != null) && (chronoChevauchementsPeriodeSalaireAvecAbsence.getTaille() > 1);
    if (presenceChevauchementPeriodeSalaireAvecAbsence) {
      cumulJoursAbsenceRetourne = traiterChevauchementsPeriodeSalaireAvecAbsence(donneesEntreeDemande.getIndividu(), periodeReference, donneesEntreeDemande.getDateFaitGenerateurDroitCourant(), donneesEntreeDemande.getDateExamen(), absenceDeductible, chronoChevauchementsPeriodeSalaireAvecAbsence, chronoPeriodeSalaireSansAbsenceChevauchantPrc, donneesEntreeComplementaires.getChronologieActiviteSalariePrc(), donneesEntreeComplementaires.getChronologiePeriodeDeductiblePrc(), outilJustificationSjr, resultatJustificationDiviseur);
    }
    FiltresTemporel listeFiltres = new FiltresTemporel();
    listeFiltres.ajouterFiltre(donnerFiltrePeriodeSalaireAvecAbsence());
    listeFiltres.ajouterFiltre(new FiltreChevauchePeriode(periodeReference));
    
    chronoActivites.iterer();
    while (chronoActivites.encoreSuivant())
    {
      periodeActiviteSalarieCourante = (ActiviteSalarie)chronoActivites.elementSuivant();
      if (periodeActiviteSalarieCourante.getContrat().estSuspensionDecoupee())
      {
        chronoPeriodesSuspension = determinerChronoPeriodesSuspension(donneesEntreeDemande.getIndividu(), periodeReference, donneesEntreeDemande.getDateFaitGenerateurDroitCourant(), donneesEntreeDemande.getDateExamen(), periodeActiviteSalarieCourante);
        if ((chronoPeriodesSuspension != null) && (!chronoPeriodesSuspension.estVide())) {
          chronoPeriodesSalaireAvecAbsence = (Chronologie)chronoPeriodesSuspension.copie();
        }
      }
      else
      {
        chronoPeriodesSalairePnds = determinerChronoPeriodesSalairePnds(donneesEntreeDemande.getIndividu(), periodeActiviteSalarieCourante, donneesEntreeDemande.getDateFaitGenerateurDroitCourant(), donneesEntreeDemande.getDateExamen());
        
        chronoPeriodesSalaireAvecAbsence = chronoPeriodesSalairePnds.copier(listeFiltres);
        
        chronoPeriodesNonRemunereesApresDjtp = determinerChronoPeriodesNonRemunereesApresDjtp(donneesEntreeDemande.getIndividu(), periodeReference, donneesEntreeDemande.getDateFaitGenerateurDroitCourant(), donneesEntreeDemande.getDateExamen(), periodeActiviteSalarieCourante);
        if ((chronoPeriodesNonRemunereesApresDjtp != null) && (!chronoPeriodesNonRemunereesApresDjtp.estVide())) {
          chronoPeriodesSalaireAvecAbsence.ajouter(chronoPeriodesNonRemunereesApresDjtp);
        }
      }
      if ((chronoPeriodesSalaireAvecAbsence != null) && (chronoPeriodesSalaireAvecAbsence.getTaille() > 0))
      {
        chronoPeriodesSalaireAvecAbsence.iterer();
        while (chronoPeriodesSalaireAvecAbsence.encoreSuivant())
        {
          periodeSalaireCourante = (Salaire)chronoPeriodesSalaireAvecAbsence.elementSuivant();
          periodeCourante = new Periode(periodeSalaireCourante.getDateDebut(), periodeSalaireCourante.getDateFin());
          if ((!presenceChevauchementPeriodeSalaireAvecAbsence) || (!contientPeriodeSalaire(chronoChevauchementsPeriodeSalaireAvecAbsence, periodeSalaireCourante)))
          {
            periodeIntersectionPrcCourante = periodeCourante.periodeIntersection(periodeReference);
            chronoPeriodesComplementaires = OutillageChronologiePeriodes.donnerPeriodesComplementaires(chronoPeriodeSalaireSansAbsenceChevauchantPrc, periodeIntersectionPrcCourante);
            if ((chronoPeriodesComplementaires != null) && (!chronoPeriodesComplementaires.estVide()))
            {
              BigDecimal nbJoursAbsencePeriodeSalaireCourante = determinerAbsenceCumuleeHorsSalaireSansAbsence(periodeSalaireCourante, chronoPeriodesComplementaires);
              if (absenceDeductible)
              {
                nbJoursDeductiblesSurSalaireCourant = periodeIntersectionPrcCourante.inter((ChronologiePeriodes)donneesEntreeComplementaires.getChronologiePeriodeDeductiblePrc());
                
                nbJoursAbsenceArrondi = Mathematiques.arrondiASup(nbJoursAbsencePeriodeSalaireCourante, 0).intValue();
                if (nbJoursAbsenceArrondi > nbJoursDeductiblesSurSalaireCourant)
                {
                  nbJoursAbsenceDeductible = nbJoursAbsenceArrondi - nbJoursDeductiblesSurSalaireCourant;
                  
                  cumulJoursAbsenceRetourne = cumulJoursAbsenceRetourne.add(new BigDecimal(nbJoursAbsenceDeductible));
                  if (outilJustificationSjr != null) {
                    outilJustificationSjr.justifierDiviseurPeriodeParticipanteJoursDeductibles(resultatJustificationDiviseur, periodeCourante, periodeActiviteSalarieCourante, nbJoursAbsenceDeductible);
                  }
                }
              }
              else
              {
                cumulJoursAbsenceRetourne = cumulJoursAbsenceRetourne.add(nbJoursAbsencePeriodeSalaireCourante);
                if (outilJustificationSjr != null) {
                  outilJustificationSjr.justifierDiviseurPeriodeParticipanteJoursAbsence(resultatJustificationDiviseur, periodeCourante, periodeActiviteSalarieCourante, nbJoursAbsencePeriodeSalaireCourante);
                }
              }
            }
          }
        }
      }
    }
    if (!absenceDeductible) {
      resultatPrc.setNombreJourAbsence(cumulJoursAbsenceRetourne);
    }
    outilComblage.supprimerSalairesCrees();
    
    return cumulJoursAbsenceRetourne;
  }
}

/* Location:
 * Qualified Name:     StrategieDeterminationDiviseurSjrCasGeneralConvention2017
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */