package fr.unedic.cali.asu.cge01.p07.parametres;

import fr.unedic.cali.asu.cge01.parametres.ParametrageListePRASpec;
import fr.unedic.cali.asu.produits.liquidation.dom.Pra;
import fr.unedic.cali.asu.produits.liquidation.parametres.CleAccesPRA;
import fr.unedic.cali.parametres.GestionnaireDateApplication;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.ApplicativeRuntimeException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.List;

public class ParametrageListePRA
  implements ParametrageListePRASpec
{
  public static final int PRA_36_MOIS = 36;
  public static final int PRA_28_MOIS = 28;
  public static final int PRA_24_MOIS = 24;
  public static final int INF_50ANS = 1;
  public static final int SUP_EGAL_50ANS = 2;
  public static final int SUP_EGAL_53ANS = 4;
  public static final int SUP_EGAL_57ANS = 3;
  public static final int DUREE_DROIT_1277 = 1277;
  public static final int DUREE_DROIT_1014 = 1014;
  public static final int DUREE_DROIT_182 = 182;
  public static final int DUREE_DROIT_122 = 122;
  public static final int DUREE_DROIT_2246 = 2246;
  public static final int DUREE_DROIT_88 = 88;
  public static final int DUREE_HEURE_610 = 610;
  public static final int UNITE_AFFILIATION_174 = 174;
  public static final int UNITE_AFFILIATION_271 = 271;
  public static final int UNITE_AFFILIATION_840 = 840;
  private Collection<Pra> listePRA;
  private static ParametrageListePRA instance;
  private static final int UN = 1;
  private static final int DEUX = 2;
  private static final int TROIS = 3;
  private static final int QUATRE = 4;
  public static final int DONNEE_SANS_OBJET = -1;
  
  public ParametrageListePRA()
  {
    initInstance();
  }
  
  public static ParametrageListePRA getInstance()
  {
    if (instance == null) {
      instance = new ParametrageListePRA();
    }
    return instance;
  }
  
  private void initInstance()
  {
    listePRA = new ArrayList();
    
    initInstanceRG();
    
    initInstanceRGInterimaire();
    
    initInstanceRGParticulier();
    
    initInstanceA1();
    
    initInstanceA2A();
    
    initInstanceA2B();
    
    initInstanceA3();
    
    initInstanceA5();
    
    initInstanceA9A();
  }
  
  public List<Pra> getListePra(CleAccesPRA cle)
    throws CoucheLogiqueException
  {
    List<Pra> resultatListePRA = new ArrayList();
    if ("OP".equals(cle.getNomReglement())) {
      throw new CoucheLogiqueException("Le règlement RG_OP n'est pas géré pour le produit ARE09");
    }
    Iterator<Pra> it = listePRA.iterator();
    while (it.hasNext())
    {
      Pra pra = (Pra)it.next();
      if (pra.estApplicable(cle)) {
        resultatListePRA.add((Pra)pra.copie());
      }
    }
    return resultatListePRA;
  }
  
  private void initInstanceRG()
  {
    Pra pra = new Pra("RG", new int[] { 4, 3 }, 36, 2, 1);
    
    positionnerQuantiteAffiliationRequise(pra, 88, "jour travaillés");
    positionnerQuantiteAffiliationRequise(pra, 610, "heure de travail");
    ajouterPRASurCollection(pra);
    
    pra = new Pra("RG", new int[] { 1, 2 }, 28, 1, 2);
    
    positionnerQuantiteAffiliationRequise(pra, 88, "jour travaillés");
    positionnerQuantiteAffiliationRequise(pra, 610, "heure de travail");
    ajouterPRASurCollection(pra);
    try
    {
      Damj datePivot = GestionnaireDateApplication.getInstance().recupererDateApplication("Application des règles métropole pour Mayotte");
      
      pra = new Pra("RG", null, 24, 1, 2, "AREMAYOTTE");
      positionnerQuantiteAffiliationRequise(pra, 271, "jour d'affiliation");
      positionnerQuantiteAffiliationRequise(pra, 2246, "heure de travail");
      pra.setPeriodeValidite(new Periode(Damj.NUIT_DES_TEMPS, datePivot.veille()));
      ajouterPRASurCollection(pra);
      
      pra = new Pra("RG", null, 24, 1, 2, "AREMAYOTTE");
      positionnerQuantiteAffiliationRequise(pra, 182, "jour d'affiliation");
      positionnerQuantiteAffiliationRequise(pra, 1014, "heure de travail");
      pra.setPeriodeValidite(new Periode(datePivot, Damj.FIN_DES_TEMPS));
      ajouterPRASurCollection(pra);
    }
    catch (CoucheLogiqueException ex)
    {
      throw new ApplicativeRuntimeException(ex.getCode(), ex.getMessage(), ex);
    }
  }
  
  private void initInstanceRGInterimaire()
  {
    Pra pra = new Pra("RG5", new int[] { 4, 3 }, 36, 2, 1);
    
    positionnerQuantiteAffiliationRequise(pra, 610, "heure de travail");
    ajouterPRASurCollection(pra);
    
    pra = new Pra("RG5", new int[] { 1, 2 }, 28, 1, 2);
    
    positionnerQuantiteAffiliationRequise(pra, 610, "heure de travail");
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceRGParticulier()
  {
    Pra pra = new Pra("RGP", new int[] { 4, 3 }, 36, 2, 1);
    
    positionnerQuantiteAffiliationRequise(pra, 88, "jour travaillés");
    positionnerQuantiteAffiliationRequise(pra, 610, "heure de travail");
    ajouterPRASurCollection(pra);
    
    pra = new Pra("RGP", new int[] { 1, 2 }, 28, 1, 2);
    
    positionnerQuantiteAffiliationRequise(pra, 88, "jour travaillés");
    positionnerQuantiteAffiliationRequise(pra, 610, "heure de travail");
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceA1()
  {
    Pra pra = new Pra("A1", new int[] { 4, 3 }, 36, 2, 1);
    
    positionnerQuantiteAffiliationRequise(pra, 88, "jour travaillés");
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A1", new int[] { 1, 2 }, 28, 1, 2);
    
    positionnerQuantiteAffiliationRequise(pra, 88, "jour travaillés");
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceA2A()
  {
    Pra pra = new Pra("A2a", new int[] { 4, 3 }, 36, 2, 1);
    
    positionnerQuantiteAffiliationRequise(pra, 122, "embarquement administratif");
    positionnerQuantiteAffiliationRequise(pra, 840, "heure de travail");
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A2a", new int[] { 1, 2 }, 28, 1, 2);
    
    positionnerQuantiteAffiliationRequise(pra, 122, "embarquement administratif");
    positionnerQuantiteAffiliationRequise(pra, 840, "heure de travail");
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceA2B()
  {
    Pra pra = new Pra("A2b", new int[] { 4, 3 }, 36, 2, 1);
    
    positionnerQuantiteAffiliationRequise(pra, 122, "embarquement administratif");
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A2b", new int[] { 1, 2 }, 28, 1, 2);
    
    positionnerQuantiteAffiliationRequise(pra, 122, "embarquement administratif");
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceA3()
  {
    Pra pra = new Pra("A3", new int[] { 4, 3 }, 36, 2, 1);
    
    positionnerQuantiteAffiliationRequise(pra, 174, "vacation");
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A3", new int[] { 1, 2 }, 28, 1, 2);
    
    positionnerQuantiteAffiliationRequise(pra, 174, "vacation");
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceA5()
  {
    Pra pra = new Pra("A5", new int[] { 4, 3 }, 36, 2, 1);
    
    positionnerQuantiteAffiliationRequise(pra, 610, "heure de travail");
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A5", new int[] { 1, 2 }, 28, 1, 2);
    
    positionnerQuantiteAffiliationRequise(pra, 610, "heure de travail");
    ajouterPRASurCollection(pra);
  }
  
  private void initInstanceA9A()
  {
    Pra pra = new Pra("A9A", new int[] { 4, 3 }, 36, 4, 1);
    positionnerQuantiteAffiliationRequise(pra, 88, "jour travaillés");
    positionnerQuantiteAffiliationRequise(pra, 610, "heure de travail");
    ajouterPRASurCollection(pra);
    
    pra = new Pra("A9A", new int[] { 1, 2 }, 28, 2, 3);
    positionnerQuantiteAffiliationRequise(pra, 88, "jour travaillés");
    positionnerQuantiteAffiliationRequise(pra, 610, "heure de travail");
    ajouterPRASurCollection(pra);
  }
  
  private void ajouterPRASurCollection(Pra pra)
  {
    listePRA.add(pra);
  }
  
  private void positionnerQuantiteAffiliationRequise(Pra pra, int valeurQuantite, String uniteAffiliation)
  {
    Unite unite = Unite.get(uniteAffiliation);
    Quantite quantite = new Quantite(valeurQuantite, unite);
    pra.getListeQuantitesAffiliationRequises().put(unite, quantite);
  }
}

/* Location:
 * Qualified Name:     ParametrageListePRA
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */