package fr.unedic.cali.asu.csa06.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.cge01.liquidation.dom.ParametresCalculAppartenance;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.RechercheReglementApplicable;
import fr.unedic.cali.asu.csa06.parametres.spec.ParametresSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.parametres.OutilAccesListeUnitesReglement;
import fr.unedic.cali.asu.produits.liquidation.dom.Pra;
import fr.unedic.cali.asu.produits.liquidation.dom.QuantitesAppartenance;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.affiliation.OutilVerificationReglementsMultiples;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.affectation.Parametres;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.affectation.ValidationProduitSpec;
import fr.unedic.cali.dom.spec.CalculAppartenanceSpec;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parametres.GestionnaireDateApplication;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;
import java.util.Iterator;
import java.util.List;

public abstract class RechercheValiditeProduit
  extends fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.RechercheValiditeProduit
{
  private static final int NB_CHIFFRE_APRES_VIRGULE = 10;
  
  public ValidationProduitSpec validerProduit(ActiviteSalarie activiteSalarie, DemandeAssuranceSpec demandeAssurance, boolean avecPeriodeNonAttestee, ParametresSpec parametres, ProduitAsuSpec produit)
    throws ApplicativeException
  {
    ValidationProduit validationProduit = null;
    
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Validation du produit pour l'activité : ", activiteSalarie });
    if (activiteSalarie.estQualifiable())
    {
      Pra pra = ConstructionPra.getPra(activiteSalarie, demandeAssurance, parametres);
      
      boolean presenceReglementAppartenanceDifferent = OutilVerificationReglementsMultiples.getInstance().verifierReglementAppartenanceDifferent(demandeAssurance, pra);
      if (presenceReglementAppartenanceDifferent) {
        validationProduit = verifierConditionAffiliation(demandeAssurance, pra, avecPeriodeNonAttestee, parametres, produit);
      }
      if (validationProduit != null)
      {
        validationProduit.setPeriodeValidationProduit(activiteSalarie);
        validationProduit.setPeriodePra(pra);
      }
    }
    return validationProduit;
  }
  
  protected ValidationProduit verifierConditionAffiliation(DemandeAssuranceSpec demande, Pra pra, boolean avecPeriodeNonAttestee, ParametresSpec pParametres, ProduitAsuSpec produit)
    throws ApplicativeException
  {
    Chronologie chronoPeriodesParticipantes = RechercheReglementApplicable.getInstance().determinerActivitesParticipantes((Demande)demande, pra, avecPeriodeNonAttestee);
    
    Reglement reglementAppartenance = Reglement.getInstance("RG", getProduitCandidat());
    
    CalculAppartenanceSpec outilCalculAppartenance = produit.getOutilCalculAppartenance(demande, false);
    
    ParametresCalculAppartenance parametres = new ParametresCalculAppartenance();
    parametres.setEffectuerImputationAffiliationPmvs(true);
    parametres.setPrendreEnCompteDernierJourFevrier(true);
    parametres.setPrendreEnCompteDonneesForcees(true);
    parametres.setActiverSpecificitesRechargement(true);
    parametres.setComptabiliserAssimilation(true);
    parametres.setContexteAppel("rechercheReglementApplicable");
    if (estApplicableNonPriseEnCompteAssimilationEtDerniersJoursFevrier(demande.getDateExamen()))
    {
      parametres.setPrendreEnCompteDernierJourFevrier(false);
      parametres.setComptabiliserAssimilation(false);
    }
    List<Unite> listeUnite = OutilAccesListeUnitesReglement.getInstance().recupererListeUniteRechercheReglementApplicable(reglementAppartenance.getNomReglement(), demande.estEnContexteDemande("RECHARGE"), getProduitCandidat());
    
    parametres.setListeUnitesReglement(listeUnite);
    
    QuantitesAppartenance quantitesAppartenance = (QuantitesAppartenance)outilCalculAppartenance.calculer(demande, pra, chronoPeriodesParticipantes, reglementAppartenance, parametres);
    
    boolean affiliationSuffisante = false;
    
    Iterator<Unite> iter = listeUnite.iterator();
    ValidationProduit validationCsa = null;
    Quantite qteAffiliation = null;
    while ((!affiliationSuffisante) && (iter.hasNext()))
    {
      Unite unite = (Unite)iter.next();
      qteAffiliation = quantitesAppartenance.getQuantiteAffiliation(unite);
      if (qteAffiliation == null) {
        qteAffiliation = new Quantite("0", unite);
      }
      Quantite qteAssimilation = quantitesAppartenance.getQuantiteAssimilation(unite);
      if (qteAssimilation == null) {
        qteAssimilation = new Quantite("0", unite);
      }
      BigDecimal valAcquise = qteAffiliation.getValeur().add(qteAssimilation.getValeur());
      BigDecimal valRequise = pParametres.getQuantiteAffiliationRequise(unite).getValeur();
      if (valAcquise.compareTo(valRequise) >= 0)
      {
        affiliationSuffisante = true;
        validationCsa = new ValidationProduit();
        
        validationCsa.setQuantiteAcquise(new Quantite(valAcquise.setScale(10, 1), unite));
        validationCsa.setReglementApplicable(Parametres.getReglement(reglementAppartenance.getNomReglement(), getProduitCandidat()));
      }
    }
    if (validationCsa != null)
    {
      iter = listeUnite.iterator();
      while (iter.hasNext())
      {
        Unite unite = (Unite)iter.next();
        if (!unite.equals(qteAffiliation.getUnite()))
        {
          qteAffiliation = quantitesAppartenance.getQuantiteAffiliation(unite);
          if (qteAffiliation == null) {
            qteAffiliation = new Quantite("0", unite);
          }
          Quantite qteAssimilation = quantitesAppartenance.getQuantiteAssimilation(unite);
          if (qteAssimilation == null) {
            qteAssimilation = new Quantite("0", unite);
          }
          validationCsa.setQuantiteAcquiseSecondaire(new Quantite(qteAffiliation.ajouter(qteAssimilation).getValeur().setScale(10, 1), qteAffiliation.getUnite()));
        }
      }
    }
    if (quantitesAppartenance.estEnConflit()) {
      demande.setLiquideeAvecConflits(true);
    }
    return validationCsa;
  }
  
  protected boolean estApplicableNonPriseEnCompteAssimilationEtDerniersJoursFevrier(Damj dateExamen)
    throws CoucheLogiqueException
  {
    Damj dateApplication = GestionnaireDateApplication.getInstance().recupererDateApplication("Activation de la non prise en compte de l'assimilation pour la ligne CSA");
    return dateExamen.estApresOuCoincideAvec(dateApplication);
  }
  
  protected abstract ProduitSpec getProduitCandidat();
}

/* Location:
 * Qualified Name:     RechercheValiditeProduit
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */