package fr.unedic.cali.asu.csr04.p01.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConditionCSRDateAttributionPendantSuspension;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConditionsAttributionAdmission;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionDateAttribution;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p03.liquidation.parcours.DeterminationConditionAgePourReprise;
import fr.unedic.cali.asu.cge01.p03.liquidation.parcours.DeterminationConditionAppartenancePourMaintien;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsChomageSansRCT;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;

public class DeterminationConditionCSRDateAttributionPendantSuspension
  extends ParcoursCali
  implements ParcoursAssurance
{
  public void controlerContexte(Contexte p_context)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(p_context) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null: determination condition age reprise impossible.");
    }
    if (DomLiquidationAssurance.getDemande(p_context).getDemandeur() == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_DEMANDEUR", "Le demandeur est null: determination condition age reprise impossible.");
    }
  }
  
  public Resultat demarrer(Contexte p_contexte)
    throws ApplicativeException
  {
    if (Log.isTraceActive(DeterminationConditionAgePourReprise.class, Niveau.DEBUG))
    {
      Log.ecritTrace(Niveau.DEBUG, DeterminationConditionAgePourReprise.class, "demarrer", "");
      Log.ecritTrace(Niveau.DEBUG, DeterminationConditionAgePourReprise.class, "demarrer", "\t\t******** Début Parcours DeterminationConditionDecisionCP ********\n");
    }
    Resultat resultatConditionCSRDateAttributionPendantSuspension = new Resultat(1);
    
    Demande demandeCourante = DomLiquidationAssurance.getDemande(p_contexte);
    DossierExamen dossierExamenCourant = (DossierExamen)demandeCourante.getDossierExamen();
    
    dossierExamenCourant.getConditionsAttributionAdmission().createConditionCSRDateAttributionPendantSuspension();
    ConditionCSRDateAttributionPendantSuspension conditionCSRDateAttributionPendantSuspension = dossierExamenCourant.getConditionsAttributionAdmission().getConditionCSRDateAttributionPendantSuspension();
    
    Damj dateAttribution = dossierExamenCourant.getConstitutionDateAttribution().getDateAttribution();
    
    Periode periodeSuspension = OutilsChomageSansRCT.getPeriodeSuspension(demandeCourante).getPeriode();
    if (dateAttribution.estContenueDans(periodeSuspension))
    {
      conditionCSRDateAttributionPendantSuspension.setEtatSatisfait(true);
      resultatConditionCSRDateAttributionPendantSuspension.setEtat(0);
    }
    else
    {
      conditionCSRDateAttributionPendantSuspension.setEtatSatisfait(false);
      resultatConditionCSRDateAttributionPendantSuspension.setEtat(1);
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_CSR_NON_APPLICABLE_POUR_REGLEMENT");
    }
    if (Log.isTraceActive(DeterminationConditionAppartenancePourMaintien.class, Niveau.DEBUG))
    {
      Log.ecritTrace(Niveau.DEBUG, DeterminationConditionAppartenancePourMaintien.class, "demarrer", "");
      Log.ecritTrace(Niveau.DEBUG, DeterminationConditionAppartenancePourMaintien.class, "demarrer", "\t\t******** Fin Parcours DeterminationConditionDecisionCP ********\n");
    }
    return resultatConditionCSRDateAttributionPendantSuspension;
  }
}

/* Location:
 * Qualified Name:     DeterminationConditionCSRDateAttributionPendantSuspension
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */