package fr.unedic.cali.asu.cva10.calcul.outilsfonctionnels;

import fr.unedic.cali.asu.cge01.outilsfonctionnels.RevalorisationSalaire;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.SalaireJournalierAbstrait;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.parametres.EvenementCategorieA2B;
import fr.unedic.cali.asu.parametres.ParametresIndemnisationA2B;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.QuantiteDroitSpec;
import fr.unedic.cali.dom.QuantiteIndemnisationSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.Iterator;

public class MajCi
{
  protected static final int CINQUANTE_ANS = 50;
  
  public static ConstituantsIndemnisation miseAJourConstituantsIndemnisation(AttributionSpec attribution, ConstituantsIndemnisation constituantsIndemnisation, Damj dateDeMiseAjour)
    throws CoucheLogiqueException
  {
    QuantiteDroitSpec dureeDroit = null;
    Collection collectionDurees = null;
    Iterator iterator = null;
    String codeFormuleMontant = null;
    
    codeFormuleMontant = constituantsIndemnisation.getCodeFormuleMontant();
    if (codeFormuleMontant != null) {
      miseAJourParametres(attribution, constituantsIndemnisation, dateDeMiseAjour);
    }
    collectionDurees = constituantsIndemnisation.getCollectionQuantiteDroit();
    if (collectionDurees != null)
    {
      iterator = collectionDurees.iterator();
      while (iterator.hasNext())
      {
        dureeDroit = (QuantiteDroitSpec)iterator.next();
        if ((dureeDroit instanceof QuantiteIndemnisationSpec)) {
          miseAJourParametres(attribution, constituantsIndemnisation, dateDeMiseAjour);
        }
      }
    }
    return constituantsIndemnisation;
  }
  
  private static void miseAJourParametres(AttributionSpec attribution, ConstituantsIndemnisation constituantsIndemnisation, Damj dateDeMiseAjour)
    throws CoucheLogiqueException
  {
    ElementBaseIndemnisation elementBaseIndemnisation = null;
    ElementBaseIndemnisation elementBaseIndemnisationDroitAssocie = null;
    Sjr nouveauSjr = null;
    SalaireJournalierAbstrait nouveauSjrDroitAssocie = null;
    Attribution attrib = (Attribution)attribution;
    AttributionAssuranceSpec attributionAssociee = attrib.getAttributionAssociee();
    
    elementBaseIndemnisation = (ElementBaseIndemnisation)constituantsIndemnisation.getElementBaseIndemnisationCourant();
    
    elementBaseIndemnisationDroitAssocie = elementBaseIndemnisation.getElementBaseIndemnisationDroitAssocie();
    
    nouveauSjr = RevalorisationSalaire.revaloriserSjr(attrib, dateDeMiseAjour);
    
    elementBaseIndemnisation.getSjr().setSalaire(nouveauSjr.getSalaire());
    if (attributionAssociee != null)
    {
      ElementBaseIndemnisation elementBaseIndemnisationAttributionAssociee = attributionAssociee.getElementBaseIndemnisation();
      ProduitSpec produit = attributionAssociee.getProduit();
      Reglement reglementOdAssociee = null;
      if (elementBaseIndemnisationAttributionAssociee.getReglementApplicableMontantRetenu() != null) {
        reglementOdAssociee = elementBaseIndemnisationAttributionAssociee.getReglementApplicableMontantRetenu().getReglement();
      }
      if ((reglementOdAssociee != null) && (reglementOdAssociee.equals(produit.getReglement("A2b"))))
      {
        Sjr sjr = elementBaseIndemnisationAttributionAssociee.getSjr();
        ParametresIndemnisationA2B param = ParametresIndemnisationA2B.getParametresIndemnisation();
        EvenementCategorieA2B evtParam = param.getElementActif(dateDeMiseAjour);
        BigDecimal salaireForfaitaireJournalier = evtParam.getSalaireA2B(elementBaseIndemnisationAttributionAssociee.getCodeEmploiA2B());
        nouveauSjrDroitAssocie = new Sjr(salaireForfaitaireJournalier, sjr.getDateDepart(), sjr.getContexteParticulier());
      }
      else
      {
        nouveauSjrDroitAssocie = (SalaireJournalierAbstrait)((ProduitAsuSpec)attributionAssociee.getProduit()).revaloriserSalaireJournalier(attributionAssociee.getElementBaseIndemnisation(), dateDeMiseAjour);
      }
      elementBaseIndemnisationDroitAssocie.getSjr().setSalaire(nouveauSjrDroitAssocie.getSalaire());
    }
    if ((elementBaseIndemnisation.getCoefficientSaisonnier() != null) && 
      (elementBaseIndemnisation.getCoefficientSaisonnier().intValue() != 1) && (attribution.getDemandeur().getAgeALaDate(dateDeMiseAjour).getAnnees() >= 50)) {
      if ((elementBaseIndemnisation.getTypeCaractereSaisonnierRetenu() == 1) && (elementBaseIndemnisation.isConditionCaractereSaisonnierParRythme())) {
        elementBaseIndemnisation.setCoefficientSaisonnier(new BigDecimal("1.00"));
      }
    }
    if ((elementBaseIndemnisationDroitAssocie.getCoefficientSaisonnier() != null) && 
      (elementBaseIndemnisationDroitAssocie.getCoefficientSaisonnier().intValue() != 1) && (attribution.getDemandeur().getAgeALaDate(dateDeMiseAjour).getAnnees() >= 50)) {
      if ((elementBaseIndemnisationDroitAssocie.getTypeCaractereSaisonnierRetenu() == 1) && (elementBaseIndemnisationDroitAssocie.isConditionCaractereSaisonnierParRythme())) {
        elementBaseIndemnisationDroitAssocie.setCoefficientSaisonnier(new BigDecimal("1.00"));
      }
    }
    if ((elementBaseIndemnisation.getAvecPrecompteCRC() == null) && 
      (attrib.getCompetenceFinanciere() == 2) && ((attrib.getCompetenceAdministrative() != 1) || ((((AttributionAssuranceSpec)attribution).getConventionGestion() != null) && (!((AttributionAssuranceSpec)attribution).getConventionGestion().estPrecompteCRC())))) {
      elementBaseIndemnisation.setAvecPrecompteCRC(Boolean.FALSE);
    }
    if ((elementBaseIndemnisationDroitAssocie.getAvecPrecompteCRC() == null) && 
      (attrib.getCompetenceFinanciere() == 2) && ((attrib.getCompetenceAdministrative() != 1) || ((((AttributionAssuranceSpec)attribution).getConventionGestion() != null) && (!((AttributionAssuranceSpec)attribution).getConventionGestion().estPrecompteCRC())))) {
      elementBaseIndemnisationDroitAssocie.setAvecPrecompteCRC(Boolean.FALSE);
    }
  }
}

/* Location:
 * Qualified Name:     MajCi
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */