package fr.unedic.cali.asu.ddm16.p01.calcul;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.ari.calcul.FacadeCalculProduitPourLiquidationAriSpec;
import fr.unedic.cali.ari.dom.ElementBaseIndemnisationAriSpec;
import fr.unedic.cali.asu.calcul.outilsfonctionnels.RecuperationPensionInvaliditeAvantDate;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.outilsfonctionnels.OutilMappingSjmSjr;
import fr.unedic.cali.asu.parametres.ParametresIndemnisation;
import fr.unedic.cali.calcul.FacadeCalculProduitPourLiquidationAbstraite;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.calcul.dom.periode.PeriodeAvantageVieillesse;
import fr.unedic.cali.calcul.outilsfonctionnels.RecuperationAvantageVieillesseAvantPJI;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.ElementBaseIndemnisationSpec;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuCge01P04;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.outilsfonctionnels.GestionnaireErreur;
import fr.unedic.cali.parcours.ResultatExecutionCalcul;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public class FacadeCalculProduitPourLiquidationImpl
  extends FacadeCalculProduitPourLiquidationAbstraite
  implements FacadeCalculProduitPourLiquidationAriSpec
{
  public MontantBaseSpec determinerMontant(IndividuSpec p_individu, ElementBaseIndemnisationAriSpec p_elementBaseIndemnisation, FormuleMontantSpec p_formuleMontant, Damj p_dateCalcul)
    throws CoucheLogiqueException
  {
    ConstituantsIndemnisation constituantsIndemnisation = initialiserConstituantsIndemnisation(p_individu, p_elementBaseIndemnisation, p_dateCalcul);
    
    return p_formuleMontant.calculer(constituantsIndemnisation, p_dateCalcul);
  }
  
  public Periode determinerPeriodeAvantSansCalendrier(AttributionSpec p_attribution)
    throws ApplicativeException
  {
    return null;
  }
  
  public ResultatExecutionCalcul executerCalculDeterminationEtatDroit(AttributionSpec p_attributionAEtudier, Damj p_dateEtude, boolean p_priseEnCompteGaec, boolean p_determinationApres)
    throws ApplicativeException
  {
    return null;
  }
  
  private ConstituantsIndemnisation initialiserConstituantsIndemnisation(IndividuSpec p_individu, ElementBaseIndemnisationSpec p_elementBaseIndemnisation, Damj p_dateCalcul)
    throws CoucheLogiqueException
  {
    ConstituantsIndemnisation constituantsIndemnisation = new ConstituantsIndemnisation();
    fr.unedic.cali.asu.ddm16.p01.calcul.dom.ElementBaseIndemnisation elementBaseIndemnisationCourant = new fr.unedic.cali.asu.ddm16.p01.calcul.dom.ElementBaseIndemnisation();
    
    constituantsIndemnisation.setElementBaseIndemnisationCourant(elementBaseIndemnisationCourant);
    ParametresIndemnisation parametresIndemnisation = ParametresIndemnisation.getParametresIndemnisation();
    
    Sjr sjr = OutilMappingSjmSjr.convertirSjr(p_elementBaseIndemnisation.getSalaireJournalier());
    elementBaseIndemnisationCourant.setSjr(sjr);
    
    ProduitAsuSpec produitARE = ProduitAsuCge01P04.getInstance();
    Sjr sjrRevalorise = (Sjr)produitARE.revaloriserSalaireJournalierReference(sjr.getSalaire(), sjr.getDateDepart(), p_dateCalcul, sjr.getContexteParticulier());
    
    elementBaseIndemnisationCourant.setCoefficientSaisonnier(new BigDecimal("1.00"));
    if (p_elementBaseIndemnisation.getCoefficientTempsPartiel() != null) {
      elementBaseIndemnisationCourant.setCoefficientTempsPartiel(p_elementBaseIndemnisation.getCoefficientTempsPartiel());
    }
    PeriodeAvantageVieillesse periodeAvCourante = null;
    DureeCalendaire ageALaDate = null;
    if (p_individu != null)
    {
      elementBaseIndemnisationCourant.setMontantPensionInvaliditeADeduire(RecuperationPensionInvaliditeAvantDate.recuperationMontantPI(p_individu, p_dateCalcul));
      
      periodeAvCourante = RecuperationAvantageVieillesseAvantPJI.recupererPeriodeAvADate(p_individu, p_dateCalcul);
      ageALaDate = p_individu.getAgeALaDate(p_dateCalcul);
      elementBaseIndemnisationCourant.setAgeALaDateCalcul(ageALaDate);
    }
    else
    {
      elementBaseIndemnisationCourant.setMontantPensionInvaliditeADeduire(p_elementBaseIndemnisation.getMontantPensionInvaliditeADeduire());
      periodeAvCourante = p_elementBaseIndemnisation.getPeriodeAvantageVieillesse();
      ageALaDate = p_elementBaseIndemnisation.getAgeFinMoisDateAttribution();
    }
    if (periodeAvCourante != null)
    {
      BigDecimal montantAV = periodeAvCourante.getQuantiteEuro().getValeur();
      
      elementBaseIndemnisationCourant.setDateEffetAV(p_dateCalcul);
      BigDecimal coeffAV = new BigDecimal("0.00");
      if ((sjrRevalorise != null) && (sjrRevalorise.getSalaire() != null) && (!sjrRevalorise.getSalaire().equals(new BigDecimal("0.00")))) {
        coeffAV = montantAV.divide(sjrRevalorise.getSalaire(), 10, 4);
      }
      elementBaseIndemnisationCourant.setCoefficientAvantageVieillesse(coeffAV);
      elementBaseIndemnisationCourant.setMontantAvantageVieillesse(montantAV);
    }
    else
    {
      elementBaseIndemnisationCourant.setDateEffetAV(p_elementBaseIndemnisation.getDateEffetAV());
      elementBaseIndemnisationCourant.setCoefficientAvantageVieillesse(p_elementBaseIndemnisation.getCoefficientAvantageVieillesse());
      elementBaseIndemnisationCourant.setMontantAvantageVieillesse(p_elementBaseIndemnisation.getMontantAvantageVieillesse());
    }
    BigDecimal tauxavantageVieillesse = parametresIndemnisation.getTauxAvantageViellesse(ageALaDate);
    if (tauxavantageVieillesse != null) {
      elementBaseIndemnisationCourant.setTauxAvantageVieillesse(tauxavantageVieillesse);
    }
    elementBaseIndemnisationCourant.setCoefficientSanctionReduction(new BigDecimal("1.00"));
    
    fr.unedic.cali.asu.dom.ElementBaseIndemnisation ebiEnEntree = (fr.unedic.cali.asu.dom.ElementBaseIndemnisation)p_elementBaseIndemnisation;
    if (ebiEnEntree.getAvecPrecompteCRC() != null) {
      elementBaseIndemnisationCourant.setAvecPrecompteCRC(ebiEnEntree.getAvecPrecompteCRC());
    } else {
      elementBaseIndemnisationCourant.setAvecPrecompteCRC(new Boolean(true));
    }
    return constituantsIndemnisation;
  }
  
  public Damj recupererDateFinDroitTheorique(AttributionSpec p_attribution)
    throws CoucheLogiqueException
  {
    return null;
  }
  
  public MontantBaseSpec determinerMontant(AttributionSpec p_attribution, Damj p_dateCalcul)
    throws ApplicativeException
  {
    GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_PRODUIT_METHODE_NON_IMPLEMENTE");
    return null;
  }
  
  public Damj recupererDateDrv(AttributionSpec p_attribution)
    throws CoucheLogiqueException
  {
    GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_PRODUIT_METHODE_NON_IMPLEMENTE");
    return null;
  }
  
  public Damj recupererDateEpuisementDuree(AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_PRODUIT_METHODE_NON_IMPLEMENTE");
    return null;
  }
}

/* Location:
 * Qualified Name:     FacadeCalculProduitPourLiquidationImpl
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */