package fr.unedic.cali.asu.dom;

import fr.unedic.archi.commun.lang.ExceptionUtil;
import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.dom.AlerteAffiliation;
import fr.unedic.cali.asu.dom.conteneur.DonneesRessortissant;
import fr.unedic.cali.asu.dom.gen.DemandeGen;
import fr.unedic.cali.asu.dom.pc.DemandePC;
import fr.unedic.cali.asu.liquidation.outilsfonctionnels.OutilAdhesionVolontaire;
import fr.unedic.cali.asu.liquidation.pnds.OutilDeterminationPNDS;
import fr.unedic.cali.asu.mnt.dom.DemandeMaintien;
import fr.unedic.cali.asu.outilsfonctionnels.OutilAsr;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsActiviteConserve;
import fr.unedic.cali.asu.outilsfonctionnels.RechercherDemandeMaintien;
import fr.unedic.cali.autresdoms.d12i.dom.DemandeInstruction;
import fr.unedic.cali.autresdoms.d12i.dom.DonneesNPDE;
import fr.unedic.cali.autresdoms.d12i.dom.PeriodeAffiliationInstruction;
import fr.unedic.cali.autresdoms.d12i.spec.DonneesDALSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.calcul.dom.UniteTraitementForcee;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.ClassementAdministratif;
import fr.unedic.cali.dom.ClassementCompetenceSecteurPublic;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.DecisionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.Entretien;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.OdSpec;
import fr.unedic.cali.dom.Prescription;
import fr.unedic.cali.dom.affectation.ContexteDemandeSpec;
import fr.unedic.cali.dom.affectation.GammeAsu;
import fr.unedic.cali.dom.affectation.GammeSpec;
import fr.unedic.cali.dom.affectation.LigneSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.cali.dom.pivot.DemandePivot;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.RechercherDernierSinistre;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieEtantFCT;
import fr.unedic.cali.util.OutilDomToString;
import fr.unedic.cali.utilitaire.filtres.FiltreCaliSpec;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreOuvertureDroitStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourTypeContexteDemande;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreOU;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.ApplicativeRuntimeException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;

public class Demande
  extends DemandeGen
  implements DemandeAssuranceSpec
{
  private static final long serialVersionUID = 3132182375435291069L;
  public static final int REJET_AUTOMATIQUE = 1;
  public static final int REPRISE_AUTOMATIQUE = 2;
  public static final int REJET_NCP = 3;
  private transient ObjectifExamen objectifCourant;
  private transient Collection listeObjectifExamenTriee;
  private transient int decisionAutomatique;
  private boolean pndsChargees = true;
  private transient boolean droitOptionReprise;
  private transient boolean droitOptionAss;
  private transient boolean liquideeAvecDroitOptionReprise;
  private transient Boolean estUnContexteDeChomageSansRuptureAsr = null;
  private transient Boolean estUnContexteDeCSPSurAERevisee = null;
  private transient Boolean estUnContexteDeChomageSansRupturefinAsr = null;
  private transient boolean estUnContexteDeRepriseSansFCT = false;
  private transient AttributionAssuranceSpec attributionPrecedenteDuMemeType = null;
  private transient OdAssuranceSpec ouvertureDroitPrecedenteDuMemeType = null;
  private transient String idDecorDepuisPN;
  private transient TraitementReliquat traitementReliquat;
  private transient Damj dateFgOdPrecedente = null;
  private transient Collection collectionPNDS = null;
  private transient Periode periodePNDS = null;
  private transient int revisionANotifier;
  private transient Chronologie periodesAffiliation = null;
  private transient List<AlerteAffiliation> listeAlertesAffiliation;
  private DossierAffectation dossierAffectationAdmissionSauvegarde = null;
  private boolean estDossierAffectationAdmissionSauvegarde = false;
  private DossierAffectation dossierAffectationRepriseSauvegarde = null;
  private boolean estDossierAffectationRepriseSauvegarde = false;
  private boolean besoinVerifierCoherenceDossierAffectation = false;
  private Damj dateForceeFaitGenerateurOdPrecedente = null;
  private String commentaireSauvegarde = null;
  private boolean estDonneesDalChargees = false;
  private boolean estTopPropositionCharges = false;
  private transient DonneesDALSpec donneesDAL;
  private boolean estDonneesNPDEChargees = false;
  private transient DonneesNPDE donneesNPDE;
  private transient boolean estInstallationNPDEsurTransaction = false;
  private transient DonneesRessortissant donneesRessortissant = new DonneesRessortissant();
  private List<String> listeBlocageALever;
  private boolean presencePNDS = false;
  private boolean modeSimulation = false;
  private String derniereStrategiePNDSUtilisee = "";
  private transient String justificationGenerique;
  private transient boolean affichageJustificationGenerique;
  
  public Demande() {}
  
  public Demande(DomPCSpec pc)
  {
    super(pc);
  }
  
  public DonneesTemporaires getDonneesTemporaires()
  {
    if (super.getDonneesTemporaires() == null) {
      super.createDonneesTemporaires();
    }
    return super.getDonneesTemporaires();
  }
  
  public void setDonneesTemporaires(DonneesTemporaires donneesTemporaires)
  {
    donneesTemporaires.copieElements(super.getDonneesTemporaires());
  }
  
  public DonneesSortieNPDE getDonneesSortieNPDE()
  {
    if (super.getDonneesSortieNPDE() == null) {
      super.createDonneesSortieNPDE();
    }
    return super.getDonneesSortieNPDE();
  }
  
  public void setDonneesSortieNPDE(DonneesSortieNPDE donneesSortieNPDE)
  {
    donneesSortieNPDE.copieElements(super.getDonneesSortieNPDE());
  }
  
  public DonneesDAL getDonneesDAL()
  {
    if (super.getDonneesDAL() == null) {
      super.createDonneesDAL();
    }
    return super.getDonneesDAL();
  }
  
  public DonneesDALSpec getDonneesDalEnrichies()
  {
    if (!estDonneesDalChargees)
    {
      chargerDonneesDAL();
      estDonneesDalChargees = true;
    }
    return donneesDAL;
  }
  
  public DonneesNPDE getDonneesNPDE()
  {
    if (!estDonneesNPDEChargees)
    {
      chargerDonneesNPDE();
      estDonneesNPDEChargees = true;
    }
    return donneesNPDE;
  }
  
  private void chargerDonneesNPDE()
  {
    FormulaireAsu formulaireAsu = (FormulaireAsu)getFormulaire();
    String referenceExterne = formulaireAsu.getReferenceExterne();
    DonneesNPDE donneesNPDEavecTop = null;
    
    boolean versionDeploiementOPIValide = (formulaireAsu.getDeploiementInstruction() != null) && (!"N".equalsIgnoreCase(formulaireAsu.getDeploiementInstruction())) && (!"1".equalsIgnoreCase(formulaireAsu.getDeploiementInstruction()));
    if (versionDeploiementOPIValide)
    {
      DemandeInstruction demandeInstruction = getDemandeur().getDemandeInstruction(referenceExterne);
      if (demandeInstruction != null) {
        donneesNPDEavecTop = demandeInstruction.getDonneesNPDE();
      }
    }
    if (donneesNPDEavecTop == null)
    {
      donneesNPDEavecTop = new DonneesNPDE();
      donneesNPDEavecTop.initialiserAFaux();
    }
    donneesNPDE = donneesNPDEavecTop;
  }
  
  private void chargerDonneesDAL()
  {
    boolean versionDeploiementOPIValide = (getFormulaireAsu().getDeploiementInstruction() != null) && (!"N".equalsIgnoreCase(getFormulaireAsu().getDeploiementInstruction())) && (!"1".equalsIgnoreCase(getFormulaireAsu().getDeploiementInstruction()));
    if (versionDeploiementOPIValide)
    {
      String referenceExterne = getFormulaireAsu().getReferenceExterne();
      DemandeInstruction demandeInstruction = getDemandeur().getDemandeInstruction(referenceExterne);
      fr.unedic.cali.autresdoms.d12i.dom.DonneesDAL donneesDALCourante = null;
      if (demandeInstruction != null) {
        donneesDALCourante = demandeInstruction.getDonneesDal();
      }
      if (donneesDALCourante == null) {
        donneesDALCourante = new fr.unedic.cali.autresdoms.d12i.dom.DonneesDAL();
      }
      donneesDALCourante.setTopFinDeDroit(getDonneesDAL().estTopFinDeDroit());
      
      donneesDAL = donneesDALCourante;
    }
    else
    {
      donneesDAL = getDonneesDAL();
    }
  }
  
  public void setDonneesDAL(DonneesDAL donneesDAL)
  {
    if (donneesDAL != null)
    {
      if (!donneesDAL.getPC().equals(getPC()))
      {
        super.getDonneesDAL().setCategorieParticuliere(donneesDAL.getCategorieParticuliere());
        donneesDAL.setPC(getPC());
      }
      ((DemandePC)getPC()).setPresenceDonneesDonneesDAL(true);
    }
    else
    {
      ((DemandePC)getPC()).setPresenceDonneesDonneesDAL(false);
    }
  }
  
  public DossierExamenSpec getDossierExamen()
  {
    return getDossierAffectation().getDossierExamen();
  }
  
  public void setDossierExamen(DossierExamenSpec dossierExamen)
  {
    getDossierAffectation().setDossierExamen(dossierExamen);
  }
  
  public FaitGenerateurSpec getFaitGenerateur()
  {
    if (getDossierExamen() != null) {
      return ((DossierExamenAssuranceSpec)getDossierExamen()).getFaitGenerateur();
    }
    return null;
  }
  
  public Damj getDateFaitGenerateurOdPrecedente()
  {
    if (dateFgOdPrecedente == null)
    {
      ContexteDemande contexteDemandeAdhVol = (ContexteDemande)OutilGestionContexteDemande.trouverContexteDemande(getListContexteDemande(), "ADHVOLARE");
      ContexteDemande contexteAreSousJacentRevision = (ContexteDemande)OutilGestionContexteDemande.trouverContexteDemande(getListContexteDemande(), "ARESJREV");
      if (contexteAreSousJacentRevision != null)
      {
        dateFgOdPrecedente = null;
      }
      else if (contexteDemandeAdhVol != null)
      {
        OutilAdhesionVolontaire.trouverOdAreAdhesionVolontaire(this);
        dateFgOdPrecedente = ((Demande)contexteDemandeAdhVol.getAttributionAreAdhesionVolontaire().getDemande()).getDateFaitGenerateurOdPrecedente();
      }
      else if (estEnContexteDroitAnterieurSecteurPublic())
      {
        dateFgOdPrecedente = getDonneesTemporaires().getDateFgDroitAnterieurSp();
      }
      else if (estEnContexteDroitAnterieurSecteurPublicAvecFGDAreApresDateFGDDroitSP())
      {
        dateFgOdPrecedente = recupererDateFaitGenerateurDroitArePrecedent();
      }
      else
      {
        DecisionSpec odPrecedente = getOdAssurancePrecedente(this);
        dateFgOdPrecedente = getDateFaitGenerateurOdPrecedenteContexteRAC(odPrecedente);
      }
    }
    return dateFgOdPrecedente;
  }
  
  private DecisionSpec getOdAssurancePrecedente(DemandeSpec demande)
  {
    FiltreET filtreOdAssurance = getFiltreCsr(new FiltreOuvertureDroitStandardAssurance(true, true, true, false, this));
    Chronologie chronoRecherche = demande.getChronologieDemandesAssuranceSansCourante();
    return OutilRecherche.rechercherDecisionPrecedente(chronoRecherche, demande, filtreOdAssurance);
  }
  
  private FiltreET getFiltreCsr(FiltreCaliSpec filtre)
  {
    FiltreET filtreOdAssurance = new FiltreET();
    
    filtreOdAssurance.ajouterFiltre(filtre);
    if (getDonneesTemporaires().isEstIgnorerAttribPrecCSR())
    {
      FiltreOU filtreCsr = new FiltreOU();
      filtreCsr.ajouterFiltre(new FiltreDemandePourTypeContexteDemande("CSRSUSP"));
      filtreCsr.ajouterFiltre(new FiltreDemandePourTypeContexteDemande("RUPCTRSUSP"));
      FiltreNegation filtreNonCsr = new FiltreNegation(filtreCsr);
      filtreOdAssurance.ajouterFiltre(filtreNonCsr);
    }
    return filtreOdAssurance;
  }
  
  private Damj getDateFaitGenerateurOdPrecedenteContexteRAC(DecisionSpec odPrecedente)
  {
    if (odPrecedente != null)
    {
      DemandeAssuranceSpec demandeOdPrecedente = (DemandeAssuranceSpec)odPrecedente.getDemande();
      if (demandeOdPrecedente != null)
      {
        FaitGenerateurSpec fgPrecedent = demandeOdPrecedente.getFaitGenerateur();
        if (fgPrecedent != null) {
          dateFgOdPrecedente = fgPrecedent.getDateFaitGenerateur();
        } else {
          OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "Aucun Fait Générateur précédent n'a été trouvé pour la demande précédente ???" });
        }
      }
    }
    return dateFgOdPrecedente;
  }
  
  public Damj getDateFaitGenerateurOuFinDernierContratTravailRompu()
    throws CoucheLogiqueException
  {
    ContexteDemande contexteAreSousJacentRevision = (ContexteDemande)OutilGestionContexteDemande.trouverContexteDemande(getListContexteDemande(), "ARESJREV");
    if (contexteAreSousJacentRevision != null) {
      return null;
    }
    if (getFaitGenerateur() != null) {
      return getFaitGenerateur().getDateFaitGenerateur();
    }
    TravailSpec dernierSinistre = RechercherDernierSinistre.rechercherDernierContratTravailRompu(getDateExamen().veille(), getDemandeur().getChronoPeriodePasseProfessionnelLiquidation());
    
    return dernierSinistre.getDateFin();
  }
  
  public Damj getDateFaitGenerateurOuDernierSinistrePourCarences()
    throws CoucheLogiqueException
  {
    FiltresTemporel filtres = new FiltresTemporel();
    
    FiltreActiviteSalarie filtrePas = new FiltreActiviteSalarieEtantFCT();
    filtres.ajouterFiltre(filtrePas);
    Chronologie chronoResultat = getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(filtres);
    
    return getDateFaitGenerateurOuDernierSinistre(chronoResultat);
  }
  
  public Damj getDateFaitGenerateurOuDernierSinistre()
    throws CoucheLogiqueException
  {
    return getDateFaitGenerateurOuDernierSinistre(getDemandeur().getChronoPeriodePasseProfessionnelLiquidation());
  }
  
  private Damj getDateFaitGenerateurOuDernierSinistre(Chronologie chronologie)
    throws CoucheLogiqueException
  {
    Damj dateFGOuDernierSinistre = null;
    if (getFaitGenerateur() != null)
    {
      dateFGOuDernierSinistre = getFaitGenerateur().getDateFaitGenerateur();
    }
    else
    {
      TravailSpec dernierSinistre = RechercherDernierSinistre.rechercherDateDernierSinistre(getDateExamen().veille(), chronologie);
      if ((dernierSinistre != null) && ((getDateFaitGenerateurOdPrecedente() == null) || (getDateFaitGenerateurOdPrecedente().estAvant(dernierSinistre.getDateFin())))) {
        dateFGOuDernierSinistre = dernierSinistre.getDateFin();
      }
    }
    return dateFGOuDernierSinistre;
  }
  
  public TravailSpec getFaitGenerateurOuDernierSinistre()
    throws CoucheLogiqueException
  {
    TravailSpec faitGenerateurOuDernierSinistre = null;
    if (getFaitGenerateur() != null)
    {
      faitGenerateurOuDernierSinistre = getFaitGenerateur().getPeriodeFaitGenerateur();
    }
    else
    {
      TravailSpec dernierSinistre = RechercherDernierSinistre.rechercherDateDernierSinistre(getDateExamen().veille(), getDemandeur().getChronoPeriodePasseProfessionnelLiquidation());
      if ((dernierSinistre != null) && ((getDateFaitGenerateurOdPrecedente() == null) || (getDateFaitGenerateurOdPrecedente().estAvant(dernierSinistre.getDateFin())))) {
        faitGenerateurOuDernierSinistre = dernierSinistre;
      }
    }
    return faitGenerateurOuDernierSinistre;
  }
  
  public OdSpec getOdAcquise()
  {
    OdSpec odCourante = null;
    if ((getDossierExamen() != null) && (getDossierExamen().estType(OdSpec.class))) {
      odCourante = (OdSpec)getDossierExamen();
    }
    return odCourante;
  }
  
  public AttributionAssuranceSpec getAttribution()
  {
    AttributionAssuranceSpec attribution = null;
    if ((getDossierExamen() != null) && (getDossierExamen().estType(AttributionAssuranceSpec.class))) {
      attribution = (AttributionAssuranceSpec)getDossierExamen();
    }
    return attribution;
  }
  
  public DossierAffectationSpec getDossierAffectation()
  {
    ObjectifExamen objectif = getObjectifCourant();
    if (objectif == null) {
      objectif = getObjectifDecisionne();
    }
    DossierAffectation dossierARetourner = getDossierAffectationAdmission();
    if (objectif != null) {
      switch (objectif.getType())
      {
      case 2: 
      case 5: 
      case 6: 
        dossierARetourner = getDossierAffectationReprise();
        break;
      case 4: 
        dossierARetourner = getDossierAffectationRevision();
        break;
      }
    }
    return dossierARetourner;
  }
  
  public void supprimerDossierAffectationReprise()
  {
    setDossierAffectationReprise(null);
  }
  
  public void setDossierAffectation(DossierAffectationSpec dossierAffectation)
  {
    ObjectifExamen objectif = getObjectifCourant();
    if ((objectif != null) && (objectif.getType() == 2)) {
      setDossierAffectationReprise((DossierAffectation)dossierAffectation);
    } else {
      setDossierAffectationAdmission((DossierAffectation)dossierAffectation);
    }
    dateFgOdPrecedente = null;
  }
  
  public int getNumeroGamme()
  {
    return 1;
  }
  
  public ObjectifExamen creerObjectifExamen(int sousType, ProduitAsuSpec produit)
  {
    ObjectifExamen objectif = null;
    if (produit != null) {
      objectif = (ObjectifExamen)produit.creerObjectifExamen(sousType, getListContexteDemande());
    }
    return objectif;
  }
  
  public void ajouterObjectifExamen(ObjectifExamen objectifExamen)
  {
    if (objectifExamen != null)
    {
      super.ajouterObjectifExamen(objectifExamen);
      
      listeObjectifExamenTriee = null;
    }
  }
  
  public void supprimerObjectifExamen(ObjectifExamen objectifExamen)
  {
    if (objectifExamen != null)
    {
      super.supprimerObjectifExamen(objectifExamen);
      listeObjectifExamenTriee = null;
    }
  }
  
  public Collection getListeObjectifsExamen()
  {
    if (listeObjectifExamenTriee == null)
    {
      List tmp = new LinkedList(getListeObjectifsExamenPrive());
      Collections.sort(tmp);
      listeObjectifExamenTriee = Collections.unmodifiableList(tmp);
    }
    return listeObjectifExamenTriee;
  }
  
  private Collection getListeObjectifsExamenPrive()
  {
    return super.getCollectionObjectifExamen();
  }
  
  private Collection getListeMotifsReexamenPrive()
  {
    return super.getCollectionMotifReexamen();
  }
  
  public void viderListeObjectifsExamen()
  {
    if (getListeObjectifsExamenPrive() != null)
    {
      Iterator<?> iter = getListeObjectifsExamenPrive().iterator();
      while (iter.hasNext())
      {
        ObjectifExamen element = (ObjectifExamen)iter.next();
        DomManager.supprimer(element);
      }
      clearCollectionObjectifExamen();
      
      listeObjectifExamenTriee = null;
    }
  }
  
  public ObjectifExamen getObjectifSatisfait()
  {
    for (Iterator<?> iter = getListeObjectifsExamen().iterator(); iter.hasNext();)
    {
      ObjectifExamen objectif = (ObjectifExamen)iter.next();
      if ((objectif.getEtat() == 21) || (objectif.getEtat() == 23)) {
        return objectif;
      }
    }
    return null;
  }
  
  public ObjectifExamen getObjectifDecisionne()
  {
    Iterator<?> iter = getListeObjectifsExamen().iterator();
    ObjectifExamen objectifDecisionne = null;
    while ((iter.hasNext()) && (objectifDecisionne == null))
    {
      ObjectifExamen objectif = (ObjectifExamen)iter.next();
      if (objectif.getEtat() == 23) {
        objectifDecisionne = objectif;
      }
    }
    if ((objectifDecisionne == null) && (!getListeObjectifsExamen().isEmpty())) {
      objectifDecisionne = (ObjectifExamen)getListeObjectifsExamen().iterator().next();
    }
    return objectifDecisionne;
  }
  
  public ObjectifExamen getObjectifCourant()
  {
    return objectifCourant;
  }
  
  public void setObjectifCourant(ObjectifExamen objectifCourant)
  {
    this.objectifCourant = objectifCourant;
  }
  
  public DossierAffectation getDossierAffectationRevision()
  {
    DossierAffectation dossierAffectation = super.getDossierAffectationAdmission();
    if (dossierAffectation == null)
    {
      super.setDossierAffectationAdmission(new DossierAAffecter(4));
      dossierAffectation = super.getDossierAffectationAdmission();
    }
    if (dossierAffectation.getDemande() != this) {
      dossierAffectation.setDemande(this);
    }
    return dossierAffectation;
  }
  
  public DossierAffectation getDossierAffectationAdmission()
  {
    DossierAffectation dossierAffectation = super.getDossierAffectationAdmission();
    if (dossierAffectation == null)
    {
      super.setDossierAffectationAdmission(new DossierAAffecter(1));
      dossierAffectation = super.getDossierAffectationAdmission();
    }
    if (dossierAffectation.getDemande() != this) {
      dossierAffectation.setDemande(this);
    }
    return dossierAffectation;
  }
  
  public void setDossierAffectationAdmission(DossierAffectation dossierAffectationAdmission)
  {
    remplacerDossiersAffectations(1, dossierAffectationAdmission);
    if ((super.getDossierAffectationAdmission() != null) && (super.getDossierAffectationAdmission().getDemande() != this)) {
      super.getDossierAffectationAdmission().setDemande(this);
    }
  }
  
  public DossierAffectation getDossierAffectationReprise()
  {
    DossierAffectation dossierAffectation = super.getDossierAffectationReprise();
    if ((dossierAffectation != null) && (dossierAffectation.getDemande() != this)) {
      dossierAffectation.setDemande(this);
    }
    return dossierAffectation;
  }
  
  public void setDossierAffectationReprise(DossierAffectation dossierAffectationReprise)
  {
    remplacerDossiersAffectations(2, dossierAffectationReprise);
    if ((super.getDossierAffectationReprise() != null) && (super.getDossierAffectationReprise().getDemande() != this)) {
      super.getDossierAffectationReprise().setDemande(this);
    }
  }
  
  public DossierExamenSpec getDossierExamen(int typeObjectif)
  {
    DossierAffectationSpec dossierAffectation = getDossierAffectation(getObjectif(typeObjectif));
    if (dossierAffectation != null) {
      return dossierAffectation.getDossierExamen();
    }
    return null;
  }
  
  public ObjectifExamen getObjectif(int typeObjectif)
  {
    for (Iterator<?> iter = getListeObjectifsExamen().iterator(); iter.hasNext();)
    {
      ObjectifExamen zeObjectifExamen = (ObjectifExamen)iter.next();
      if (zeObjectifExamen.getType() == typeObjectif) {
        return zeObjectifExamen;
      }
    }
    return null;
  }
  
  public ObjectifExamen getObjectifParNumeroOrdre(int numeroOrdre)
  {
    for (Iterator<?> iter = getListeObjectifsExamen().iterator(); iter.hasNext();)
    {
      ObjectifExamen zeObjectifExamen = (ObjectifExamen)iter.next();
      if (zeObjectifExamen.getNumeroOrdre() == numeroOrdre) {
        return zeObjectifExamen;
      }
    }
    return null;
  }
  
  private DossierAffectationSpec getDossierAffectation(ObjectifExamen objectif)
  {
    DossierAffectation zeDossierAffectation = getDossierAffectationAdmission();
    if ((objectif != null) && ((objectif.getType() == 2) || (objectif.getType() == 5) || (objectif.getType() == 6))) {
      zeDossierAffectation = getDossierAffectationReprise();
    }
    return zeDossierAffectation;
  }
  
  public boolean estClasseeOuDecisionneeValidee()
  {
    boolean demandeDecisionneeValidee = false;
    if ((getDossierExamen() != null) && (getDossierExamen().estType(DecisionSpec.class)))
    {
      demandeDecisionneeValidee = ((DecisionSpec)getDossierExamen()).estValidee();
    }
    else if (getClassementAdministratif() != null)
    {
      demandeDecisionneeValidee = true;
      if ((getClassementAdministratif() instanceof Prescription)) {
        demandeDecisionneeValidee = ((Prescription)getClassementAdministratif()).isValidite();
      }
    }
    return demandeDecisionneeValidee;
  }
  
  public void marquerGraphePersistant()
  {
    setEvenementReferenceExamen((EvenementReferenceExamenSpec)getEvenementReferenceExamen().copie());
    if (besoinVerifierCoherenceDossierAffectation) {
      verifierCoherenceDossiersAffectations();
    }
    super.marquerGraphePersistant();
    DomManager.persisterEnProfondeur(super.getDonneesTemporaires());
    DomManager.persisterEnProfondeur(super.getDonneesSortieNPDE());
    DomManager.persisterEnProfondeur(super.getFormulaireAsu());
    DomManager.persisterEnProfondeur(super.getReliquat());
    DomManager.persisterEnProfondeur(super.getDonneesDAL());
    DomManager.persisterEnProfondeur(super.getElementJustification());
    DomManager.persisterEnProfondeur(super.getDonneesDemandeAssociee());
    DomManager.persisterEnProfondeur(super.getContexteDemande());
    DomManager.persisterEnProfondeur(super.getDemandePivot());
    DomManager.persisterEnProfondeur(super.getDossierAffectationAdmission());
    DomManager.persisterEnProfondeur(super.getDossierAffectationReprise());
    DomManager.persisterEnProfondeur(super.getClassementAdministratif());
    DomManager.persisterEnProfondeur(super.getEntretien());
    DomManager.persisterEnProfondeur(super.getSaisieAntecedent());
    DomManager.persisterEnProfondeur(super.getCollectionObjectifExamen());
    DomManager.persisterEnProfondeur(super.getCollectionUniteTraitementForcee());
    DomManager.persisterEnProfondeur(super.getCollectionContexteDemande());
    DomManager.persisterEnProfondeur(super.getDonneesSortieNPDE());
  }
  
  public List getListeDossiersExamen()
  {
    List listeDossiersExamen = new ArrayList();
    if (getDossierExamen() != null) {
      listeDossiersExamen.add(getDossierExamen());
    }
    return listeDossiersExamen;
  }
  
  public void setClassementAdministratif(ClassementAdministratif classement)
  {
    DomManager.supprimer(super.getClassementAdministratif(), classement);
    super.setClassementAdministratif(classement);
  }
  
  public FormulaireSpec getFormulaire()
  {
    FormulaireAsu formulaireAsu = super.getFormulaireAsu();
    if ((!estUneDemandeV2()) && (!estFormulaireCharge()))
    {
      Damj ancienneDateDepot = formulaireAsu.getDateDepot();
      setEstFormulaireCharge(true);
      FormulaireSpec formulaire = getDemandeur().getFormulaire(this);
      formulaireAsu.miseAjour(formulaire);
      if (estDemandeExpresseEnSortieCRA()) {
        if ((getFaitGenerateur() != null) && (getFaitGenerateur().getDateFaitGenerateur() != null)) {
          formulaireAsu.setDateDepot(getFaitGenerateur().getDateFaitGenerateur().lendemain());
        } else {
          formulaireAsu.setDateDepot(ancienneDateDepot);
        }
      }
    }
    formulaireAsu.setDemandeAssurance(this);
    
    return super.getFormulaireAsu();
  }
  
  private boolean estDemandeExpresseEnSortieCRA()
  {
    return (estDecisionnee()) && ("ASU_02".equals(getEvenementReferenceExamen().getTypeExamen())) && (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(this, "SORTIECRA"));
  }
  
  public FormulaireAsu createFormulaireAsu()
  {
    FormulaireAsu formulaireAsu = super.createFormulaireAsu();
    formulaireAsu.setDemandeAssurance(this);
    
    return formulaireAsu;
  }
  
  public void setFormulaire(FormulaireSpec formulaire)
  {
    if ((super.getFormulaireAsu() != null) && (super.getFormulaireAsu() != formulaire)) {
      DomManager.supprimer(super.getFormulaireAsu(), formulaire);
    }
    ((FormulaireAsu)formulaire).copieElements(super.getFormulaireAsu());
  }
  
  public void setEnReExamen(boolean reExamen)
  {
    if (reExamen) {
      ajouterMotifReexamen("1");
    } else {
      supprimerMotifReexamen("1");
    }
  }
  
  public Collection getListeMotifsReexamen()
  {
    return Collections.unmodifiableCollection(getListeMotifsReexamenPrive());
  }
  
  public void setListeMotifsReexamen(Collection listeMotifsReexamen)
  {
    if (listeMotifsReexamen == null)
    {
      clearCollectionMotifReexamen();
      setMotifReexamenPrincipal(null);
    }
  }
  
  public void ajouterMotifReexamen(String motifReexamen)
  {
    if ((motifReexamen != null) && (super.getMotifReexamenPrincipal() != null))
    {
      if ((!getListeMotifsReexamenPrive().contains(motifReexamen)) && (!super.getMotifReexamenPrincipal().equalsIgnoreCase(motifReexamen))) {
        super.ajouterMotifReexamen(motifReexamen);
      }
    }
    else {
      setMotifReexamenPrincipal(motifReexamen);
    }
  }
  
  public void supprimerMotifReexamen(String motifReexamen)
  {
    if (motifReexamen != null) {
      super.supprimerMotifReexamen(motifReexamen);
    }
  }
  
  public GammeSpec getGamme()
  {
    return GammeAsu.getInstance();
  }
  
  public void mettreAJourDemande(DemandeSpec demandeSauvegardee)
  {
    Demande demandeSauvegarde = (Demande)demandeSauvegardee;
    
    setObjectifCourant(demandeSauvegarde.getObjectifCourant());
    
    viderListeObjectifsExamen();
    for (Iterator<?> itListeObjectifsExamen = demandeSauvegarde.getListeObjectifsExamen().iterator(); itListeObjectifsExamen.hasNext();) {
      ajouterObjectifExamen((ObjectifExamen)itListeObjectifsExamen.next());
    }
    restaurerDossiersAffectations();
    
    setClassementAdministratif(demandeSauvegarde.getClassementAdministratif());
    
    setMotifReexamenPrincipal(demandeSauvegarde.getMotifReexamenPrincipal());
    
    Iterator<?> itMotifReExamen = null;
    String motifReExamen = null;
    for (itMotifReExamen = demandeSauvegarde.getListeMotifsReexamen().iterator(); itMotifReExamen.hasNext();)
    {
      motifReExamen = (String)itMotifReExamen.next();
      ajouterMotifReexamen(motifReExamen);
    }
    getGamme().setTopRenoncementDecision(this, getGamme().estDecisionRenoncement(demandeSauvegardee));
    
    setDemandeOrigine(demandeSauvegarde.getDemandeOrigine());
    
    ArrayList listeContextesCopies = new ArrayList();
    Iterator<?> iterListContexteDemande = demandeSauvegarde.getListContexteDemande().iterator();
    while (iterListContexteDemande.hasNext())
    {
      ContexteDemande element = (ContexteDemande)iterListContexteDemande.next();
      listeContextesCopies.add(element.copie());
    }
    remplacerCollectionContexteDemande(listeContextesCopies);
    
    createDonneesDemandeAssociee();
    if ((demandeSauvegarde.getDonneesDemandeAssociee() != null) && (demandeSauvegarde.getDonneesDemandeAssociee().getDemandeAssociee() != null)) {
      getDonneesDemandeAssociee().setDemandeAssociee(demandeSauvegarde.getDonneesDemandeAssociee().getDemandeAssociee());
    }
  }
  
  public boolean estLiquideeAvecConflits()
  {
    return super.isLiquideeAvecConflits();
  }
  
  public void setDemandePivot(DemandePivot pivot)
  {
    DomManager.supprimer(super.getDemandePivot(), pivot);
    super.setDemandePivot(pivot);
  }
  
  public ObjetMetierSpec copie()
  {
    Demande copie = new Demande();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec copie)
  {
    Demande copieDemande = (Demande)copie;
    super.copieElements(copieDemande);
    
    copierElementsComplexe(copieDemande);
    
    copieDemande.setDemandeExpresse(isDemandeExpresse());
    copieDemande.setEnReExamen(estEnReExamen());
    copieDemande.setLiquideeAvecConflits(estLiquideeAvecConflits());
    copieDemande.setDateDerniereValidation(getDateDerniereValidation());
    copieDemande.setDateDerniereNotification(getDateDerniereNotification());
    copieDemande.setRevisionANotifier(getRevisionANotifier());
    copieDemande.setPndsChargees(isPndsChargees());
    copieDemande.setEstNonExecutable(isEstNonExecutable());
    
    copierDonneesReexamen(copieDemande);
    if (getDemandeOrigine() != null) {
      copieDemande.setDemandeOrigine(getDemandeOrigine());
    }
    copierDonneesMigration(copieDemande);
    if (getForcageExecution() != null) {
      copieDemande.setForcageExecution(getForcageExecution());
    }
    copieDemande.getElementJustification().setPrsRepriseContextuelle(getElementJustification().getPrsRepriseContextuelle() != null ? new Periode(getElementJustification().getPrsRepriseContextuelle().getDebut(), getElementJustification().getPrsRepriseContextuelle().getFin()) : null);
    
    Iterator<?> iter = getElementJustification().getListePeriodesChomageSaisonnierRepContextuelle().iterator();
    while (iter.hasNext())
    {
      PeriodeChomageSaisonnier element = (PeriodeChomageSaisonnier)iter.next();
      copieDemande.getElementJustification().ajouterPeriodeChomageSaisonnierRepContextuelle((PeriodeChomageSaisonnier)element.copie());
    }
    copieDemande.setObjectifCourant(getObjectifCourant() != null ? (ObjectifExamen)getObjectifCourant().copie() : null);
    copieDemande.setDecisionAutomatique(getDecisionAutomatique());
    copieDemande.setDroitOptionReadmission(estDroitOptionReadmission());
    copieDemande.setDroitOptionReprise(estDroitOptionReprise());
    copieDemande.setDroitOptionASS(estDroitOptionASS());
    copieDemande.setLiquideeAvecDroitOptionReprise(estLiquideeAvecDroitOptionReprise());
    copieDemande.setIdDecorDepuisPN(getIdDecorDepuisPN());
    copieDemande.setValide(estValide());
    copieDemande.setDateAnnulationReexamen(getDateAnnulationReexamen());
    copieDemande.setModeLiquidation(getModeLiquidation());
    copieDemande.setCommentaire(getCommentaire());
    
    Iterator<?> iterListContexteDemande = getListContexteDemande().iterator();
    while (iterListContexteDemande.hasNext())
    {
      ContexteDemande element = (ContexteDemande)iterListContexteDemande.next();
      copieDemande.ajouterContexteDemande((ContexteDemande)element.copie());
    }
    copieDemande.setIdentifiantObjetMetier(getIdentifiantObjetMetier());
    copieDemande.setEstRepriseStockSpectacle2016Faite(isEstRepriseStockSpectacle2016Faite());
  }
  
  private void copierElementsComplexe(Demande copieDemande)
  {
    copierDonneesDecision(copieDemande);
    copierDonneesForcees(copieDemande);
    if (getEvenementReferenceExamen() != null) {
      copieDemande.setEvenementReferenceExamen((EvenementReferenceExamenSpec)getEvenementReferenceExamen().copie());
    }
    if (getDonneesDAL() != null)
    {
      DonneesDAL copieDonneesDAL = copieDemande.createDonneesDAL();
      getDonneesDAL().copieElements(copieDonneesDAL);
    }
    if (getFormulaire() != null)
    {
      FormulaireAsu copieFormulaireASU = copieDemande.createFormulaireAsu();
      getFormulaire().copieElements(copieFormulaireASU);
    }
    if (getReliquat() != null)
    {
      Reliquat copieReliquat = copieDemande.createReliquat();
      getReliquat().copieElements(copieReliquat);
    }
    if (getDonneesSortieNPDE() != null)
    {
      DonneesSortieNPDE copieDonneesSortieNPDE = copieDemande.createDonneesSortieNPDE();
      getDonneesSortieNPDE().copieElements(copieDonneesSortieNPDE);
    }
  }
  
  private void copierDonneesForcees(Demande copieDemande)
  {
    if (getDonneesTemporaires() != null)
    {
      DonneesTemporaires copieDonneesTemporaires = copieDemande.createDonneesTemporaires();
      getDonneesTemporaires().copieElements(copieDonneesTemporaires);
    }
    if (getSaisieAntecedent() != null)
    {
      SaisieAntecedent copieSaisieAntecedent = (SaisieAntecedent)getSaisieAntecedent().copie();
      copieDemande.setSaisieAntecedent(copieSaisieAntecedent);
    }
    if (getEntretien() != null)
    {
      Entretien copieEntretien = (Entretien)getEntretien().copie();
      copieDemande.setEntretien(copieEntretien);
    }
    if (getClassementAdministratif() != null) {
      copieDemande.setClassementAdministratif((ClassementAdministratif)getClassementAdministratif().copie());
    }
  }
  
  private void copierDonneesDecision(Demande copieDemande)
  {
    Iterator<?> iterObjectifs = getListeObjectifsExamen().iterator();
    while (iterObjectifs.hasNext()) {
      copieDemande.ajouterObjectifExamen((ObjectifExamen)((ObjectifExamen)iterObjectifs.next()).copie());
    }
    if (getDossierAffectationAdmission() != null)
    {
      DossierAffectation copieDossierAffectationAdmission = (DossierAffectation)getDossierAffectationAdmission().copie();
      copieDemande.setDossierAffectationAdmission(copieDossierAffectationAdmission);
      
      copieDossierAffectationAdmission.setDemande(copieDemande);
    }
    if (getDossierAffectationReprise() != null)
    {
      DossierAffectation copieDossierAffectationReprise = (DossierAffectation)getDossierAffectationReprise().copie();
      copieDemande.setDossierAffectationReprise(copieDossierAffectationReprise);
      
      copieDossierAffectationReprise.setDemande(copieDemande);
    }
    if (getElementJustification() != null)
    {
      ElementJustification copieElementJustification = copieDemande.createElementJustification();
      getElementJustification().copieElements(copieElementJustification);
    }
    if (getDonneesDemandeAssociee() != null) {
      getDonneesDemandeAssociee().copieElements(copieDemande.createDonneesDemandeAssociee());
    }
  }
  
  private void copierDonneesReexamen(Demande copieDemande)
  {
    Iterator<?> iterMotifsReex = getListeMotifsReexamen().iterator();
    while (iterMotifsReex.hasNext()) {
      copieDemande.ajouterMotifReexamen((String)iterMotifsReex.next());
    }
    if (getMotifReexamenPrincipal() != null) {
      copieDemande.setMotifReexamenPrincipal(getMotifReexamenPrincipal());
    }
  }
  
  private void copierDonneesMigration(Demande copieDemande)
  {
    copieDemande.setMigree(getMigree());
    copieDemande.setEstNeutraliseeLiquidation(isEstNeutraliseeLiquidation());
    copieDemande.setEstNeutraliseeCalcul(isEstNeutraliseeCalcul());
    copieDemande.setEstDeneutralisable(estDeneutralisable());
    copieDemande.setEstLiquidable(estLiquidable());
    copieDemande.setComportmentDemandeMigree(getComportmentDemandeMigree());
  }
  
  protected void setForcageExecution(Collection forcageExecution)
  {
    super.remplacerCollectionUniteTraitementForcee(forcageExecution);
  }
  
  public Collection getForcageExecution()
  {
    return super.getCollectionUniteTraitementForcee();
  }
  
  public TraitementReliquat getTraitementReliquat()
  {
    if (traitementReliquat == null)
    {
      Reliquat reliquat = getReliquat();
      if (reliquat == null) {
        reliquat = createReliquat();
      }
      traitementReliquat = new TraitementReliquat(reliquat);
    }
    return traitementReliquat;
  }
  
  public void validerDecision()
  {
    if ((DecisionSpec)getDossierExamen() != null) {
      ((DecisionSpec)getDossierExamen()).setValidee(true);
    }
  }
  
  public ElementJustification getElementJustification()
  {
    if (super.getElementJustification() == null) {
      super.createElementJustification();
    }
    return super.getElementJustification();
  }
  
  public void setElementJustification(ElementJustification elementJustification)
  {
    DomManager.supprimer(super.getElementJustification(), elementJustification);
    ExceptionUtil.shouldNotPassHere("Appeler createElementJustification au lieu de faire new ElementJustification() puis setElementJustification()");
  }
  
  public int getMigree()
  {
    return super.getEstMigree();
  }
  
  public void setMigree(int demandeMigree)
  {
    super.setEstMigree(demandeMigree);
  }
  
  public boolean estNeutraliseeCalcul()
  {
    return super.isEstNeutraliseeCalcul();
  }
  
  public boolean estNeutraliseeLiquidation()
  {
    return super.isEstNeutraliseeLiquidation();
  }
  
  public boolean estDeneutralisable()
  {
    return super.isEstDeneutralisable();
  }
  
  public boolean estLiquidable()
  {
    return super.isEstLiquidable();
  }
  
  public void annulerDecisions()
  {
    if (OutilsActiviteConserve.estUneDemandeDeRevision(this))
    {
      setDossierAffectationAdmission(new DossierAAffecter(4));
      getDonneesTemporaires().setIdentifiantPeriodeActiviteConserveePerdue(null);
    }
    else
    {
      setDossierAffectationAdmission(new DossierAAffecter(1));
      setDossierAffectationReprise(null);
    }
    setDateEvenement(null);
    
    viderListeObjectifsExamen();
    supprimerDossiersAffectations();
    
    remplacerCollectionContexteDemande(new ArrayList());
    if (getDonneesDemandeAssociee() != null) {
      removeDonneesDemandeAssociee();
    }
  }
  
  public void setMotifReexamenPrincipal(String motifReexamenPrincipal)
  {
    super.setMotifReexamenPrincipal(motifReexamenPrincipal);
    if (motifReexamenPrincipal != null) {
      setDateEvenement(null);
    }
  }
  
  public Damj getDateFinAppletLiquidation()
  {
    Damj dateFinApplet = null;
    
    DossierExamenSpec dossierExamen = null;
    if (!getListeDossiersExamen().isEmpty()) {
      dossierExamen = (DossierExamenSpec)getListeDossiersExamen().get(0);
    }
    if (dossierExamen != null) {
      if ((dossierExamen instanceof AttributionSpec)) {
        dateFinApplet = ((AttributionSpec)dossierExamen).getPji();
      } else {
        dateFinApplet = getDateExamen();
      }
    }
    return dateFinApplet;
  }
  
  public boolean estEnContexteDroitAnterieurSecteurPublic()
  {
    DonneesTemporaires df = getDonneesTemporaires();
    return ((df.getCapitalReliquatSecteurPublic() != null) && (df.getDateFgDroitAnterieurSp() != null) && (df.getDateAttributionDroitAnterieurSp() != null) && ((df.getCapitalReliquatSecteurPublic().getValeurEntiere() == 0) || ((df.getSjrSP() != null) && (df.getTermePrcSp() != null) && (df.getCoefficientSaisonnierSp() != null) && (df.getCoefficientTempsPartielSp() != null) && (df.getDureeInitialeDroitAnterieurSp() > 0)))) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(this, "ANTSPAUTOM"));
  }
  
  public boolean estEnContexteDroitAnterieurSecteurPublicAvecFGDAreApresDateFGDDroitSP()
  {
    return (estEnContexteDroitAnterieurSecteurPublic()) && (existeFGDApresDateFGDDroitSP(getDonneesTemporaires().getDateFgDroitAnterieurSp()));
  }
  
  public boolean estEnContexteDroitAnterieurSecteurPublicValide()
  {
    boolean saisieCapitalReliquatNonNul = (getDonneesTemporaires().getCapitalReliquatSecteurPublic() != null) && (getDonneesTemporaires().getCapitalReliquatSecteurPublic().getValeur().compareTo(BigDecimal.ZERO) != 0);
    
    boolean saisieSjrSPNonNul = (getDonneesTemporaires().getSjrSP() != null) && (getDonneesTemporaires().getSjrSP().getValeur().compareTo(BigDecimal.ZERO) != 0);
    
    return ((estEnContexteDroitAnterieurSecteurPublic()) && (saisieCapitalReliquatNonNul) && (saisieSjrSPNonNul)) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(this, "ANTSPAUTOM"));
  }
  
  public boolean estClasseeEnCompetenceSecteurPublic()
  {
    return getClassementAdministratif() instanceof ClassementCompetenceSecteurPublic;
  }
  
  public boolean estCategorieParticuliere()
  {
    return (getDonneesDalEnrichies().getCategorieParticuliere() != 0) || (getDonneesDalEnrichies().estTopFinDeDroit());
  }
  
  public boolean estDroitOptionASS()
  {
    return droitOptionAss;
  }
  
  public boolean estDroitOptionReadmission()
  {
    return isDemandeExpresse();
  }
  
  public boolean estDroitOptionReprise()
  {
    return droitOptionReprise;
  }
  
  public void setDroitOptionASS(boolean droitOption)
  {
    droitOptionAss = droitOption;
  }
  
  public void setDroitOptionReadmission(boolean droitOption)
  {
    setDemandeExpresse(droitOption);
  }
  
  public void setDroitOptionReprise(boolean droitOption)
  {
    droitOptionReprise = droitOption;
  }
  
  public boolean estLiquideeAvecDroitOptionReprise()
  {
    return liquideeAvecDroitOptionReprise;
  }
  
  public void setLiquideeAvecDroitOptionReprise(boolean liquideeAvecDroitOptionReprise)
  {
    this.liquideeAvecDroitOptionReprise = liquideeAvecDroitOptionReprise;
  }
  
  public String getIdDecorDepuisPN()
  {
    return idDecorDepuisPN;
  }
  
  public void setIdDecorDepuisPN(String idDecor)
  {
    idDecorDepuisPN = idDecor;
  }
  
  public int getDecisionAutomatique()
  {
    return decisionAutomatique;
  }
  
  public void setDecisionAutomatique(int decisionAutomatique)
  {
    this.decisionAutomatique = decisionAutomatique;
  }
  
  public void setDemandeOrigine(DemandeAssuranceSpec demandeOrigine)
  {
    if (demandeOrigine != null)
    {
      DomManager.supprimer(super.getDemandeOrigine(), (Demande)demandeOrigine);
      super.setDemandeOrigine((Demande)demandeOrigine);
    }
  }
  
  public boolean estMaintenue()
  {
    return getAttribution().estMaintenue();
  }
  
  public DemandeMaintien getDemandeMaintien()
  {
    DemandeMaintien demandeMaintien = null;
    AttributionAssuranceSpec attribution = getAttribution();
    if (attribution != null) {
      demandeMaintien = RechercherDemandeMaintien.rechercherDemandeMaintien(getDemandeur(), attribution);
    }
    return demandeMaintien;
  }
  
  public boolean estExamenSuiteRejetDV()
  {
    return getEvenementReferenceExamen() instanceof ErePassageCPSuiteRejetDV;
  }
  
  public boolean contientDonneesForcees()
  {
    return false;
  }
  
  public Damj getDateAttribution()
  {
    Damj dateAttribution = null;
    if ((getDossierExamen() instanceof AttributionAssuranceSpec)) {
      dateAttribution = getDossierExamen().getDateAttribution();
    }
    return dateAttribution;
  }
  
  public void ajouterForcageExecution(UniteTraitementForcee ut)
  {
    super.ajouterUniteTraitementForcee(ut);
  }
  
  public String toString()
  {
    return OutilDomToString.toString(this);
  }
  
  private Damj recupererDateFaitGenerateurDroitArePrecedent()
  {
    Damj dateFaitGenerateur = null;
    
    AttributionAssuranceSpec attributionPrecedente = rechercherAttributionPrecedenteDuMemeType();
    if ((attributionPrecedente != null) && (attributionPrecedente.getFaitGenerateur() != null)) {
      dateFaitGenerateur = attributionPrecedente.getFaitGenerateur().getDateFaitGenerateur();
    }
    return dateFaitGenerateur;
  }
  
  public boolean existeFGDApresDateFGDDroitSP(Damj date)
  {
    AttributionAssuranceSpec attributionPrecedente = (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(getChronologieDemandesAssuranceSansCourante(), this, new FiltreAttributionStandardAssurance(false, true, false, false, null));
    if (attributionPrecedente != null)
    {
      Damj dateFaitGenerateur = attributionPrecedente.getDateFaitGenerateurDroit();
      if ((dateFaitGenerateur != null) && (dateFaitGenerateur.estApres(date))) {
        return true;
      }
    }
    return false;
  }
  
  public Chronologie getChronologiePNDS(Periode periodeReference)
    throws ApplicativeException
  {
    if (collectionPNDS == null) {
      collectionPNDS = new ArrayList();
    }
    if (periodePNDS == null) {
      periodePNDS = new Periode(Damj.NUIT_DES_TEMPS, Damj.FIN_DES_TEMPS);
    }
    Collection collectionPNDSCourante = OutilDeterminationPNDS.recherchePeriodePNDS(this, periodePNDS, periodeReference);
    if (collectionPNDSCourante != null) {
      collectionPNDS.addAll(collectionPNDSCourante);
    }
    ChronologiePeriodes chronologiePNDS = OutilDeterminationPNDS.filtreParPeriodePNDS(collectionPNDS, periodeReference);
    if (!presencePNDS) {
      presencePNDS = ((chronologiePNDS != null) && (!chronologiePNDS.estVide()));
    }
    return chronologiePNDS;
  }
  
  public void supprimerCachePNDS()
  {
    collectionPNDS = null;
    periodePNDS = null;
  }
  
  public boolean estUneDemandeV2()
  {
    return fr.unedic.cali.asu.outilsfonctionnels.OutilDemande.estUneDemandeV2(this);
  }
  
  public boolean estUneDemandeAps()
  {
    boolean estUneDemandeAps;
    boolean estUneDemandeAps;
    if ((getSaisieAntecedent() != null) && (getSaisieAntecedent().getCodeProduit() != null) && (getSaisieAntecedent().getCodeProduit().intValue() == 3)) {
      estUneDemandeAps = true;
    } else {
      estUneDemandeAps = fr.unedic.cali.asu.outilsfonctionnels.OutilDemande.estUneDemandeAps(this);
    }
    return estUneDemandeAps;
  }
  
  public boolean estUneDemandeAtAfd()
  {
    boolean estUneDemandeAtAfd;
    if ((getSaisieAntecedent() != null) && (getSaisieAntecedent().getCodeProduit() != null) && (getSaisieAntecedent().getCodeProduit().intValue() == 4)) {
      estUneDemandeAtAfd = true;
    } else {
      return fr.unedic.cali.asu.outilsfonctionnels.OutilDemande.estUneDemandeAtAfd(this);
    }
    boolean estUneDemandeAtAfd;
    return estUneDemandeAtAfd;
  }
  
  public boolean estUneDemandeAreEfe()
  {
    return fr.unedic.cali.asu.outilsfonctionnels.OutilDemande.estUneDemandeAreEfe(this);
  }
  
  public boolean estUneDemandeApsFdd()
  {
    return fr.unedic.cali.asu.outilsfonctionnels.OutilDemande.estUneDemandeApsFdd(this);
  }
  
  public boolean estUneDemandeApsIde()
  {
    return fr.unedic.cali.asu.outilsfonctionnels.OutilDemande.estUneDemandeApsIde(this);
  }
  
  public boolean estUneDemandeEfe()
  {
    return fr.unedic.cali.asu.outilsfonctionnels.OutilDemande.estUneDemandeEfe(this);
  }
  
  public boolean estUneDemandeAreFdd()
  {
    return fr.unedic.cali.asu.outilsfonctionnels.OutilDemande.estUneDemandeAreFdd(this);
  }
  
  public boolean estUneDemandeAre()
  {
    LigneSpec ligne = getAttribution().getProduit().getLigne();
    return fr.unedic.cali.asu.outilsfonctionnels.OutilDemande.estUneDemandeAre(ligne);
  }
  
  public boolean estUneDemandeAreIde()
  {
    return fr.unedic.cali.asu.outilsfonctionnels.OutilDemande.estUneDemandeAreIde(this);
  }
  
  public boolean estUneDemandeAreSpe()
  {
    LigneSpec ligne = getAttribution().getProduit().getLigne();
    return fr.unedic.cali.asu.outilsfonctionnels.OutilDemande.estUneDemandeAreSpe(ligne);
  }
  
  public boolean estUneDemandeExpresse()
  {
    return fr.unedic.cali.outilsfonctionnels.OutilDemande.estUneDemandeExpresse(this);
  }
  
  public boolean estUneDemandeSuiteCsr()
    throws ApplicativeException
  {
    if (estUnContexteDeChomageSansRuptureAsr == null) {
      estUnContexteDeChomageSansRuptureAsr = Boolean.valueOf(fr.unedic.cali.asu.outilsfonctionnels.OutilDemande.estUneDemandeSuiteCsr(this));
    }
    return estUnContexteDeChomageSansRuptureAsr.booleanValue();
  }
  
  public void setUneDemandeSuiteCsr(boolean estUnedemandeSuiteCsr)
  {
    estUnContexteDeChomageSansRuptureAsr = Boolean.valueOf(estUnedemandeSuiteCsr);
  }
  
  private boolean estUneDemandeCSPSurAERevisee()
    throws ApplicativeException
  {
    if (estUnContexteDeCSPSurAERevisee == null) {
      estUnContexteDeCSPSurAERevisee = Boolean.valueOf(fr.unedic.cali.asu.outilsfonctionnels.OutilDemande.estUneDemandeAspSurAERevision(this));
    }
    return estUnContexteDeCSPSurAERevisee.booleanValue();
  }
  
  public String getContexteAffiliationValide()
    throws ApplicativeException
  {
    String contexteCourant = null;
    if (estUneDemandeSuiteCsr()) {
      contexteCourant = "SUITECSR";
    } else if (estUneDemandeCSPSurAERevisee()) {
      contexteCourant = "CSPAEREV";
    }
    return contexteCourant;
  }
  
  public boolean estContexteAsrPrecSuiteCsr()
    throws ApplicativeException
  {
    if (estUnContexteDeChomageSansRupturefinAsr == null) {
      estUnContexteDeChomageSansRupturefinAsr = Boolean.valueOf(OutilAsr.estDemandeFinAsrContexteAsrPrecSuiteCsr(this));
    }
    return estUnContexteDeChomageSansRupturefinAsr.booleanValue();
  }
  
  public void setContexteAsrPrecSuiteCsr(boolean estContexteAsrSuiteCsr)
  {
    estUnContexteDeChomageSansRupturefinAsr = Boolean.valueOf(estContexteAsrSuiteCsr);
  }
  
  public void setContexteDeRepriseSansFCT(boolean estUnContexteDeRepriseSansFCT)
  {
    this.estUnContexteDeRepriseSansFCT = estUnContexteDeRepriseSansFCT;
  }
  
  public boolean estUnContexteDeRepriseSansFCT()
  {
    return estUnContexteDeRepriseSansFCT;
  }
  
  public boolean estUneDemandeAfdFdd()
  {
    return fr.unedic.cali.asu.outilsfonctionnels.OutilDemande.estUneDemandeAfdFdd(this);
  }
  
  public boolean estUneDemandeAsr()
  {
    return fr.unedic.cali.asu.outilsfonctionnels.OutilDemande.estUneDemandeAsr(this);
  }
  
  public boolean estUneDemandeFinDroitAsr()
  {
    return fr.unedic.cali.asu.outilsfonctionnels.OutilDemande.estUneDemandeFinDroitAsr(this);
  }
  
  public int getRevisionANotifier()
  {
    return revisionANotifier;
  }
  
  public void setRevisionANotifier(int revisionANotifier)
  {
    this.revisionANotifier = revisionANotifier;
  }
  
  public void setSaisieAntecedent(SaisieAntecedent saisieAntecedent)
  {
    DomManager.supprimer(super.getSaisieAntecedent(), saisieAntecedent);
    super.setSaisieAntecedent(saisieAntecedent);
  }
  
  public boolean estUneDemandeAtpBasculeCrp()
  {
    return fr.unedic.cali.outilsfonctionnels.OutilDemande.estUneDemandeBasculeAsrAtp(this);
  }
  
  public boolean estUneDemandeAtp()
  {
    return fr.unedic.cali.outilsfonctionnels.OutilDemande.estUneDemandeAtp(this);
  }
  
  public boolean estUneDemandeFinancement()
  {
    return fr.unedic.cali.asu.outilsfonctionnels.OutilDemande.estUneDemandeAssociee(this);
  }
  
  public boolean estUneDemandeFinDroitAtp()
  {
    return fr.unedic.cali.outilsfonctionnels.OutilDemande.estUneDemandeFinDroitAtp(this);
  }
  
  public boolean estUneDemandeAsp()
  {
    return fr.unedic.cali.outilsfonctionnels.OutilDemande.estUneDemandeAsp(this);
  }
  
  public boolean estUneDemandeFinDroitAsp()
  {
    return fr.unedic.cali.outilsfonctionnels.OutilDemande.estUneDemandeFinDroitAsp(this);
  }
  
  public boolean estUneDemandePrestation()
  {
    return !fr.unedic.cali.outilsfonctionnels.OutilDemande.estUneDemandeFinancement(this);
  }
  
  public boolean estUneDemandeAntecedentFinDroitSp()
  {
    return fr.unedic.cali.asu.outilsfonctionnels.OutilDemande.estUneDemandeAntecedentFinDroitSp(this);
  }
  
  public boolean estUneDemandeFinDroitCasGeneral()
  {
    return fr.unedic.cali.outilsfonctionnels.OutilDemande.estUneDemandeFinDroitCasGeneral(this);
  }
  
  public boolean estReexecutable()
  {
    boolean estAntecedent = (getSaisieAntecedent() != null) && (getSaisieAntecedent().getContexteDemande() != null) && ((5 == getSaisieAntecedent().getContexteDemande().intValue()) || (7 == getSaisieAntecedent().getContexteDemande().intValue()));
    
    boolean estNonAntecedentOuPoursuite = (getEvenementReferenceExamen() != null) && (!"ASU_22".equals(getEvenementReferenceExamen().getTypeExamen())) && ((!"ASU_23".equals(getEvenementReferenceExamen().getTypeExamen())) || (estAntecedent));
    
    return (super.estReexecutable()) && (estNonAntecedentOuPoursuite);
  }
  
  public boolean estDemandeSuiteFinDeDroit()
  {
    return (estUneDemandeApsFdd()) || (estUneDemandeAreFdd()) || (estUneDemandeAfdFdd()) || (estUneDemandeFinDroitCasGeneralOuCra());
  }
  
  protected boolean estUneDemandeFinDroitCasGeneralOuCra()
  {
    return (estUneDemandeFinDroitCasGeneral()) || (estUneDemandeFinDroitCRA());
  }
  
  protected boolean estUneDemandeFinDroitCRA()
  {
    return (estEreCraEtContexteEntreeCRA()) || (estContexteSortieCRASpectacle());
  }
  
  protected boolean estEreCraEtContexteEntreeCRA()
  {
    return ((getEvenementReferenceExamen() instanceof EreClauseRattrapageSpectacle)) && (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(this, "ENTREECRA"));
  }
  
  protected boolean estContexteSortieCRASpectacle()
  {
    boolean retour = false;
    if ((getAttribution() != null) && (getAttribution().getProduit() != null))
    {
      String ligne = getAttribution().getProduit().getLigne().getNomUnique();
      retour = (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(this, "SORTIECRA")) && ("ASU_SPE02".equals(ligne));
    }
    return retour;
  }
  
  public Chronologie getPeriodesAffiliation()
  {
    return periodesAffiliation;
  }
  
  public void setPeriodesAffiliation(Chronologie periodesAffiliation)
  {
    this.periodesAffiliation = periodesAffiliation;
  }
  
  public void setAttributionPrecedenteDuMemeType(AttributionAssuranceSpec attributionPrecedenteDuMemeType)
  {
    this.attributionPrecedenteDuMemeType = attributionPrecedenteDuMemeType;
  }
  
  public AttributionAssuranceSpec rechercherAttributionPrecedenteDuMemeType()
  {
    ContexteDemande contexteAreSousJacentRevision = (ContexteDemande)OutilGestionContexteDemande.trouverContexteDemande(getListContexteDemande(), "ARESJREV");
    ContexteDemande contexteAspSousJacent = (ContexteDemande)OutilGestionContexteDemande.trouverContexteDemande(getListContexteDemande(), "ASPSJACENT");
    if (contexteAreSousJacentRevision != null) {
      return null;
    }
    if ((contexteAspSousJacent != null) && (attributionPrecedenteDuMemeType == null))
    {
      EreDemandeAssociee ere = (EreDemandeAssociee)getEvenementReferenceExamen();
      attributionPrecedenteDuMemeType = ere.getDemandeMere().rechercherAttributionPrecedenteDuMemeType();
    }
    else if (attributionPrecedenteDuMemeType == null)
    {
      FiltreET filtreAttributionAssurance = getFiltreCsr(new FiltreAttributionStandardAssurance(true, true, false, true, this));
      attributionPrecedenteDuMemeType = ((AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(getChronologieDemandesAssuranceSansCourante(), this, filtreAttributionAssurance));
    }
    return attributionPrecedenteDuMemeType;
  }
  
  public void setOuvertureDroitPrecedenteDuMemeType(OdAssuranceSpec ouvertureDroitPrecedenteDuMemeType)
  {
    this.ouvertureDroitPrecedenteDuMemeType = ouvertureDroitPrecedenteDuMemeType;
  }
  
  public OdAssuranceSpec rechercherOuvertureDroitPrecedenteDuMemeType()
  {
    ContexteDemande contexteAreSousJacentRevision = (ContexteDemande)OutilGestionContexteDemande.trouverContexteDemande(getListContexteDemande(), "ARESJREV");
    ContexteDemande contexteAspSousJacent = (ContexteDemande)OutilGestionContexteDemande.trouverContexteDemande(getListContexteDemande(), "ASPSJACENT");
    if (contexteAreSousJacentRevision != null) {
      return null;
    }
    if ((contexteAspSousJacent != null) && (ouvertureDroitPrecedenteDuMemeType == null))
    {
      EreDemandeAssociee ere = (EreDemandeAssociee)getEvenementReferenceExamen();
      ouvertureDroitPrecedenteDuMemeType = ere.getDemandeMere().rechercherOuvertureDroitPrecedenteDuMemeType();
    }
    else if (ouvertureDroitPrecedenteDuMemeType == null)
    {
      FiltreET filtreOdAssurance = getFiltreCsr(new FiltreOuvertureDroitStandardAssurance(true, true, false, true, this));
      ouvertureDroitPrecedenteDuMemeType = ((OdAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(getChronologieDemandesAssuranceSansCourante(), this, filtreOdAssurance));
    }
    return ouvertureDroitPrecedenteDuMemeType;
  }
  
  public boolean estUneDemandeFinDroit()
  {
    return (estUneDemandeFinDroitAsr()) || (estUneDemandeFinDroitAtp()) || (estUneDemandeFinDroitAsp());
  }
  
  public List<AlerteAffiliation> getListeAlertesAffiliation()
  {
    return listeAlertesAffiliation;
  }
  
  public void setListeAlertesAffiliation(List<AlerteAffiliation> listeAlertesAffiliation)
  {
    this.listeAlertesAffiliation = listeAlertesAffiliation;
  }
  
  private void remplacerDossiersAffectations(int typeDossierAffectation, DossierAffectation dossierAffectation)
  {
    if (typeDossierAffectation == 2)
    {
      if (!estDossierAffectationRepriseSauvegarde)
      {
        dossierAffectationRepriseSauvegarde = super.getDossierAffectationReprise();
        estDossierAffectationRepriseSauvegarde = true;
      }
      super.setDossierAffectationReprise(dossierAffectation);
    }
    else
    {
      if (!estDossierAffectationAdmissionSauvegarde)
      {
        dossierAffectationAdmissionSauvegarde = super.getDossierAffectationAdmission();
        estDossierAffectationAdmissionSauvegarde = true;
      }
      super.setDossierAffectationAdmission(dossierAffectation);
    }
  }
  
  public void restaurerDossiersAffectations()
  {
    if (estDossierAffectationAdmissionSauvegarde)
    {
      super.setDossierAffectationAdmission(dossierAffectationAdmissionSauvegarde);
      estDossierAffectationAdmissionSauvegarde = false;
      dossierAffectationAdmissionSauvegarde = null;
    }
    if (estDossierAffectationRepriseSauvegarde)
    {
      super.setDossierAffectationReprise(dossierAffectationRepriseSauvegarde);
      estDossierAffectationRepriseSauvegarde = false;
      dossierAffectationRepriseSauvegarde = null;
    }
  }
  
  public void supprimerDossiersAffectations()
  {
    DomManager.supprimer(dossierAffectationAdmissionSauvegarde, super.getDossierAffectationAdmission());
    DomManager.supprimer(dossierAffectationRepriseSauvegarde, super.getDossierAffectationReprise());
    dossierAffectationAdmissionSauvegarde = null;
    dossierAffectationRepriseSauvegarde = null;
    besoinVerifierCoherenceDossierAffectation = true;
    estDossierAffectationAdmissionSauvegarde = false;
    estDossierAffectationRepriseSauvegarde = false;
    if ((getDonneesDemandeAssociee() != null) && (getDonneesDemandeAssociee().getDemandeAssociee() != null)) {
      getDonneesDemandeAssociee().getDemandeAssociee().supprimerDossiersAffectations();
    }
  }
  
  public void verifierCoherenceDossiersAffectations()
  {
    if ((dossierAffectationAdmissionSauvegarde != null) || (dossierAffectationRepriseSauvegarde != null)) {
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_PERSISTANCE_DOSSIER_AFFECTATION", "Il existe toujours un dossier d'affectation sauvegardé, on va générer un orphelin");
    }
  }
  
  public Damj getDateForceeFaitGenerateurOdPrecedente()
  {
    return dateForceeFaitGenerateurOdPrecedente;
  }
  
  public void setDateForceeFaitGenerateurOdPrecedente(Damj dateForceeFaitGenerateurOdPrecedente)
  {
    this.dateForceeFaitGenerateurOdPrecedente = dateForceeFaitGenerateurOdPrecedente;
  }
  
  public void clearCollectionContexteDemande()
  {
    for (Iterator<?> iter = getCollectionContexteDemande().iterator(); iter.hasNext();)
    {
      ContexteDemande element = (ContexteDemande)iter.next();
      DomManager.supprimer(element);
    }
    super.clearCollectionContexteDemande();
  }
  
  public void supprimerContexteDemande(ContexteDemande contextes)
  {
    DomManager.supprimer(contextes);
    super.supprimerContexteDemande(contextes);
  }
  
  public void remplacerCollectionContexteDemande(Collection collectionACopier)
  {
    for (Iterator<?> iter = getCollectionContexteDemande().iterator(); iter.hasNext();)
    {
      ContexteDemande element = (ContexteDemande)iter.next();
      DomManager.supprimer(element);
    }
    super.remplacerCollectionContexteDemande(collectionACopier);
  }
  
  public void setListeContexteDemande(Collection listeContexteDemande)
  {
    remplacerCollectionContexteDemande(listeContexteDemande);
  }
  
  public boolean estEnContexteDemande(String typeContexte)
  {
    return OutilGestionContexteDemande.estContexteDemandeAssurancePresent(this, typeContexte);
  }
  
  public boolean estEnContexteDemande(int regroupementContexte)
  {
    return OutilGestionContexteDemande.estContexteDemandeAssurancePresent(this, regroupementContexte);
  }
  
  public List<ContexteDemandeSpec> getListContexteDemande()
  {
    OutilGestionContexteDemande.reprendreStockContexteDemande(this);
    return super.getListContexteDemande();
  }
  
  public void desactiverTrancheExecutable()
  {
    commentaireSauvegarde = getCommentaire();
    setCommentaire("DESACTIVER_TRANCHE_EXEC");
  }
  
  public void reactiverTrancheExecutable()
  {
    setCommentaire(commentaireSauvegarde);
  }
  
  public boolean isPndsChargees()
  {
    return pndsChargees;
  }
  
  public void setPndsChargees(boolean pndsChargees)
  {
    this.pndsChargees = pndsChargees;
  }
  
  public String getRefusPropositionFNE()
  {
    boolean versionDeploiementOPIValide = (((FormulaireAsu)getFormulaire()).getDeploiementInstruction() != null) && (!"N".equalsIgnoreCase(getFormulaireAsu().getDeploiementInstruction())) && (!"1".equalsIgnoreCase(getFormulaireAsu().getDeploiementInstruction())) && (!"2".equalsIgnoreCase(getFormulaireAsu().getDeploiementInstruction()));
    String refusPropositionFNE;
    String refusPropositionFNE;
    if (versionDeploiementOPIValide) {
      refusPropositionFNE = getDonneesDalEnrichies().getRefusPropositionFNE();
    } else {
      refusPropositionFNE = ((FormulaireAsu)getFormulaire()).getRefusFNE();
    }
    return refusPropositionFNE;
  }
  
  public String getTopContribution()
  {
    boolean versionDeploiementOPIValide = (getFormulaireAsu().getDeploiementInstruction() != null) && (!"N".equalsIgnoreCase(getFormulaireAsu().getDeploiementInstruction())) && (!"1".equalsIgnoreCase(getFormulaireAsu().getDeploiementInstruction())) && (!"2".equalsIgnoreCase(getFormulaireAsu().getDeploiementInstruction()));
    String topContribution;
    String topContribution;
    if (versionDeploiementOPIValide) {
      topContribution = getTopPropositionCSP();
    } else {
      topContribution = ((FormulaireAsu)getFormulaire()).getPareCrpCtpPropose();
    }
    return topContribution;
  }
  
  protected void chargerTopPropositionNPDE()
  {
    DonneesNPDE donneesNPDECourant = getDonneesNPDE();
    if ((donneesNPDECourant != null) && (donneesNPDECourant.getListePeriodesEtPropositionCsp() != null))
    {
      fr.unedic.cali.autresdoms.d12i.dom.DonneesDAL donneesDal = (fr.unedic.cali.autresdoms.d12i.dom.DonneesDAL)getDonneesDalEnrichies();
      
      PeriodeAffiliationInstruction dernierePeriode = getDernierePeriodeDeclareeInstruction();
      if ((dernierePeriode != null) && ("O".equals(dernierePeriode.getTopPropositionCSP()))) {
        donneesDal.setTopPropositionCSP("O");
      }
      if (dernierePeriode != null) {
        donneesDal.setTopPropositionPAP(dernierePeriode.getTopPropositionPAP());
      }
    }
    estTopPropositionCharges = true;
  }
  
  protected String getTopPropositionCSP()
  {
    DonneesDALSpec donneesDal = getDonneesDalEnrichies();
    if (!estTopPropositionCharges) {
      chargerTopPropositionNPDE();
    }
    return donneesDal.getTopPropositionCSP();
  }
  
  public Boolean estTopPropositionPAP()
  {
    DonneesDALSpec donneesDal = getDonneesDalEnrichies();
    if (!estTopPropositionCharges) {
      chargerTopPropositionNPDE();
    }
    return donneesDal.estTopPropositionPAP();
  }
  
  private PeriodeAffiliationInstruction getDernierePeriodeDeclareeInstruction()
  {
    PeriodeAffiliationInstruction dernierePeriode = null;
    Damj dateExamen = getDateExamen();
    Damj dateFinMax = Damj.NUIT_DES_TEMPS;
    if (getDonneesNPDE() != null)
    {
      List<PeriodeAffiliationInstruction> listePeriodes = getDonneesNPDE().getListePeriodesEtPropositionCsp();
      for (PeriodeAffiliationInstruction periodeCourante : listePeriodes)
      {
        Damj finPeriode = periodeCourante.getDateFin();
        if ((dateExamen.estApres(finPeriode)) && (finPeriode.estApres(dateFinMax)))
        {
          dateFinMax = finPeriode;
          dernierePeriode = periodeCourante;
        }
      }
    }
    return dernierePeriode;
  }
  
  public boolean isEstNonExecutable()
  {
    setEstNonExecutable(false);
    
    String typeExamen = getEvenementReferenceExamen().getTypeExamen();
    
    boolean nonExecutable = false;
    if (("ASU_29".equals(typeExamen)) && (estValide()) && (getDatePremiereValidation() == null) && (getDateDerniereValidation() != null)) {
      nonExecutable = true;
    }
    return nonExecutable;
  }
  
  public void ajouterBlocageLiquidation(String codeErreur)
  {
    if (listeBlocageALever == null) {
      listeBlocageALever = new ArrayList();
    }
    listeBlocageALever.add(codeErreur);
  }
  
  public boolean contientBlocageLiquidation(String codeErreur)
  {
    boolean contientBlocage = false;
    if (listeBlocageALever != null) {
      contientBlocage = listeBlocageALever.contains(codeErreur);
    }
    return contientBlocage;
  }
  
  public void reinitialiserBlocageLiquidation()
  {
    listeBlocageALever = null;
  }
  
  public boolean isPresencePNDS()
  {
    return presencePNDS;
  }
  
  public boolean isEstInstallationNPDEsurTransaction()
  {
    return estInstallationNPDEsurTransaction;
  }
  
  public void setEstInstallationNPDEsurTransaction(boolean estInstallationNPDEsurTransaction)
  {
    this.estInstallationNPDEsurTransaction = estInstallationNPDEsurTransaction;
  }
  
  public boolean getModeSimulation()
  {
    return modeSimulation;
  }
  
  public void setModeSimulation(boolean modeSimulation)
  {
    this.modeSimulation = modeSimulation;
  }
  
  public String getDerniereStrategiePNDSUtilisee()
  {
    return derniereStrategiePNDSUtilisee;
  }
  
  public void setDerniereStrategiePNDSUtilisee(String derniereStrategiePNDSUtilisee)
  {
    this.derniereStrategiePNDSUtilisee = derniereStrategiePNDSUtilisee;
  }
  
  public void remplacerCollectionObjectifExamen(Collection collectionACopier)
  {
    for (Iterator<?> iter = super.getCollectionObjectifExamen().iterator(); iter.hasNext();)
    {
      ObjectifExamen element = (ObjectifExamen)iter.next();
      DomManager.supprimer(element);
    }
    super.remplacerCollectionObjectifExamen(collectionACopier);
  }
  
  public void remplacerCollectionMotifReexamen(Collection collectionACopier)
  {
    for (Iterator<?> iter = super.getCollectionMotifReexamen().iterator(); iter.hasNext();)
    {
      String element = (String)iter.next();
      DomManager.supprimer(element);
    }
    super.remplacerCollectionMotifReexamen(collectionACopier);
  }
  
  public void remplacerCollectionUniteTraitementForcee(Collection collectionACopier)
  {
    for (Iterator<?> iter = super.getCollectionUniteTraitementForcee().iterator(); iter.hasNext();)
    {
      UniteTraitementForcee element = (UniteTraitementForcee)iter.next();
      DomManager.supprimer(element);
    }
    super.remplacerCollectionUniteTraitementForcee(collectionACopier);
  }
  
  public void setEntretien(Entretien entretien)
  {
    DomManager.supprimer(super.getEntretien(), entretien);
    super.setEntretien(entretien);
  }
  
  public boolean isDemandeNPDE()
  {
    return "4".equalsIgnoreCase(((FormulaireAsu)getFormulaire()).getDeploiementInstruction());
  }
  
  public String getIdentifiantObjetMetier()
  {
    String idObjetMetier = super.getIdentifiantObjetMetier();
    if ((idObjetMetier == null) && (getDemandeur() != null))
    {
      idObjetMetier = getDemandeur().getNumeroAllocataire() + getFormulaireAsu().getReferenceExterne();
      setIdentifiantObjetMetier(idObjetMetier);
    }
    return idObjetMetier;
  }
  
  protected Damj determinerDateFinAbonnementSurAttribution(Damj dateExamen, Damj dateAttribution)
  {
    Damj dateFinAbonnement;
    Damj dateFinAbonnement;
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(this, "SORTIECRA")) {
      dateFinAbonnement = dateAttribution;
    } else {
      dateFinAbonnement = super.determinerDateFinAbonnementSurAttribution(dateExamen, dateAttribution);
    }
    return dateFinAbonnement;
  }
  
  public DonneesRessortissant getDonneesRessortissant()
  {
    return donneesRessortissant;
  }
  
  public void setDonneesRessortissant(DonneesRessortissant donneesRessortissant)
  {
    this.donneesRessortissant = donneesRessortissant;
  }
  
  public String getJustificationGenerique()
  {
    return justificationGenerique;
  }
  
  public void setJustificationGenerique(String justificationGenerique)
  {
    this.justificationGenerique = justificationGenerique;
  }
  
  public boolean isAffichageJustificationGenerique()
  {
    return affichageJustificationGenerique;
  }
  
  public void setAffichageJustificationGenerique(boolean affichageJustificationGenerique)
  {
    this.affichageJustificationGenerique = affichageJustificationGenerique;
  }
}

/* Location:
 * Qualified Name:     Demande
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */