package fr.unedic.cali.asu.dom;

import fr.unedic.cali.affectation.parametres.AccesDecorReglementaire;
import fr.unedic.cali.asu.dom.gen.DossierAffectationGen;
import fr.unedic.cali.asu.dom.spec.DossierAffectationAssuranceSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.ObjetPersistantSpec;
import fr.unedic.cali.dom.affectation.DecorReglementaire;
import fr.unedic.cali.dom.affectation.Parametres;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;

public abstract class DossierAffectation
  extends DossierAffectationGen
  implements DossierAffectationAssuranceSpec, ObjetPersistantSpec
{
  private static final long serialVersionUID = -6623709191744051466L;
  private transient DecorReglementaire decorReglementaire = null;
  private transient TravailSpec sinistre = null;
  private transient ProduitSpec produitSecours = null;
  private transient int typeRepriseContextuellePourSuivi = 0;
  private transient TravailSpec derniereFctEtudiee;
  
  protected DossierAffectation() {}
  
  public DossierAffectation(DomPCSpec p_pc)
  {
    super(p_pc);
  }
  
  protected DossierAffectation(int p_typeDossier)
  {
    super.setTypeDossier(p_typeDossier);
  }
  
  protected void copie(DossierAffectation p_source)
  {
    if (p_source == null) {
      return;
    }
    setDemande(p_source.getDemande());
    if (p_source.getValidationProduit() != null) {
      setValidationProduit((ValidationProduit)p_source.getValidationProduit().copie());
    }
    if (p_source.getSinistre() != null) {
      setSinistre((ActiviteSalarie)p_source.getSinistre().copie());
    }
    setIdentifiantSinistre(p_source.getIdentifiantSinistre());
    if (p_source.getDelaiRecherche() != null) {
      setDelaiRecherche((DelaiRechercheProduit)p_source.getDelaiRecherche().copie());
    }
    setDecorReglementaire(p_source.getDecorReglementaire());
    setProduitSecours(p_source.getProduitSecours());
    setJustificationAffectation(p_source.getJustificationAffectation());
    setTypeDossier(p_source.getTypeDossier());
    setTypeRepriseContextuellePourSuivi(p_source.getTypeRepriseContextuellePourSuivi());
    
    setDerniereFctEtudiee(p_source.getDerniereFctEtudiee());
  }
  
  public abstract DossierExamenSpec getDossierExamen();
  
  public void setDossierExamen(DossierExamenSpec p_dossierExamen)
  {
    throw new UnsupportedOperationException("Méthode non implémentée");
  }
  
  public void setDemande(DemandeSpec p_demande)
  {
    super.setDemande(p_demande);
    switch (super.getTypeDossier())
    {
    case 1: 
    case 4: 
      if ((getDemande() != null) && (((Demande)getDemande()).getDossierAffectationAdmission() != this)) {
        ((Demande)getDemande()).setDossierAffectationAdmission(this);
      }
      break;
    case 2: 
      if ((getDemande() != null) && (((Demande)getDemande()).getDossierAffectationReprise() != this)) {
        ((Demande)getDemande()).setDossierAffectationReprise(this);
      }
      break;
    case 3: 
    default: 
      throw new UnsupportedOperationException("Objectif de type " + super.getTypeDossier() + " non prévu");
    }
  }
  
  public abstract ProduitSpec getProduit();
  
  public Reglement getReglementPeriodeValidationProduit()
  {
    Reglement reglementTrouve = null;
    if ((getValidationProduit() != null) && (getValidationProduit().isEstProduitValide())) {
      reglementTrouve = getValidationProduit().getReglementApplicable();
    }
    return reglementTrouve;
  }
  
  public DecorReglementaire getDecorReglementaire()
  {
    if (decorReglementaire == null) {
      decorReglementaire = AccesDecorReglementaire.getInstance().getDecorParId(getIdDecorReglementaire());
    }
    return decorReglementaire;
  }
  
  public TravailSpec getSinistre()
  {
    if ((sinistre == null) && (super.getIdentifiantSinistre() != null) && (!super.getIdentifiantSinistre().equals(""))) {
      sinistre = ((TravailSpec)getDemande().getDemandeur().rechercherPeriodePasseProfessionnel(super.getIdentifiantSinistre()));
    }
    return sinistre;
  }
  
  public void setDecorReglementaire(DecorReglementaire p_decorReglementaire)
  {
    decorReglementaire = p_decorReglementaire;
    if (p_decorReglementaire != null) {
      setIdDecorReglementaire(p_decorReglementaire.getIdDecor());
    }
  }
  
  public void setDelaiRecherche(DelaiRechercheProduit p_delaiRecherche)
  {
    DomManager.supprimer(super.getDelaiRecherche(), p_delaiRecherche);
    super.setDelaiRecherche(p_delaiRecherche);
  }
  
  public void setSinistre(TravailSpec p_sinistre)
  {
    sinistre = p_sinistre;
    if (p_sinistre != null) {
      setIdentifiantSinistre(p_sinistre.getIdentifiant());
    } else {
      setIdentifiantSinistre(null);
    }
  }
  
  public void setValidationProduit(ValidationProduit p_validationProduit)
  {
    DomManager.supprimer(super.getValidationProduit(), p_validationProduit);
    super.setValidationProduit(p_validationProduit);
  }
  
  public ProduitSpec getProduitSecours()
  {
    if ((produitSecours == null) && (super.getCodeProduitSecours() != 0)) {
      produitSecours = Parametres.getProduit(super.getCodeProduitSecours());
    }
    return produitSecours;
  }
  
  public void setProduitSecours(ProduitSpec p_produitSecours)
  {
    produitSecours = p_produitSecours;
    if (p_produitSecours != null) {
      super.setCodeProduitSecours(p_produitSecours.getCode());
    }
  }
  
  public void jdoPostLoad() {}
  
  public void jdoPreClear() {}
  
  public void jdoPreDelete()
  {
    DomManager.supprimer(super.getValidationProduit());
    DomManager.supprimer(super.getDelaiRecherche());
  }
  
  public void jdoPreStore() {}
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    DossierAffectation copie = (DossierAffectation)p_copie;
    if (getValidationProduit() != null) {
      copie.setValidationProduit((ValidationProduit)getValidationProduit().copie());
    }
    if (getDelaiRecherche() != null) {
      copie.setDelaiRecherche((DelaiRechercheProduit)getDelaiRecherche().copie());
    }
    copie.setDecorReglementaire(getDecorReglementaire());
    copie.setProduitSecours(getProduitSecours());
    copie.setIdentifiantSinistre(getIdentifiantSinistre());
    copie.setJustificationAffectation(getJustificationAffectation());
    copie.setTypeDossier(getTypeDossier());
    
    copie.setDerniereFctEtudiee(getDerniereFctEtudiee());
    copie.setCodeProduitExecutable(getCodeProduitExecutable());
  }
  
  public int getTypeRepriseContextuellePourSuivi()
  {
    return typeRepriseContextuellePourSuivi;
  }
  
  public void setTypeRepriseContextuellePourSuivi(int p_typeRepriseContextuelle)
  {
    typeRepriseContextuellePourSuivi = p_typeRepriseContextuelle;
  }
  
  public TravailSpec getDerniereFctEtudiee()
  {
    return derniereFctEtudiee;
  }
  
  public void setDerniereFctEtudiee(TravailSpec p_derniereFctEtudiee)
  {
    derniereFctEtudiee = p_derniereFctEtudiee;
  }
  
  public void marquerGraphePersistant()
  {
    DomManager.persisterEnProfondeur(super.getDelaiRecherche());
    DomManager.persisterEnProfondeur(super.getValidationProduit());
  }
}

/* Location:
 * Qualified Name:     DossierAffectation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */