package fr.unedic.cali.asu.dom;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.outilsfonctionnels.DetectionContexteParticulierLiquidation;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.parcours.AffectationDemandeAsp;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.parcours.ParcoursAffectationDemandeAssurance;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnChargeSansFiltre;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.ObjetAlertesNonBloquantes;
import fr.unedic.cali.dom.OdAssuranceSpec;
import fr.unedic.cali.dom.affectation.ContexteDemandeSpec;
import fr.unedic.cali.dom.affectation.LigneAsuCge01;
import fr.unedic.cali.dom.affectation.LigneAsuCva10;
import fr.unedic.cali.dom.affectation.LigneSpec;
import fr.unedic.cali.dom.affectation.ProduitAbstrait;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.outilsfonctionnels.OutilAsp;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.outilsfonctionnels.RechercherDernierSinistre;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalariePourMotifFin;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreFinAvantDate;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreOu;
import fr.unedic.cali.parametres.GestionnaireDateApplication;
import fr.unedic.cali.utilitaire.filtres.FiltreCaliSpec;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDecisionPourProduit;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreOU;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreDecisionARESurDecision;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ComparateurTemporelsSurDateFin;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltresTemporel;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Hashtable;

public class EreAspSuiteIDE
  extends EreGammeAsu
{
  private static final long serialVersionUID = 6021882448185185010L;
  
  public String getLibelle()
  {
    return "IDE";
  }
  
  public String getLibelleLong()
  {
    return "Adhésion CSP";
  }
  
  public String getTypeExamen()
  {
    return "ASU_24";
  }
  
  public String getTypeSegment()
  {
    return "LE1D";
  }
  
  public int getPriorite()
  {
    return 14;
  }
  
  public ObjetMetierSpec copie()
  {
    EreAspSuiteIDE copie = new EreAspSuiteIDE();
    copieElements(copie);
    return copie;
  }
  
  public Damj getDateDeclenchementExamen(DemandeSpec demande)
  {
    Damj dateIde = null;
    if ((getDateEvenement() != null) && ((demande.estDecisionnee()) || (demande.estDemandeLiquidee())) && (!demande.estEnReExamen()))
    {
      setDateDeclenchementExamen(getDateEvenement());
    }
    else
    {
      ObjetChronoPeriodePriseEnChargeSansFiltre periodePEC = OutillagePEC.getPeriodePEC(demande.getDemandeur(), demande.getFormulaire().getIdPec());
      if (periodePEC != null) {
        dateIde = periodePEC.getDateDebut();
      }
      if (dateIde != null) {
        setDateDeclenchementExamen(dateIde);
      } else if (demande.getDateDepot() != null) {
        setDateDeclenchementExamen(demande.getDateDepot());
      } else {
        setDateDeclenchementExamen(demande.getFormulaire().getDateCreationDal());
      }
    }
    return getDateDeclenchementExamen();
  }
  
  public Damj getDateExamen(DemandeSpec demande)
  {
    Damj dernierAu = null;
    Damj dateIde = null;
    if (getDateEvenement() == null)
    {
      try
      {
        TravailSpec fct = RechercherDernierSinistre.rechercherDernierSinistre(demande.getDateDeclenchementExamen().veille(), demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation());
        if (fct != null) {
          dernierAu = fct.getDateFin();
        }
      }
      catch (CoucheLogiqueException ex)
      {
        dernierAu = null;
      }
      ObjetChronoPeriodePriseEnChargeSansFiltre periodePEC = OutillagePEC.getPeriodePEC(demande.getDemandeur(), demande.getFormulaire().getIdPec());
      if (periodePEC != null) {
        dateIde = periodePEC.getDateDebut();
      }
      Damj dateExamen;
      Damj dateExamen;
      if (dateIde != null) {
        dateExamen = dateIde;
      } else {
        dateExamen = demande.getDateDepot();
      }
      if (dernierAu != null) {
        dateExamen = Damj.max(dernierAu.lendemain(), dateExamen);
      }
      setDateEvenement(dateExamen);
    }
    return getDateEvenement();
  }
  
  public void verifierContexte(DemandeSpec demande)
    throws CoucheLogiqueException
  {
    Demande demandeAsu = (Demande)demande;
    
    int idPec = demande.getFormulaire().getIdPec();
    
    ObjetChronoPeriodePriseEnChargeSansFiltre periodePEC = OutillagePEC.getPeriodePEC(demandeAsu.getDemandeur(), idPec);
    if (periodePEC == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_CALI_L_CONTEXTE_PEC_INTROUVABLE", new Object[] { Integer.toString(idPec) }, 1);
    }
  }
  
  public FiltreCaliSpec getFiltreRechercheDecisionDuMemeType()
  {
    FiltreOU filtreAttributionAsp = new FiltreOU();
    filtreAttributionAsp.ajouterFiltre(new FiltreDecisionARESurDecision());
    filtreAttributionAsp.ajouterFiltre(new FiltreDecisionPourProduit(50));
    filtreAttributionAsp.ajouterFiltre(new FiltreDecisionPourProduit(51));
    return filtreAttributionAsp;
  }
  
  public ParcoursAffectationDemandeAssurance determinerParcoursAffectationDemandeAssurance(DemandeSpec demande)
  {
    return new AffectationDemandeAsp();
  }
  
  public void determinerContexteDemande(DemandeSpec demande)
    throws CoucheLogiqueException
  {
    ContexteDemande contexte = new ContexteDemande();
    ((Demande)demande).ajouterContexteDemande(contexte);
    contexte.setTypeContexteDemande(trouverContexteAspPap((Demande)demande, contexte));
    ProduitAsuSpec produitActif = (ProduitAsuSpec)LigneAsuCge01.getInstance().getProduitActif(demande.getDateRecherche());
    contexte.setSousTypeContexteDemande(String.valueOf(produitActif.getCode()));
    
    AttributionAssuranceSpec attributionAssurancePrecedente = (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande, new FiltreAttributionStandardAssurance(true, true, false, true, demande));
    if (attributionAssurancePrecedente != null)
    {
      Demande demandePrecedente = (Demande)attributionAssurancePrecedente.getDemandeAssurance();
      if (demandePrecedente.estUneDemandeAsp())
      {
        ContexteDemandeSpec contexteDemandePrecedente = OutilGestionContexteDemande.trouverUnContexteDemandeAssurancePresent(demandePrecedente, 1);
        
        contexte.setSousTypeContexteDemande(contexteDemandePrecedente.getSousTypeContexteDemande());
      }
    }
  }
  
  private String trouverContexteAspPap(Demande demande, ContexteDemande contexteDemande)
  {
    FiltresTemporel filtresAeEligiles = new FiltresTemporel();
    FiltreOu filtreAeCspOuPap = new FiltreOu();
    filtreAeCspOuPap.ajouterFiltre(new FiltreActiviteSalariePourMotifFin(45));
    filtreAeCspOuPap.ajouterFiltre(new FiltreActiviteSalariePourMotifFin(44));
    filtreAeCspOuPap.ajouterFiltre(new FiltreActiviteSalariePourMotifFin(48));
    filtreAeCspOuPap.ajouterFiltre(new FiltreActiviteSalariePourMotifFin(49));
    
    filtresAeEligiles.ajouterFiltre(filtreAeCspOuPap);
    filtresAeEligiles.ajouterFiltre(new FiltreFinAvantDate(getDateExamen(demande)));
    
    ActiviteSalarie derniereActiviteCspAdhesionVolontaire = null;
    Chronologie chronologiePeriodePasseProfessionnelLiquidation = demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation();
    if ((chronologiePeriodePasseProfessionnelLiquidation != null) && (!chronologiePeriodePasseProfessionnelLiquidation.estVide()))
    {
      Chronologie periodesCspVolontaire = chronologiePeriodePasseProfessionnelLiquidation.copier(filtresAeEligiles);
      if ((periodesCspVolontaire != null) && (!periodesCspVolontaire.estVide()))
      {
        periodesCspVolontaire.setComparateur(new ComparateurTemporelsSurDateFin());
        
        derniereActiviteCspAdhesionVolontaire = (ActiviteSalarie)periodesCspVolontaire.premierElement();
      }
    }
    String typeContexteDemande = "IDEASP";
    
    boolean estDerniereActiviteCspOuPapEnAdhesionVolontaire = (derniereActiviteCspAdhesionVolontaire != null) && ((45 == Integer.parseInt(derniereActiviteCspAdhesionVolontaire.getMotifFin())) || (49 == Integer.parseInt(derniereActiviteCspAdhesionVolontaire.getMotifFin())));
    if (estDerniereActiviteCspOuPapEnAdhesionVolontaire)
    {
      AttributionAssuranceSpec attributionAssurancePrecedente = DetectionContexteParticulierLiquidation.getInstance().trouverOdArePrecedente(demande);
      if (attributionAssurancePrecedente != null)
      {
        FaitGenerateurSpec faitGenerateurOdPrecedente = attributionAssurancePrecedente.getFaitGenerateur();
        if (faitGenerateurOdPrecedente.getIdentifiantPeriodeFaitGenerateur().equals(derniereActiviteCspAdhesionVolontaire.getIdentifiant()))
        {
          typeContexteDemande = "ADHVOLARE";
          contexteDemande.setDerniereAeCspVolontaire(derniereActiviteCspAdhesionVolontaire);
          contexteDemande.setTypeContexteDemande("ADHVOLARE");
          contexteDemande.setAttributionAreAdhesionVolontaire(attributionAssurancePrecedente);
          contexteDemande.setDerniereAeCspVolontaire(derniereActiviteCspAdhesionVolontaire);
        }
        else if (derniereActiviteCspAdhesionVolontaire.getDateFin().estApres(faitGenerateurOdPrecedente.getDateFaitGenerateur()))
        {
          typeContexteDemande = "ASPVOLSARE";
          contexteDemande.setDerniereAeCspVolontaire(derniereActiviteCspAdhesionVolontaire);
          contexteDemande.setTypeContexteDemande("ASPVOLSARE");
          contexteDemande.setDerniereAeCspVolontaire(derniereActiviteCspAdhesionVolontaire);
        }
      }
    }
    return typeContexteDemande;
  }
  
  public void determinerContextesLiquidation(Contexte contexte)
    throws ApplicativeException
  {
    DomLiquidationAssurance donnees = (DomLiquidationAssurance)contexte.getDonnees();
    Demande demande = donnees.getDemande();
    if ((donnees.getProduitPrecedent() == null) || (!LigneAsuCva10.getInstance().getNomUnique().equals(donnees.getProduitPrecedent().getLigne().getNomUnique())))
    {
      detecterTousContextesCspPapPapParlementaire(demande);
    }
    else
    {
      AttributionAssuranceSpec attributionPrecedente = donnees.getAttributionPrecedente();
      if (attributionPrecedente != null)
      {
        DemandeAssuranceSpec demandePrecedentePivot = (DemandeAssuranceSpec)attributionPrecedente.getOuvertureDroit().getDemande();
        
        Demande demandeFddAspPrecedente = (Demande)rechercherDemandeFinAspSuivantDemandeAsp(demandePrecedentePivot);
        if ((demandeFddAspPrecedente != null) && (demandeFddAspPrecedente.getDateExamen() != null) && (demandeFddAspPrecedente.getDateExamen().estAvant(demande.getDateExamen()))) {
          detecterTousContextesCspPapPapParlementaire(demande);
        }
      }
    }
  }
  
  protected DemandeSpec rechercherDemandeFinAspSuivantDemandeAsp(DemandeAssuranceSpec demandePrecedentePivot)
  {
    return OutilAsp.rechercherDemandeFinAspSuivantDemandeAsp(demandePrecedentePivot);
  }
  
  protected void detecterTousContextesCspPapPapParlementaire(Demande demande)
    throws ApplicativeException
  {
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteAreEnEntreeCSPouPAP(demande);
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteAreEnCoursCSPouPAP(demande);
    
    verifierPresenceContexteLiquidation(demande);
    detecterContextePapParlementaire(demande);
  }
  
  private void verifierPresenceContexteLiquidation(Demande pDemande)
    throws ApplicativeException
  {
    ProduitSpec produitAffecte = pDemande.getDossierAffectation().getProduit();
    if ((ProduitAbstrait.estDuType(5, produitAffecte)) && (!OutilGestionContexteDemande.estContexteDemandeAssurancePresent(pDemande, "AREENTRCSP")) && (!OutilGestionContexteDemande.estContexteDemandeAssurancePresent(pDemande, "ARECOURCSP"))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_CONTEXTE_ASP_INVALIDE");
    }
  }
  
  protected void detecterContextePapParlementaire(Demande demande)
    throws ApplicativeException
  {
    if ((demande.estEnContexteDemande("AREENTRCSP")) && (demande.estEnContexteDemande(10)))
    {
      ActiviteSalarie dernierSinistre = (ActiviteSalarie)demande.getDossierAffectationAdmission().getSinistre();
      if ((dernierSinistre != null) && (dernierSinistre.getDateEngagementProcedureLicenciement() != null))
      {
        Damj dateArretPap = recupererGestionnaireDateApplication().recupererDateApplication("Arret du PAP");
        Damj dateDebutPapParlementaire = recupererGestionnaireDateApplication().recupererDateApplication("Debut du PAP Parlementaire");
        if (dernierSinistre.getDateEngagementProcedureLicenciement().estApresOuCoincideAvec(dateDebutPapParlementaire))
        {
          ContexteDemande contexteDemande = new ContexteDemande();
          contexteDemande.setTypeContexteDemande("PAPPARLEM");
          demande.ajouterContexteDemande(contexteDemande);
          ajouterAlerteNonBloquantePapParlementaire(demande);
        }
        else if (dernierSinistre.getDateEngagementProcedureLicenciement().estApresOuCoincideAvec(dateArretPap))
        {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PAP_ARRET_PAP", new Object[] { dateArretPap });
        }
      }
    }
  }
  
  protected GestionnaireDateApplication recupererGestionnaireDateApplication()
    throws CoucheLogiqueException
  {
    return GestionnaireDateApplication.getInstance();
  }
  
  protected void ajouterAlerteNonBloquantePapParlementaire(Demande demande)
  {
    Collection<ObjetAlertesNonBloquantes> listePeriodes = new ArrayList();
    
    ObjetAlertesNonBloquantes objetAlerteNonBloquante = new ObjetAlertesNonBloquantes(Damj.NUIT_DES_TEMPS, Damj.FIN_DES_TEMPS, 999);
    
    listePeriodes.add(objetAlerteNonBloquante);
    demande.getAlertesNonBloquantes().put("ANB_DETECTION_PAP_PARLEMENTAIRE", listePeriodes);
  }
}

/* Location:
 * Qualified Name:     EreAspSuiteIDE
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */