package fr.unedic.cali.asu.dom;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsChomageSansRCT;
import fr.unedic.cali.asu.parcours.AffectationDemandeASUClassique;
import fr.unedic.cali.asu.parcours.AffectationDemandeAsuCsr;
import fr.unedic.cali.asu.parcours.ParcoursAffectationDemandeAssurance;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.outilsfonctionnels.GestionnaireErreur;
import fr.unedic.cali.utilitaire.filtres.FiltreCaliSpec;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreOuvertureDroitStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreFinDroitAssurancePourAttributionAssurance;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreReexamenSurDemande;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreDecisionARESurDecision;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;

public class EreFinDroitSuiteRepriseNonSaisonniere
  extends EreGammeAsu
{
  private static final long serialVersionUID = -2600278076357713696L;
  
  public String getLibelle()
  {
    return "LFD_ASU";
  }
  
  public String getLibelleLong()
  {
    return "demande de fin de droit suite reprise non saisonnière";
  }
  
  public String getTypeExamen()
  {
    return "ASU_03";
  }
  
  public int getPriorite()
  {
    return 9;
  }
  
  public ObjetMetierSpec copie()
  {
    EreFinDroitSuiteRepriseNonSaisonniere copie = new EreFinDroitSuiteRepriseNonSaisonniere();
    copieElements(copie);
    return copie;
  }
  
  public Damj getDateDeclenchementExamen(DemandeSpec demande)
  {
    if ((getDateEvenement() != null) && ((demande.estDecisionnee()) || (demande.estDemandeLiquidee())) && (!demande.estEnReExamen())) {
      setDateDeclenchementExamen(getDateEvenement());
    } else if (demande.getFormulaire().getDateDepot() != null) {
      setDateDeclenchementExamen(demande.getFormulaire().getDateDepot());
    } else {
      setDateDeclenchementExamen(demande.getFormulaire().getDateCreationDal());
    }
    return getDateDeclenchementExamen();
  }
  
  public Damj getDateExamen(DemandeSpec demande)
  {
    if (getDateEvenement() == null)
    {
      Damj dateDeclenchementExamen = demande.getDateDeclenchementExamen();
      
      OdAssuranceSpec ouvertureDeDroitPrecedente = (OdAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), dateDeclenchementExamen.lendemain(), new FiltreOuvertureDroitStandardAssurance(false, true, true, false, demande));
      
      FiltreET filtre = new FiltreET();
      filtre.ajouterFiltre(new FiltreFinDroitAssurancePourAttributionAssurance(ouvertureDeDroitPrecedente));
      filtre.ajouterFiltre(new FiltreNegation(new FiltreReexamenSurDemande()));
      AttributionSpec dernierDroitAsu = (AttributionSpec)OutilRecherche.rechercherDecisionSuivante(demande.getChronologieDemandesAssuranceSansCourante(), ouvertureDeDroitPrecedente, filtre);
      try
      {
        Damj djiParEpuisement = ((ProduitAsuSpec)dernierDroitAsu.getDossierAffecte().getProduit()).recupererDJIParEpuisement(demande, dernierDroitAsu, true);
        if (djiParEpuisement != null) {
          setDateEvenement(djiParEpuisement.lendemain());
        } else {
          setDateEvenement(null);
        }
      }
      catch (ApplicativeException ex)
      {
        setDateEvenement(null);
      }
    }
    return getDateEvenement();
  }
  
  public void verifierContexte(DemandeSpec demande)
    throws ApplicativeException
  {
    boolean contexteValide = false;
    
    AttributionAssuranceSpec derniereAttributionAsu = ((DemandeAssuranceSpec)demande).rechercherAttributionPrecedenteDuMemeType();
    if (derniereAttributionAsu != null)
    {
      int typeObjectif = ((DemandeAssuranceSpec)derniereAttributionAsu.getDossierAffecte().getDemande()).getObjectifDecisionne().getType();
      int sousTypeObjectif = ((DemandeAssuranceSpec)derniereAttributionAsu.getDossierAffecte().getDemande()).getObjectifDecisionne().getSousType();
      if ((typeObjectif == 2) && (sousTypeObjectif == 14))
      {
        boolean estNonDroitSaisonnier = !derniereAttributionAsu.estDroitSaisonnier();
        if (estNonDroitSaisonnier) {
          contexteValide = true;
        }
      }
      if (derniereAttributionAsu.getDemande().estMigree())
      {
        boolean estRepriseDroitCommun = (typeObjectif == 2) && (sousTypeObjectif == 13);
        if (estRepriseDroitCommun)
        {
          boolean estNonDroitSaisonnier = !derniereAttributionAsu.estDroitSaisonnier();
          if (estNonDroitSaisonnier) {
            contexteValide = true;
          }
        }
      }
    }
    if (!contexteValide) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_CONTEXTE_LIQUIDATION_IMPOSSIBLE");
    }
  }
  
  public void verifierPostContexte(DemandeSpec demande)
    throws CoucheLogiqueException
  {
    boolean contexteValide = false;
    
    int typeObjectif = ((DemandeAssuranceSpec)demande).getObjectifDecisionne().getType();
    int sousTypeObjectif = ((DemandeAssuranceSpec)demande).getObjectifDecisionne().getSousType();
    if (typeObjectif == 1) {
      switch (sousTypeObjectif)
      {
      case 11: 
      case 12: 
      case 26: 
        if ((!(((DemandeAssuranceSpec)demande).getDossierExamen() instanceof AttributionAssuranceSpec)) || (((DossierExamenAssuranceSpec)((DemandeAssuranceSpec)demande).getDossierExamen()).estDroitSaisonnier())) {
          contexteValide = true;
        }
        break;
      }
    }
    if (!contexteValide) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_CONTEXTE_LIQUIDATION_IMPOSSIBLE");
    }
  }
  
  public FiltreCaliSpec getFiltreRechercheDecisionDuMemeType()
  {
    return new FiltreDecisionARESurDecision();
  }
  
  public ParcoursAffectationDemandeAssurance determinerParcoursAffectationDemandeAssurance(DemandeSpec demande)
  {
    if (OutilsChomageSansRCT.estDemandeEnContexteDeChomageEnCoursDeSuspension(demande)) {
      return new AffectationDemandeAsuCsr();
    }
    return new AffectationDemandeASUClassique();
  }
  
  public void determinerContexteDemande(DemandeSpec demande)
    throws CoucheLogiqueException
  {}
  
  public void determinerContextesLiquidation(Contexte contexte)
    throws ApplicativeException
  {}
}

/* Location:
 * Qualified Name:     EreFinDroitSuiteRepriseNonSaisonniere
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */