package fr.unedic.cali.asu.dom;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.outilsfonctionnels.DetectionContexteParticulierLiquidation;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsChomageSansRCT;
import fr.unedic.cali.asu.parcours.AffectationDemandeASUClassique;
import fr.unedic.cali.asu.parcours.AffectationDemandeAsuCsr;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.parcours.ParcoursAffectationDemandeAssurance;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnChargeSansFiltre;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.OdSpec;
import fr.unedic.cali.dom.affectation.LigneAsuSpe02;
import fr.unedic.cali.dom.affectation.LigneSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.utilitaire.filtres.FiltreCaliSpec;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreDecisionARESurDecision;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;

public class EreInscriptionDemandeurEmploi
  extends EreGammeAsu
{
  private static final long serialVersionUID = 6021882448185185010L;
  
  public String getLibelle()
  {
    return "IDE";
  }
  
  public String getLibelleLong()
  {
    return "demande d'Inscription Demandeur Emploi";
  }
  
  public String getTypeExamen()
  {
    return "ASU_01";
  }
  
  public int getPriorite()
  {
    return 12;
  }
  
  public ObjetMetierSpec copie()
  {
    EreInscriptionDemandeurEmploi copie = new EreInscriptionDemandeurEmploi();
    copieElements(copie);
    return copie;
  }
  
  public Damj getDateDeclenchementExamen(DemandeSpec demande)
  {
    Damj dateIde = null;
    if ((getDateEvenement() != null) && ((demande.estDecisionnee()) || (demande.estDemandeLiquidee())) && (!demande.estEnReExamen()))
    {
      setDateDeclenchementExamen(getDateEvenement());
    }
    else
    {
      ObjetChronoPeriodePriseEnChargeSansFiltre periodePEC = OutillagePEC.getPeriodePEC(demande.getDemandeur(), demande.getFormulaire().getIdPec());
      if (periodePEC != null) {
        dateIde = periodePEC.getDateDebut();
      }
      if (dateIde != null) {
        setDateDeclenchementExamen(dateIde);
      } else if (demande.getDateDepot() != null) {
        setDateDeclenchementExamen(demande.getDateDepot());
      } else {
        setDateDeclenchementExamen(demande.getFormulaire().getDateCreationDal());
      }
    }
    return getDateDeclenchementExamen();
  }
  
  public Damj getDateExamen(DemandeSpec demande)
  {
    Damj dateIde = null;
    if (getDateEvenement() == null)
    {
      ObjetChronoPeriodePriseEnChargeSansFiltre periodePEC = OutillagePEC.getPeriodePEC(demande.getDemandeur(), demande.getFormulaire().getIdPec());
      if (periodePEC != null) {
        dateIde = periodePEC.getDateDebut();
      }
      if (dateIde != null) {
        setDateEvenement(dateIde);
      } else {
        setDateEvenement(demande.getDateDepot());
      }
    }
    return getDateEvenement();
  }
  
  public void verifierContexte(DemandeSpec demande)
    throws ApplicativeException
  {
    int idPec = demande.getFormulaire().getIdPec();
    ObjetChronoPeriodePriseEnChargeSansFiltre periodePEC = OutillagePEC.getPeriodePEC(demande.getDemandeur(), idPec);
    if (periodePEC == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_CALI_L_CONTEXTE_PEC_INTROUVABLE", new Object[] { Integer.toString(idPec) }, 1);
    }
  }
  
  public FiltreCaliSpec getFiltreRechercheDecisionDuMemeType()
  {
    return new FiltreDecisionARESurDecision();
  }
  
  public ParcoursAffectationDemandeAssurance determinerParcoursAffectationDemandeAssurance(DemandeSpec demande)
  {
    if (OutilsChomageSansRCT.estDemandeEnContexteDeChomageEnCoursDeSuspension(demande)) {
      return new AffectationDemandeAsuCsr();
    }
    return new AffectationDemandeASUClassique();
  }
  
  public void determinerContexteDemande(DemandeSpec demande)
    throws CoucheLogiqueException
  {
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteParticulierCsr((Demande)demande);
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteSortieClauseRattrapageSpectacle((Demande)demande);
  }
  
  public void determinerContextesLiquidation(Contexte contexte)
    throws ApplicativeException
  {
    DomLiquidationAssurance donnees = (DomLiquidationAssurance)contexte.getDonnees();
    Demande demande = donnees.getDemande();
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteSortieDispositifASPouPAPARE(demande);
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteSortieDispositifASPouPAPDC(demande);
    DetectionContexteParticulierLiquidation.getInstance().detectionContextePremiereSortieCsp(demande);
    
    ContexteDemande contexteDemandeEnCoursDispo = (ContexteDemande)OutilGestionContexteDemande.trouverContexteDemandeAssurance(demande, "COURSDISPO");
    if (contexteDemandeEnCoursDispo != null) {
      demande.supprimerContexteDemande(contexteDemandeEnCoursDispo);
    }
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteEnCoursDeDisponibilite(demande);
    
    ContexteDemande contexteDemandeEnSortieDispo = (ContexteDemande)OutilGestionContexteDemande.trouverContexteDemandeAssurance(demande, "POSTDISPO");
    if (contexteDemandeEnSortieDispo != null) {
      demande.supprimerContexteDemande(contexteDemandeEnSortieDispo);
    }
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteEnSortieDeDisponibilite(demande);
  }
  
  public void verifierPostContexte(DemandeSpec demande)
    throws CoucheLogiqueException
  {
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)demande, "SORTIECRA"))
    {
      boolean estUneOd = ((Demande)demande).getAttribution() instanceof OdSpec;
      if (estUneOd)
      {
        ProduitSpec produit = ((Demande)demande).getDossierAffectation().getProduit();
        if (LigneAsuSpe02.getInstance().getNomUnique().equals(produit.getLigne().getNomUnique())) {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_SORTIE_CRA_SUR_IDE");
        }
      }
    }
  }
}

/* Location:
 * Qualified Name:     EreInscriptionDemandeurEmploi
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */