package fr.unedic.cali.asu.dom;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.outilsfonctionnels.DetectionContexteParticulierLiquidation;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsChomageSansRCT;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.parcours.ParcoursAffectationDemandeAssurance;
import fr.unedic.cali.asu.parcours.ParcoursInstallationAntecedent;
import fr.unedic.cali.asu.parcours.ParcoursLiquidationAssurance;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnChargeSansFiltre;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenAntecedentSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.utilitaire.filtres.FiltreCaliSpec;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreVrai;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;

public class EreSaisieAntecedent
  extends EreGammeAsu
  implements EvenementReferenceExamenAntecedentSpec
{
  private static final long serialVersionUID = 1L;
  
  public ObjetMetierSpec copie()
  {
    EreSaisieAntecedent copie = new EreSaisieAntecedent();
    copieElements(copie);
    return copie;
  }
  
  public Damj getDateDeclenchementExamen(DemandeSpec pDemande)
  {
    if ((getDateEvenement() != null) && ((pDemande.estDecisionnee()) || (pDemande.estDemandeLiquidee())) && (!pDemande.estEnReExamen())) {
      setDateDeclenchementExamen(getDateEvenement());
    } else {
      setDateDeclenchementExamen(getDateDeclenchementExamenPourAffichage(pDemande));
    }
    return getDateDeclenchementExamen();
  }
  
  public Damj getDateDeclenchementExamenPourAffichage(DemandeSpec pDemande)
  {
    Damj djc = null;
    Damj dateIde = null;
    Damj dateAAfficher = null;
    if (((Demande)pDemande).getSaisieAntecedent() != null) {
      djc = ((Demande)pDemande).getSaisieAntecedent().getDateDernierJourCalcule();
    }
    if (djc != null)
    {
      dateAAfficher = djc;
    }
    else if (pDemande.getDateDepot() != null)
    {
      dateAAfficher = pDemande.getDateDepot();
    }
    else
    {
      ObjetChronoPeriodePriseEnChargeSansFiltre periodePEC = OutillagePEC.getPeriodePEC(pDemande.getDemandeur(), pDemande.getFormulaire().getIdPec());
      if (periodePEC != null) {
        dateIde = periodePEC.getDateDebut();
      }
      if (dateIde != null) {
        dateAAfficher = dateIde;
      } else {
        dateAAfficher = pDemande.getFormulaire().getDateCreationDal();
      }
    }
    return dateAAfficher;
  }
  
  public Damj getDateExamen(DemandeSpec pDemande)
  {
    Damj dateIde = null;
    Demande demande = (Demande)pDemande;
    if (getDateEvenement() == null) {
      if ((demande.getSaisieAntecedent() != null) && (demande.getSaisieAntecedent().getDateAttribution() != null))
      {
        setDateEvenement(demande.getSaisieAntecedent().getDateAttribution());
      }
      else
      {
        ObjetChronoPeriodePriseEnChargeSansFiltre periodePEC = OutillagePEC.getPeriodePEC(pDemande.getDemandeur(), pDemande.getFormulaire().getIdPec());
        if (periodePEC != null) {
          dateIde = periodePEC.getDateDebut();
        }
        if (dateIde != null) {
          setDateEvenement(dateIde);
        } else {
          setDateEvenement(pDemande.getDateDepot());
        }
      }
    }
    return getDateEvenement();
  }
  
  public void verifierContexte(DemandeSpec pDemande)
    throws ApplicativeException
  {
    if (OutilsChomageSansRCT.estDemandeEnContexteDeChomageSansRuptureDeContrat(pDemande)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_IMPOSSIBLE_CSR");
    }
  }
  
  public String getLibelle()
  {
    return "ANT";
  }
  
  public String getLibelleLong()
  {
    return "Saisie antécédent";
  }
  
  public String getTypeExamen()
  {
    return "ASU_22";
  }
  
  public String getTypeSegment()
  {
    return "LE1D";
  }
  
  public int getPriorite()
  {
    return 21;
  }
  
  public FiltreCaliSpec getFiltreRechercheDecisionDuMemeType()
  {
    return new FiltreVrai();
  }
  
  public ParcoursAffectationDemandeAssurance determinerParcoursAffectationDemandeAssurance(DemandeSpec pDemande)
  {
    return null;
  }
  
  public boolean verifierPremiereDemandeIndividu(DemandeSpec pDemande)
  {
    Demande demande = (Demande)pDemande;
    boolean estFinDroitLiee = false;
    if (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(demande.getListContexteDemande(), "ARESJASPDC")) {
      estFinDroitLiee = true;
    }
    SaisieAntecedent saisieAntecedent = demande.getSaisieAntecedent();
    if ((!"0".equals(saisieAntecedent.getMontantReadmissionRetenu())) || (saisieAntecedent.estAntecedentAsp()) || (estFinDroitLiee)) {
      return false;
    }
    return true;
  }
  
  public ParcoursLiquidationAssurance determinerParcoursLiquidationDemandeAssurance(DemandeSpec pDemande)
  {
    return new ParcoursInstallationAntecedent();
  }
  
  public void determinerContexteDemande(DemandeSpec pDemande)
    throws CoucheLogiqueException
  {
    Demande demande = (Demande)pDemande;
    if (demande.getSaisieAntecedent() != null)
    {
      determinerContextesAsp(demande);
      determinerContextesClauseRattrapage(demande);
    }
  }
  
  protected void determinerContextesClauseRattrapage(Demande demande)
  {
    SaisieAntecedent saisieAntecedent = demande.getSaisieAntecedent();
    if (saisieAntecedent.isEntreeCra()) {
      DetectionContexteParticulierLiquidation.getInstance().ajouterContexteDemande(demande, "ENTREECRA");
    }
    if (saisieAntecedent.isSortieCra()) {
      DetectionContexteParticulierLiquidation.getInstance().ajouterContexteDemande(demande, "SORTIECRA");
    }
  }
  
  private void determinerContextesAsp(Demande demande)
    throws CoucheLogiqueException
  {
    if (demande.getSaisieAntecedent().estAntecedentAsp())
    {
      EreAspSuiteIDE ereAsp = new EreAspSuiteIDE();
      ereAsp.determinerContexteDemande(demande);
    }
  }
  
  public void determinerContextesLiquidation(Contexte pContexte)
    throws ApplicativeException
  {
    DomLiquidationAssurance donnees = (DomLiquidationAssurance)pContexte.getDonnees();
    Demande demande = donnees.getDemande();
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteAreEnEntreeCSPouPAP(demande);
  }
}

/* Location:
 * Qualified Name:     EreSaisieAntecedent
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */