package fr.unedic.cali.asu.dom;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.outilsfonctionnels.OutilAtp;
import fr.unedic.cali.asu.outilsfonctionnels.OutilFinDroit;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsChomageSansRCT;
import fr.unedic.cali.asu.parcours.AffectationDemandeASUClassique;
import fr.unedic.cali.asu.parcours.AffectationDemandeAsuCsr;
import fr.unedic.cali.asu.parcours.ParcoursAffectationDemandeAssurance;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.spec.EvenementReferenceExamenFinDroitSpec;
import fr.unedic.cali.outilsfonctionnels.AppelCalculParLiquidation;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.cali.utilitaire.filtres.FiltreCaliSpec;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreDecisionARESurDecision;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.temps.Damj;

public class EreSuiteFinDroitAtp
  extends EreGammeAsu
  implements EvenementReferenceExamenFinDroitSpec
{
  private transient boolean m_calculerDateExamenHorsLiquidation = false;
  private static final long serialVersionUID = -4227610548061770069L;
  
  public Damj getDateDeclenchementExamen(DemandeSpec p_demande)
  {
    if ((!p_demande.estDemandeLiquidee()) && (getDateEvenement() != null) && (p_demande.estDecisionnee()) && (!p_demande.estEnReExamen())) {
      setDateDeclenchementExamen(getDateEvenement());
    } else if (p_demande.getDateDepot() != null) {
      if (p_demande.getDateDepot() != null) {
        setDateDeclenchementExamen(p_demande.getDateDepot());
      } else {
        setDateDeclenchementExamen(p_demande.getFormulaire().getDateCreationDal());
      }
    }
    return getDateDeclenchementExamen();
  }
  
  public Damj getDateExamen(DemandeSpec p_demande)
  {
    Damj dateExamen = null;
    if (isCalculerDateExamenHorsLiquidation()) {
      dateExamen = calculerDateExamenHorsLiquidation(p_demande);
    } else if (p_demande.estDemandeLiquidee()) {
      dateExamen = calculerDateExamen(p_demande);
    } else {
      dateExamen = calculerDateExamenHorsLiquidation(p_demande);
    }
    setDateEvenement(dateExamen);
    return dateExamen;
  }
  
  private Damj calculerDateExamen(DemandeSpec p_demande)
  {
    AttributionAssuranceSpec attributionAtpOrigine = OutilAtp.rechercherAttributionAtpOrigine(p_demande, p_demande.getDateDeclenchementExamen());
    
    Damj dateExamen = null;
    if (attributionAtpOrigine != null) {
      dateExamen = attributionAtpOrigine.getDateFaitGenerateur().lendemain();
    }
    return dateExamen;
  }
  
  public Damj calculerDateExamenHorsLiquidation(DemandeSpec p_demande)
  {
    AttributionSpec attributionAtpPrecedente = rechercherAttributionPrecedente(p_demande);
    
    Damj dateExamen = null;
    if (attributionAtpPrecedente != null)
    {
      try
      {
        Damj djiAsu = AppelCalculParLiquidation.executerCalculDeterminationEtatDroit(attributionAtpPrecedente, null, true).getDernierJourIndemnisable();
        
        dateExamen = djiAsu.lendemain();
      }
      catch (ApplicativeException ex)
      {
        dateExamen = null;
      }
    }
    else
    {
      DemandeSpec demandeAtpPrecedente = OutilAtp.getDemandeAtpPrecedente(p_demande, p_demande.getDateDeclenchementExamen());
      if (demandeAtpPrecedente != null) {
        dateExamen = demandeAtpPrecedente.getDateExamen();
      }
    }
    return dateExamen;
  }
  
  public void verifierContexte(DemandeSpec p_demande)
    throws ApplicativeException
  {
    AttributionSpec attributionAtpPrecedente = OutilAtp.rechercherDernierDroitAtp(p_demande);
    if (attributionAtpPrecedente == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_CTX_NE_PERMET_PLUS_LIQUIDER_DMD_FIN_DROIT_ATP");
    }
  }
  
  public String getLibelle()
  {
    return "FIN ATP";
  }
  
  public String getLibelleLong()
  {
    return "Fin CTP";
  }
  
  public String getTypeExamen()
  {
    return "ASU_19";
  }
  
  public ObjetMetierSpec copie()
  {
    EreSuiteFinDroitAtp copie = new EreSuiteFinDroitAtp();
    copieElements(copie);
    return copie;
  }
  
  public int getPriorite()
  {
    return 18;
  }
  
  public FiltreCaliSpec getFiltreRechercheDecisionDuMemeType()
  {
    FiltreET filtreAreEtNonFinAsr = new FiltreET();
    filtreAreEtNonFinAsr.ajouterFiltre(new FiltreDecisionARESurDecision());
    
    return filtreAreEtNonFinAsr;
  }
  
  public ParcoursAffectationDemandeAssurance determinerParcoursAffectationDemandeAssurance(DemandeSpec p_demande)
  {
    if (OutilsChomageSansRCT.estDemandeEnContexteDeChomageEnCoursDeSuspension(p_demande)) {
      return new AffectationDemandeAsuCsr();
    }
    return new AffectationDemandeASUClassique();
  }
  
  public boolean isCalculerDateExamenHorsLiquidation()
  {
    return m_calculerDateExamenHorsLiquidation;
  }
  
  public void setCalculerDateExamenHorsLiquidation(boolean p_calculerDateExamenHorsLiquidation)
  {
    m_calculerDateExamenHorsLiquidation = p_calculerDateExamenHorsLiquidation;
  }
  
  public void determinerContexteDemande(DemandeSpec p_demande)
  {
    AttributionAssuranceSpec attributionOrigine = (AttributionAssuranceSpec)OutilFinDroit.rechercherAttributionOrigineCorrespondante(p_demande);
    if (attributionOrigine != null)
    {
      ContexteDemande contexteDemande = new ContexteDemande();
      Demande demandeOrigine = (Demande)attributionOrigine.getDemande();
      if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeOrigine, "IDEATP")) {
        contexteDemande.setTypeContexteDemande("FINATP");
      } else if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeOrigine, "BASCULEATP")) {
        contexteDemande.setTypeContexteDemande("FINATPBASC");
      }
      ((Demande)p_demande).ajouterContexteDemande(contexteDemande);
    }
  }
  
  public void determinerContextesLiquidation(Contexte p_contexte)
    throws ApplicativeException
  {}
  
  public AttributionSpec rechercherAttributionPrecedente(DemandeSpec demande)
  {
    return OutilAtp.rechercherAttributionAtpPrecedent(demande, demande.getDateDepot());
  }
}

/* Location:
 * Qualified Name:     EreSuiteFinDroitAtp
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */