package fr.unedic.cali.asu.dom;

import fr.unedic.cali.asu.dom.gen.ValidationProduitGen;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.affectation.Parametres;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.affectation.ValidationProduitSpec;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.cali.parcours.ContexteParcoursCali;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;

public class ValidationProduit
  extends ValidationProduitGen
  implements ValidationProduitSpec
{
  private static final long serialVersionUID = -6785107085148876956L;
  protected transient ActiviteSalarie m_periodeValidationProduit;
  protected transient Quantite m_qteAcquiseSecondaire;
  protected transient Reglement m_reglementApplicable;
  protected transient ProduitSpec m_produitValide;
  protected transient Quantite m_qteAssimilationAcquise;
  protected transient Quantite m_qteAssimilationAcquiseSecondaire;
  protected transient boolean m_estProduitValide;
  
  public ValidationProduit()
  {
    m_estProduitValide = true;
  }
  
  public ValidationProduit(DomPCSpec p_pc)
  {
    super(p_pc);
    m_estProduitValide = true;
  }
  
  public ActiviteSalarie getPeriodeValidationProduit()
  {
    if (m_periodeValidationProduit == null)
    {
      Individu individuCourant = ContexteParcoursCali.getIndividuCourant();
      
      m_periodeValidationProduit = ((ActiviteSalarie)individuCourant.rechercherPeriodePasseProfessionnel(getIdentifiantPeriodeValidationProduit()));
    }
    return m_periodeValidationProduit;
  }
  
  public void setPeriodeValidationProduit(ActiviteSalarie p_periode)
  {
    m_periodeValidationProduit = p_periode;
    if (p_periode != null)
    {
      setIdentifiantPeriodeValidationProduit(p_periode.getIdentifiant());
      setDateFinPeriode(p_periode.getDateFin());
      setMotifFinPeriode(p_periode.getMotifFin());
      setDjtpPeriode(p_periode.getDernierJourTravaillePaye());
      setCatEmploiPart(p_periode.getCategorieEmploiParticulier());
      setPopOccHorsFrance(p_periode.getContrat().getPohf());
    }
  }
  
  public void jdoPostLoad() {}
  
  public void jdoPreClear() {}
  
  public void jdoPreDelete() {}
  
  public void marquerGraphePersistant()
  {
    DomManager.persisterEnProfondeur(super.getJustificationCalculAffiliation());
    DomManager.persisterEnProfondeur(super.getJustificationAffiliationJoursTravailles());
  }
  
  public void jdoPreStore() {}
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
  
  public ObjetMetierSpec copie()
  {
    ValidationProduit copie = new ValidationProduit();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    ValidationProduit copie = (ValidationProduit)p_copie;
    
    copie.setDateFinPeriode(getDateFinPeriode());
    copie.setDjtpPeriode(getDjtpPeriode());
    copie.setIdentifiantPeriodeValidationProduit(getIdentifiantPeriodeValidationProduit());
    copie.setMotifFinPeriode(getMotifFinPeriode());
    copie.setQuantiteAcquise(getQuantiteAcquise());
    copie.setQuantiteAcquiseSecondaire(getQuantiteAcquiseSecondaire());
    copie.setPeriodePra(getPeriodePra());
    copie.setCatEmploiPart(getCatEmploiPart());
    copie.setPopOccHorsFrance(getPopOccHorsFrance());
    
    copie.setNomReglementApplicable(super.getNomReglementApplicable());
    copie.setCodeProduitValide(super.getCodeProduitValide());
    copie.setQuantiteAssimilationAcquise(getQuantiteAssimilationAcquise());
    copie.setQuantiteAssimilationAcquiseSecondaire(getQuantiteAssimilationAcquiseSecondaire());
    if (getJustificationAffiliationJoursTravailles() != null) {
      copie.setJustificationAffiliationJoursTravailles((JustificationAffiliationJoursTravailles)getJustificationAffiliationJoursTravailles().copie());
    }
    if (getJustificationCalculAffiliation() != null) {
      copie.setJustificationCalculAffiliation((JustificationAffiliation)getJustificationCalculAffiliation().copie());
    }
    copie.setEstProduitValide(isEstProduitValide());
  }
  
  public ProduitSpec getProduitValide()
  {
    if ((m_produitValide == null) && (super.getCodeProduitValide() != 0)) {
      m_produitValide = Parametres.getProduit(super.getCodeProduitValide());
    }
    return m_produitValide;
  }
  
  public void setProduitValide(ProduitSpec p_produitValide)
  {
    m_produitValide = p_produitValide;
    if (p_produitValide != null) {
      super.setCodeProduitValide(p_produitValide.getCode());
    }
  }
  
  public Quantite getQuantiteAcquise()
  {
    return super.getQteAcquise();
  }
  
  public Reglement getReglementApplicable()
  {
    if ((m_reglementApplicable == null) && (super.getNomReglementApplicable() != null)) {
      m_reglementApplicable = Parametres.getReglement(super.getNomReglementApplicable(), getProduitValide());
    }
    return m_reglementApplicable;
  }
  
  public void setQuantiteAcquise(Quantite p_qteAcquise)
  {
    super.setQteAcquise(p_qteAcquise);
  }
  
  public void setReglementApplicable(Reglement p_reglementApplicable)
  {
    m_reglementApplicable = p_reglementApplicable;
    super.setNomReglementApplicable(p_reglementApplicable.getNomReglement());
  }
  
  public Quantite getQuantiteAcquiseSecondaire()
  {
    return m_qteAcquiseSecondaire;
  }
  
  public void setQuantiteAcquiseSecondaire(Quantite p_qteAcquiseSecondaire)
  {
    m_qteAcquiseSecondaire = p_qteAcquiseSecondaire;
  }
  
  public boolean isEstProduitValide()
  {
    return m_estProduitValide;
  }
  
  public void setEstProduitValide(boolean p_estProduitValide)
  {
    m_estProduitValide = p_estProduitValide;
  }
  
  public Quantite getQuantiteAssimilationAcquise()
  {
    return m_qteAssimilationAcquise;
  }
  
  public void setQuantiteAssimilationAcquise(Quantite p_qteAssimilationAcquise)
  {
    m_qteAssimilationAcquise = p_qteAssimilationAcquise;
  }
  
  public Quantite getQuantiteAssimilationAcquiseSecondaire()
  {
    return m_qteAssimilationAcquiseSecondaire;
  }
  
  public void setQuantiteAssimilationAcquiseSecondaire(Quantite p_qteAssimilationAcquiseSecondaire)
  {
    m_qteAssimilationAcquiseSecondaire = p_qteAssimilationAcquiseSecondaire;
  }
  
  public void setJustificationCalculAffiliation(JustificationAffiliation justificationCalculAffiliation)
  {
    DomManager.supprimer(super.getJustificationCalculAffiliation(), justificationCalculAffiliation);
    super.setJustificationCalculAffiliation(justificationCalculAffiliation);
  }
  
  public void setJustificationAffiliationJoursTravailles(JustificationAffiliationJoursTravailles justificationAffiliationJoursTravailles)
  {
    DomManager.supprimer(super.getJustificationAffiliationJoursTravailles(), justificationAffiliationJoursTravailles);
    super.setJustificationAffiliationJoursTravailles(justificationAffiliationJoursTravailles);
  }
}

/* Location:
 * Qualified Name:     ValidationProduit
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */