package fr.unedic.cali.asu.eur05.p01.calcul.outilsfonctionnels;

import fr.unedic.cali.asu.calcul.dom.temps.ObjetChronoPeriodeAssDemandeExpresse;
import fr.unedic.cali.asu.calcul.dom.temps.ObjetChronoPeriodeRejetDVDemandeExpresse;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnCharge;
import fr.unedic.cali.calcul.OutillagePeriodes;
import fr.unedic.cali.calcul.dom.QualificationPeriodes;
import fr.unedic.cali.calcul.dom.periode.ActionFormation;
import fr.unedic.cali.calcul.dom.periode.DsmAbsenceAuPointage;
import fr.unedic.cali.calcul.dom.periode.DsmMaladie;
import fr.unedic.cali.calcul.dom.periode.DsmTravail;
import fr.unedic.cali.calcul.dom.periode.PeriodeAbsenceAuPointage;
import fr.unedic.cali.calcul.dom.periode.PeriodeActiviteSalarieSansSalaire;
import fr.unedic.cali.calcul.dom.periode.PeriodeBlocageIndemnisation;
import fr.unedic.cali.calcul.dom.periode.PeriodeConflitGAEC;
import fr.unedic.cali.calcul.dom.periode.PeriodeEvenementBloquant;
import fr.unedic.cali.calcul.dom.periode.PeriodeEvenementPersonnel;
import fr.unedic.cali.calcul.dom.periode.PeriodeFormation;
import fr.unedic.cali.calcul.dom.periode.PeriodeFormationNonIndemnisee;
import fr.unedic.cali.calcul.dom.periode.PeriodeFormationNonIndemniseeAbsenceHeure;
import fr.unedic.cali.calcul.dom.periode.PeriodePrime;
import fr.unedic.cali.calcul.dom.periode.PeriodeServiceCivique;
import fr.unedic.cali.calcul.dom.periode.PeriodeTravailJustifiee;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeAttributionSecteurPublic;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeCalcul;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeInterProduits;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeLendemainDja;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeLimiteIndemnisationAUE;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodePEC;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeRadiation;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeSegmentationARI;
import fr.unedic.cali.calcul.outilsfonctionnels.QualificationAbstraite;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.RepriseSpec;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;

public class Qualification
  extends QualificationAbstraite
{
  protected boolean estTypeAPrendreEnCompte(ObjetChronoPeriode periode)
  {
    return periode instanceof PeriodeActiviteSalarieSansSalaire;
  }
  
  protected boolean qualifierUnePeriodeAlertante(ObjetChronoPeriodeCalcul periode, QualificationPeriodes qualificationPeriodes, AttributionSpec attribution)
  {
    return false;
  }
  
  protected boolean qualifierUnePeriodeDecalante(ObjetChronoPeriodeCalcul p_periode, QualificationPeriodes p_qualificationPeriodes, AttributionSpec p_attribution)
  {
    if ((p_periode instanceof PeriodeFormationNonIndemnisee)) {
      p_qualificationPeriodes.ajouterPeriodesDecalantes(p_periode);
    } else if ((p_periode instanceof PeriodeFormation))
    {
      if (((PeriodeFormation)p_periode).getActionFormation().estBasculeAutoriserEnContexteFormation()) {
        p_qualificationPeriodes.ajouterPeriodesDecalantes(p_periode);
      }
    }
    else if (((p_periode instanceof PeriodeTravailJustifiee)) || ((p_periode instanceof DsmTravail)) || ((p_periode instanceof PeriodePrime))) {
      p_qualificationPeriodes.ajouterPeriodesDecalantes(p_periode);
    } else {
      return false;
    }
    return true;
  }
  
  protected boolean qualifierUnePeriodeGelante(ObjetChronoPeriodeCalcul p_periode, QualificationPeriodes p_qualificationPeriodes, AttributionSpec p_attribution)
  {
    if ((p_periode instanceof PeriodeAbsenceAuPointage)) {
      p_qualificationPeriodes.ajouterPeriodesGelantes(p_periode);
    } else if ((p_periode instanceof PeriodeFormationNonIndemnisee)) {
      p_qualificationPeriodes.ajouterPeriodesGelantes(p_periode);
    } else if ((p_periode instanceof PeriodeFormation))
    {
      if (((PeriodeFormation)p_periode).getActionFormation().estBasculeAutoriserEnContexteFormation()) {
        p_qualificationPeriodes.ajouterPeriodesGelantes(p_periode);
      }
    }
    else if (((p_periode instanceof PeriodeTravailJustifiee)) || ((p_periode instanceof DsmTravail)) || ((p_periode instanceof PeriodePrime))) {
      p_qualificationPeriodes.ajouterPeriodesGelantes(p_periode);
    } else {
      return false;
    }
    return true;
  }
  
  protected boolean qualifierUnePeriodeInterruptives(ObjetChronoPeriodeCalcul p_periode, QualificationPeriodes p_qualificationPeriodes, AttributionSpec p_attribution)
  {
    return false;
  }
  
  protected boolean qualifierUnePeriodeInterruptivesDefinitives(ObjetChronoPeriodeCalcul p_periode, QualificationPeriodes p_qualificationPeriodes, AttributionSpec p_attribution)
    throws CoucheLogiqueException
  {
    boolean resultat = true;
    if ((p_periode instanceof ObjetChronoPeriodeLimiteIndemnisationAUE))
    {
      p_qualificationPeriodes.ajouterPeriodesInterruptivesDefinitives(p_periode);
    }
    else if ((p_periode instanceof PeriodeConflitGAEC))
    {
      if (!p_attribution.estNeutralise())
      {
        if ((p_attribution.getDateAttribution() != null) && (p_attribution.getDateAttribution().estApres(p_periode.getDateDebut()))) {
          if (p_attribution.getDateAttribution().coincideAvec(p_attribution.getDateAttribution().getFinMois()))
          {
            p_periode.setDateDebut(p_attribution.getDateAttribution().lendemain());
            p_periode.setDateFin(p_attribution.getDateAttribution().lendemain());
          }
          else
          {
            p_periode.setDateDebut(p_attribution.getDateAttribution().getFinMois());
            p_periode.setDateFin(p_attribution.getDateAttribution().getFinMois());
          }
        }
        p_qualificationPeriodes.ajouterPeriodesInterruptivesDefinitives(p_periode);
      }
    }
    else if ((p_periode instanceof PeriodeFormationNonIndemniseeAbsenceHeure))
    {
      if (!p_attribution.estNeutralise())
      {
        if ((p_attribution.getDateAttribution() != null) && (p_attribution.getDateAttribution().estApres(p_periode.getDateDebut()))) {
          p_periode.setDateDebut(p_attribution.getDateAttribution());
        }
        p_qualificationPeriodes.ajouterPeriodesInterruptivesDefinitives(p_periode);
      }
    }
    else if ((p_periode instanceof ObjetChronoPeriodeRadiation))
    {
      ObjetChronoPeriodePriseEnCharge periodePEC = OutillagePeriodes.recupererPeriodePECContenant(p_attribution.getDemandeur(), p_attribution.getPji());
      if (((ObjetChronoPeriodeRadiation)p_periode).getPEC().getPeriode().coincideAvec(new Periode(periodePEC.getDateDebut(), periodePEC.getDateFin()))) {
        p_qualificationPeriodes.ajouterPeriodesInterruptivesDefinitives(p_periode);
      }
    }
    else if ((p_periode instanceof PeriodeBlocageIndemnisation))
    {
      p_qualificationPeriodes.ajouterPeriodesInterruptivesDefinitives(p_periode);
    }
    else if ((p_periode instanceof ObjetChronoPeriodeAssDemandeExpresse))
    {
      p_qualificationPeriodes.ajouterPeriodesInterruptivesDefinitives(p_periode);
    }
    else if ((p_periode instanceof ObjetChronoPeriodeRejetDVDemandeExpresse))
    {
      p_qualificationPeriodes.ajouterPeriodesInterruptivesDefinitives(p_periode);
    }
    else if (((p_periode instanceof ObjetChronoPeriodeAttributionSecteurPublic)) && (!p_attribution.equals(((ObjetChronoPeriodeAttributionSecteurPublic)p_periode).getAttribution())))
    {
      p_qualificationPeriodes.ajouterPeriodesInterruptivesDefinitives(p_periode);
    }
    else if (((p_periode instanceof ObjetChronoPeriodeInterProduits)) && (!p_attribution.equals(((ObjetChronoPeriodeInterProduits)p_periode).getAttribution())))
    {
      if ((((ObjetChronoPeriodeInterProduits)p_periode).getTypePeriode() == 1) && (((ObjetChronoPeriodeInterProduits)p_periode).getGamme().equals("ASU")) && (((p_attribution.getNatureDecision() != 12) && (p_attribution.getNatureDecision() != 26) && (p_attribution.getNatureDecision() != 11) && (!(p_attribution instanceof RepriseSpec))) || (((ObjetChronoPeriodeInterProduits)p_periode).getAttribution().getNatureDecision() != 30) || (!p_attribution.getDateAttribution().coincideAvec(((ObjetChronoPeriodeInterProduits)p_periode).getAttribution().getDateAttribution())))) {
        p_qualificationPeriodes.ajouterPeriodesInterruptivesDefinitives(p_periode);
      } else if (((ObjetChronoPeriodeInterProduits)p_periode).getNomProduit().equals("INR_RCE04_01")) {
        p_qualificationPeriodes.ajouterPeriodesInterruptivesDefinitives(p_periode);
      } else if ((((ObjetChronoPeriodeInterProduits)p_periode).getNomProduit().equals("RET_ACO01_01")) && (((ObjetChronoPeriodeInterProduits)p_periode).getTypePeriode() == 2)) {
        p_qualificationPeriodes.ajouterPeriodesInterruptivesDefinitives(p_periode);
      }
    }
    else
    {
      resultat = false;
    }
    return resultat;
  }
  
  protected boolean qualifierUnePeriodeSegmentante(ObjetChronoPeriodeCalcul p_periode, QualificationPeriodes p_qualificationPeriodes, AttributionSpec p_attribution)
  {
    if ((p_periode instanceof PeriodeEvenementBloquant)) {
      p_qualificationPeriodes.ajouterPeriodesSegmentantes(p_periode);
    } else if ((p_periode instanceof ObjetChronoPeriodeLendemainDja)) {
      p_qualificationPeriodes.ajouterPeriodesSegmentantes(p_periode);
    } else if ((p_periode instanceof ObjetChronoPeriodeSegmentationARI)) {
      p_qualificationPeriodes.ajouterPeriodesSegmentantes(p_periode);
    } else {
      return false;
    }
    return true;
  }
  
  protected boolean qualifierUnePeriodeSuspensives(ObjetChronoPeriodeCalcul p_periode, QualificationPeriodes p_qualificationPeriodes, AttributionSpec p_attribution)
    throws CoucheLogiqueException
  {
    if (((p_periode instanceof PeriodeEvenementPersonnel)) && (!(p_periode instanceof PeriodeServiceCivique))) {
      p_qualificationPeriodes.ajouterPeriodesSuspensives(p_periode);
    } else if (((p_periode instanceof DsmMaladie)) || ((p_periode instanceof DsmAbsenceAuPointage))) {
      p_qualificationPeriodes.ajouterPeriodesSuspensives(p_periode);
    } else {
      return false;
    }
    return true;
  }
}

/* Location:
 * Qualified Name:     Qualification
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */