package fr.unedic.cali.asu.fds12.p02.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.ConditionQuantiteAffiliationSpec;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.fds12.p02.liquidation.outilsfonctionnels.filtres.FiltreAttributionAFDFiliere;
import fr.unedic.cali.asu.fps.liquidation.outilsfonctionnels.OutilConditionBeneficeAutreProduitFPS;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConditionBeneficeAutreProduit;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConditionsAttributionAdmission;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuFds12P02;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreAttributionAssurancePourProduit;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologieDebuts;
import fr.unedic.util.temps.FiltresTemporel;

public class OutilConditionBeneficeAutreProduit
  implements OutilFonctionnel
{
  private static final int NOMBRE_ADMISSION_MAX_FILIERE_COURTE = 1;
  private static final int NOMBRE_ADMISSION_MAX_FILIERE_INTERMEDIAIRE = 2;
  private static final int NOMBRE_ADMISSION_MAX_FILIERE_LONGUE = 3;
  
  public static ConditionBeneficeAutreProduit verifierConditionBeneficeAutreProduit(DemandeAssuranceSpec p_demandeAssurance)
    throws ApplicativeException
  {
    ConditionBeneficeAutreProduit capa14 = ((DossierExamen)p_demandeAssurance.getDossierExamen()).getConditionAttributionAdmission().createConditionBeneficeAutreProduit();
    
    boolean conditionQuantiteAffiliationSatisfaite = false;
    DossierExamenSpec dossierExamen = p_demandeAssurance.getDossierExamen();
    if ((dossierExamen != null) && (((DossierExamenAssuranceSpec)dossierExamen).getConditionQuantiteAffiliation() != null)) {
      conditionQuantiteAffiliationSatisfaite = ((DossierExamenAssuranceSpec)dossierExamen).getConditionQuantiteAffiliation().estSatisfait();
    }
    if (!conditionQuantiteAffiliationSatisfaite)
    {
      capa14.setEtatSatisfait(true);
    }
    else
    {
      Integer anciennete = OutilDeterminationFiliere.determinerAnciennete(p_demandeAssurance);
      if ((anciennete == null) || (anciennete.intValue() == 0)) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB20");
      }
      capa14.setDureeAncienneteIntermittant(anciennete);
      
      verifierConditionLieeAAdmissionPrecedente(p_demandeAssurance, capa14);
      
      OutilConditionBeneficeAutreProduitFPS.verifierPresenceAttributionPrecedentePourProduitFds(p_demandeAssurance, ProduitAsuFds12P02.getInstance());
    }
    return capa14;
  }
  
  private static void verifierConditionLieeAAdmissionPrecedente(DemandeAssuranceSpec p_demandeAssurance, ConditionBeneficeAutreProduit p_capa14)
    throws CoucheLogiqueException
  {
    int filiere = OutilDeterminationFiliere.determinerFiliere(p_demandeAssurance);
    int nombreMaxAttribution = 0;
    int codeMotifEchec = 0;
    int attributionsNonInstallees = 0;
    
    IndividuSpec individu = p_demandeAssurance.getDemandeur();
    switch (filiere)
    {
    case 0: 
      nombreMaxAttribution = 1;
      codeMotifEchec = 97;
      attributionsNonInstallees = individu.getAttributionsAfdFiliereCourte();
      break;
    case 1: 
      nombreMaxAttribution = 2;
      codeMotifEchec = 98;
      attributionsNonInstallees = individu.getAttributionsAfdFiliereIntermediaire();
      break;
    case 2: 
      nombreMaxAttribution = 3;
      codeMotifEchec = 99;
      attributionsNonInstallees = individu.getAttributionsAfdFiliereLongue();
    }
    FiltreAttributionAssurancePourProduit filtreProduit = new FiltreAttributionAssurancePourProduit(ProduitAsuFds12P02.getInstance());
    FiltreAttributionAFDFiliere filtreFiliere = new FiltreAttributionAFDFiliere(filiere);
    
    FiltresTemporel listeFiltres = new FiltresTemporel();
    listeFiltres.ajouterFiltre(filtreProduit);
    listeFiltres.ajouterFiltre(filtreFiliere);
    
    Chronologie chronoAttributionFPS = p_demandeAssurance.getDemandeur().getChronoDemandeAssurance().copier(listeFiltres);
    if (attributionsNonInstallees + chronoAttributionFPS.getTaille() >= nombreMaxAttribution)
    {
      p_capa14.setEtatSatisfait(false);
      p_capa14.setCodeMotifEchec(codeMotifEchec);
    }
    else
    {
      p_capa14.setRangAttributionAFDFiliere(chronoAttributionFPS.getTaille() + 1);
    }
  }
}

/* Location:
 * Qualified Name:     OutilConditionBeneficeAutreProduit
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */