package fr.unedic.cali.asu.fps.liquidation.outilsaffiliation;

import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.CalculAffiliationSupplementaire;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.ComportementAffiliationSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import java.util.Map;

public class CalculAffiliationSupplementaireFPS
  extends CalculAffiliationSupplementaire
{
  public Quantite determinerAffiliationSupplementaire(IndividuSpec p_individu, ComportementAffiliationSpec p_comportementCalcul, JustificationAffiliation p_justification, Map p_chronologies)
    throws CoucheLogiqueException
  {
    Quantite affiliationSupplementaire = super.determinerAffiliationSupplementaire(p_individu, p_comportementCalcul, p_justification, p_chronologies);
    
    Quantite quantiteMaladieLongueDureeSupplementaire = null;
    Quantite quantiteMaladieGraveSupplementaire = null;
    if (p_comportementCalcul.isCalculAffiliationSupplementaireMaladieLongueDuree())
    {
      verifierComportementMaladieLongueDuree(p_comportementCalcul);
      
      quantiteMaladieLongueDureeSupplementaire = calculerMaladieLongueDureeSurChevauchementAffiliationA(p_comportementCalcul, p_justification, p_chronologies);
    }
    if (p_comportementCalcul.isCalculAffiliationSupplementaireMaladieGrave())
    {
      verifierComportementMaladieGrave(p_comportementCalcul);
      
      quantiteMaladieGraveSupplementaire = calculerMaladieGraveSurChevauchementAffiliationA(p_comportementCalcul, p_justification, p_chronologies);
    }
    if (quantiteMaladieLongueDureeSupplementaire != null) {
      affiliationSupplementaire = affiliationSupplementaire.ajouter(quantiteMaladieLongueDureeSupplementaire);
    }
    if (quantiteMaladieGraveSupplementaire != null) {
      affiliationSupplementaire = affiliationSupplementaire.ajouter(quantiteMaladieGraveSupplementaire);
    }
    return affiliationSupplementaire;
  }
  
  private Quantite calculerMaladieLongueDureeSurChevauchementAffiliationA(ComportementAffiliationSpec p_comportementCalcul, JustificationAffiliation p_justification, Map p_chronologies)
  {
    Chronologie chronoPourAffiliationSupMaladieLongueDuree = (Chronologie)p_chronologies.get("chronoAffiMaladiesLongueDuree");
    
    Chronologie chronoActivitesAffiliationBase = (Chronologie)p_chronologies.get("chronoAffiBase");
    
    return calculerSuspensionSurChevauchementAffiliationA(p_comportementCalcul, p_justification, chronoActivitesAffiliationBase, chronoPourAffiliationSupMaladieLongueDuree);
  }
  
  private Quantite calculerMaladieGraveSurChevauchementAffiliationA(ComportementAffiliationSpec p_comportementCalcul, JustificationAffiliation p_justification, Map p_chronologies)
  {
    Chronologie chronoPourAffiliationSupMaladieGrave = (Chronologie)p_chronologies.get("chronoAffiMaladiesGraves");
    
    Chronologie chronoActivitesAffiliationBase = (Chronologie)p_chronologies.get("chronoAffiBase");
    
    return calculerSuspensionSurChevauchementAffiliationA(p_comportementCalcul, p_justification, chronoActivitesAffiliationBase, chronoPourAffiliationSupMaladieGrave);
  }
  
  private void verifierComportementMaladieLongueDuree(ComportementAffiliationSpec p_comportement)
    throws CoucheLogiqueException
  {
    if (p_comportement == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_COMPORTEMENT_AFFILIATION_ABSENT");
    }
    if (p_comportement.getPeriodeRecherche() == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_COMPORTEMENT_PERIODE_ABSENTE");
    }
  }
  
  private void verifierComportementMaladieGrave(ComportementAffiliationSpec p_comportement)
    throws CoucheLogiqueException
  {
    if (p_comportement == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_COMPORTEMENT_AFFILIATION_ABSENT");
    }
    if (p_comportement.getPeriodeRecherche() == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_COMPORTEMENT_PERIODE_ABSENTE");
    }
  }
}

/* Location:
 * Qualified Name:     CalculAffiliationSupplementaireFPS
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */