package fr.unedic.cali.asu.fps.liquidation.parcours.convention17.cep.sjm;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionSalaireJournalierMoyen;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionSalaireReference;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Decision;
import fr.unedic.cali.asu.spe02.p05.liquidation.parcours.cep.sjm.ConstitutionSalaireReferenceEtSjm;
import fr.unedic.cali.asu.spe02.p05.liquidation.parcours.cep.sjm.ConstitutionSjm;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public class ConstitutionSalaireReferenceEtSjmConvention17
  extends ConstitutionSalaireReferenceEtSjm
{
  protected ParcoursCali getParcoursConstitutionSalaireReference()
  {
    return new ConstitutionSalaireReferenceConvention17();
  }
  
  private ConstitutionSjm getParcoursConstitutionSjm()
  {
    return new ConstitutionSjm();
  }
  
  protected Resultat effectuerTraitementClassique(Contexte contexte)
    throws ApplicativeException
  {
    Resultat resultatCEPA = new Resultat();
    
    DomLiquidationAssurance dom = (DomLiquidationAssurance)contexte.getDonnees();
    DomLiquidationAssurance domPrf = copierDom(dom);
    domPrf.setCalculSurPrf(true);
    
    Demande demandeCourante = ((DomLiquidationAssurance)contexte.getDonnees()).getDemande();
    ParcoursCali parcoursConstitutionSalaireReference = getParcoursConstitutionSalaireReference();
    Resultat res1 = parcoursConstitutionSalaireReference.demarrer(contexte);
    ParcoursCali parcoursConstitutionSjm = getParcoursConstitutionSjm();
    Resultat res2 = parcoursConstitutionSjm.demarrer(contexte);
    
    Damj dateDernierFgd = demandeCourante.getDateFaitGenerateurOdPrecedente();
    ValidationProduit validationProduit = demandeCourante.getDossierAffectationAdmission().getValidationProduit();
    Periode periodePra = validationProduit.getPeriodePra();
    boolean calculSurPrfEffectue = false;
    if ((dateDernierFgd != null) && (periodePra.getDebut().estAvant(dateDernierFgd)))
    {
      contexte.setDonnees(domPrf);
      try
      {
        parcoursConstitutionSalaireReference.demarrer(contexte);
        parcoursConstitutionSjm.demarrer(contexte);
      }
      finally
      {
        contexte.setDonnees(dom);
      }
      calculSurPrfEffectue = true;
    }
    alimenterCepaAvecDonneesPrf(dom.getDemande(), domPrf.getDemande(), calculSurPrfEffectue);
    
    resultatCEPA.setEtat((res1.estSatisfait()) && (res2.estSatisfait()) ? 0 : 1);
    resultatCEPA.setCodeErreur(res1.getCodeErreur() != null ? res1.getCodeErreur() : res2.getCodeErreur());
    resultatCEPA.setMessageErreur(res1.getMessageErreur() != null ? res1.getMessageErreur() : res2.getMessageErreur());
    
    return resultatCEPA;
  }
  
  private void alimenterCepaAvecDonneesPrf(DemandeAssuranceSpec demandeOrigine, DemandeAssuranceSpec demandePrf, boolean estPrfCalculee)
  {
    Decision decisionDemandeOrigine = (Decision)demandeOrigine.getDossierExamen();
    Periode prf;
    BigDecimal montantSJMPrf;
    Periode prf;
    if (estPrfCalculee)
    {
      Decision decisionDemandePrf = (Decision)demandePrf.getDossierExamen();
      BigDecimal montantSJMPrf = decisionDemandePrf.getConstitutionSalaireJournalierMoyen().getMontantSalaireJournalierMoyenRevalorisePlafonne().getValeur();
      
      prf = decisionDemandePrf.getConstitutionSalaireReference().getPrc();
    }
    else
    {
      montantSJMPrf = decisionDemandeOrigine.getConstitutionSalaireJournalierMoyen().getMontantSalaireJournalierMoyenRevalorisePlafonne().getValeur();
      
      prf = decisionDemandeOrigine.getConstitutionSalaireReference().getPrc();
    }
    decisionDemandeOrigine.getConstitutionSalaireJournalierMoyen().setMontantSJMRPPrf(montantSJMPrf);
    decisionDemandeOrigine.getConstitutionSalaireReference().setPrf((Periode)prf.copie());
  }
  
  private DomLiquidationAssurance copierDom(DomLiquidationAssurance domSource)
  {
    DomLiquidationAssurance resultat = new DomLiquidationAssurance();
    resultat.copie(domSource);
    Demande demandeCopiee = resultat.getDemande();
    demandeCopiee.setDemandeLiquidee(true);
    
    return resultat;
  }
}

/* Location:
 * Qualified Name:     ConstitutionSalaireReferenceEtSjmConvention17
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */