package fr.unedic.cali.asu.liquidation.antecedent;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.SaisieAntecedent;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.PeriodeGaecSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.ConteneurConventionGestion;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpe02P03;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.cali.outilsfonctionnels.OutilConventionGestion;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.parametres.GestionnaireDateApplication;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.List;

public class VerificationDonneesSaisieAntecedent
  implements VerificationDonneesSaisieAntecedentSpec
{
  private static final Integer ZERO = Integer.valueOf(0);
  private static final Integer MAX_DELAI_ATTENTE = Integer.valueOf(7);
  private static final Integer MAX_ISLR = Integer.valueOf(75);
  private static final int MAX_FCP_POSSIBLE = 3;
  private static final int MAX_FS_POSSIBLE = 31;
  private static final BigDecimal BD_ZERO = new BigDecimal("0");
  private static final BigDecimal BD_UN = new BigDecimal("1");
  private static final BigDecimal BD_182 = new BigDecimal("182");
  private static final Damj DATE_ATTRIB_SPE = new Damj(2007, 5, 1);
  private static final Damj DATE_MIN_FGD = new Damj(2003, 1, 1);
  private static final Damj DATE_ATTRIB_ARE01 = new Damj(1997, 1, 1);
  private static final Damj DATE_FGD_MIN_ARE01 = new Damj(1997, 1, 1);
  private static final Damj DATE_FGD_MAX_ARE01 = new Damj(2002, 12, 31);
  private static final int AGE_MAINTIEN = 60;
  private static final int AGE_ELIGIBLE_ALLONGEMENT = 53;
  private static final BigDecimal DUREE_DROIT_INITIAL_MAX = new BigDecimal(913);
  
  public static VerificationDonneesSaisieAntecedent getInstance()
  {
    return new VerificationDonneesSaisieAntecedent();
  }
  
  public void verifierDonneesForcees(Demande demande, Damj dateTraitement)
    throws CoucheLogiqueException
  {
    SaisieAntecedent saisieAntecedent = demande.getSaisieAntecedent();
    if ((saisieAntecedent == null) || (saisieAntecedent.getCodeProduit() == null)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_ANTECEDENT_CODE_PRODUIT");
    }
    boolean spectacle = false;
    if ((saisieAntecedent.getCodeProduit().compareTo(ZERO) != 0) && (
      (saisieAntecedent.getCodeProduit().compareTo(Integer.valueOf(4)) == 0) || (saisieAntecedent.getCodeProduit().compareTo(Integer.valueOf(3)) == 0) || (saisieAntecedent.getCodeProduit().compareTo(Integer.valueOf(2)) == 0))) {
      spectacle = true;
    }
    verifierDonneesContexte(saisieAntecedent);
    
    verifierDonneesConstituants(saisieAntecedent, demande, spectacle);
    
    verifierDonneesReliquat(saisieAntecedent, demande, spectacle, dateTraitement);
    
    verifierDonneesAllongement(demande, spectacle);
    
    verifierDonneesConventionGestion(saisieAntecedent, demande);
  }
  
  private static void verifierDonneesContexte(SaisieAntecedent saisieAntecedent)
    throws CoucheLogiqueException
  {
    if ((saisieAntecedent.getCodeProduit() == null) || (saisieAntecedent.getCodeProduit().compareTo(ZERO) == 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_N_CALI_ANTECEDENT_OBLG_PRODUIT");
    }
    if ((saisieAntecedent.getContexteDemande() == null) || (saisieAntecedent.getContexteDemande().compareTo(ZERO) == 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_N_CALI_ANTECEDENT_OBLG_CONTEXTE");
    }
    if ((saisieAntecedent.getContexteDemande() != null) && (saisieAntecedent.getCodeProduit() != null) && (saisieAntecedent.getContexteDemande().compareTo(Integer.valueOf(3)) == 0) && (saisieAntecedent.getCodeProduit().compareTo(Integer.valueOf(1)) != 0) && (saisieAntecedent.getCodeProduit().compareTo(Integer.valueOf(9)) != 0) && (saisieAntecedent.getCodeProduit().compareTo(Integer.valueOf(5)) != 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_SP");
    }
    if ((saisieAntecedent.getContexteDemande() != null) && (saisieAntecedent.getCodeProduit() != null) && (saisieAntecedent.getContexteDemande().compareTo(Integer.valueOf(4)) == 0) && (saisieAntecedent.getCodeProduit().compareTo(Integer.valueOf(2)) != 0) && (saisieAntecedent.getCodeProduit().compareTo(Integer.valueOf(3)) != 0) && (saisieAntecedent.getCodeProduit().compareTo(Integer.valueOf(4)) != 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHERENCE_DROIT");
    }
    if ((saisieAntecedent.getContexteDemande() != null) && (saisieAntecedent.getCodeProduit() != null) && ((saisieAntecedent.getContexteDemande().compareTo(Integer.valueOf(5)) == 0) || (saisieAntecedent.getContexteDemande().compareTo(Integer.valueOf(6)) == 0) || (saisieAntecedent.getContexteDemande().compareTo(Integer.valueOf(9)) == 0)) && (saisieAntecedent.getCodeProduit().compareTo(Integer.valueOf(1)) != 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_SP_2");
    }
    if ((saisieAntecedent.getContexteDemande() != null) && (saisieAntecedent.getCodeProduit() != null) && (saisieAntecedent.getContexteDemande().compareTo(Integer.valueOf(9)) == 0) && (saisieAntecedent.getCodeProduit().compareTo(Integer.valueOf(1)) != 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_SP_3");
    }
    if ((saisieAntecedent.getContexteDemande() != null) && (saisieAntecedent.getCodeProduit() != null) && (saisieAntecedent.getContexteDemande().compareTo(Integer.valueOf(7)) == 0) && (saisieAntecedent.getCodeProduit().compareTo(Integer.valueOf(1)) != 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_MAINTIEN_EUROPEEN");
    }
  }
  
  private static void verifierDonneesConstituants(SaisieAntecedent saisieAntecedent, Demande demande, boolean spectacle)
    throws CoucheLogiqueException
  {
    ActiviteSalarie fctRetenue = (ActiviteSalarie)demande.getDemandeur().rechercherPeriodePasseProfessionnel(saisieAntecedent.getIdentifiantFCTRetenue());
    
    TravailSpec faitGenerateur = (TravailSpec)demande.getDemandeur().rechercherPeriodePasseProfessionnel(saisieAntecedent.getIdentifiantFaitGenerateur());
    
    ActiviteSalarie periodeCompetence = (ActiviteSalarie)demande.getDemandeur().rechercherPeriodePasseProfessionnel(saisieAntecedent.getIdentifiantCompetence());
    if (faitGenerateur == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_ANTECEDENT_FGD_INCONNUE");
    }
    if ((saisieAntecedent.getDateAttribution() == null) || (saisieAntecedent.getDateAttribution().coincideAvec(Damj.FIN_DES_TEMPS))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_N_CALI_ANTECEDENT_OBLG_DTE_ATTRIB");
    }
    if (saisieAntecedent.estAntecedentAsp())
    {
      ActiviteSalarie pasFgd = (ActiviteSalarie)faitGenerateur;
      if (!pasFgd.getCollectionOrigineInformationPAS().contains(Integer.valueOf(56))) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_ASP_FGD");
      }
      if (!saisieAntecedent.getIdentifiantFaitGenerateur().equalsIgnoreCase(saisieAntecedent.getIdentifiantFCTRetenue())) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_ASP_FCT_DIFFERENTE_FGD");
      }
    }
    else if (saisieAntecedent.getContexteDemande().intValue() != 4)
    {
      if (fctRetenue == null) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_ANTECEDENT_FCT_INCONNUE");
      }
      if ((saisieAntecedent.getIdentifiantCompetence() != null) && (periodeCompetence == null)) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_ANTECEDENT_FCT_COMPETENCE_INCONNUE");
      }
      if ((saisieAntecedent.getContexteDemande() != null) && ((saisieAntecedent.getContexteDemande().compareTo(Integer.valueOf(4)) == 0) || (saisieAntecedent.getContexteDemande().compareTo(Integer.valueOf(2)) == 0) || (saisieAntecedent.getContexteDemande().compareTo(Integer.valueOf(1)) == 0))) {
        if ((periodeCompetence != null) && (periodeCompetence.getChampApplication() == 3) && 
          (saisieAntecedent.getReliquatDuree() != null) && (saisieAntecedent.getReliquatDuree().getValeurEntiere() == 0)) {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_ASSURANCE_SP_EPUISE");
        }
      }
      if ((fctRetenue.getDateFin() != null) && (faitGenerateur.getDateFin() != null) && (fctRetenue.getDateFin().estApres(faitGenerateur.getDateFin()))) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_FCT");
      }
      if ((saisieAntecedent.getCodeProduit().intValue() == 1) || (saisieAntecedent.getCodeProduit().intValue() == 9) || (saisieAntecedent.getCodeProduit().intValue() == 5) || (saisieAntecedent.getCodeProduit().intValue() == 4) || (saisieAntecedent.estAntecedentAsp())) {
        if (saisieAntecedent.getDureeInitialeDroit() == null) {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_OBLG_DUREE_INIT");
        } else if (saisieAntecedent.getDureeInitialeDroit().getValeur().equals(BD_ZERO)) {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_DUREE_INITIALE");
        }
      }
      if ((!saisieAntecedent.isSortieCra()) && (saisieAntecedent.getDateAttribution() != null) && (saisieAntecedent.getDateAttribution().estAvant(fctRetenue.getDateFin()))) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_DTE_ATTRIB");
      }
      if ((fctRetenue.getCollectionOrigineInformationPAS().contains(Integer.valueOf(10))) && (saisieAntecedent.getTypeCoordinationEuropeenne() == 0)) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHERENCE_COORDINATION");
      }
      if (!spectacle) {
        verifierDonneesConstituantsCG(saisieAntecedent, fctRetenue, faitGenerateur, periodeCompetence);
      } else {
        verifierDonneesConstituantsSpectacle(saisieAntecedent, demande, fctRetenue);
      }
    }
    else
    {
      verifierDonneesConstituantsSpectacleParticulier(saisieAntecedent, demande);
      if ((faitGenerateur.getDateFin() != null) && (faitGenerateur.getDateFin().estAvant(DATE_MIN_FGD))) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_FGD");
      }
    }
  }
  
  private static void verifierDonneesConstituantsCG(SaisieAntecedent saisieAntecedent, ActiviteSalarie fctRetenue, TravailSpec faitGenerateur, PeriodeGaecSpec periodeCompetence)
    throws CoucheLogiqueException
  {
    if ((fctRetenue.getCategorieEmploiParticulier() != 38) && (saisieAntecedent.getSalaireJournalierReferencePlafonne() == null)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_OBLG_SJRP");
    }
    if ((fctRetenue.getCategorieEmploiParticulier() != 38) && ((saisieAntecedent.getTermePRC() == null) || (saisieAntecedent.getTermePRC().coincideAvec(Damj.FIN_DES_TEMPS)))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_OBLG_FIN_PRC");
    }
    if ((fctRetenue.getCategorieEmploiParticulier() != 38) && ((saisieAntecedent.getDateDebutPRC() == null) || (saisieAntecedent.getDateDebutPRC().coincideAvec(Damj.FIN_DES_TEMPS)))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_OBLG_DEBUT_PRC");
    }
    if ((saisieAntecedent.getDateDebutPRC() != null) && (saisieAntecedent.getTermePRC() != null) && (saisieAntecedent.getTermePRC().estAvant(saisieAntecedent.getDateDebutPRC()))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_CORH_PRC");
    }
    if ((periodeCompetence != null) && (faitGenerateur != null) && (periodeCompetence.getDateFin().estApres(faitGenerateur.getDateFin()))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_FCT_FINANCIERE");
    }
    if ((saisieAntecedent.getDateAttribution() != null) && (saisieAntecedent.getDateAttribution().estAvant(DATE_ATTRIB_ARE01))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_DTE_ATTRIB_CG");
    }
    if ((saisieAntecedent.getCoefficientTempsPartiel() != null) && ((saisieAntecedent.getCoefficientTempsPartiel().compareTo(BD_UN) > 0) || (saisieAntecedent.getCoefficientTempsPartiel().compareTo(BD_ZERO) <= 0))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_COEF_TP");
    }
    if ((saisieAntecedent.getCoefficientSaisonnier() != null) && ((saisieAntecedent.getCoefficientSaisonnier().compareTo(BD_UN) > 0) || (saisieAntecedent.getCoefficientSaisonnier().compareTo(BD_ZERO) <= 0))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_COEF_SAISONNIER");
    }
    if ((saisieAntecedent.getCoefficientSaisonnier() != null) && (saisieAntecedent.getCoefficientSaisonnier().compareTo(BD_UN) < 0) && ((saisieAntecedent.getTypeCaractereSaisonnier() == null) || (saisieAntecedent.getTypeCaractereSaisonnier().compareTo(ZERO) == 0))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_TYPE_SAISONNIER");
    }
    if ((saisieAntecedent.isA3ansActiviteEn5ans()) && ((saisieAntecedent.getTypeCaractereSaisonnier() == null) || (saisieAntecedent.getTypeCaractereSaisonnier().compareTo(Integer.valueOf(1)) != 0))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_ACTIVITE_3_ANS");
    }
    fctRetenue.getCategorieEmploiParticulier();
    if ((saisieAntecedent.getCodeEmploiA2B() != null) && (saisieAntecedent.getCodeEmploiA2B().compareTo(ZERO) != 0) && (fctRetenue.getCategorieEmploiParticulier() != 38)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_REGLEMENT_A2B_2");
    } else if (((saisieAntecedent.getCodeEmploiA2B() == null) || (saisieAntecedent.getCodeEmploiA2B().compareTo(ZERO) == 0)) && (fctRetenue.getCategorieEmploiParticulier() == 38)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_REGLEMENT_A2B");
    }
    if (((saisieAntecedent.getSalaireJournalierReferencePlafonne() != null) || ((saisieAntecedent.getTermePRC() != null) && (!saisieAntecedent.getTermePRC().coincideAvec(Damj.FIN_DES_TEMPS)))) && (fctRetenue.getCategorieEmploiParticulier() == 38)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_REGLEMENT_A2B_3");
    }
    if ((saisieAntecedent.getTermePRC() != null) && (saisieAntecedent.getDateAttribution() != null) && (saisieAntecedent.getTermePRC().estApresOuCoincideAvec(saisieAntecedent.getDateAttribution()))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_FIN_PRC_DATE_ATTRIB");
    }
    if (faitGenerateur.getDateFin().estAvant(DATE_FGD_MIN_ARE01)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_FGD_ARE01_CG");
    }
    if ((!saisieAntecedent.isEstSituationParticuliereAre2001()) && 
      (faitGenerateur.getDateFin().estApresOuCoincideAvec(DATE_FGD_MIN_ARE01)) && (faitGenerateur.getDateFin().estAvantOuCoincideAvec(DATE_FGD_MAX_ARE01))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHERENCE_FGD_ARE01");
    }
    if ((saisieAntecedent.isEstSituationParticuliereAre2001()) && 
      (faitGenerateur.getDateFin().estApres(DATE_FGD_MAX_ARE01))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTE_COHERENCE_FGD_ARE01_APRES");
    }
    if ((!"0".equals(saisieAntecedent.getMontantReadmissionRetenu())) && 
      (saisieAntecedent.getCodeProduit().intValue() != 1)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTE_COHERENCE_PRODUIT_COMPOSITE");
    }
  }
  
  private static void verifierDonneesConstituantsSpectacle(SaisieAntecedent saisieAntecedent, Demande demande, ActiviteSalarie fctRetenue)
    throws CoucheLogiqueException
  {
    if (saisieAntecedent.getCodeProduit().intValue() == 4)
    {
      if (saisieAntecedent.getRangAllongementPraSpectacle() != null) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_AFD");
      }
      if (saisieAntecedent.getSalaireReferenceInitialPlafonne() != null) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_AFD");
      }
      if (saisieAntecedent.getNbHeuresTravailPlafonne() != null) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_AFD");
      }
      if (saisieAntecedent.getNbHeuresTravailEtendu() != null) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_AFD");
      }
      if (saisieAntecedent.getNbJourContratSurPra() != null) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_AFD");
      }
      if (saisieAntecedent.isDelaiAttente()) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_AFD");
      }
    }
    else
    {
      if (saisieAntecedent.getRangAllongementPraSpectacle() == null) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_OBLG_RANG");
      }
      if (saisieAntecedent.getSalaireReferenceInitialPlafonne() == null) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_OBLG_SRIP");
      }
      if (saisieAntecedent.getNbHeuresTravailPlafonne() == null) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_OBLG_PRA_SJM");
      }
      if (saisieAntecedent.getNbHeuresTravailEtendu() == null) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_OBLG_PRA_MONTANT");
      }
      if ((saisieAntecedent.getNbHeuresTravailPlafonne() != null) && (saisieAntecedent.getNbHeuresTravailPlafonne().compareTo(BD_ZERO) == 0)) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_PRA_SJM");
      }
      if ((saisieAntecedent.getNbHeuresTravailEtendu() != null) && (saisieAntecedent.getNbHeuresTravailEtendu().compareTo(BD_ZERO) == 0)) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_PRA_MONTANT");
      }
      if (saisieAntecedent.getNbJourContratSurPra() == null) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_OBLG_JOURS_CONTRAT");
      }
    }
    if (saisieAntecedent.getNomReglementApplicable() == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_OBLG_REGLEMENT");
    }
    if (saisieAntecedent.getDateAttribution().estAvant(DATE_ATTRIB_SPE)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_DTE_ATTRIB_SPE");
    }
    if ((4 == saisieAntecedent.getCodeProduit().intValue()) && (saisieAntecedent.getDureeInitialeDroit() == null)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_OBLG_DUREE_INIT");
    }
    detecterBlocageDateLimiteNonSaisieSpectacle2016(fctRetenue.getDateFin(), saisieAntecedent.getDateLimite());
    detecterBlocageSaisieMontantCraSpectacle2016(saisieAntecedent.getMontantCra(), saisieAntecedent.isEntreeCra());
    detecterBlocageSaisieSjmSpectacle2016(saisieAntecedent.getSjmCra(), saisieAntecedent.isEntreeCra());
    detecterBlocageSaisieFCPMax(saisieAntecedent.getFranchiseCPMensuelle());
    detecterBlocageSaisieFSMax(saisieAntecedent.getFranchiseSalaireMensuelle());
    
    verifierDonneesConstituantsSpectacleParticulier(saisieAntecedent, demande);
  }
  
  protected static void detecterBlocageSaisieFSMax(int nombreFSsaisie)
    throws CoucheLogiqueException
  {
    if (nombreFSsaisie > 31) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_ANTECEDENT_NOMBRE_FS_MAX");
    }
  }
  
  protected static void detecterBlocageSaisieFCPMax(int nombreFCPsaisie)
    throws CoucheLogiqueException
  {
    if (nombreFCPsaisie > 3) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_ANTECEDENT_NOMBRE_FCP_MAX");
    }
  }
  
  protected static void detecterBlocageSaisieMontantCraSpectacle2016(QuantiteEuro quantiteCra, boolean estEntreeCra)
    throws CoucheLogiqueException
  {
    if ((estEntreeCra) && (quantiteCra == null)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_ANTECEDENT_MONTANT_CRA_SPE16");
    }
  }
  
  protected static void detecterBlocageSaisieSjmSpectacle2016(QuantiteEuro quantiteSjm, boolean estEntreeCra)
    throws CoucheLogiqueException
  {
    if ((estEntreeCra) && (quantiteSjm == null)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_ANTECEDENT_SJM_SPE16");
    }
  }
  
  protected static void detecterBlocageDateLimiteNonSaisieSpectacle2016(Damj dateFinFct, Damj dateLimiteForcee)
    throws CoucheLogiqueException
  {
    if ((dateFinFct.estApresOuCoincideAvec(GestionnaireDateApplication.getInstance().recupererDateApplication("Date d'application de la nouvelle convention Spectacle 2016"))) && (dateLimiteForcee == null)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_ANTECEDENT_DATE_LIMITE_SPE16");
    }
  }
  
  private static void verifierDonneesConstituantsSpectacleParticulier(SaisieAntecedent saisieAntecedent, Demande demande)
    throws CoucheLogiqueException
  {
    if ((4 == saisieAntecedent.getCodeProduit().intValue()) || (4 == saisieAntecedent.getCodeProduit().intValue()))
    {
      if (demande.getDemandeur().getDernierJourIndemnisableAreSpe() == null) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_DJI_ARE_SPE_OBLIGATOIRE");
      }
      if (demande.getDemandeur().getDernierJourIndemnisableAreSpe().estAvant(ProduitAsuSpe02P03.getInstance().getPeriodeValidite().getDebut())) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_DJI_ARE_ANTERIEUR");
      }
      if (demande.getDemandeur().getDernierJourIndemnisableAreSpe().estApresOuCoincideAvec(saisieAntecedent.getPremierJourIndemnisable())) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_DJI_ARE_SPE_SUPERIEUR_PJI");
      }
    }
  }
  
  private static void verifierDonneesReliquat(SaisieAntecedent saisieAntecedent, Demande demande, boolean estSpectacle, Damj dateTraitement)
    throws CoucheLogiqueException
  {
    if ((saisieAntecedent.getDateDernierJourCalcule() == null) || (saisieAntecedent.getDateDernierJourCalcule().equals(Damj.FIN_DES_TEMPS))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_N_CALI_ANTECEDENT_OBLG_DJC");
    }
    if ((saisieAntecedent.getDateDernierJourCalcule() != null) && (dateTraitement != null) && (saisieAntecedent.getDateDernierJourCalcule().estApres(dateTraitement))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_N_CALI_ANTECEDENT_DJC_POSTERIEUR_DATE_JOUR");
    }
    if ((saisieAntecedent.getContexteDemande().intValue() == 5) && (saisieAntecedent.getDateDernierJourCalcule() != null) && (!OutillagePEC.estContenueDansUnePecIndemnisable(demande.getDemandeur(), saisieAntecedent.getDateDernierJourCalcule().lendemain()))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_SP_DJC_HORS_PEC");
    }
    if ((!saisieAntecedent.estAntecedentAsp()) && ((saisieAntecedent.getPremierJourIndemnisable() == null) || (saisieAntecedent.getPremierJourIndemnisable().equals(Damj.FIN_DES_TEMPS)))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_OBLG_PJI");
    }
    ActiviteSalarie fctRetenue = (ActiviteSalarie)demande.getDemandeur().rechercherPeriodePasseProfessionnel(saisieAntecedent.getIdentifiantFCTRetenue());
    
    boolean estFctRetenueApresDateMepSpectacle = false;
    if (fctRetenue != null) {
      estFctRetenueApresDateMepSpectacle = (estSpectacle) && (fctRetenue.getDateFin().estApresOuCoincideAvec(GestionnaireDateApplication.getInstance().recupererDateApplication("Date d'application de la nouvelle convention Spectacle 2016")));
    }
    if ((!estFctRetenueApresDateMepSpectacle) && (saisieAntecedent.getReliquatDuree() == null) && ((saisieAntecedent.getReliquatJoursDelaiAttente() == null) || (saisieAntecedent.getReliquatJoursDelaiAttente().compareTo(ZERO) == 0)) && ((saisieAntecedent.getReliquatJoursICCP() == null) || (saisieAntecedent.getReliquatJoursICCP().compareTo(ZERO) == 0)) && ((saisieAntecedent.getReliquatJoursISLR() == null) || (saisieAntecedent.getReliquatJoursISLR().compareTo(ZERO) == 0))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_N_CALI_ANTECEDENT_OBLG_RELIQUAT_DUREE");
    }
    if ((saisieAntecedent.getDateDernierJourCalcule() != null) && (saisieAntecedent.getDateAttribution() != null) && (saisieAntecedent.getDateDernierJourCalcule().estAvant(saisieAntecedent.getDateAttribution()))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_N_CALI_ANTECEDENT_COHR_DJC");
    }
    if (saisieAntecedent.getCodeProduit().intValue() == 4)
    {
      if (saisieAntecedent.getDateFinPMC() != null) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_AFD");
      }
      if (saisieAntecedent.getReliquatJourDiffereStandard() != null) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_AFD");
      }
      if (saisieAntecedent.getReliquatJoursISLR() != null) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_AFD");
      }
      if (saisieAntecedent.getReliquatJoursDelaiAttente() != null) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_AFD");
      }
    }
    else if ((saisieAntecedent.getPremierJourIndemnisable() != null) && (saisieAntecedent.getDateDernierJourCalcule() != null) && (saisieAntecedent.getPremierJourIndemnisable().estApres(saisieAntecedent.getDateDernierJourCalcule())) && ((saisieAntecedent.getReliquatJoursDelaiAttente() == null) || (saisieAntecedent.getReliquatJoursDelaiAttente().compareTo(ZERO) == 0)) && ((saisieAntecedent.getReliquatJoursICCP() == null) || (saisieAntecedent.getReliquatJoursICCP().compareTo(ZERO) == 0)) && ((saisieAntecedent.getReliquatJourDiffereStandard() == null) || (saisieAntecedent.getReliquatJourDiffereStandard().compareTo(ZERO) == 0)) && ((saisieAntecedent.getReliquatJoursISLR() == null) || (saisieAntecedent.getReliquatJoursISLR().compareTo(ZERO) == 0)) && (saisieAntecedent.getDateFinPMC() == null))
    {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_PJI_DELAI");
    }
    if ((saisieAntecedent.getPremierJourIndemnisable() != null) && (saisieAntecedent.getDateDernierJourCalcule() != null) && (saisieAntecedent.getPremierJourIndemnisable().estAvant(saisieAntecedent.getDateDernierJourCalcule())) && (((saisieAntecedent.getReliquatJoursDelaiAttente() != null) && (saisieAntecedent.getReliquatJoursDelaiAttente().compareTo(ZERO) > 0)) || ((saisieAntecedent.getReliquatJoursICCP() != null) && (saisieAntecedent.getReliquatJoursICCP().compareTo(ZERO) > 0)) || ((saisieAntecedent.getReliquatJourDiffereStandard() != null) && (saisieAntecedent.getReliquatJourDiffereStandard().compareTo(ZERO) > 0)) || ((saisieAntecedent.getReliquatJoursISLR() != null) && (saisieAntecedent.getReliquatJoursISLR().compareTo(ZERO) > 0)) || (saisieAntecedent.getDateFinPMC() != null))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_PJI");
    }
    if ((saisieAntecedent.getNombreJourIndemniseARE() != null) && (saisieAntecedent.getDureeInitialeDroit() != null) && (saisieAntecedent.getDureeInitialeDroit().getValeur().compareTo(new BigDecimal(saisieAntecedent.getNombreJourIndemniseARE().intValue())) < 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_JOURS_ARE");
    }
    if ((saisieAntecedent.getNombreJourIndemniseAREF() != null) && (saisieAntecedent.getDureeInitialeDroit() != null) && (saisieAntecedent.getDureeInitialeDroit().getValeur().compareTo(new BigDecimal(saisieAntecedent.getNombreJourIndemniseAREF().intValue())) < 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_JOURS_AREF");
    }
    if ((saisieAntecedent.getPremierJourIndemnisable() != null) && (saisieAntecedent.getDateDernierJourCalcule() != null) && (saisieAntecedent.getPremierJourIndemnisable().estApres(saisieAntecedent.getDateDernierJourCalcule())) && (saisieAntecedent.getNombreJourIndemniseAREF() != null) && (saisieAntecedent.getNombreJourIndemniseAREF().compareTo(ZERO) > 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_JOURS_AREF_2");
    }
    if ((saisieAntecedent.getReliquatDuree() != null) && (saisieAntecedent.getDureeInitialeDroit() != null) && (saisieAntecedent.getReliquatDuree().compareTo(saisieAntecedent.getDureeInitialeDroit()) > 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_RELIQUAT_DUREE");
    }
    if ((saisieAntecedent.getDateFinPMC() != null) && (!saisieAntecedent.getDateFinPMC().coincideAvec(Damj.FIN_DES_TEMPS)) && (saisieAntecedent.getDateAttribution() != null) && (!saisieAntecedent.getDateAttribution().coincideAvec(Damj.FIN_DES_TEMPS)) && (saisieAntecedent.getDateFinPMC().estAvant(saisieAntecedent.getDateAttribution()))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_FIN_PMC");
    }
    if ((saisieAntecedent.getDateFinPMC() != null) && (!saisieAntecedent.getDateFinPMC().coincideAvec(Damj.FIN_DES_TEMPS)) && (saisieAntecedent.getDateDernierJourCalcule() != null) && (!saisieAntecedent.getDateDernierJourCalcule().coincideAvec(Damj.FIN_DES_TEMPS)) && (saisieAntecedent.getDateFinPMC().estAvantOuCoincideAvec(saisieAntecedent.getDateDernierJourCalcule()))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_FIN_PMC_DJC");
    }
    if ((saisieAntecedent.getReliquatJoursDelaiAttente() != null) && (saisieAntecedent.getReliquatJoursDelaiAttente().compareTo(MAX_DELAI_ATTENTE) > 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_DELAI_ATTENTE");
    }
    if ((saisieAntecedent.getReliquatJoursDelaiAttente() != null) && (saisieAntecedent.getReliquatJoursDelaiAttente().intValue() != 0) && (saisieAntecedent.getReliquatJoursDelaiAttente().compareTo(MAX_DELAI_ATTENTE) < 0) && (((saisieAntecedent.getReliquatJoursICCP() != null) && (saisieAntecedent.getReliquatJoursICCP().compareTo(ZERO) > 0)) || ((saisieAntecedent.getReliquatJoursISLR() != null) && (saisieAntecedent.getReliquatJoursISLR().compareTo(ZERO) > 0)))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTE_COHR_DELAI_ATTENTE_DELAIS");
    }
    if ((saisieAntecedent.isEstEnFormationAuDJC()) && ((saisieAntecedent.getNombreJourIndemniseAREF() == null) || (saisieAntecedent.getNombreJourIndemniseAREF().compareTo(ZERO) == 0))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_FORMATION_DJC");
    }
    if ((saisieAntecedent.getReliquatJoursDelaiAttente() != null) && (!saisieAntecedent.isDelaiAttente())) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_DELAI_ATTENTE_2");
    }
    if ((saisieAntecedent.isEstDroitMaintenu()) && (saisieAntecedent.getDateDernierJourCalcule() != null))
    {
      DureeCalendaire ageDateOuvertureDroit = demande.getDemandeur().getAgeALaDate(saisieAntecedent.getDateDernierJourCalcule());
      if (ageDateOuvertureDroit.getAnnees() < 60) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_AGE_MAINTENU");
      }
    }
    if (!estSpectacle) {
      verifierDonneesReliquatCG(saisieAntecedent);
    } else {
      verifierDonneesReliquatSpectacle(saisieAntecedent);
    }
  }
  
  private static void verifierDonneesReliquatSpectacle(SaisieAntecedent saisieAntecedent)
    throws CoucheLogiqueException
  {
    if (saisieAntecedent.getNombreMoisIndemnisationAssurance() == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_OBLG_MOIS_ASU");
    }
    if ((saisieAntecedent.getNombreMoisIndemnisationAssurance() != null) && (saisieAntecedent.getDureeInitialeDroit() != null) && (saisieAntecedent.getDureeInitialeDroit().getValeur().compareTo(new BigDecimal(saisieAntecedent.getNombreMoisIndemnisationAssurance().intValue())) < 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_MOIS_ASU");
    }
    if ((saisieAntecedent.getReliquatJoursISLR() != null) && (saisieAntecedent.getReliquatJoursISLR().compareTo(MAX_ISLR) > 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_SPECIFIQUE");
    }
  }
  
  private static void verifierDonneesReliquatCG(SaisieAntecedent saisieAntecedent)
    throws CoucheLogiqueException
  {
    if (saisieAntecedent.getCumulMoisActiviteReduite() == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_N_CALI_ANTECEDENT_OBLG_CUMUL_AR");
    }
    if ((saisieAntecedent.getReliquatJoursISLR() != null) && (saisieAntecedent.getReliquatJoursISLR().compareTo(MAX_ISLR) > 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_ISLR");
    }
    if ((saisieAntecedent.getReliquatDureeRenouvellement() != null) && (saisieAntecedent.getReliquatDureeRenouvellement().getValeur().compareTo(BD_182) > 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANT_COHR_RELIQUAT_DUREE_RNVL");
    }
  }
  
  public void verifierDonneesForceesPostLiquidation(Demande demande)
    throws CoucheLogiqueException
  {
    DossierAffectation dossierAffectation = (DossierAffectation)demande.getDossierAffectation();
    
    ProduitAsuSpec produit = (ProduitAsuSpec)dossierAffectation.getValidationProduit().getProduitValide();
    
    BigDecimal dureeMaximale = produit.determinerDureeMaximumPourProduit();
    SaisieAntecedent saisieAntecedent = demande.getSaisieAntecedent();
    if ((saisieAntecedent.getCodeProduit().intValue() == 1) && (saisieAntecedent.getDureeInitialeDroit().getValeur().compareTo(dureeMaximale) > 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_DUREE_INITIALE_CG");
    } else if ((saisieAntecedent.getCodeProduit().intValue() == 9) && (saisieAntecedent.getDureeInitialeDroit().getValeur().compareTo(dureeMaximale) > 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_DUREE_INITIALE_EX");
    } else if ((saisieAntecedent.getCodeProduit().intValue() == 5) && (saisieAntecedent.getDureeInitialeDroit().getValeur().compareTo(dureeMaximale) > 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_DUREE_INITIALE_CS");
    } else if ((saisieAntecedent.getCodeProduit().intValue() == 4) && (saisieAntecedent.getDureeInitialeDroit() != null) && (saisieAntecedent.getDureeInitialeDroit().getValeur().compareTo(dureeMaximale) > 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_DUREE_INITIALE_SP");
    } else if ((saisieAntecedent.getCodeProduit().intValue() == 12) && (saisieAntecedent.getDureeInitialeDroit() != null) && (saisieAntecedent.getDureeInitialeDroit().getValeur().compareTo(dureeMaximale) > 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_DUREE_INITIALE_ASP");
    }
    verifierDonneesForceesPensionInvaliditePostLiquidation(demande);
  }
  
  protected void verifierDonneesAllongement(Demande demande, boolean spectacle)
    throws CoucheLogiqueException
  {
    if (!spectacle)
    {
      SaisieAntecedent saisieAntecedent = demande.getSaisieAntecedent();
      if (saisieAntecedent.getDureeAllongementAREF() > BD_182.intValue()) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_DUREE_ALGT_AREF");
      }
      if ((saisieAntecedent.getDureeAllongementAREF() > ZERO.intValue()) && (saisieAntecedent.getDureeInitialeDroit() != null) && (saisieAntecedent.getDureeInitialeDroit().getValeur().compareTo(DUREE_DROIT_INITIAL_MAX) < 0)) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_ELIGIBLE_ALGT_AREF_DUREE");
      }
      IndividuSpec demandeur = demande.getDemandeur();
      String identifiantFaitGenerateur = saisieAntecedent.getIdentifiantFaitGenerateur();
      ActiviteSalarie periodeFaitGenerateur = (ActiviteSalarie)demandeur.rechercherPeriodePasseProfessionnel(identifiantFaitGenerateur);
      int ageDemandeur = demandeur.getAgeALaDate(periodeFaitGenerateur.getDateFin()).getAnnees();
      if ((ageDemandeur < 53) && (saisieAntecedent.getDureeAllongementAREF() > ZERO.intValue())) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_ELIGIBLE_ALGT_AREF_AGE", new Object[] { Integer.valueOf(53) });
      }
    }
  }
  
  public void verifierDonneesForceesPensionInvaliditePostLiquidation(Demande demande)
    throws CoucheLogiqueException
  {
    ProduitAsuSpec produit = (ProduitAsuSpec)demande.getDossierAffectation().getProduit();
    if (!produit.estProduitGerantPensionInvalidite(demande))
    {
      DonneesTemporaires donneesTemporaires = demande.getDonneesTemporaires();
      if ((donneesTemporaires.getListPensionInvalidite() != null) && (donneesTemporaires.getListPensionInvalidite().size() != 0)) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_N_PENSION_INVALIDITE_NON_GERE", 1);
      }
    }
  }
  
  private void verifierDonneesConventionGestion(SaisieAntecedent saisieAntecedent, Demande demande)
    throws CoucheLogiqueException
  {
    ConventionGestionSpec convention = null;
    if (((saisieAntecedent.getEtablissementFinanceur() != null) && (saisieAntecedent.getEtablissementFinanceur().length() > 0)) || ((saisieAntecedent.getCodeAffectation() != null) && (saisieAntecedent.getCodeAffectation().length() > 0))) {
      convention = OutilConventionGestion.getInstance().trouverConventionGestion(new ConteneurConventionGestion(saisieAntecedent.getEtablissementFinanceur(), saisieAntecedent.getCodeAffectation(), demande.getDateDepot(), demande.getCommentaire()));
    }
    if ((saisieAntecedent.getContexteDemande() != null) && (saisieAntecedent.getCodeProduit() != null) && ((saisieAntecedent.getContexteDemande().compareTo(Integer.valueOf(5)) == 0) || (saisieAntecedent.getContexteDemande().compareTo(Integer.valueOf(6)) == 0)))
    {
      if (saisieAntecedent.getCodeProduit().compareTo(Integer.valueOf(1)) != 0) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_SP_2");
      }
      if ((saisieAntecedent.getEtablissementFinanceur() == null) || (saisieAntecedent.getEtablissementFinanceur().length() == 0) || (saisieAntecedent.getCodeAffectation() == null) || (saisieAntecedent.getCodeAffectation().length() == 0)) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_OBLG_CONVENTION_GESTION");
      }
      if (convention == null) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_CONVENTION_GESTION");
      } else if ((convention.estIdExterneObligatoire()) && ((saisieAntecedent.getIdExterneEmployeurSp() == null) || (saisieAntecedent.getIdExterneEmployeurSp().equals("")))) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_OBLG_ID_EXTERNE");
      }
    }
    else if (((saisieAntecedent.getEtablissementFinanceur() != null) && (saisieAntecedent.getEtablissementFinanceur().length() > 0)) || ((saisieAntecedent.getCodeAffectation() != null) && (saisieAntecedent.getCodeAffectation().length() > 0)))
    {
      if (convention == null) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_OBLG_CONVENTION_GESTION");
      } else if ((convention.estIdExterneObligatoire()) && ((saisieAntecedent.getIdExterneEmployeurSp() == null) || (saisieAntecedent.getIdExterneEmployeurSp().equals("")))) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_OBLG_ID_EXTERNE");
      }
    }
    ActiviteSalarie fctRetenue = (ActiviteSalarie)demande.getDemandeur().rechercherPeriodePasseProfessionnel(saisieAntecedent.getIdentifiantFCTRetenue());
    
    TravailSpec faitGenerateur = (TravailSpec)demande.getDemandeur().rechercherPeriodePasseProfessionnel(saisieAntecedent.getIdentifiantFaitGenerateur());
    
    ActiviteSalarie periodeCompetence = (ActiviteSalarie)demande.getDemandeur().rechercherPeriodePasseProfessionnel(saisieAntecedent.getIdentifiantCompetence());
    
    AttributionAssuranceSpec attributionAssurancePrecedente = demande.rechercherOuvertureDroitPrecedenteDuMemeType();
    if (attributionAssurancePrecedente != null)
    {
      Damj fgdOdprecedente = attributionAssurancePrecedente.getFaitGenerateur().getDateFaitGenerateur();
      if (autoriseFaitGenerateurOdPrecedente(saisieAntecedent, demande, convention))
      {
        if ((faitGenerateur != null) && (faitGenerateur.getDateFin().estAvant(fgdOdprecedente))) {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_INCOHERENCE_CGPE_FAIT_GEN");
        }
      }
      else
      {
        if (faitGenerateur.getDateFin().estAvantOuCoincideAvec(fgdOdprecedente)) {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_INCOHERENCE_CGPE_FGD");
        }
        if (fctRetenue.getDateFin().estAvantOuCoincideAvec(fgdOdprecedente)) {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_INCOHERENCE_CGPE_FCT");
        }
        if ((periodeCompetence != null) && (periodeCompetence.getDateFin().estAvantOuCoincideAvec(fgdOdprecedente))) {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_INCOHERENCE_CGPE_FCT_COMP");
        }
      }
    }
  }
  
  private boolean autoriseFaitGenerateurOdPrecedente(SaisieAntecedent saisieAntecedent, Demande demande, ConventionGestionSpec convention)
  {
    boolean retour = false;
    if ((convention != null) && (("1401EPEAAR".equals(convention.getNumeroConventionGestion())) || ("1401EPEIRC".equals(convention.getNumeroConventionGestion())))) {
      retour = true;
    }
    if ((demande.getContexteDemande() != null) && ((OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "ADHVOLARE")) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "ARESJASPDC")))) {
      retour = true;
    }
    if (saisieAntecedent.getContexteDemande().compareTo(Integer.valueOf(9)) == 0) {
      retour = true;
    }
    return retour;
  }
}

/* Location:
 * Qualified Name:     VerificationDonneesSaisieAntecedent
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */