package fr.unedic.cali.asu.may17.p02.calcul;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.ari.calcul.FacadeCalculProduitPourLiquidationAriSpec;
import fr.unedic.cali.ari.dom.ElementBaseIndemnisationAriSpec;
import fr.unedic.cali.asu.calcul.outilsfonctionnels.RecuperationPensionInvaliditeAvantDate;
import fr.unedic.cali.asu.calcul.parcours.ResultatDeterminationEtatDroit;
import fr.unedic.cali.asu.cge01.calcul.FacadeCalculLignePourLiquidationImpl;
import fr.unedic.cali.asu.cge01.outilsfonctionnels.RevalorisationSalaire;
import fr.unedic.cali.asu.cge01.outilsfonctionnels.RevalorisationSalaireMayotte;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisationAREF;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.may17.p02.calcul.dom.FormuleMontantPremiereTranche;
import fr.unedic.cali.asu.may17.p02.calcul.dom.FormuleMontantPremiereTrancheF;
import fr.unedic.cali.asu.may17.p02.calcul.dom.FormuleMontantSecondeTranche;
import fr.unedic.cali.asu.may17.p02.calcul.dom.FormuleMontantSecondeTrancheF;
import fr.unedic.cali.asu.may17.p02.calcul.dom.FormuleMontantTroisiemeTranche;
import fr.unedic.cali.asu.may17.p02.calcul.dom.FormuleMontantTroisiemeTrancheF;
import fr.unedic.cali.asu.may17.p02.liquidation.dom.Admission;
import fr.unedic.cali.asu.may17.p03.calcul.dom.FormuleMontantAREM2016PremiereTranche;
import fr.unedic.cali.asu.may17.p03.calcul.dom.FormuleMontantAREM2016PremiereTrancheF;
import fr.unedic.cali.asu.may17.p03.calcul.dom.FormuleMontantAREM2016SecondeTranche;
import fr.unedic.cali.asu.may17.p03.calcul.dom.FormuleMontantAREM2016SecondeTrancheF;
import fr.unedic.cali.asu.parametres.ParametresIndemnisation;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculPeriodique;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculSpec;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.calcul.dom.periode.PeriodeAvantageVieillesse;
import fr.unedic.cali.calcul.outilsfonctionnels.RecuperationAvantageVieillesseAvantPJI;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.Competences;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.conteneurs.DonneesCalculMontant;
import fr.unedic.cali.dom.conteneurs.DonneesEntreesRecuperationMontant;
import fr.unedic.cali.outilsfonctionnels.AppelAvant;
import fr.unedic.cali.outilsfonctionnels.AppelCalcul;
import fr.unedic.cali.outilsfonctionnels.GestionnaireErreur;
import fr.unedic.cali.parcours.ResultatAvant;
import fr.unedic.cali.parcours.ResultatDeterminationEtatDroitProduit;
import fr.unedic.cali.parcours.ResultatExecutionCalcul;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public class FacadeCalculProduitPourLiquidationImpl
  extends FacadeCalculLignePourLiquidationImpl
  implements FacadeCalculProduitPourLiquidationAriSpec
{
  private static final int DIX = 10;
  
  public MontantBaseSpec determinerMontant(DonneesEntreesRecuperationMontant donneesEntreesRecuperationMontant, Competences competences)
    throws CoucheLogiqueException
  {
    FormuleMontantSpec fm = null;
    ConstituantsIndemnisation constituantsIndemnisation = initialiserConstituantsIndemnisation(donneesEntreesRecuperationMontant, competences);
    DonneesCalculMontant donneesCalculMontant = donneesEntreesRecuperationMontant.getDonneesCalculMontant();
    
    fm = donneesCalculMontant.getFormuleMontant();
    return fm.calculer(constituantsIndemnisation, donneesEntreesRecuperationMontant.getDateCalculMontant());
  }
  
  public MontantBaseSpec determinerMontant(DonneesEntreesRecuperationMontant donneesEntreesRecuperationMontant)
    throws CoucheLogiqueException
  {
    FormuleMontantSpec formuleMontant = null;
    ConstituantsIndemnisation constituantsIndemnisation = initialiserConstituantsIndemnisation(donneesEntreesRecuperationMontant);
    DonneesCalculMontant donneesCalculMontant = donneesEntreesRecuperationMontant.getDonneesCalculMontant();
    boolean estContexteFormation = donneesCalculMontant.isContexteFormation();
    if (donneesCalculMontant.getFormuleMontant() != null)
    {
      formuleMontant = donneesCalculMontant.getFormuleMontant();
      if (estContexteFormation) {
        formuleMontant = passerEnFMformation(formuleMontant);
      }
    }
    else if (estContexteFormation)
    {
      formuleMontant = getFormuleMontantEnFormation();
    }
    else
    {
      formuleMontant = getFormuleMontant();
    }
    return formuleMontant.calculer(constituantsIndemnisation, donneesEntreesRecuperationMontant.getDateCalculMontant());
  }
  
  protected ConstituantsIndemnisation initialiserConstituantsIndemnisation(DonneesEntreesRecuperationMontant donneesEntreesRecuperationMontant)
    throws CoucheLogiqueException
  {
    ConstituantsIndemnisation constituantIndemnisation = super.initialiserConstituantsIndemnisation(donneesEntreesRecuperationMontant);
    Sjr sjrRevalorise = RevalorisationSalaireMayotte.revaloriserSjrMayotte((Sjr)donneesEntreesRecuperationMontant.getDonneesCalculMontant().getSalaireJournalier(), donneesEntreesRecuperationMontant.getDateCalculMontant());
    
    ((ElementBaseIndemnisation)constituantIndemnisation.getElementBaseIndemnisationCourant()).setSjr(sjrRevalorise);
    return constituantIndemnisation;
  }
  
  private FormuleMontantSpec passerEnFMformation(FormuleMontantSpec formuleMontant)
  {
    FormuleMontantSpec fm = null;
    if ((formuleMontant instanceof FormuleMontantAREM2016PremiereTranche)) {
      fm = new FormuleMontantAREM2016PremiereTrancheF();
    } else if ((formuleMontant instanceof FormuleMontantAREM2016SecondeTranche)) {
      fm = new FormuleMontantAREM2016SecondeTrancheF();
    } else if ((formuleMontant instanceof FormuleMontantPremiereTranche)) {
      fm = new FormuleMontantPremiereTrancheF();
    } else if ((formuleMontant instanceof FormuleMontantSecondeTranche)) {
      fm = new FormuleMontantSecondeTrancheF();
    } else if ((formuleMontant instanceof FormuleMontantTroisiemeTranche)) {
      fm = new FormuleMontantTroisiemeTrancheF();
    }
    return fm;
  }
  
  public FormuleMontantSpec getFormuleMontant()
  {
    return new FormuleMontantAREM2016PremiereTranche();
  }
  
  public FormuleMontantSpec getFormuleMontantEnFormation()
  {
    return new FormuleMontantAREM2016PremiereTrancheF();
  }
  
  public Boolean determinerReliquatValide(AttributionSpec attribution, Damj dateRecherche)
    throws CoucheLogiqueException
  {
    return null;
  }
  
  protected ConstituantsIndemnisation initialiserConstituantsIndemnisation(DonneesEntreesRecuperationMontant donneesEntreesRecuperationMontant, Competences competences)
    throws CoucheLogiqueException
  {
    Damj dateCalcul = donneesEntreesRecuperationMontant.getDateCalculMontant();
    IndividuSpec individu = donneesEntreesRecuperationMontant.getIndividu();
    
    ConstituantsIndemnisation constituantsIndemnisation = new ConstituantsIndemnisation();
    ElementBaseIndemnisation elementBaseIndemnisationCourant = new ElementBaseIndemnisation();
    
    DonneesCalculMontant donneesCalculMontant = donneesEntreesRecuperationMontant.getDonneesCalculMontant();
    
    constituantsIndemnisation.setElementBaseIndemnisationCourant(elementBaseIndemnisationCourant);
    ParametresIndemnisation parametresIndemnisation = ParametresIndemnisation.getParametresIndemnisation();
    if (donneesCalculMontant.getSalaireJournalier() != null) {
      elementBaseIndemnisationCourant.setSalaireJournalier(donneesCalculMontant.getSalaireJournalier());
    }
    Sjr sjrRevalorise = RevalorisationSalaire.revaloriserSjr(elementBaseIndemnisationCourant.getSjr(), dateCalcul);
    elementBaseIndemnisationCourant.setSjr(sjrRevalorise);
    if (donneesCalculMontant.getCoefficientTempsPartiel() != null) {
      elementBaseIndemnisationCourant.setCoefficientTempsPartiel(donneesCalculMontant.getCoefficientTempsPartiel());
    } else {
      elementBaseIndemnisationCourant.setCoefficientTempsPartiel(new BigDecimal("1"));
    }
    PeriodeAvantageVieillesse periodeAvCourante = null;
    DureeCalendaire ageALaDate = null;
    if (individu != null)
    {
      elementBaseIndemnisationCourant.setMontantPensionInvaliditeADeduire(RecuperationPensionInvaliditeAvantDate.recuperationMontantPI(individu, dateCalcul));
      
      periodeAvCourante = RecuperationAvantageVieillesseAvantPJI.recupererPeriodeAvMayotteADate(individu, dateCalcul);
      ageALaDate = individu.getAgeALaDate(dateCalcul);
    }
    if (periodeAvCourante != null)
    {
      BigDecimal montantAV = periodeAvCourante.getQuantiteEuro().getValeur();
      
      elementBaseIndemnisationCourant.setDateEffetAV(dateCalcul);
      BigDecimal coeffAV = new BigDecimal("0.00");
      if ((sjrRevalorise != null) && (sjrRevalorise.getSalaire() != null) && (!sjrRevalorise.getSalaire().equals(new BigDecimal("0.00")))) {
        coeffAV = montantAV.divide(sjrRevalorise.getSalaire(), 10, 4);
      }
      elementBaseIndemnisationCourant.setCoefficientAvantageVieillesse(coeffAV);
      elementBaseIndemnisationCourant.setMontantAvantageVieillesse(montantAV);
    }
    BigDecimal tauxavantageVieillesse = parametresIndemnisation.getTauxAvantageViellesse(ageALaDate);
    if (tauxavantageVieillesse != null) {
      elementBaseIndemnisationCourant.setTauxAvantageVieillesse(tauxavantageVieillesse);
    }
    elementBaseIndemnisationCourant.setCoefficientSanctionReduction(new BigDecimal("1.00"));
    elementBaseIndemnisationCourant.setProduitMontantRetenu((ProduitAsuSpec)donneesCalculMontant.getProduit());
    if (donneesCalculMontant.isContexteFormation())
    {
      ElementBaseIndemnisationAREF ebiAREF = new ElementBaseIndemnisationAREF(elementBaseIndemnisationCourant);
      constituantsIndemnisation.setElementBaseIndemnisationCourant(ebiAREF);
    }
    return constituantsIndemnisation;
  }
  
  public ResultatExecutionCalcul executerCalculDeterminationEtatDroit(AttributionSpec attributionAEtudier, Damj dateEtude, boolean priseEnCompteGaec, boolean determinationApres)
    throws ApplicativeException
  {
    ResultatAvant resultatAvant = null;
    ResultatDeterminationEtatDroitProduit resultatPendant = null;
    ResultatExecutionCalcul resultatCalcul = new ResultatExecutionCalcul();
    
    Admission attribution = (Admission)attributionAEtudier;
    if ((attribution.getDemande() == null) || (attribution.getCalendrierExecutionCalcul() == null) || (attribution.getCalendrierExecutionCalcul().getEtatAuDJI() == null)) {
      try
      {
        resultatAvant = AppelAvant.executerCalculDeterminationEtatAvant(attribution, priseEnCompteGaec, dateEtude);
      }
      catch (CoucheLogiqueException cLE)
      {
        if (attribution.getDemande() == null) {
          throw cLE;
        }
      }
    }
    resultatCalcul.setResultatAvant(resultatAvant);
    if ((resultatAvant != null) && (resultatAvant.getEtat() == 9))
    {
      resultatPendant = new ResultatDeterminationEtatDroit();
      resultatPendant.setEtatAttribution(1);
      resultatPendant.setAttribution(attributionAEtudier);
    }
    else
    {
      resultatPendant = (ResultatDeterminationEtatDroit)AppelCalcul.executerCalculDeterminationEtatDroit(attribution, dateEtude);
    }
    resultatCalcul.setResultatPendant(resultatPendant);
    
    return resultatCalcul;
  }
  
  public MontantBaseSpec determinerMontant(IndividuSpec individu, ElementBaseIndemnisationAriSpec elementBaseIndemnisation, FormuleMontantSpec formuleMontant, Damj dateCalcul)
    throws CoucheLogiqueException
  {
    GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_PRODUIT_METHODE_NON_IMPLEMENTE");
    return null;
  }
  
  public MontantBaseSpec determinerMontant(AttributionSpec attribution, Damj dateCalcul)
    throws ApplicativeException
  {
    GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_PRODUIT_METHODE_NON_IMPLEMENTE");
    return null;
  }
  
  public Periode determinerPeriodeAvantSansCalendrier(AttributionSpec attribution)
    throws ApplicativeException
  {
    GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_PRODUIT_METHODE_NON_IMPLEMENTE");
    return null;
  }
  
  public Damj recupererDateFinDroitTheorique(AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_PRODUIT_METHODE_NON_IMPLEMENTE");
    return null;
  }
  
  public Damj recupererDateDrv(AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    CalendrierExecutionCalculPeriodique calPeriodique = (CalendrierExecutionCalculPeriodique)attribution.getCalendrierExecutionCalcul();
    return calPeriodique.getDateDrv();
  }
  
  public Damj recupererDateEpuisementDuree(AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_PRODUIT_METHODE_NON_IMPLEMENTE");
    return null;
  }
}

/* Location:
 * Qualified Name:     FacadeCalculProduitPourLiquidationImpl
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */