package fr.unedic.cali.asu.may17.p02.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.ari.dom.Demande;
import fr.unedic.cali.ari.dom.ElementDroit;
import fr.unedic.cali.ari.outilsfonctionnels.AppelCalculParLiquidationAri;
import fr.unedic.cali.ari.outilsfonctionnels.OutilElementDroit;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.liquidation.outilsfonctionnels.DeterminationMontant;
import fr.unedic.cali.asu.liquidation.outilsfonctionnels.OutilConstructionDonneesEntreesRecuperationMontant;
import fr.unedic.cali.asu.may17.p02.liquidation.dom.Admission;
import fr.unedic.cali.dom.ConteneurConventionGestion;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.cali.dom.affectation.ProduitAriSpec;
import fr.unedic.cali.dom.conteneurs.DonneesCalculMontant;
import fr.unedic.cali.dom.conteneurs.DonneesEntreesRecuperationMontant;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.cali.outilsfonctionnels.OutilConventionGestion;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import java.math.BigDecimal;
import java.util.Collection;

public class DeterminationConstituantsSupplementaires
  implements OutilFonctionnel
{
  public static String determinerAgeAuFaitGenerateur(Demande p_demande)
    throws CoucheLogiqueException
  {
    Admission admission = (Admission)p_demande.getDossierExamen();
    DureeCalendaire ageAuFaitGenerateur = null;
    Collection collectionElementDroit = admission.getCollectionElementsDroits();
    
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(collectionElementDroit, new String[] { "DATE_FAIT_GENERATEUR" });
    if ((eltDroit != null) && (eltDroit.getDate1Generique() != null)) {
      ageAuFaitGenerateur = p_demande.getDemandeur().getAgeALaDate(eltDroit.getDate1Generique());
    } else {
      return null;
    }
    String texteAgeFaitGenerateur = ageAuFaitGenerateur.getAnnees() + " ans et " + ageAuFaitGenerateur.getMois() + " mois ";
    return texteAgeFaitGenerateur;
  }
  
  public static MontantBaseSpec determinerMontantTranche(Demande p_demande, String p_codeFormuleMontantTranche)
    throws CoucheLogiqueException
  {
    Admission admission = (Admission)p_demande.getDossierExamen();
    ProduitAriSpec produit = (ProduitAriSpec)p_demande.getDossierAffectation().getProduit();
    MontantBaseSpec montant = null;
    
    OutilConstructionDonneesEntreesRecuperationMontant outil = new OutilConstructionDonneesEntreesRecuperationMontant();
    DonneesEntreesRecuperationMontant donneesEntrees = outil.creerDonneesEntreesRecuperationMontant((ElementBaseIndemnisation)admission.getElementBaseIndemnisation().copie());
    
    donneesEntrees.setDateCalculMontant(admission.getDateAttribution());
    donneesEntrees.getDonneesCalculMontant().setProduit(produit);
    donneesEntrees.setIndividu(p_demande.getDemandeur());
    donneesEntrees.getDonneesCalculMontant().setFormuleMontant(produit.getFormuleMontant(p_codeFormuleMontantTranche));
    
    montant = DeterminationMontant.determinerMontant(donneesEntrees);
    return montant;
  }
  
  public static QuantiteEuro determinerCapitalTranche(Demande p_demande, Quantite p_montant, String p_elementDureeTranche)
    throws CoucheLogiqueException
  {
    Admission admission = (Admission)p_demande.getDossierExamen();
    QuantiteEuro capital = new QuantiteEuro("0");
    Collection collectionElementDroit = admission.getCollectionElementsDroits();
    ElementDroit eltDroitDuree = null;
    
    eltDroitDuree = OutilElementDroit.rechercherElement(collectionElementDroit, new String[] { p_elementDureeTranche });
    if ((eltDroitDuree != null) && (eltDroitDuree.getQuantiteGenerique() != null) && (p_montant != null)) {
      capital = new QuantiteEuro(eltDroitDuree.getQuantiteGenerique().getValeur().multiply(p_montant.getValeur()));
    }
    return capital;
  }
  
  public static Damj determinerPJI(Demande p_demande)
    throws ApplicativeException
  {
    Admission admission = (Admission)p_demande.getDossierExamen();
    
    ResultatExecutionCalculSpec resultatCalcul = AppelCalculParLiquidationAri.executerCalculDeterminationEtatDroit(admission, null, false);
    
    return resultatCalcul.getPji();
  }
  
  public static ConventionGestionSpec determinerConventionGestion(Demande p_demande)
    throws ApplicativeException
  {
    String numeroConventionGestionPe = OutilCalculDonneesNonPersistantes.trouverNumeroConventionGestionPE(p_demande);
    String codeAffectation = OutilCalculDonneesNonPersistantes.trouverCodeAffectationConvention(p_demande);
    String commentaire = p_demande.getCommentaire();
    Damj dateDepot = p_demande.getDateDepot();
    ConventionGestionSpec conventionGestion = null;
    if ((numeroConventionGestionPe != null) && (!"".equals(numeroConventionGestionPe)) && (codeAffectation != null) && (!"".equals(codeAffectation))) {
      conventionGestion = OutilConventionGestion.getInstance().trouverConventionGestion(new ConteneurConventionGestion(numeroConventionGestionPe, codeAffectation, dateDepot, commentaire));
    }
    return conventionGestion;
  }
  
  public static String determinerCompetenceAdministrative()
    throws ApplicativeException
  {
    return Integer.toString(1);
  }
  
  public static String determinerCompetenceFinanciere(Demande p_demande)
    throws ApplicativeException
  {
    String numeroConventionGestionPe = OutilCalculDonneesNonPersistantes.trouverNumeroConventionGestionPE(p_demande);
    String numeroConventionUnedic = OutilCalculDonneesNonPersistantes.trouverNumeroConventionUnedic(p_demande);
    int competence = 1;
    if (((numeroConventionGestionPe != null) && (!"".equals(numeroConventionGestionPe))) || ((numeroConventionUnedic != null) && (!"".equals(numeroConventionUnedic)))) {
      competence = 2;
    }
    return Integer.toString(competence);
  }
}

/* Location:
 * Qualified Name:     DeterminationConstituantsSupplementaires
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */