package fr.unedic.cali.asu.may17.p02.liquidation.outilsfonctionnels;

import fr.unedic.cali.ari.dom.AttributionARISpec;
import fr.unedic.cali.ari.dom.Demande;
import fr.unedic.cali.ari.dom.ElementDroit;
import fr.unedic.cali.ari.outilsfonctionnels.OutilElementDroit;
import fr.unedic.cali.ari.outilsfonctionnels.OutilPiSurElementDroit;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.OutilDelaiReport;
import fr.unedic.cali.asu.may17.p02.calcul.dom.DureeIndemnisationPremiereTranche;
import fr.unedic.cali.asu.may17.p02.calcul.dom.DureeIndemnisationSecondeTranche;
import fr.unedic.cali.asu.may17.p02.calcul.dom.DureeIndemnisationTroisiemeTranche;
import fr.unedic.cali.autresdoms.cohab.dom.spec.PeriodePensionInvaliditeChaineeSpec;
import fr.unedic.cali.dom.ConventionGestion;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.cali.util.ObjetChronoPeriodeConcreteCarence;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.ObjetChronoPeriode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

public class OutilCalculDonneesNonPersistantes
  implements OutilFonctionnel
{
  private static final int NB_DECIMALES_ARRONDI = 2;
  private static final int VALEUR_PAR_DEFAUT = 0;
  
  public static Collection recupererCollectionElementDroit(Demande demande)
  {
    return ((AttributionARISpec)demande.getDossierExamen()).getCollectionElementsDroits();
  }
  
  public static String trouverElementDroitDeTypeString(Demande demande, String nomElement)
    throws CoucheLogiqueException
  {
    Collection collectionElementDroit = recupererCollectionElementDroit(demande);
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(collectionElementDroit, new String[] { nomElement });
    String elementDroit = "";
    if ((eltDroit != null) && (eltDroit.getStringGenerique() != null)) {
      elementDroit = eltDroit.getStringGenerique();
    }
    return elementDroit;
  }
  
  public static boolean trouverElementDroitDeTypeBoolean(Demande demande, String nomElement)
    throws CoucheLogiqueException
  {
    Collection collectionElementDroit = recupererCollectionElementDroit(demande);
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(collectionElementDroit, new String[] { nomElement });
    boolean retour = false;
    if (eltDroit != null) {
      retour = eltDroit.isBooleenGenerique();
    }
    return retour;
  }
  
  public static Damj trouverElementDroitDeTypeDamj(Demande demande, String nomElement)
    throws CoucheLogiqueException
  {
    Collection collectionElementDroit = recupererCollectionElementDroit(demande);
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(collectionElementDroit, new String[] { nomElement });
    Damj retour = null;
    if (eltDroit != null) {
      retour = eltDroit.getDate1Generique();
    }
    return retour;
  }
  
  public static int trouverElementDroitDeTypeInt(Demande demande, String nomElement)
    throws CoucheLogiqueException
  {
    Collection collectionElementDroit = recupererCollectionElementDroit(demande);
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(collectionElementDroit, new String[] { nomElement });
    int retour = 0;
    if ((eltDroit != null) && (eltDroit.getQuantiteGenerique() != null)) {
      retour = eltDroit.getQuantiteGenerique().getValeurEntiere();
    }
    return retour;
  }
  
  public static BigDecimal trouverElementDroitDeTypeBigDecimal(Demande demande, String nomElement, int nombreDecimalArrondi)
    throws CoucheLogiqueException
  {
    Collection collectionElementDroit = recupererCollectionElementDroit(demande);
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(collectionElementDroit, new String[] { nomElement });
    BigDecimal retour = new BigDecimal(0);
    if ((eltDroit != null) && (eltDroit.getQuantiteGenerique() != null))
    {
      BigDecimal elementDroit = eltDroit.getQuantiteGenerique().getValeur();
      retour = Mathematiques.arrondiASup(elementDroit, nombreDecimalArrondi);
    }
    return retour;
  }
  
  public static Damj trouverDateFinPMC(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeDamj(demande, "DATE_FIN_PMC");
  }
  
  public static Damj trouverDateFaitGenerateur(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeDamj(demande, "DATE_FAIT_GENERATEUR");
  }
  
  public static int trouverNbJoursICCP(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeInt(demande, "NB_JOURS_ICCP");
  }
  
  public static int trouverNbJoursISLR(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeInt(demande, "NB_JOURS_ISLR");
  }
  
  public static int trouverNbJoursDelaiAttente(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeInt(demande, "NB_JOURS_DELAI_ATTENTE");
  }
  
  public static Damj trouverPointDepartDelaisReport(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeDamj(demande, "POINT_DEPART_DELAIS_REPORT");
  }
  
  public static Damj trouverPjiTheorique(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeDamj(demande, "PJI");
  }
  
  public static List trouverListeCarences(Demande demande)
    throws CoucheLogiqueException
  {
    List listeCarences = new ArrayList();
    
    Damj pointDepart = trouverPointDepartDelaisReport(demande);
    Damj dateFinPMC = trouverDateFinPMC(demande);
    int nbICCP = trouverNbJoursICCP(demande);
    int nbISLR = trouverNbJoursISLR(demande);
    int nbDelaiAttente = trouverNbJoursDelaiAttente(demande);
    
    ObjetChronoPeriode origineReliquat = null;
    if (dateFinPMC != null) {
      origineReliquat = new ObjetChronoPeriodeConcreteCarence(dateFinPMC, dateFinPMC);
    } else if (pointDepart != null) {
      origineReliquat = new ObjetChronoPeriodeConcreteCarence(pointDepart.veille(), pointDepart.veille());
    }
    if (origineReliquat != null)
    {
      OutilDelaiReport.ajouterDelaiReportDansCollection(listeCarences, OutilDelaiReport.creerDelaiReport("ICCP", origineReliquat, new QuantiteJour(new BigDecimal(nbICCP))));
      
      OutilDelaiReport.ajouterDelaiReportDansCollection(listeCarences, OutilDelaiReport.creerDelaiReport("ISLR", origineReliquat, new QuantiteJour(new BigDecimal(nbISLR))));
      
      OutilDelaiReport.ajouterDelaiReportDansCollection(listeCarences, OutilDelaiReport.creerDelaiReport("Différé", origineReliquat, new QuantiteJour(new BigDecimal(nbDelaiAttente))));
    }
    return listeCarences;
  }
  
  public static BigDecimal trouverCoefficientTP(Demande demande)
    throws CoucheLogiqueException
  {
    Collection collectionElementDroit = recupererCollectionElementDroit(demande);
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(collectionElementDroit, new String[] { "COEFFICIENT_TEMPS_PARTIEL" });
    if (eltDroit != null)
    {
      BigDecimal coeffTP = eltDroit.getQuantiteGenerique().getValeur();
      return Mathematiques.arrondiASup(coeffTP, 2);
    }
    return new BigDecimal("1");
  }
  
  public static Damj trouverTermePRC(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeDamj(demande, "TERME_PRC");
  }
  
  public static BigDecimal trouverRevenuMensuelANSConservee(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeBigDecimal(demande, "REVENU_MENSUEL_ANS_CONSERVEE", 2);
  }
  
  public static boolean trouverTopContratsRemuneresBaseSmic(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeBoolean(demande, "TOP_SR_POURCENTAGE_SMIG");
  }
  
  public static BigDecimal trouverSJRInitial(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeBigDecimal(demande, "SJR_INITIAL", 2);
  }
  
  public static BigDecimal trouverSJCInitial(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeBigDecimal(demande, "SJC_INITIAL", 2);
  }
  
  public static BigDecimal trouverSJRRP(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeBigDecimal(demande, "SJR_RP", 2);
  }
  
  public static DureeCalendaire trouverAgeFaitGenerateur(Demande demande)
    throws CoucheLogiqueException
  {
    Collection collectionElementDroit = recupererCollectionElementDroit(demande);
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(collectionElementDroit, new String[] { "DATE_FAIT_GENERATEUR" });
    if ((eltDroit != null) && (eltDroit.getDate1Generique() != null)) {
      return demande.getDemandeur().getAgeALaDate(eltDroit.getDate1Generique());
    }
    return null;
  }
  
  public static List trouverListeDurees(Demande demande)
    throws CoucheLogiqueException
  {
    List listeDurees = new ArrayList();
    
    BigDecimal dureetranche1 = BigDecimal.ZERO;
    BigDecimal dureetranche2 = BigDecimal.ZERO;
    BigDecimal dureetranche3 = BigDecimal.ZERO;
    
    Collection collectionElementDroit = recupererCollectionElementDroit(demande);
    
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(collectionElementDroit, new String[] { "DUREE_TRANCHE1" });
    if ((eltDroit != null) && (eltDroit.getQuantiteGenerique() != null)) {
      dureetranche1 = eltDroit.getQuantiteGenerique().getValeur();
    }
    DureeIndemnisationPremiereTranche duree1 = new DureeIndemnisationPremiereTranche(dureetranche1.intValue());
    listeDurees.add(duree1);
    
    eltDroit = OutilElementDroit.rechercherElement(collectionElementDroit, new String[] { "DUREE_TRANCHE2" });
    if ((eltDroit != null) && (eltDroit.getQuantiteGenerique() != null)) {
      dureetranche2 = eltDroit.getQuantiteGenerique().getValeur();
    }
    DureeIndemnisationSecondeTranche duree2 = new DureeIndemnisationSecondeTranche(dureetranche2.intValue());
    listeDurees.add(duree2);
    
    eltDroit = OutilElementDroit.rechercherElement(collectionElementDroit, new String[] { "DUREE_TRANCHE3" });
    if ((eltDroit != null) && (eltDroit.getQuantiteGenerique() != null)) {
      dureetranche3 = eltDroit.getQuantiteGenerique().getValeur();
    }
    DureeIndemnisationTroisiemeTranche duree3 = new DureeIndemnisationTroisiemeTranche(dureetranche3.intValue());
    listeDurees.add(duree3);
    
    return listeDurees;
  }
  
  public static BigDecimal trouverDureeTranche1(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeBigDecimal(demande, "DUREE_TRANCHE1", 0);
  }
  
  public static BigDecimal trouverDureeTranche2(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeBigDecimal(demande, "DUREE_TRANCHE2", 0);
  }
  
  public static BigDecimal trouverDureeTranche3(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeBigDecimal(demande, "DUREE_TRANCHE3", 0);
  }
  
  public static BigDecimal trouverMontantTranche1(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeBigDecimal(demande, "MONTANT_TRANCHE1", 2);
  }
  
  public static BigDecimal trouverMontantTranche2(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeBigDecimal(demande, "MONTANT_TRANCHE2", 2);
  }
  
  public static BigDecimal trouverMontantTranche3(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeBigDecimal(demande, "MONTANT_TRANCHE3", 2);
  }
  
  public static BigDecimal trouverCapitalTranche1(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeBigDecimal(demande, "CAPITAL_TRANCHE1", 2);
  }
  
  public static BigDecimal trouverCapitalTranche2(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeBigDecimal(demande, "CAPITAL_TRANCHE2", 2);
  }
  
  public static BigDecimal trouverCapitalTranche3(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeBigDecimal(demande, "CAPITAL_TRANCHE3", 2);
  }
  
  public static BigDecimal trouverMontantCrcTranche1(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeBigDecimal(demande, "MONTANT_CRC_TRANCHE1", 2);
  }
  
  public static BigDecimal trouverMontantCrcTranche2(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeBigDecimal(demande, "MONTANT_CRC_TRANCHE2", 2);
  }
  
  public static BigDecimal trouverMontantCrcTranche3(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeBigDecimal(demande, "MONTANT_CRC_TRANCHE3", 2);
  }
  
  public static String trouverNumeroConventionGestionPE(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeString(demande, "NUMERO_CONVENTION_GESTION_PE");
  }
  
  public static String trouverCodeAffectationConvention(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeString(demande, "CODE_AFFECTATION");
  }
  
  public static String trouverNumeroConventionUnedic(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeString(demande, "NUMERO_CONVENTION_UNEDIC");
  }
  
  public static String trouverLibelleAffectationConvention(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeString(demande, "LIBELLE_AFFECTATION");
  }
  
  public static String trouverApplicationDesAides(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeString(demande, "APPLICATION_DES_AIDES");
  }
  
  public static boolean trouverEstAideAdr(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeBoolean(demande, "EST_AIDE_ADR");
  }
  
  public static boolean trouverEstAideAllocationDeces(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeBoolean(demande, "EST_AIDE_ALLOCATION_DECES");
  }
  
  public static boolean trouverEstAideArce(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeBoolean(demande, "EST_AIDE_ARCE");
  }
  
  public static boolean trouverEstAideCongeNonPaye(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeBoolean(demande, "EST_AIDE_CONGE_NON_PAYE");
  }
  
  public static boolean trouverEstAideFinDroit(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeBoolean(demande, "EST_AIDE_FIN_DROIT");
  }
  
  public static boolean trouverEstPrecompteCrc(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeBoolean(demande, "PRECOMPTE_CRC");
  }
  
  public static String trouverSignataireConvention(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeString(demande, "SIGNATAIRE_CONVENTION");
  }
  
  public static Damj trouverDebutValiditeConventionGestion(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeDamj(demande, "DEBUT_VALIDITE_CG");
  }
  
  public static Damj trouverFinValiditeConventionGestion(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeDamj(demande, "FIN_VALIDITE_CG");
  }
  
  public static boolean trouverEstIdExterneObligatoire(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeBoolean(demande, "EST_ID_EXTERNE_OBLIGATOIRE");
  }
  
  public static String trouverCompetenceAdministrative(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeString(demande, "COMPETENCE_ADMINISTRATIVE");
  }
  
  public static boolean trouverPresenceActiviteConservee(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeBoolean(demande, "PRESENCE_AC");
  }
  
  public static String trouverCompetenceFinanciere(Demande demande)
    throws CoucheLogiqueException
  {
    return trouverElementDroitDeTypeString(demande, "COMPETENCE_FINANCIERE");
  }
  
  public static ConventionGestionSpec creerConventionGestion(Demande demande)
    throws CoucheLogiqueException
  {
    ConventionGestionSpec conventionGestion = null;
    if (!"".equals(trouverNumeroConventionUnedic(demande))) {
      conventionGestion = new ConventionGestion(trouverNumeroConventionUnedic(demande), null, false, false, false, false, false, trouverSignataireConvention(demande), trouverEstPrecompteCrc(demande), null, null, null, false);
    } else if (!"".equals(trouverNumeroConventionGestionPE(demande))) {
      conventionGestion = new ConventionGestion(trouverNumeroConventionGestionPE(demande), trouverCodeAffectationConvention(demande), trouverEstAideArce(demande), trouverEstAideAdr(demande), trouverEstAideCongeNonPaye(demande), trouverEstAideFinDroit(demande), trouverEstAideAllocationDeces(demande), trouverSignataireConvention(demande), trouverEstPrecompteCrc(demande), trouverDebutValiditeConventionGestion(demande), trouverFinValiditeConventionGestion(demande), trouverLibelleAffectationConvention(demande), trouverEstIdExterneObligatoire(demande));
    }
    return conventionGestion;
  }
  
  public static BigDecimal trouverMontantMontantPensionInvaliditeADeduire(Demande demande)
    throws CoucheLogiqueException
  {
    Collection collectionElementDroit = recupererCollectionElementDroit(demande);
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(collectionElementDroit, new String[] { "PI_DEDUITE" });
    if ((eltDroit != null) && (eltDroit.getQuantiteGenerique() != null)) {
      return Mathematiques.arrondiASup(eltDroit.getQuantiteGenerique().getValeur(), 2);
    }
    return new BigDecimal(0);
  }
  
  public static BigDecimal trouverMontantAvantageVieillesse(Demande demande)
    throws CoucheLogiqueException
  {
    Collection collectionElementDroit = recupererCollectionElementDroit(demande);
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(collectionElementDroit, new String[] { "AVANTAGE_VIEILLESSE_DEDUIT" });
    if ((eltDroit != null) && (eltDroit.getQuantiteGenerique() != null)) {
      return Mathematiques.arrondiASup(eltDroit.getQuantiteGenerique().getValeur(), 2);
    }
    return new BigDecimal(0);
  }
  
  public static Collection<PeriodePensionInvaliditeChaineeSpec> trouverListePensionsInvalidite(Demande demande)
    throws CoucheLogiqueException
  {
    Collection collectionElementDroit = recupererCollectionElementDroit(demande);
    return OutilPiSurElementDroit.mapperConstituantsVersListePi(collectionElementDroit);
  }
}

/* Location:
 * Qualified Name:     OutilCalculDonneesNonPersistantes
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */