package fr.unedic.cali.asu.migration.graphes;

import fr.unedic.cali.affectation.parametres.AccesDecorReglementaire;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.migration.controles.ControleDelaisReportPji;
import fr.unedic.cali.asu.migration.recalcul.RecalculerCapitalDroitCourant;
import fr.unedic.cali.asu.migration.recalcul.RecalculerMontantBrutDroitCourant;
import fr.unedic.cali.asu.migration.recalcul.RecalculerPji;
import fr.unedic.cali.asu.produits.liquidation.dom.CarenceIccp;
import fr.unedic.cali.asu.produits.liquidation.dom.CarenceIslr;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionFaitGenerateur;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionCaractereSaisonnier;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionCoefficientSaisonnier;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionCoefficientTempsPartiel;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDateAttribution;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDelais;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionMontantsBruts;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionPointDepartIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionQuantiteAffiliation;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionReglementApplicable;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionSjc;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.Decision;
import fr.unedic.cali.asu.produits.liquidation.dom.Differe;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.Prc;
import fr.unedic.cali.asu.produits.liquidation.dom.PrcSjc;
import fr.unedic.cali.asu.produits.liquidation.dom.PrcSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.PreavisMesureConservatoireNonIndemnisable;
import fr.unedic.cali.asu.produits.liquidation.dom.Sjcip;
import fr.unedic.cali.asu.produits.liquidation.dom.SjrActiviteConservee;
import fr.unedic.cali.asu.produits.liquidation.dom.Sjrip;
import fr.unedic.cali.autresdoms.cohab.dom.CodesErreursMigration;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.PeriodeGaecSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.ConteneurAccesDecorReglementaire;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.Erreur;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.affectation.Parametres;
import fr.unedic.cali.dom.affectation.ProduitAsuAbstrait;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.cali.outilsfonctionnels.OutilConventionGestion;
import fr.unedic.cali.parcours.ContexteParcoursCali;
import fr.unedic.cali.util.ObjetChronoPeriodeConcreteCarence;
import fr.unedic.cohabitation.sigma.migration.dom.DecisionMigreeAsuV1;
import fr.unedic.cohabitation.sigma.migration.dom.DemandeMigreeAsuV1;
import fr.unedic.cohabitation.sigma.migration.dom.DemandeMigreeV1;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import org.apache.commons.lang.StringUtils;

public abstract class GrapheDecision
  extends GrapheAssurance
{
  private final String indexPeriodeGaec = "-0";
  
  protected Collection getListControle()
  {
    Collection listeControle = new ArrayList();
    
    listeControle.addAll(super.getListControle());
    listeControle.add(new ControleDelaisReportPji());
    
    return listeControle;
  }
  
  protected void alimenterDonnees(DemandeMigreeV1 demandeV1, DemandeSpec demande)
  {
    super.alimenterDonnees(demandeV1, demande);
    
    Decision decisionAsu = (Decision)demande.getDossierAffectation().getDossierExamen();
    
    DemandeMigreeAsuV1 demandeTemporaireSigma = (DemandeMigreeAsuV1)demandeV1;
    DecisionMigreeAsuV1 decisionTemporaireSigma = demandeTemporaireSigma.getDecision();
    
    alimenterValidationProduit(demandeTemporaireSigma, decisionAsu);
    
    alimenterDonneesSimples(decisionTemporaireSigma, decisionAsu);
    
    alimenterCompetences(decisionTemporaireSigma, decisionAsu);
    
    alimenterIdentifiant(decisionTemporaireSigma, decisionAsu);
    
    DossierExamen dossierExamen = (DossierExamen)demande.getDossierAffectation().getDossierExamen();
    
    alimenterCaps(decisionTemporaireSigma, dossierExamen);
    
    alimenterCeps(decisionTemporaireSigma, dossierExamen);
  }
  
  protected void alimenterDonneesForcage(DemandeMigreeV1 demandeV1, DemandeSpec demande)
  {
    super.alimenterDonneesForcage(demandeV1, demande);
    alimenterDonneesImposees(demandeV1, demande);
  }
  
  protected void alimenterDonneesImposees(DemandeMigreeV1 demandeV1, DemandeSpec demande)
  {
    DossierExamen dossierExamen = (DossierExamen)demande.getDossierAffectation().getDossierExamen();
    DecisionMigreeAsuV1 decisionAsu = ((DemandeMigreeAsuV1)demandeV1).getDecision();
    
    alimenterConstitutionDateAttribution(decisionAsu, dossierExamen);
    alimenterConstitutionDurees(decisionAsu, dossierExamen);
    alimenterConstitutionSjr(decisionAsu, dossierExamen);
    alimenterConstitutionSjc(decisionAsu, dossierExamen);
    alimenterConstitutionCoefficientSaisonnier(decisionAsu, dossierExamen);
    alimenterConstitutionCoefficientTempsPartiel(decisionAsu, dossierExamen);
    alimenterConstitutionCaractereSaisonnier(decisionAsu, dossierExamen);
    alimenterConstitutionDelaisReport(decisionAsu, dossierExamen);
  }
  
  protected Collection getListRecalcule()
  {
    Collection listeRecalcul = super.getListRecalcule();
    
    listeRecalcul.add(new RecalculerPji());
    listeRecalcul.add(new RecalculerMontantBrutDroitCourant());
    listeRecalcul.add(new RecalculerCapitalDroitCourant());
    
    return listeRecalcul;
  }
  
  protected DemandeSpec construireGraphe(DemandeMigreeV1 demandeV1)
  {
    DemandeSpec demande = super.construireGraphe(demandeV1);
    
    DemandeMigreeAsuV1 demandeTemporaireSigma = (DemandeMigreeAsuV1)demandeV1;
    
    Demande demandeAsu = (Demande)demande;
    
    demandeAsu.setDossierAffectation(creerDossierAffectation());
    
    int natureDecision = demandeTemporaireSigma.getDecision().getNatureDecision();
    
    demandeAsu.getDossierAffectation().setDossierExamen(creerDecision(natureDecision));
    
    DossierExamen dossierExamen = (DossierExamen)demandeAsu.getDossierAffectation().getDossierExamen();
    
    creerCaps(dossierExamen);
    
    creerCeps(dossierExamen);
    
    return demande;
  }
  
  public DemandeMigreeV1 lireDonnees(DemandeSpec demande)
  {
    DemandeMigreeAsuV1 demandeLue = (DemandeMigreeAsuV1)super.lireDonnees(demande);
    
    DecisionMigreeAsuV1 decisionLue = demandeLue.getDecision();
    
    Demande demandeAsu = (Demande)demande;
    Decision decision = (Decision)demandeAsu.getDossierAffectation().getDossierExamen();
    
    lireValidationProduit(decision, decisionLue);
    
    lireDecision(decision, decisionLue);
    
    lireDonneesSimples(decision, decisionLue);
    
    lireCompetences(decision, decisionLue);
    
    lireIdentifiant(decision, decisionLue);
    
    lireCaps(decision, decisionLue);
    
    lireCeps(decision, decisionLue);
    
    return demandeLue;
  }
  
  protected abstract DossierAffectation creerDossierAffectation();
  
  protected abstract Decision creerDecision(int paramInt);
  
  protected abstract void creerCaps(DossierExamen paramDossierExamen);
  
  protected abstract void creerCeps(DossierExamen paramDossierExamen);
  
  protected abstract void alimenterIdentifiant(DecisionMigreeAsuV1 paramDecisionMigreeAsuV1, Decision paramDecision);
  
  protected abstract void alimenterCaps(DecisionMigreeAsuV1 paramDecisionMigreeAsuV1, DossierExamen paramDossierExamen);
  
  protected abstract void alimenterCeps(DecisionMigreeAsuV1 paramDecisionMigreeAsuV1, DossierExamen paramDossierExamen);
  
  protected void alimenterValidationProduit(DemandeMigreeAsuV1 demandeTemporaireSource, Decision decision)
  {
    ValidationProduit validationProduit = ((DossierAffecte)decision.getDossierAffecte()).getValidationProduit();
    
    String idPeriodeValidation = demandeTemporaireSource.getDecision().getIdPeriodeValidation();
    if (idPeriodeValidation == null)
    {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_PERIO_VALID"));
    }
    else if (isPeriodeValidationProduitValide(idPeriodeValidation))
    {
      validationProduit.setIdentifiantPeriodeValidationProduit(idPeriodeValidation);
      
      ActiviteSalarie periodeValidation = validationProduit.getPeriodeValidationProduit();
      if (periodeValidation == null)
      {
        validationProduit.setIdentifiantPeriodeValidationProduit(idPeriodeValidation + "-0");
        
        periodeValidation = validationProduit.getPeriodeValidationProduit();
        if (periodeValidation == null) {
          getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_PERIO_VALID"));
        } else {
          validationProduit.setPeriodeValidationProduit(periodeValidation);
        }
      }
      else
      {
        validationProduit.setPeriodeValidationProduit(periodeValidation);
      }
    }
    else
    {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_PER_INVALIDE"));
    }
    ProduitSpec produit = Parametres.getProduit(demandeTemporaireSource.getCodeProduit());
    validationProduit.setProduitValide(produit);
    if ((demandeTemporaireSource.getDecision().getReglementApplicable() != null) || (produit.getReglement(demandeTemporaireSource.getDecision().getReglementApplicable()) != null)) {
      validationProduit.setReglementApplicable(produit.getReglement(demandeTemporaireSource.getDecision().getReglementApplicable()));
    } else {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_RA"));
    }
    if (validationProduit.getPeriodeValidationProduit() != null)
    {
      ConteneurAccesDecorReglementaire conteneur = new ConteneurAccesDecorReglementaire();
      conteneur.setDemande(decision.getDemande());
      conteneur.setDateRecherche(validationProduit.getPeriodeValidationProduit().getDateFin());
      try
      {
        ((DossierAffectation)decision.getDossierAffecte()).setDecorReglementaire(AccesDecorReglementaire.getInstance().getDecor(conteneur));
      }
      catch (CoucheLogiqueException ex) {}
    }
  }
  
  private boolean isPeriodeValidationProduitValide(String idPeriodeValidation)
  {
    Individu individuCourant = ContexteParcoursCali.getIndividuCourant();
    
    PeriodeGaecSpec periode = individuCourant.rechercherPeriodePasseProfessionnel(idPeriodeValidation);
    if (periode == null) {
      periode = individuCourant.rechercherPeriodePasseProfessionnel(idPeriodeValidation + "-0");
    }
    return periode instanceof ActiviteSalarie;
  }
  
  protected void alimenterDonneesSimples(DecisionMigreeAsuV1 decisionTemporaireSource, Decision decisionInstallee)
  {
    Damj dateDerniereValidation = decisionTemporaireSource.getDateDerniereValidation();
    if (dateDerniereValidation == null)
    {
      getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_DATE_VALID"));
    }
    else
    {
      decisionInstallee.getDemande().setDateDerniereValidation(dateDerniereValidation);
      
      decisionInstallee.setValidee(true);
    }
  }
  
  protected void alimenterCompetences(DecisionMigreeAsuV1 decisionTemporaireSource, Decision decisionInstallee)
  {
    CompetenceSpec competence = decisionInstallee.getCompetence();
    if (decisionTemporaireSource.getCompetenceAdministrative() == null) {
      getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_COMP_ADMIN"));
    } else {
      competence.setCompetenceAdministrative(decisionTemporaireSource.getCompetenceAdministrative().intValue());
    }
    if (decisionTemporaireSource.getCompetenceFinanciere() == null) {
      getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_COMP_FIN"));
    } else {
      competence.setCompetenceFinanciere(decisionTemporaireSource.getCompetenceFinanciere().intValue());
    }
    if (decisionTemporaireSource.getNumeroConventionGestionEmployeur() == null)
    {
      getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_NUM_G_EMPLOY"));
    }
    else
    {
      competence.setNumeroConventionGestion(decisionTemporaireSource.getNumeroConventionGestionEmployeur());
      if (StringUtils.isNotEmpty(decisionTemporaireSource.getNumeroConventionGestionEmployeur()))
      {
        competence.setSignataireConvention("1");
        ConventionGestionSpec conventionGestionOrigine = competence.getConventionGestion();
        
        boolean precompteCrc = true;
        if (conventionGestionOrigine != null) {
          if (OutilConventionGestion.estTypeConventionGestionEtSignataireUnedic("555", true, conventionGestionOrigine)) {
            precompteCrc = false;
          }
        }
        competence.setPrecompteCrc(precompteCrc);
      }
    }
    decisionInstallee.setCompetence(competence);
  }
  
  protected void alimenterConditionFaitGenerateur(DecisionMigreeAsuV1 decisionTemporaireSource, DossierExamen dossierExamen)
  {
    ConditionFaitGenerateur capaFg = (ConditionFaitGenerateur)dossierExamen.getFaitGenerateur();
    
    String idPeriodeFgd = decisionTemporaireSource.getIdPeriodeFgd();
    if (idPeriodeFgd == null)
    {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_ID_PERIO_FGD"));
    }
    else if (isPeriodeValidationProduitValide(idPeriodeFgd))
    {
      capaFg.setIdentifiantPeriodeFaitGenerateur(idPeriodeFgd);
      
      Individu individuCourant = ContexteParcoursCali.getIndividuCourant();
      
      ActiviteSalarie periodeFgd = (ActiviteSalarie)individuCourant.rechercherPeriodePasseProfessionnel(idPeriodeFgd);
      if (periodeFgd == null)
      {
        periodeFgd = (ActiviteSalarie)individuCourant.rechercherPeriodePasseProfessionnel(idPeriodeFgd + "-0");
        if (periodeFgd == null)
        {
          getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_PERIO_FGD"));
        }
        else
        {
          capaFg.setPeriodeFaitGenerateur(periodeFgd);
          
          ((DossierAffecte)dossierExamen.getDossierAffecte()).setSinistre(periodeFgd);
        }
      }
      else
      {
        capaFg.setPeriodeFaitGenerateur(periodeFgd);
        
        ((DossierAffecte)dossierExamen.getDossierAffecte()).setSinistre(periodeFgd);
      }
    }
    else
    {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_PER_FGD"));
    }
    capaFg.setEtatSatisfait(true);
  }
  
  protected void alimenterConditionFaitGenerateurFlagEstApprenti(DecisionMigreeAsuV1 p_decisionTemporaireSource, DossierExamen p_dossierExamen)
  {
    ConstitutionSjr constitutionSjr = p_dossierExamen.getConstitutionSjr();
    if (constitutionSjr != null)
    {
      Prc prcSjr = constitutionSjr.getSjrip().getPrc();
      
      prcSjr.setTopContratsDeTypeParticulier(p_decisionTemporaireSource.isEstApprenti());
    }
  }
  
  protected void alimenterConstitutionMontantsBruts(DecisionMigreeAsuV1 p_decisionTemporaireSource, DossierExamen p_dossierExamen)
  {
    ConstitutionMontantsBruts cepaMontantsBruts = p_dossierExamen.getConstitutionMontantsBruts();
    if (p_decisionTemporaireSource.getCapitalOdCourante() == null)
    {
      cepaMontantsBruts.setCapitalInitialBrut(new QuantiteEuro("0"));
      getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_CAPITAL_DC"));
    }
    else
    {
      cepaMontantsBruts.setCapitalInitialBrut(p_decisionTemporaireSource.getCapitalOdCourante());
    }
    if (p_decisionTemporaireSource.getMontantBrut() == null)
    {
      cepaMontantsBruts.setMontantJournalierBrut(new QuantiteEuro("0"));
      getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_MONTANT_BRUT"));
    }
    else
    {
      cepaMontantsBruts.setMontantJournalierBrut(p_decisionTemporaireSource.getMontantBrut());
    }
  }
  
  protected void alimenterConstitutionDurees(DecisionMigreeAsuV1 p_decisionTemporaireSource, DossierExamen p_dossierExamen)
  {
    ConstitutionDurees cepaDuree = p_dossierExamen.getConstitutionDurees();
    DureeIndemnisation dureeIndemnisation = cepaDuree.createDureeIndemnisation();
    if (p_decisionTemporaireSource.getDureeTheoriqueDroitCourant() != null) {
      dureeIndemnisation.setDureeTheorique(p_decisionTemporaireSource.getDureeTheoriqueDroitCourant());
    } else {
      getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_DUREE_THEOR"));
    }
    if (p_decisionTemporaireSource.getDureeEffectiveDroitCourant() != null) {
      dureeIndemnisation.setDureeEffective(p_decisionTemporaireSource.getDureeEffectiveDroitCourant());
    } else {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_DUREE_EFFECT"));
    }
  }
  
  protected void alimenterConstitutionSjr(DecisionMigreeAsuV1 p_decisionTemporaireSource, DossierExamen p_dossierExamen)
  {
    ConstitutionSjr cepaSjr = p_dossierExamen.getConstitutionSjr();
    if (p_decisionTemporaireSource.getMontantSjrInitialDroitCourant() == null) {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_MT_SJRI"));
    }
    if (p_decisionTemporaireSource.getMontantSjrrpDroitCourant() == null) {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_MT_SJRRP"));
    }
    if (p_decisionTemporaireSource.getDateDebutPrcSjrInitialDroitCourant() == null) {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_DEBUT_SJRI"));
    }
    if (p_decisionTemporaireSource.getDateFinPrcSjrInitialDroitCourant() == null) {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_FIN_SJRI"));
    }
    if (p_decisionTemporaireSource.getDiviseurSjrInitialCourant() == null) {
      getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_DIV_SJRI"));
    }
    if ((p_decisionTemporaireSource.getMontantSjrInitialDroitCourant() != null) && (p_decisionTemporaireSource.getDateDebutPrcSjrInitialDroitCourant() != null) && (p_decisionTemporaireSource.getDateFinPrcSjrInitialDroitCourant() != null) && (p_decisionTemporaireSource.getMontantSjrrpDroitCourant() != null))
    {
      PrcSjr prcSjr = new PrcSjr(new Periode(p_decisionTemporaireSource.getDateDebutPrcSjrInitialDroitCourant(), p_decisionTemporaireSource.getDateFinPrcSjrInitialDroitCourant()));
      
      Sjrip sjrip = cepaSjr.createSjrip();
      
      sjrip.setSjrInitial(p_decisionTemporaireSource.getMontantSjrInitialDroitCourant());
      sjrip.setDateEvenement(p_decisionTemporaireSource.getDateFinPrcSjrInitialDroitCourant());
      
      prcSjr.setDiviseur(p_decisionTemporaireSource.getDiviseurSjrInitialCourant());
      
      cepaSjr.setSjrrp(new Sjr(p_decisionTemporaireSource.getMontantSjrrpDroitCourant()));
      
      sjrip.setPrc(prcSjr);
      
      alimenterConditionFaitGenerateurFlagEstApprenti(p_decisionTemporaireSource, p_dossierExamen);
    }
  }
  
  protected void alimenterConstitutionSjc(DecisionMigreeAsuV1 p_decisionTemporaireSource, DossierExamen p_dossierExamen)
  {
    ConstitutionSjc cepaSjc = p_dossierExamen.getConstitutionSjc();
    if (p_decisionTemporaireSource.getMontantSjcInitialDroitCourant() == null) {
      getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_MONTANT_SJCI"));
    }
    if (p_decisionTemporaireSource.getDateSjcInitialDroitCourant() == null) {
      getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_DATE_SJCI"));
    }
    Sjcip sjcip = cepaSjc.createSjcip();
    if ((p_decisionTemporaireSource.getMontantSjcInitialDroitCourant() != null) && (p_decisionTemporaireSource.getDateSjcInitialDroitCourant() != null))
    {
      sjcip.setSjcInitial(p_decisionTemporaireSource.getMontantSjcInitialDroitCourant());
      sjcip.setDateEvenement(p_decisionTemporaireSource.getDateSjcInitialDroitCourant());
      if (p_dossierExamen.getConstitutionSjr().getSjrip() != null) {
        sjcip.setPlafond(p_dossierExamen.getConstitutionSjr().getSjrip().getPlafondSjr());
      }
    }
    else
    {
      sjcip.setSjcInitial(new QuantiteEuro("0"));
      if (p_dossierExamen.getConstitutionSjr().getSjrip() != null) {
        sjcip.setDateEvenement(p_dossierExamen.getConstitutionSjr().getSjrip().getDateEvenement());
      }
    }
    if (p_dossierExamen.getConstitutionSjr().getSjrip() != null) {
      sjcip.setPlafond(p_dossierExamen.getConstitutionSjr().getSjrip().getPlafondSjr());
    }
  }
  
  protected void alimenterListeActivitesConservees(DecisionMigreeAsuV1 p_decisionTemporaireSource, DossierExamen p_dossierExamen)
    throws CoucheLogiqueException
  {
    ConstitutionSjc cepaSjc = p_dossierExamen.getConstitutionSjc();
    Sjcip sjcip = cepaSjc.getSjcip();
    if ((sjcip.getSjcInitial() != null) && (sjcip.getSjcInitial().getValeur().compareTo(new BigDecimal("0")) != 0))
    {
      Chronologie chronoActivitesConservees = getChronoActivitesConservees(p_dossierExamen);
      Prc prcSjr = getPrcSjr(p_dossierExamen);
      Periode periodePrcSjc = new Periode(prcSjr.getDateDebut(), prcSjr.getDateFin());
      
      Iterator it = chronoActivitesConservees.iterer();
      SjrActiviteConservee sjrActiviteConservee = null;
      ActiviteSalarie activiteSalarie = null;
      PrcSjc prcSjcCourante = null;
      if (chronoActivitesConservees.estVide()) {
        getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_PERIODES_SJC"));
      } else {
        while (it.hasNext())
        {
          activiteSalarie = (ActiviteSalarie)it.next();
          
          sjrActiviteConservee = new SjrActiviteConservee(new QuantiteEuro("0"));
          prcSjcCourante = new PrcSjc(periodePrcSjc, activiteSalarie, null);
          sjrActiviteConservee.setPrc(prcSjcCourante);
          sjrActiviteConservee.setPeriodeActiviteConservee(activiteSalarie);
          if ((!sjrActiviteConservee.getPeriodeActiviteConservee().getDateFin().equals(Damj.FIN_DES_TEMPS)) && (activiteSalarie.estUneFct())) {
            sjrActiviteConservee.setTypeActiviteConservee("P");
          } else {
            sjrActiviteConservee.setTypeActiviteConservee("C");
          }
          sjcip.ajouterSjrActiviteConservee(sjrActiviteConservee);
          
          getListeErreurs().add(new Erreur(2, "LIQ_ASU_PERIODES_SJC", "Période AC du " + activiteSalarie.getDateDebut() + " au " + activiteSalarie.getDateFin()));
        }
      }
    }
  }
  
  protected abstract Chronologie getChronoActivitesConservees(DossierExamen paramDossierExamen)
    throws CoucheLogiqueException;
  
  protected abstract Prc getPrcSjr(DossierExamen paramDossierExamen);
  
  protected void reinitialiserCarences(ConstitutionDelais p_cepaDelaisReport)
  {
    p_cepaDelaisReport.clearCollectionCarences();
    
    p_cepaDelaisReport.setDebutCarenceDiffere(null);
    p_cepaDelaisReport.setTermeCarenceDiffere(null);
    p_cepaDelaisReport.setNbJoursCarenceDiffere(0);
    
    p_cepaDelaisReport.setDebutCarenceICCP(null);
    p_cepaDelaisReport.setTermeCarenceICCP(null);
    p_cepaDelaisReport.setNbJoursCarenceICCP(0);
    
    p_cepaDelaisReport.setDebutCarenceISLR(null);
    p_cepaDelaisReport.setTermeCarenceISLR(null);
    p_cepaDelaisReport.setNbJoursCarenceISLR(0);
    
    p_cepaDelaisReport.setDebutPMC(null);
    p_cepaDelaisReport.setTermePMC(null);
    p_cepaDelaisReport.setNbJoursPMC(0);
  }
  
  protected void alimenterConstitutionDelaisReport(DecisionMigreeAsuV1 p_decisionTemporaireSource, DossierExamen p_dossierExamen)
  {
    ConstitutionDelais cepaDelaisReport = p_dossierExamen.getConstitutionDelais();
    
    reinitialiserCarences(cepaDelaisReport);
    
    ObjetChronoPeriodeConcreteCarence periodeOrigine = recupererPeriodeOriginePourDelaisReport(p_decisionTemporaireSource);
    if ((p_decisionTemporaireSource.getNbJoursDiffere() != -1) && (p_decisionTemporaireSource.getDebutDiffere() != null) && (p_decisionTemporaireSource.getFinDiffere() != null))
    {
      Differe differe = new Differe();
      cepaDelaisReport.ajouterCarences(differe);
      differe.setQuantiteInitial(new QuantiteJour(String.valueOf(p_decisionTemporaireSource.getNbJoursDiffere())));
      cepaDelaisReport.setNbJoursCarenceDiffere(p_decisionTemporaireSource.getNbJoursDiffere());
      differe.setPeriodeApplicationCarence(new Periode(p_decisionTemporaireSource.getDebutDiffere(), p_decisionTemporaireSource.getFinDiffere()));
      cepaDelaisReport.setDebutCarenceDiffere(p_decisionTemporaireSource.getDebutDiffere());
      cepaDelaisReport.setTermeCarenceDiffere(p_decisionTemporaireSource.getFinDiffere());
    }
    else if ((p_decisionTemporaireSource.getNbJoursDiffere() != -1) || (p_decisionTemporaireSource.getDebutDiffere() != null) || (p_decisionTemporaireSource.getFinDiffere() != null))
    {
      if (p_decisionTemporaireSource.getNbJoursDiffere() == -1) {
        getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_NB_JRS_DIFF"));
      }
      if (p_decisionTemporaireSource.getDebutDiffere() == null) {
        getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_DEBUT_DIFF"));
      }
      if (p_decisionTemporaireSource.getFinDiffere() == null) {
        getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_FIN_DIFFERE"));
      }
    }
    if ((p_decisionTemporaireSource.getNbJoursCarenceICCP() != -1) && (p_decisionTemporaireSource.getDebutCarenceICCP() != null) && (p_decisionTemporaireSource.getFinCarenceICCP() != null))
    {
      CarenceIccp carenceIccp = new CarenceIccp();
      cepaDelaisReport.ajouterCarences(carenceIccp);
      cepaDelaisReport.setNbJoursCarenceICCP(p_decisionTemporaireSource.getNbJoursCarenceICCP());
      carenceIccp.setQuantiteInitial(new QuantiteJour(String.valueOf(p_decisionTemporaireSource.getNbJoursCarenceICCP())));
      carenceIccp.setPeriodeApplicationCarence(new Periode(p_decisionTemporaireSource.getDebutCarenceICCP(), p_decisionTemporaireSource.getFinCarenceICCP()));
      if (periodeOrigine != null)
      {
        carenceIccp.setDateFinPeriodeOrigine(periodeOrigine.getDateFin());
        carenceIccp.setOrigine(periodeOrigine);
      }
      cepaDelaisReport.setDebutCarenceICCP(p_decisionTemporaireSource.getDebutCarenceICCP());
      cepaDelaisReport.setTermeCarenceICCP(p_decisionTemporaireSource.getFinCarenceICCP());
    }
    else if ((p_decisionTemporaireSource.getNbJoursCarenceICCP() != -1) || (p_decisionTemporaireSource.getDebutCarenceICCP() != null) || (p_decisionTemporaireSource.getFinCarenceICCP() != null))
    {
      if (p_decisionTemporaireSource.getNbJoursCarenceICCP() == -1) {
        getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_NB_JRS_ICCP"));
      }
      if (p_decisionTemporaireSource.getDebutCarenceICCP() == null) {
        getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_DEBUT_ICCP"));
      }
      if (p_decisionTemporaireSource.getFinCarenceICCP() == null) {
        getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_FIN_ICCP"));
      }
    }
    if ((p_decisionTemporaireSource.getNbJoursCarenceISLR() != -1) && (p_decisionTemporaireSource.getDebutCarenceISLR() != null) && (p_decisionTemporaireSource.getFinCarenceISLR() != null))
    {
      CarenceIslr carenceIslr = new CarenceIslr();
      cepaDelaisReport.ajouterCarences(carenceIslr);
      cepaDelaisReport.setNbJoursCarenceISLR(p_decisionTemporaireSource.getNbJoursCarenceISLR());
      carenceIslr.setQuantiteInitial(new QuantiteJour(String.valueOf(p_decisionTemporaireSource.getNbJoursCarenceISLR())));
      carenceIslr.setPeriodeApplicationCarence(new Periode(p_decisionTemporaireSource.getDebutCarenceISLR(), p_decisionTemporaireSource.getFinCarenceISLR()));
      if (periodeOrigine != null)
      {
        carenceIslr.setDateFinPeriodeOrigine(periodeOrigine.getDateFin());
        carenceIslr.setOrigine(periodeOrigine);
      }
      cepaDelaisReport.setDebutCarenceISLR(p_decisionTemporaireSource.getDebutCarenceISLR());
      cepaDelaisReport.setTermeCarenceISLR(p_decisionTemporaireSource.getFinCarenceISLR());
    }
    else if ((p_decisionTemporaireSource.getNbJoursCarenceISLR() != -1) || (p_decisionTemporaireSource.getDebutCarenceISLR() != null) || (p_decisionTemporaireSource.getFinCarenceISLR() != null))
    {
      if (p_decisionTemporaireSource.getNbJoursCarenceISLR() == -1) {
        getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_NB_JRS_ISLR"));
      }
      if (p_decisionTemporaireSource.getDebutCarenceISLR() == null) {
        getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_DEBUT_ISLR"));
      }
      if (p_decisionTemporaireSource.getFinCarenceISLR() == null) {
        getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_FIN_ISLR"));
      }
    }
    if ((p_decisionTemporaireSource.getNbJoursCarencePMC() != -1) && (p_decisionTemporaireSource.getDebutCarencePMC() != null) && (p_decisionTemporaireSource.getFinCarencePMC() != null))
    {
      PreavisMesureConservatoireNonIndemnisable carencePmc = new PreavisMesureConservatoireNonIndemnisable();
      cepaDelaisReport.ajouterCarences(carencePmc);
      cepaDelaisReport.setNbJoursPMC(p_decisionTemporaireSource.getNbJoursCarencePMC());
      carencePmc.setQuantiteInitial(new QuantiteJour(String.valueOf(p_decisionTemporaireSource.getNbJoursCarencePMC())));
      carencePmc.setPeriodeApplicationCarence(new Periode(p_decisionTemporaireSource.getDebutCarencePMC(), p_decisionTemporaireSource.getFinCarencePMC()));
      if (periodeOrigine != null)
      {
        carencePmc.setDateFinPeriodeOrigine(periodeOrigine.getDateFin());
        carencePmc.setOrigine(periodeOrigine);
      }
      cepaDelaisReport.setDebutPMC(p_decisionTemporaireSource.getDebutCarencePMC());
      cepaDelaisReport.setTermePMC(p_decisionTemporaireSource.getFinCarencePMC());
    }
    else if ((p_decisionTemporaireSource.getNbJoursCarencePMC() != -1) || (p_decisionTemporaireSource.getDebutCarencePMC() != null) || (p_decisionTemporaireSource.getFinCarencePMC() != null))
    {
      if (p_decisionTemporaireSource.getNbJoursCarencePMC() == -1) {
        getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_NB_JOURS_PMC"));
      }
      if (p_decisionTemporaireSource.getDebutCarencePMC() == null) {
        getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_DEBUT_PMC"));
      }
      if (p_decisionTemporaireSource.getFinCarencePMC() == null) {
        getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_FIN_PMC"));
      }
    }
  }
  
  private ObjetChronoPeriodeConcreteCarence recupererPeriodeOriginePourDelaisReport(DecisionMigreeAsuV1 p_decisionTemporaireSource)
  {
    Damj dateDebutDelaisReport = Damj.FIN_DES_TEMPS;
    ObjetChronoPeriodeConcreteCarence periodeOrigine = null;
    if (p_decisionTemporaireSource.getDebutCarencePMC() != null) {
      dateDebutDelaisReport = Damj.min(dateDebutDelaisReport, p_decisionTemporaireSource.getDebutCarencePMC());
    }
    if (p_decisionTemporaireSource.getDebutCarenceICCP() != null) {
      dateDebutDelaisReport = Damj.min(dateDebutDelaisReport, p_decisionTemporaireSource.getDebutCarenceICCP());
    }
    if (p_decisionTemporaireSource.getDebutCarenceISLR() != null) {
      dateDebutDelaisReport = Damj.min(dateDebutDelaisReport, p_decisionTemporaireSource.getDebutCarenceISLR());
    }
    if (p_decisionTemporaireSource.getDebutDiffere() != null) {
      dateDebutDelaisReport = Damj.min(dateDebutDelaisReport, p_decisionTemporaireSource.getDebutDiffere());
    }
    if (!dateDebutDelaisReport.coincideAvec(Damj.FIN_DES_TEMPS))
    {
      dateDebutDelaisReport = dateDebutDelaisReport.veille();
      periodeOrigine = new ObjetChronoPeriodeConcreteCarence(dateDebutDelaisReport, dateDebutDelaisReport);
    }
    return periodeOrigine;
  }
  
  protected void alimenterConstitutionQuantiteAffiliation(DecisionMigreeAsuV1 p_decisionTemporaireSource, DossierExamen p_dossierExamen)
  {
    ConstitutionQuantiteAffiliation cepaAffiliation = p_dossierExamen.getConstitutionQuantiteAffiliation();
    if (p_decisionTemporaireSource.getArticle3() != null) {
      cepaAffiliation.setArticle3(p_decisionTemporaireSource.getArticle3());
    } else {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_ARTICLE3"));
    }
    if (p_decisionTemporaireSource.getQteAffiliation1() == null) {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_QTE_AFFI_1"));
    }
    if (p_decisionTemporaireSource.getUniteAffiliation1() == null) {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_UNITE_AFFI_1"));
    }
    if ((p_decisionTemporaireSource.getQteAffiliation1() != null) && (p_decisionTemporaireSource.getUniteAffiliation1() != null))
    {
      Unite uniteAffiliation1 = null;
      try
      {
        uniteAffiliation1 = Unite.getParCode(p_decisionTemporaireSource.getUniteAffiliation1());
      }
      catch (NullPointerException e) {}
      if (uniteAffiliation1 == null)
      {
        getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_UNITE_AFFI_1", p_decisionTemporaireSource.getUniteAffiliation1()));
      }
      else
      {
        cepaAffiliation.setQuantiteAffiliationAcquise(new Quantite(p_decisionTemporaireSource.getQteAffiliation1(), uniteAffiliation1));
        cepaAffiliation.setQuantiteAssimilationAcquise(new Quantite("0", uniteAffiliation1));
      }
    }
    if (p_decisionTemporaireSource.getQteAffiliation2() == null) {
      getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_QTE_AFFI_2"));
    }
    if (p_decisionTemporaireSource.getUniteAffiliation2() == null) {
      getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_UNITE_AFFI_2"));
    }
    if ((p_decisionTemporaireSource.getQteAffiliation2() != null) && (p_decisionTemporaireSource.getUniteAffiliation2() != null))
    {
      Unite uniteAffiliation2 = null;
      try
      {
        uniteAffiliation2 = Unite.getParCode(p_decisionTemporaireSource.getUniteAffiliation2());
      }
      catch (NullPointerException e) {}
      if (uniteAffiliation2 == null)
      {
        getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_UNITE_AFFI_2"));
      }
      else
      {
        cepaAffiliation.setQuantiteAffiliationAcquiseSecondaire(new Quantite(p_decisionTemporaireSource.getQteAffiliation2(), uniteAffiliation2));
        
        cepaAffiliation.setQuantiteAssimilationAcquiseSecondaire(new Quantite("0", uniteAffiliation2));
      }
    }
  }
  
  protected void alimenterConstitutionReglementApplicable(DecisionMigreeAsuV1 p_decisionTemporaireSource, DossierExamen p_dossierExamen)
  {
    ConstitutionReglementApplicable cepaReglementApplicable = (ConstitutionReglementApplicable)p_dossierExamen.getConstitutionReglementApplicable();
    ProduitAsuAbstrait produit = (ProduitAsuAbstrait)p_dossierExamen.getDossierAffecte().getProduit();
    if ((p_decisionTemporaireSource.getReglementApplicable() != null) || (produit.contientReglement(p_decisionTemporaireSource.getReglementApplicable()))) {
      cepaReglementApplicable.setReglement(produit.getReglement(p_decisionTemporaireSource.getReglementApplicable()));
    } else {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_RA"));
    }
  }
  
  protected void alimenterConstitutionDateAttribution(DecisionMigreeAsuV1 p_decisionTemporaireSource, DossierExamen p_dossierExamen)
  {
    ConstitutionDateAttribution cepaDateAttribution = p_dossierExamen.getConstitutionDateAttribution();
    if (p_decisionTemporaireSource.getDateAttribution() != null) {
      cepaDateAttribution.setDateAttribution(p_decisionTemporaireSource.getDateAttribution());
    } else {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_HG_DATE_ATTRIB"));
    }
  }
  
  protected void alimenterConstitutionPji(DecisionMigreeAsuV1 p_decisionTemporaireSource, DossierExamen p_dossierExamen)
  {
    ConstitutionPointDepartIndemnisation cepaPji = p_dossierExamen.getConstitutionPointDepartIndemnisation();
    if (p_decisionTemporaireSource.getPji() != null) {
      cepaPji.setPji(p_decisionTemporaireSource.getPji());
    } else {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_HG_PJI"));
    }
  }
  
  protected void alimenterConstitutionCaractereSaisonnier(DecisionMigreeAsuV1 p_decisionTemporaireSource, DossierExamen p_dossierExamen)
  {
    ConstitutionCaractereSaisonnier cepaCaractereSaisonnier = p_dossierExamen.getConstitutionCaractereSaisonnier();
    
    cepaCaractereSaisonnier.setTypeCaractereSaisonnierRetenu(p_decisionTemporaireSource.getTypeCaractereSaisonnier());
    switch (p_decisionTemporaireSource.getTypeCaractereSaisonnier())
    {
    case 0: 
      cepaCaractereSaisonnier.setCaractereSaisonnierRetenu(false);
      break;
    case 1: 
    case 2: 
      cepaCaractereSaisonnier.setCaractereSaisonnierRetenu(true);
      cepaCaractereSaisonnier.setActivite3Sur5(false);
      break;
    default: 
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_TYPE_CARAC_S"));
    }
    if ((p_decisionTemporaireSource.getDateDebutPrcSjrInitialDroitCourant() != null) && (p_decisionTemporaireSource.getDateFinPrcSjrInitialDroitCourant() != null))
    {
      Periode prs = new Periode(p_decisionTemporaireSource.getDateDebutPrcSjrInitialDroitCourant(), p_decisionTemporaireSource.getDateFinPrcSjrInitialDroitCourant());
      
      cepaCaractereSaisonnier.setPeriodeReferenceSaisonnier(prs);
    }
  }
  
  protected void alimenterConstitutionCoefficientSaisonnier(DecisionMigreeAsuV1 p_decisionTemporaireSource, DossierExamen p_dossierExamen)
  {
    ConstitutionCoefficientSaisonnier cepaCoefficientSaisonnier = p_dossierExamen.getConstitutionCoefficientSaisonnier();
    if (p_decisionTemporaireSource.getCoefCaractereSaisonnierDroitCourant() != null) {
      cepaCoefficientSaisonnier.setCoefficientSaisonnierRetenu(p_decisionTemporaireSource.getCoefCaractereSaisonnierDroitCourant());
    } else {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_COEF_SAIS"));
    }
  }
  
  protected void alimenterConstitutionCoefficientTempsPartiel(DecisionMigreeAsuV1 p_decisionTemporaireSource, DossierExamen p_dossierExamen)
  {
    ConstitutionCoefficientTempsPartiel cepaCoefficientTempsPartiel = p_dossierExamen.getConstitutionCoefficientTempsPartiel();
    if (p_decisionTemporaireSource.getCoefTempsPartielDroitCourant() != null) {
      cepaCoefficientTempsPartiel.setCoefficientTempsPartielRetenu(p_decisionTemporaireSource.getCoefTempsPartielDroitCourant());
    } else {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_COEF_TPS_P"));
    }
  }
  
  protected abstract void lireIdentifiant(Decision paramDecision, DecisionMigreeAsuV1 paramDecisionMigreeAsuV1);
  
  protected abstract void lireCaps(Decision paramDecision, DecisionMigreeAsuV1 paramDecisionMigreeAsuV1);
  
  protected abstract void lireCeps(Decision paramDecision, DecisionMigreeAsuV1 paramDecisionMigreeAsuV1);
  
  protected void lireDecision(Decision p_decision, DecisionMigreeAsuV1 p_decisionLue)
  {
    p_decisionLue.setNatureDecision(new BigDecimal(p_decision.getNatureDecision()));
  }
  
  protected void lireValidationProduit(Decision p_decision, DecisionMigreeAsuV1 p_decisionLue)
  {
    ValidationProduit validationProduit = ((DossierAffecte)p_decision.getDossierAffecte()).getValidationProduit();
    
    p_decisionLue.setIdPeriodeValidation(validationProduit.getIdentifiantPeriodeValidationProduit());
    p_decisionLue.setDateValidationProduit(validationProduit.getDateFinPeriode());
    
    p_decisionLue.setReglementApplicable(validationProduit.getReglementApplicable().getNomReglement());
    p_decisionLue.getDemandeMigree().setCodeProduit(validationProduit.getProduitValide().getNomUnique());
  }
  
  protected void lireDonneesSimples(Decision p_decision, DecisionMigreeAsuV1 p_decisionLue)
  {
    p_decisionLue.setDateDerniereValidation(p_decision.getDemande().getDateDerniereValidation());
  }
  
  protected void lireCompetences(Decision p_decision, DecisionMigreeAsuV1 p_decisionLue)
  {
    p_decisionLue.setCompetenceAdministrative(new BigDecimal(p_decision.getCompetence().getCompetenceAdministrative()));
    p_decisionLue.setCompetenceFinanciere(new BigDecimal(p_decision.getCompetence().getCompetenceFinanciere()));
  }
  
  protected void lireConditionFaitGenerateur(Decision p_decision, DecisionMigreeAsuV1 p_decisionLue)
  {
    ConditionFaitGenerateur conditionFg = (ConditionFaitGenerateur)p_decision.getConditionFaitGenerateur();
    
    p_decisionLue.setIdPeriodeFgd(conditionFg.getIdentifiantPeriodeFaitGenerateur());
    p_decisionLue.setDateFgd(conditionFg.getDateFaitGenerateur());
  }
  
  protected void lireConstitutionCaractereSaisonnier(Decision p_decision, DecisionMigreeAsuV1 p_decisionLue)
  {
    p_decisionLue.setTypeCaractereSaisonnier(new Integer(p_decision.getConstitutionCaractereSaisonnier().getTypeCaractereSaisonnierRetenu()).toString());
  }
  
  protected void lireConstitutionCoefficientSaisonnier(Decision p_decision, DecisionMigreeAsuV1 p_decisionLue)
  {
    p_decisionLue.setCoefCaractereSaisonnierDroitCourant(p_decision.getConstitutionCoefficientSaisonnier().getCoefficientSaisonnierRetenu());
  }
  
  protected void lireConstitutionCoefficientTempsPartiel(Decision p_decision, DecisionMigreeAsuV1 p_decisionLue)
  {
    p_decisionLue.setCoefTempsPartielDroitCourant(p_decision.getConstitutionCoefficientTempsPartiel().getCoefficientTempsPartielRetenu());
  }
  
  protected void lireConstitutionDateAttribution(Decision p_decision, DecisionMigreeAsuV1 p_decisionLue)
  {
    p_decisionLue.setDateAttribution(p_decision.getConstitutionDateAttribution().getDateAttribution());
  }
  
  protected void lireConstitutionDelaisReport(Decision decision, DecisionMigreeAsuV1 decisionLue)
  {
    ConstitutionDelais cepaDelaisReport = decision.getConstitutionDelais();
    
    decisionLue.setDebutDiffere(cepaDelaisReport.getDebutCarenceDiffere());
    decisionLue.setFinDiffere(cepaDelaisReport.getTermeCarenceDiffere());
    decisionLue.setNbJoursDiffere(new BigDecimal(cepaDelaisReport.getNbJoursCarenceDiffere()));
    
    decisionLue.setDebutCarenceICCP(cepaDelaisReport.getDebutCarenceICCP());
    decisionLue.setFinCarenceICCP(cepaDelaisReport.getTermeCarenceICCP());
    decisionLue.setNbJoursCarenceICCP(new BigDecimal(cepaDelaisReport.getNbJoursCarenceICCP()));
    
    decisionLue.setDebutCarenceISLR(cepaDelaisReport.getDebutCarenceISLR());
    decisionLue.setFinCarenceISLR(cepaDelaisReport.getTermeCarenceISLR());
    decisionLue.setNbJoursCarenceISLR(new BigDecimal(cepaDelaisReport.getNbJoursCarenceISLR()));
    
    decisionLue.setDebutCarencePMC(cepaDelaisReport.getDebutPMC());
    decisionLue.setFinCarencePMC(cepaDelaisReport.getTermePMC());
    decisionLue.setNbJoursCarencePMC(new BigDecimal(cepaDelaisReport.getNbJoursPMC()));
  }
  
  protected void lireConstitutionDurees(Decision decision, DecisionMigreeAsuV1 decisionLue)
  {
    if (decision.getConstitutionDurees().getDureeIndemnisation().getDureeTheorique() != null) {
      decisionLue.setDureeTheoriqueDroitCourant(decision.getConstitutionDurees().getDureeIndemnisation().getDureeTheorique().getValeur());
    }
    if (decision.getConstitutionDurees().getDureeIndemnisation().getDureeEffective() != null) {
      decisionLue.setDureeEffectiveDroitCourant(decision.getConstitutionDurees().getDureeIndemnisation().getDureeEffective().getValeur());
    }
  }
  
  protected void lireConstitutionMontantsBruts(Decision decision, DecisionMigreeAsuV1 decisionLue)
  {
    decisionLue.setMontantBrut(decision.getConstitutionMontantsBruts().getMontantJournalierBrut().getValeur());
    decisionLue.setCapitalOdCourante(decision.getConstitutionMontantsBruts().getCapitalInitialBrut().getValeur());
  }
  
  protected void lireConstitutionPji(Decision decision, DecisionMigreeAsuV1 decisionLue)
  {
    decisionLue.setPji(decision.getConstitutionPointDepartIndemnisation().getPji());
  }
  
  protected void lireConstitutionQuantiteAffiliation(Decision decision, DecisionMigreeAsuV1 decisionLue)
  {
    decisionLue.setArticle3(decision.getConstitutionQuantiteAffiliation().getArticle3());
    decisionLue.setQteAffiliation1(decision.getConstitutionQuantiteAffiliation().getQuantiteAffiliationAcquise().getValeur());
    decisionLue.setUniteAffiliation1(decision.getConstitutionQuantiteAffiliation().getQuantiteAffiliationAcquise().getUnite().getCode());
  }
  
  protected void lireConstitutionReglementApplicable(Decision decision, DecisionMigreeAsuV1 decisionLue)
  {
    decisionLue.setReglementApplicable(decision.getConstitutionReglementApplicable().getReglement().getNomReglement());
  }
  
  protected void lireConstitutionSjc(Decision decision, DecisionMigreeAsuV1 decisionLue)
  {
    ConstitutionSjc cepaSjc = decision.getConstitutionSjc();
    if (cepaSjc != null)
    {
      decisionLue.setMontantSjcInitialDroitCourant(cepaSjc.getSjcip().getSjcInitial().getValeur());
      
      decisionLue.setDateSjcInitialDroitCourant(cepaSjc.getSjcip().getDateEvenement());
    }
  }
  
  protected void lireConstitutionSjr(Decision decision, DecisionMigreeAsuV1 decisionLue)
  {
    Sjrip sjrip = decision.getConstitutionSjr().getSjrip();
    Sjr sjrrp = decision.getConstitutionSjr().getSjrrp();
    
    decisionLue.setMontantSjrInitialDroitCourant(sjrip.getSjrInitial().getValeur());
    
    decisionLue.setMontantSjrrpDroitCourant(sjrrp.getSalaire());
    
    decisionLue.setDateDebutPrcSjrInitialDroitCourant(sjrip.getPrc().getDateDebut());
    
    decisionLue.setDateFinPrcSjrInitialDroitCourant(sjrip.getPrc().getDateFin());
    
    decisionLue.setDiviseurSjrInitialCourant(sjrip.getPrc().getDiviseur());
    if (sjrip.getPrc() != null) {
      decisionLue.setEstApprenti(sjrip.getPrc().isTopContratsDeTypeParticulier());
    }
  }
  
  protected void alimenterTranches(DossierExamen p_dossierExamen) {}
}

/* Location:
 * Qualified Name:     GrapheDecision
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */