package fr.unedic.cali.asu.mnt.dom;

import fr.unedic.cali.asu.mnt.dom.gen.ConditionsAttributionAdmissionGen;
import fr.unedic.cali.dom.ElementDroitSpec;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

public class ConditionsAttributionAdmission
  extends ConditionsAttributionAdmissionGen
  implements ConditionsAttributionSpec
{
  private static final long serialVersionUID = 628305110779727501L;
  
  public ConditionsAttributionAdmission() {}
  
  public ConditionsAttributionAdmission(DomPCSpec p_pc)
  {
    super(p_pc);
  }
  
  public List getListeConditionsAttribution()
  {
    List listeConditions = new ArrayList();
    
    listeConditions.add(super.getConditionAge());
    listeConditions.add(super.getConditionNombreTrimestres());
    listeConditions.add(super.getConditionActivite());
    listeConditions.add(super.getConditionAppartenance());
    listeConditions.add(super.getConditionDureeIndemnisation());
    listeConditions.add(super.getConditionDecisionCP());
    
    return listeConditions;
  }
  
  public boolean estSatisfait()
  {
    boolean result = true;
    Iterator iter = getListeConditionsAttribution().iterator();
    do
    {
      ElementDroitSpec droit = (ElementDroitSpec)iter.next();
      if ((droit == null) || (!droit.estSatisfait())) {
        result = false;
      }
    } while ((iter.hasNext()) && (result));
    return result;
  }
  
  public void setConditionActivite(ConditionActiviteMaintien p_conditionActivite)
  {
    DomManager.supprimer(super.getConditionActivite(), p_conditionActivite);
    super.setConditionActivite(p_conditionActivite);
  }
  
  public void setConditionAge(ConditionAgeMaintien p_conditionAge)
  {
    DomManager.supprimer(super.getConditionAge(), p_conditionAge);
    super.setConditionAge(p_conditionAge);
  }
  
  public void setConditionAppartenance(ConditionAppartenanceMaintien p_conditionAppartenance)
  {
    DomManager.supprimer(super.getConditionAppartenance(), p_conditionAppartenance);
    super.setConditionAppartenance(p_conditionAppartenance);
  }
  
  public void setConditionDureeIndemnisation(ConditionDureeIndemnisationMaintien p_conditionDureeIndemnisation)
  {
    DomManager.supprimer(super.getConditionDureeIndemnisation(), p_conditionDureeIndemnisation);
    super.setConditionDureeIndemnisation(p_conditionDureeIndemnisation);
  }
  
  public void setConditionNombreTrimestres(ConditionNombreTrimestresMaintien p_conditionNombreTrimestres)
  {
    DomManager.supprimer(super.getConditionNombreTrimestres(), p_conditionNombreTrimestres);
    super.setConditionNombreTrimestres(p_conditionNombreTrimestres);
  }
  
  public void setConditionDecisionCP(ConditionDecisionCPMaintien p_conditionDecisonCP)
  {
    DomManager.supprimer(super.getConditionDecisionCP(), p_conditionDecisonCP);
    super.setConditionDecisionCP(p_conditionDecisonCP);
  }
  
  public void jdoPreDelete()
  {
    DomManager.supprimer(super.getConditionAge());
    DomManager.supprimer(super.getConditionNombreTrimestres());
    DomManager.supprimer(super.getConditionActivite());
    DomManager.supprimer(super.getConditionAppartenance());
    DomManager.supprimer(super.getConditionDureeIndemnisation());
    DomManager.supprimer(super.getConditionDecisionCP());
  }
  
  public void marquerGraphePersistant()
  {
    DomManager.persisterEnProfondeur(super.getConditionAge());
    DomManager.persisterEnProfondeur(super.getConditionNombreTrimestres());
    DomManager.persisterEnProfondeur(super.getConditionActivite());
    DomManager.persisterEnProfondeur(super.getConditionAppartenance());
    DomManager.persisterEnProfondeur(super.getConditionDureeIndemnisation());
    DomManager.persisterEnProfondeur(super.getConditionDecisionCP());
  }
  
  public ObjetMetierSpec copie()
  {
    ConditionsAttributionAdmission copie = new ConditionsAttributionAdmission();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    ConditionsAttributionAdmission copie = (ConditionsAttributionAdmission)p_copie;
    
    super.copieElements(copie);
    copie.setConditionAge(getConditionAge() != null ? (ConditionAgeMaintien)getConditionAge().copie() : null);
    copie.setConditionNombreTrimestres(getConditionNombreTrimestres() != null ? (ConditionNombreTrimestresMaintien)getConditionNombreTrimestres().copie() : null);
    copie.setConditionActivite(getConditionActivite() != null ? (ConditionActiviteMaintien)getConditionActivite().copie() : null);
    copie.setConditionAppartenance(getConditionAppartenance() != null ? (ConditionAppartenanceMaintien)getConditionAppartenance().copie() : null);
    copie.setConditionDureeIndemnisation(getConditionDureeIndemnisation() != null ? (ConditionDureeIndemnisationMaintien)getConditionDureeIndemnisation().copie() : null);
    copie.setConditionDecisionCP(getConditionDecisionCP() != null ? (ConditionDecisionCPMaintien)getConditionDecisionCP().copie() : null);
  }
}

/* Location:
 * Qualified Name:     ConditionsAttributionAdmission
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */