package fr.unedic.cali.asu.mnt.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.OdAssuranceSpec;
import fr.unedic.cali.asu.mnt.dom.DemandeMaintien;
import fr.unedic.cali.asu.mnt.dom.DureeDetectionMaintien;
import fr.unedic.cali.asu.mnt.dom.temps.ObjetChronoPeriodeDetection100TMaintien;
import fr.unedic.cali.asu.mnt.dom.temps.ObjetChronoPeriodeDetectionAgeMaintien;
import fr.unedic.cali.asu.mnt.dom.temps.ObjetChronoPeriodeMaintien;
import fr.unedic.cali.asu.outilsfonctionnels.OutilFinDroit;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsTrancheCalcul;
import fr.unedic.cali.asu.produits.liquidation.dom.TrancheExecutable;
import fr.unedic.cali.calcul.FacadeCalculProduitFactory;
import fr.unedic.cali.calcul.FacadeCalculProduitSpec;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculSpec;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.calcul.dom.EtatAuDji;
import fr.unedic.cali.calcul.dom.UniteTraitement;
import fr.unedic.cali.calcul.outilsfonctionnels.GestionSuivi;
import fr.unedic.cali.calcul.outilsfonctionnels.OutilGestionPoursuite;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.Prescription;
import fr.unedic.cali.dom.QuantiteDroit;
import fr.unedic.cali.dom.QuantiteIndemnisationSpec;
import fr.unedic.cali.dom.RepriseSpec;
import fr.unedic.cali.dom.RevisionSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.outilsfonctionnels.OutilDemande;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public abstract class DetectionMaintien
{
  public ObjetChronoPeriodeDetectionAgeMaintien genererEvenementAgeDetection(AttributionSpec p_attribution)
    throws CoucheLogiqueException
  {
    Damj dateDetectionAgeMaintienHorsPEC = null;
    Damj pjeNcp = OutilGestionPoursuite.getInstance().recupererPremierJourExecutableNcp(p_attribution);
    
    ProduitAsuSpec produitAMaintenir = (ProduitAsuSpec)((AttributionAssuranceSpec)p_attribution).getOuvertureDroitCapitalRetenu().getProduit();
    DureeCalendaire dateAgeMaintien = produitAMaintenir.getAgeMinimumObtentionMaintien(p_attribution.getDemande());
    Damj dateDetectionAgeMaintien = p_attribution.getDemande().getDemandeur().getDateNaissance().deplacerVersAvant(dateAgeMaintien);
    if (dateDetectionAgeMaintien.estAvant(pjeNcp))
    {
      dateDetectionAgeMaintienHorsPEC = dateDetectionAgeMaintien;
      dateDetectionAgeMaintien = pjeNcp;
    }
    return new ObjetChronoPeriodeDetectionAgeMaintien(dateDetectionAgeMaintien, dateDetectionAgeMaintienHorsPEC);
  }
  
  public DureeDetectionMaintien genererDureeDetection(AttributionSpec attribution, ConstituantsIndemnisation constituantsIndemnisation, Damj date, UniteTraitement ut)
  {
    Quantite dureeIndemnisationInitiale = null;
    Quantite dureeIndemnisationRestante = null;
    int dureeIndemnisee = 0;
    int dureeIndemnisationAttributionPrecedente = 0;
    DureeDetectionMaintien dureeDetectionMaintien = null;
    
    dureeIndemnisationInitiale = OutilsTrancheCalcul.recupererEBICalcul(constituantsIndemnisation).getDureeInitialeMaintien();
    
    boolean existeDejaDureeDetectionMaintien = false;
    
    Iterator iteratorQuantiteDroit = constituantsIndemnisation.getCollectionQuantiteDroit().iterator();
    while ((iteratorQuantiteDroit.hasNext()) && ((dureeIndemnisationRestante == null) || (!existeDejaDureeDetectionMaintien)))
    {
      QuantiteDroit quantiteDroit = (QuantiteDroit)iteratorQuantiteDroit.next();
      if (((quantiteDroit instanceof QuantiteIndemnisationSpec)) && (quantiteDroit.getEtat() == 1) && (dureeIndemnisationRestante == null))
      {
        dureeIndemnisationRestante = quantiteDroit.getQuantiteCourante();
        if (dureeIndemnisationRestante == null) {
          dureeIndemnisationRestante = quantiteDroit.getQuantiteInitial();
        }
      }
      else if (((quantiteDroit instanceof DureeDetectionMaintien)) && (quantiteDroit.getEtat() == 1))
      {
        existeDejaDureeDetectionMaintien = true;
      }
    }
    if ((dureeIndemnisationInitiale != null) && (dureeIndemnisationRestante != null) && (!existeDejaDureeDetectionMaintien))
    {
      dureeIndemnisee = dureeIndemnisationInitiale.getValeurEntiere() - dureeIndemnisationRestante.getValeurEntiere();
      
      ProduitAsuSpec produit = (ProduitAsuSpec)attribution.getProduit();
      
      boolean estAdmissionMere = false;
      
      AttributionAssuranceSpec attributionCourante = (AttributionAssuranceSpec)attribution;
      while ((dureeIndemnisee < produit.getNombreJoursIndemnisationNecessairesMaintien()) && (!estAdmissionMere)) {
        if (((attributionCourante instanceof RepriseSpec)) || (attributionCourante.getNatureDecision() == 11) || (attributionCourante.getNatureDecision() == 47) || (attributionCourante.getNatureDecision() == 48) || ((attributionCourante.getNatureDecision() == 26) && (!estCapitalRetenuCourant(attributionCourante))) || ((attributionCourante instanceof RevisionSpec)) || (OutilDemande.estUneDemandeFinDroit(attributionCourante.getDemande())))
        {
          if (OutilDemande.estUneDemandeFinDroit(attributionCourante.getDemande())) {
            attributionCourante = (AttributionAssuranceSpec)OutilFinDroit.rechercherAttributionCorrespondantePecedente(attributionCourante.getDemande());
          } else {
            attributionCourante = attributionCourante.getDemandeAssurance().rechercherAttributionPrecedenteDuMemeType();
          }
          if (attributionCourante != null)
          {
            if (!attributionCourante.getProduit().getNomUnique().equals("ASU_CVE13_01")) {
              if (!OutilsTrancheCalcul.estTrancheActive(attributionCourante))
              {
                dureeIndemnisationInitiale = attributionCourante.getDureeIndemnisationInitiale();
              }
              else
              {
                TrancheExecutable tranche = OutilsTrancheCalcul.recupererTrancheInitiale(attributionCourante);
                dureeIndemnisationInitiale = tranche.getDuree(1);
              }
            }
            if (OutilDemande.estUneDemandeFinDroit(attributionCourante.getDemande())) {
              dureeIndemnisationAttributionPrecedente = 0;
            } else if ((!attributionCourante.getProduit().getNomUnique().equals("ASU_CVA10_02")) && (attributionCourante.getCalendrierExecutionCalcul() != null) && (attributionCourante.getCalendrierExecutionCalcul().getEtatAuDJI() != null) && (attributionCourante.getCalendrierExecutionCalcul().getEtatAuDJI().getReliquatDureeIndemnisation() != null)) {
              dureeIndemnisationAttributionPrecedente = dureeIndemnisationInitiale.getValeurEntiere() - attributionCourante.getCalendrierExecutionCalcul().getEtatAuDJI().getReliquatDureeIndemnisation().getValeurEntiere();
            } else if (((attributionCourante.getProduit().getNomUnique().equals("ASU_CVE13_01")) || (attributionCourante.getProduit().getNomUnique().equals("ASU_CVA10_02"))) && (attributionCourante.getCalendrierExecutionCalcul() != null) && (attributionCourante.getCalendrierExecutionCalcul().getEtatAuDJI() != null)) {
              dureeIndemnisationAttributionPrecedente = attributionCourante.getCalendrierExecutionCalcul().getEtatAuDJI().getCumulJoursIndemnise();
            } else {
              dureeIndemnisationAttributionPrecedente = 0;
            }
            dureeIndemnisee += dureeIndemnisationAttributionPrecedente;
          }
          else
          {
            estAdmissionMere = true;
          }
        }
        else
        {
          estAdmissionMere = true;
        }
      }
      if (dureeIndemnisee < produit.getNombreJoursIndemnisationNecessairesMaintien())
      {
        dureeDetectionMaintien = new DureeDetectionMaintien(produit.getNombreJoursIndemnisationNecessairesMaintien() - dureeIndemnisee);
      }
      else
      {
        dureeDetectionMaintien = new DureeDetectionMaintien(0);
        dureeDetectionMaintien.epuiser();
        fr.unedic.cali.calcul.dom.EvenementFinQuantiteDroit evtFinQuantiteDroit = new fr.unedic.cali.asu.calcul.dom.EvenementFinQuantiteDroit(date.veille(), dureeDetectionMaintien);
        
        ut.ajouterEvenementFinQuantiteDroit(evtFinQuantiteDroit);
      }
    }
    return dureeDetectionMaintien;
  }
  
  public ObjetChronoPeriodeDetection100TMaintien genererEvenement100TDetection(AttributionSpec p_attribution)
    throws CoucheLogiqueException
  {
    Damj dateDetection100TMaintien = p_attribution.getDemande().getDemandeur().getDateCentTrimestres();
    Damj pjeNcp = OutilGestionPoursuite.getInstance().recupererPremierJourExecutableNcp(p_attribution);
    if (p_attribution.getDemande().getDemandeur().getDateCentTrimestres().estAvant(pjeNcp)) {
      dateDetection100TMaintien = pjeNcp;
    }
    return new ObjetChronoPeriodeDetection100TMaintien(dateDetection100TMaintien);
  }
  
  public ObjetChronoPeriodeMaintien genererEvenementMaintien(AttributionSpec p_attribution)
    throws CoucheLogiqueException
  {
    Damj dateMaintienHorsPEC = null;
    Damj dateMaintien = ((DemandeAssuranceSpec)p_attribution.getDemande()).getDemandeMaintien().getDateExamen();
    Damj pjeNcp = OutilGestionPoursuite.getInstance().recupererPremierJourExecutableNcp(p_attribution);
    if (dateMaintien.estAvant(pjeNcp))
    {
      dateMaintienHorsPEC = dateMaintien;
      dateMaintien = pjeNcp;
    }
    return new ObjetChronoPeriodeMaintien(dateMaintien, dateMaintienHorsPEC);
  }
  
  public void detecter(AttributionAssuranceSpec p_attribution, Damj p_date, boolean p_aEmettre, ConstituantsIndemnisation p_constituantsIndemnisation)
    throws ApplicativeException
  {
    FacadeCalculProduitSpec facadeCalculProduit = FacadeCalculProduitFactory.getInstance().getInstanceGestionnaireCalculProduit(p_attribution.getProduitExecution());
    
    GestionSuivi.enregistrerEnquetePbjcNcp(p_attribution, p_date, 25, 0, p_aEmettre, null, facadeCalculProduit, p_constituantsIndemnisation);
  }
  
  public boolean evaluerConditionNombreJoursIndemnisesNecessaireMaintien(AttributionSpec p_attribution, ConstituantsIndemnisation p_constituantsIndemnisation, Damj p_date, UniteTraitement p_ut)
  {
    boolean condition = false;
    
    DureeDetectionMaintien dureeDetectionMaintien = genererDureeDetection(p_attribution, p_constituantsIndemnisation, p_date, p_ut);
    if (dureeDetectionMaintien == null)
    {
      dureeDetectionMaintien = (DureeDetectionMaintien)p_constituantsIndemnisation.getDureeDetectionMaintien();
      if ((dureeDetectionMaintien != null) && (dureeDetectionMaintien.getQuantiteCourante() != null) && (dureeDetectionMaintien.getQuantiteCourante().getValeurEntiere() == 0) && (dureeDetectionMaintien.getEtat() == 2)) {
        condition = true;
      }
    }
    else if (dureeDetectionMaintien.getEtat() != 2)
    {
      List<DureeDetectionMaintien> listeDureeDetectionMaintien = new ArrayList();
      listeDureeDetectionMaintien.add(dureeDetectionMaintien);
      p_constituantsIndemnisation.ajouterQuantiteDroit(listeDureeDetectionMaintien, dureeDetectionMaintien);
      dureeDetectionMaintien.activer();
      condition = false;
    }
    else
    {
      condition = true;
    }
    return condition;
  }
  
  public boolean evaluerCondition100T(AttributionSpec p_attribution, Damj p_date)
  {
    boolean condition = false;
    if (p_attribution.getDemande().getDemandeur().getDateCentTrimestres().estAvantOuCoincideAvec(p_date)) {
      condition = true;
    }
    return condition;
  }
  
  public boolean evaluerConditionReliquat(ConstituantsIndemnisation p_constituantsIndemnisation)
  {
    boolean condition = false;
    Quantite dureeIndemnisationRestante = null;
    
    Iterator iteratorQuantiteDroit = p_constituantsIndemnisation.getCollectionQuantiteDroit().iterator();
    while ((iteratorQuantiteDroit.hasNext()) && (dureeIndemnisationRestante == null))
    {
      QuantiteDroit quantiteDroit = (QuantiteDroit)iteratorQuantiteDroit.next();
      if (((quantiteDroit instanceof QuantiteIndemnisationSpec)) && (quantiteDroit.getEtat() == 1))
      {
        dureeIndemnisationRestante = quantiteDroit.getQuantiteCourante();
        if ((dureeIndemnisationRestante != null) && (dureeIndemnisationRestante.getValeurEntiere() > 0)) {
          condition = true;
        }
      }
    }
    return condition;
  }
  
  public boolean estDate100TConnue(AttributionSpec p_attribution)
  {
    boolean dateConnue = false;
    if (p_attribution.getDemande().getDemandeur().getDateCentTrimestres() != null) {
      dateConnue = true;
    }
    return dateConnue;
  }
  
  public boolean controlerConditionsDetectionHorsAge(AttributionSpec p_attribution, ConstituantsIndemnisation p_constituantsIndemnisation, Damj p_dateDetection, UniteTraitement p_ut)
  {
    boolean conditions = false;
    if (evaluerConditionNombreJoursIndemnisesNecessaireMaintien((AttributionAssuranceSpec)p_attribution, p_constituantsIndemnisation, p_dateDetection, p_ut)) {
      if ((!estDate100TConnue((AttributionAssuranceSpec)p_attribution)) || ((estDate100TConnue((AttributionAssuranceSpec)p_attribution)) && (evaluerCondition100T((AttributionAssuranceSpec)p_attribution, p_dateDetection)))) {
        if (evaluerConditionReliquat(p_constituantsIndemnisation)) {
          conditions = true;
        }
      }
    }
    return conditions;
  }
  
  public void effectuerDetection(AttributionAssuranceSpec p_attribution, Damj p_date, ConstituantsIndemnisation p_constituantsIndemnisation)
    throws ApplicativeException
  {
    if ((((DemandeAssuranceSpec)p_attribution.getDemande()).getDemandeMaintien() != null) && ((((DemandeAssuranceSpec)p_attribution.getDemande()).getDemandeMaintien().getClassementAdministratif() instanceof Prescription)) && (!((Prescription)((DemandeAssuranceSpec)p_attribution.getDemande()).getDemandeMaintien().getClassementAdministratif()).isValidite()))
    {
      ((DemandeAssuranceSpec)p_attribution.getDemande()).getDemandeMaintien().getEvenementReferenceExamen().setDateEvenement(p_date);
      ((DemandeAssuranceSpec)p_attribution.getDemande()).getDemandeMaintien().getEvenementReferenceExamen().setDateDeclenchementExamen(p_date);
      
      detecter(p_attribution, p_date, false, p_constituantsIndemnisation);
    }
    else
    {
      detecter(p_attribution, p_date, true, p_constituantsIndemnisation);
    }
  }
  
  public boolean controlerConditionsDetectionHors100T(AttributionSpec p_attribution, ConstituantsIndemnisation p_constituantsIndemnisation, Damj p_dateDetection, UniteTraitement p_ut)
  {
    boolean conditions = false;
    if ((evaluerConditionNombreJoursIndemnisesNecessaireMaintien((AttributionAssuranceSpec)p_attribution, p_constituantsIndemnisation, p_dateDetection, p_ut)) && (evaluerConditionAge((AttributionAssuranceSpec)p_attribution, p_dateDetection)) && (evaluerConditionReliquat(p_constituantsIndemnisation))) {
      conditions = true;
    }
    return conditions;
  }
  
  public abstract boolean evaluerConditionAge(AttributionSpec paramAttributionSpec, Damj paramDamj);
  
  private boolean estCapitalRetenuCourant(AttributionAssuranceSpec attribution)
  {
    if (OutilsTrancheCalcul.estTrancheActive(attribution)) {
      return OutilsTrancheCalcul.recupererTrancheInitiale(attribution).isCapitalRetenuCourant();
    }
    return attribution.isCapitalRetenuCourant();
  }
}

/* Location:
 * Qualified Name:     DetectionMaintien
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */