package fr.unedic.cali.asu.mnt.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.mnt.dom.DemandeMaintien;
import fr.unedic.cali.asu.mnt.dom.DonneesForcees;
import fr.unedic.cali.asu.mnt.dom.EreDemandeMaintien;
import fr.unedic.cali.asu.mnt.dom.FormulaireMaintien;
import fr.unedic.cali.asu.outilsfonctionnels.RechercherDemandeMaintien;
import fr.unedic.cali.dom.ClassementAdministratif;
import fr.unedic.cali.dom.ClassementSansObjet;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.outilsfonctionnels.OutilFluxSigma;
import fr.unedic.cali.parcours.DomCreationDemandePrestation;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.cali.parcours.ResultatCreationDemandePrestation;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;

public class CreerDemandeMaintien
  extends ParcoursCali
{
  public Resultat demarrer(Contexte p_contexte)
    throws ApplicativeException
  {
    ResultatCreationDemandePrestation resultat = new ResultatCreationDemandePrestation();
    
    FormulaireMaintien formulaire = (FormulaireMaintien)((DomCreationDemandePrestation)p_contexte.getDonnees()).getFormulaire();
    
    DemandeMaintien demandeMaintien = new DemandeMaintien();
    
    EreDemandeMaintien ere = new EreDemandeMaintien();
    ere.setDateDeclenchementExamen(formulaire.getDateDepot());
    ere.setDateEvenement(formulaire.getDateDepot());
    demandeMaintien.setEvenementReferenceExamen(ere);
    
    demandeMaintien.setFormulaire(formulaire);
    
    DonneesForcees donneesForcee = new DonneesForcees();
    demandeMaintien.setDonneesForcees(donneesForcee);
    
    demandeMaintien.setDemandeur(getIndividu(p_contexte));
    
    DemandeAssuranceSpec demandeMaintenue = RechercherDemandeMaintien.rechercherDemandeMaintenu(demandeMaintien);
    
    ResultatExamenMaintien resultatLiquidation = null;
    if (demandeMaintenue == null) {
      resultatLiquidation = classerDemandeMaintienSo(demandeMaintien);
    } else {
      resultatLiquidation = liquider(demandeMaintien);
    }
    resultatLiquidation.getDemande().setValide(true);
    resultat.setDemande(resultatLiquidation.getDemande());
    
    return resultat;
  }
  
  public static ResultatExamenMaintien liquider(DemandeMaintien p_demande)
    throws ApplicativeException
  {
    ResultatExamenMaintien resultat = null;
    
    DomLiquidationMaintien domLiquidation = new DomLiquidationMaintien();
    domLiquidation.setIndividu(p_demande.getDemandeur());
    domLiquidation.setDemande(p_demande);
    domLiquidation.setTypeExamenMaintien(-2);
    domLiquidation.setContexteService(domLiquidation.getIndividu().getContexteService());
    domLiquidation.setTypeExamenMaintien(-2);
    
    Contexte contexte = new Contexte();
    contexte.setDonnees(domLiquidation);
    
    ParcoursExaminerMaintien parcours = new ParcoursExaminerMaintien();
    try
    {
      resultat = (ResultatExamenMaintien)parcours.effectuerParcours(contexte);
    }
    catch (CoucheLogiqueException ex)
    {
      resultat = classerDemandeMaintienSo(p_demande);
    }
    OutilFluxSigma.notifierSigmaPourDecisionAutomatique(p_demande);
    if ((resultat.getDemande() != null) && (resultat.getDemande().getClassementAdministratif() != null) && ("SO".equals(resultat.getDemande().getClassementAdministratif().getTypeClassement()))) {
      return resultat;
    }
    return resultat;
  }
  
  private static ResultatExamenMaintien classerDemandeMaintienSo(DemandeMaintien p_demande)
  {
    ResultatExamenMaintien resultat = new ResultatExamenMaintien(0);
    resultat.setDemande(p_demande);
    p_demande.annulerDecisions();
    p_demande.setClassementAdministratif(new ClassementSansObjet());
    return resultat;
  }
}

/* Location:
 * Qualified Name:     CreerDemandeMaintien
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */