package fr.unedic.cali.asu.occasionnel.outilsfonctionnels;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.PensionInvaliditeChainee;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.Sjc;
import fr.unedic.cali.asu.outilsfonctionnels.OutilTranchesExecutables;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.CarencePrefixeAFixer;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionMontantsBruts;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionProduitResultant;
import fr.unedic.cali.asu.produits.liquidation.dom.Duree;
import fr.unedic.cali.asu.produits.liquidation.dom.ElementChomageSansRupture;
import fr.unedic.cali.asu.produits.liquidation.dom.TrancheExecutable;
import fr.unedic.cali.dom.ElementComparaisonReexamen;
import fr.unedic.cali.dom.MaintienEuropeen;
import fr.unedic.cali.dom.OdSpec;
import fr.unedic.cali.dom.SalaireJournalierSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.cali.occasionnel.outilsfonctionnels.CriteresTraitementPopulation;
import fr.unedic.cali.occasionnel.outilsfonctionnels.ResultatTraitementPopulation;
import fr.unedic.cali.occasionnel.outilsfonctionnels.TraitementPopulationSpec;
import fr.unedic.cali.outilsfonctionnels.GestionnaireErreur;
import fr.unedic.cali.outilsfonctionnels.TracesBouchon;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.ApplicativeRuntimeException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public class TraitementControleDroitExecutable
  implements TraitementPopulationSpec
{
  public static final String LIB_ELT_CODE_EMPLOI_A2B = "Code emploi A2B";
  public static final String LIB_ELT_CODE_PRODUIT = "Code produit";
  public static final String LIB_ELT_CODE_PRODUIT_REGLEMENT = "Code produit réglement";
  public static final String LIB_ELT_COEF_SAIS = "Coefficient saisonnier";
  public static final String LIB_ELT_COEF_TP = "Coefficient temps partiel";
  public static final String LIB_ELT_LISTE_DELAIS_REPORT = "liste delais report";
  public static final String LIB_ELT_SJI = "Salaire journalier initial";
  public static final String LIB_ELT_SJC = "Salaire journalier conservé";
  public static final String LIB_ELT_DATE_SJC = "Date salaire journalier conservé";
  public static final String LIB_ELT_DATE_SJI = "Date salaire journalier";
  public static final String LIB_ELT_DATE_LIMITE_INDEMNISATION = "Date limite d'indemnisation";
  public static final String LIB_ELT_DATE_DEBUT_MAINTIEN_EUROPEEN = "Date début maintien europeen";
  public static final String LIB_ELT_DATE_ATTRIBUTION = "Date attribution";
  public static final String LIB_ELT_COMPETENCE_FINANCIERE = "Compétence financière";
  public static final String LIB_ELT_COMPETENCE_ADMINISTRATIVE = "Compétence administrative";
  public static final String LIB_ELT_DUREE_MAINTIEN_EUROPEEN = "Durée maintien europeen";
  public static final String LIB_ELT_NUM_CG = "Etablissement financeur convention gestion";
  public static final String LIB_ELT_ID_FG = "Id fait générateur";
  public static final String LIB_ELT_MONTANT_PREAVIS = "Montant préavis";
  public static final String LIB_ELT_MONTANT_SALAIRE_JOURNIER = "Montant salaire journalier initial";
  public static final String LIB_ELT_MONTANT_SALAIRE_JOURNIER_CONSERVE = "Montant SJC";
  public static final String LIB_ELT_CODE_AFFECTATION = "Code affectation CG";
  public static final String LIB_ELT_NATURE_COEF_SAIS = "Nature Coef sais";
  public static final String LIB_ELT_NATURE_DECISION = "Nature décision";
  public static final String LIB_ELT_CODE_PRODUIT_MONTANT_RETENU = "Code produit montant retenu";
  public static final String LIB_ELT_REGLEMENT_APPLICABLE = "Réglement applicable";
  public static final String LIB_ELT_3_ANS_INACT_DS_5 = "A 3 ans d'inactivité dans 5 ans";
  public static final String LIB_ELT_EST_MAINTENU = "Est maintenu";
  public static final String LIB_ELT_EST_SJR_BASE_SMIC = "Est sjr sur base SMIC";
  public static final String LIB_ELT_PRECOMPTE_CRC = "Est précompte CRC";
  public static final String LIB_ELT_CAPITAL_RETENU = "Capital retenu";
  public static final String LIB_ELT_NB_DELAIS_REPORT = "Nombre delais report";
  public static final String LIB_ELT_DONNEE_DELAIS_REPORT = "Donnée délais report";
  public static final String LIB_ELT_TAILLE_LISTE_DUREE = "Taille liste durée";
  public static final String LIB_ELT_DUREE_EFFECTIVE = "Duree effective";
  public static final String LIB_ELT_DUREE_THEORIQUE = "Duree théorique";
  public static final String LIB_ELT_DUREE_PROLONGATION = "Duree prolongation";
  public static final String LIB_ELT_DUREE_INITIALE = "Duree initiale";
  public static final String LIB_ELT_LISTE_PI = "Liste PI";
  public static final String LIB_ELT_STATUT_PI = "Statut PI";
  public static final String LIB_ELT_PERIODE_PI = "Periode PI";
  public static final String LIB_ELT_DUREE = "durée";
  public static final String LIB_ELT_ALIM_DROIT_EXECUTABLE = "Alimentation droit executable";
  public static final String LIB_ELT_CTX_PART_SJI = "Contexte particulier SJI";
  public static final String LIB_ELT_CTX_PART_SJC = "Contexte particulier SJC";
  public static final String LIB_ELT_DATE_REPRISE_ACTIVITE = "Date de reprise activité";
  
  public ResultatTraitementPopulation effectuerTraitement(CriteresTraitementPopulation p_criteres)
  {
    ResultatTraitementPopulation resultatTraitementPopulation = new ResultatTraitementPopulation();
    
    ArrayList listeDeDemande = new ArrayList();
    resultatTraitementPopulation.setObjetsTraites(listeDeDemande);
    ArrayList listeDifferences = new ArrayList();
    resultatTraitementPopulation.setElementsComparaisons(listeDifferences);
    
    Demande demande = (Demande)p_criteres.getParametres().get(0);
    Attribution attributionAssurance = (Attribution)demande.getAttribution();
    if (((ProduitAsuSpec)attributionAssurance.getProduit()).estTrancheActivee(attributionAssurance.getDemande()))
    {
      try
      {
        if ((attributionAssurance.getListTranchesExecutables() == null) || (attributionAssurance.getListTranchesExecutables().size() == 0))
        {
          alimenterDroitExecutable(attributionAssurance);
          alimenterDifferences("Non alimenté", "Alimenté", "Alimentation droit executable", listeDifferences);
        }
        verificationDonneesAlimentees(attributionAssurance, listeDifferences);
      }
      catch (Exception e)
      {
        String message = e.getClass().getName();
        if ((e instanceof ApplicativeRuntimeException))
        {
          ApplicativeRuntimeException exception = (ApplicativeRuntimeException)e;
          if ((exception.getLibelle() != null) && (exception.getLibelle().length() <= 100)) {
            message = exception.getLibelle();
          } else {
            message = exception.getCode();
          }
        }
        alimenterDifferences("SO", message, "Exception", listeDifferences);
      }
      resultatTraitementPopulation.getObjetsTraites().add(demande);
    }
    return resultatTraitementPopulation;
  }
  
  private void alimenterDroitExecutable(Attribution p_attribution)
  {
    OutilTranchesExecutables.alimenterTranches(p_attribution);
  }
  
  private boolean estObjetIdentiques(Object p_objet1, Object p_objet2)
  {
    boolean estObjetIdentiques = false;
    String typeAttendu = "";
    if (estPresenceDifferente(p_objet1, p_objet2)) {
      estObjetIdentiques = false;
    } else if (p_objet1 != null) {
      try
      {
        if ((p_objet1 instanceof Damj))
        {
          typeAttendu = "Damj";
          
          Damj date1 = (Damj)p_objet1;
          Damj date2 = (Damj)p_objet2;
          if (date1.compareTo(date2) == 0) {
            estObjetIdentiques = true;
          }
        }
        else if ((p_objet1 instanceof BigDecimal))
        {
          typeAttendu = "BigDecimal";
          
          BigDecimal bigDecimal1 = (BigDecimal)p_objet1;
          BigDecimal bigDecimal2 = (BigDecimal)p_objet2;
          if (bigDecimal1.compareTo(bigDecimal2) == 0) {
            estObjetIdentiques = true;
          }
        }
        else if ((p_objet1 instanceof Collection))
        {
          typeAttendu = "Collection";
          Collection collection1 = (Collection)p_objet1;
          Collection collection2 = (Collection)p_objet2;
          if (collection1.size() == collection2.size()) {
            estObjetIdentiques = true;
          }
        }
        else if ((p_objet1 instanceof String))
        {
          typeAttendu = "String";
          String string1 = (String)p_objet1;
          String string2 = (String)p_objet2;
          if (string1.equals(string2)) {
            estObjetIdentiques = true;
          }
        }
        else if ((p_objet1 instanceof ObjetChronoPeriode))
        {
          typeAttendu = "ObjetChronoPeriode";
          ObjetChronoPeriode objetChronoPeriode1 = (ObjetChronoPeriode)p_objet1;
          ObjetChronoPeriode objetChronoPeriode2 = (ObjetChronoPeriode)p_objet2;
          if ((objetChronoPeriode1.getDateDebut().coincideAvec(objetChronoPeriode2.getDateDebut())) && (objetChronoPeriode1.getDateFin().coincideAvec(objetChronoPeriode2.getDateFin())) && (objetChronoPeriode1.getDateEffet().coincideAvec(objetChronoPeriode2.getDateEffet()))) {
            estObjetIdentiques = true;
          }
        }
        else if ((p_objet1 instanceof Periode))
        {
          typeAttendu = "Periode";
          Periode periode1 = (Periode)p_objet1;
          Periode periode2 = (Periode)p_objet2;
          if ((periode1.getDebut().coincideAvec(periode2.getDebut())) && (periode1.getFin().coincideAvec(periode2.getFin()))) {
            estObjetIdentiques = true;
          }
        }
        else if ((p_objet1 instanceof Quantite))
        {
          typeAttendu = "Quantite";
          Quantite quantite1 = (Quantite)p_objet1;
          Quantite quantite2 = (Quantite)p_objet2;
          if (quantite1.compareTo(quantite2) == 0) {
            estObjetIdentiques = true;
          }
        }
        else
        {
          try
          {
            GestionnaireErreur.getInstance().genererException("PR_CALI_OBJET_NON_GERE", new Object[] { "estObjetIdentiques" }, 3);
          }
          catch (CoucheLogiqueException ex) {}
        }
      }
      catch (Exception e)
      {
        try
        {
          GestionnaireErreur.getInstance().genererException("PR_CALI_OBJET_TYPE_ATTENDUE", new Object[] { typeAttendu }, 3);
        }
        catch (CoucheLogiqueException ex) {}
      }
    } else if (p_objet1 == null) {
      estObjetIdentiques = true;
    }
    return estObjetIdentiques;
  }
  
  private boolean alimenterListeSiDifference(Object p_objet1, Object p_objet2, ArrayList p_listeDifferences, String p_libelleElement)
  {
    boolean estDifference = false;
    if (!estObjetIdentiques(p_objet1, p_objet2))
    {
      alimenterDifferences(p_objet1, p_objet2, p_libelleElement, p_listeDifferences);
      
      estDifference = true;
    }
    return estDifference;
  }
  
  private boolean alimenterListeSiDifference(int p_int1, int p_int2, ArrayList p_listeDifferences, String p_libelleElement)
  {
    boolean estDifference = false;
    if (p_int1 != p_int2)
    {
      alimenterDifferences(Integer.toString(p_int1), Integer.toString(p_int2), p_libelleElement, p_listeDifferences);
      
      estDifference = true;
    }
    return estDifference;
  }
  
  private boolean alimenterListeSiDifference(boolean p_boolean1, boolean p_boolean2, ArrayList p_listeDifferences, String p_libelleElement)
  {
    boolean estDifference = false;
    if (p_boolean1 != p_boolean2)
    {
      alimenterDifferences(Boolean.toString(p_boolean1), Boolean.toString(p_boolean2), p_libelleElement, p_listeDifferences);
      
      estDifference = true;
    }
    return estDifference;
  }
  
  private void verificationCodeEmploiA2b(ElementBaseIndemnisation p_elementBaseIndemnisation, TrancheExecutable p_trancheExecutable, ArrayList p_listeDifferences)
  {
    alimenterListeSiDifference(p_elementBaseIndemnisation.getCodeEmploiA2B(), p_trancheExecutable.getCodeEmploiA2B(), p_listeDifferences, "Code emploi A2B");
  }
  
  private void verificationCodeProduit(Attribution p_attribution, TrancheExecutable p_trancheExecutable, ArrayList p_listeDifferences)
  {
    alimenterListeSiDifference(p_attribution.getProduit().getCode(), p_trancheExecutable.getCodeProduit(), p_listeDifferences, "Code produit");
  }
  
  private void verificationCodeProduitReglementApplicable(Attribution p_attribution, TrancheExecutable p_trancheExecutable, ArrayList p_listeDifferences)
  {
    alimenterListeSiDifference(p_attribution.getReglementApplicable().getReglement().getProduit().getCode(), p_trancheExecutable.getCodeProduitReglement(), p_listeDifferences, "Code produit réglement");
  }
  
  private void verificationCoefficientSaisonnier(ElementBaseIndemnisation p_elementBaseIndemnisation, TrancheExecutable p_trancheExecutable, ArrayList p_listeDifferences)
  {
    alimenterListeSiDifference(p_elementBaseIndemnisation.getCoefficientSaisonnier(), p_trancheExecutable.getCoefficientSaisonnier(), p_listeDifferences, "Coefficient saisonnier");
    
    alimenterListeSiDifference(p_elementBaseIndemnisation.getTypeCaractereSaisonnierRetenu(), p_trancheExecutable.getNatureCoefficientSaisonnier(), p_listeDifferences, "Nature Coef sais");
  }
  
  private void verificationCoefficientTp(ElementBaseIndemnisation p_elementBaseIndemnisation, TrancheExecutable p_trancheExecutable, ArrayList p_listeDifferences)
  {
    alimenterListeSiDifference(p_elementBaseIndemnisation.getCoefficientTempsPartiel(), p_trancheExecutable.getCoefficientTempsPartiel(), p_listeDifferences, "Coefficient temps partiel");
  }
  
  private void verificationDelaisReports(Attribution p_attribution, TrancheExecutable p_trancheExecutable, ArrayList p_listeDifferences)
  {
    Collection listDelaisReportsAttribution = p_attribution.getListeCarences();
    Collection listDelaisReportsDroitExecutable = p_trancheExecutable.getCollectionDelaisReports();
    int tailleListDelaisReportsAttribution = 0;
    if (listDelaisReportsAttribution != null) {
      tailleListDelaisReportsAttribution = listDelaisReportsAttribution.size();
    }
    int tailleListDelaisReportsDroitExecutable = 0;
    if (listDelaisReportsDroitExecutable != null) {
      tailleListDelaisReportsDroitExecutable = listDelaisReportsDroitExecutable.size();
    }
    if (alimenterListeSiDifference(tailleListDelaisReportsAttribution, tailleListDelaisReportsDroitExecutable, p_listeDifferences, "liste delais report")) {
      return;
    }
    if (listDelaisReportsAttribution != null)
    {
      Iterator it = listDelaisReportsAttribution.iterator();
      while (it.hasNext())
      {
        CarencePrefixeAFixer carenceAttribution = (CarencePrefixeAFixer)it.next();
        Periode periodeApplicationCarenceAttribution = carenceAttribution.getPeriodeApplicationCarence();
        String typeCarrenceAttribution = carenceAttribution.getTypeCarence();
        
        Iterator itDroitExecutable = listDelaisReportsDroitExecutable.iterator();
        
        boolean estCarrenceTrouvee = false;
        while (itDroitExecutable.hasNext())
        {
          CarencePrefixeAFixer carenceDroitExecutable = (CarencePrefixeAFixer)itDroitExecutable.next();
          Periode periodeApplicationCarencetExecutable = carenceDroitExecutable.getPeriodeApplicationCarence();
          String typeCarrenceDroitExecutable = carenceDroitExecutable.getTypeCarence();
          if ((estObjetIdentiques(typeCarrenceAttribution, typeCarrenceDroitExecutable)) && (estObjetIdentiques(periodeApplicationCarenceAttribution, periodeApplicationCarencetExecutable)))
          {
            estCarrenceTrouvee = true;
            
            alimenterListeSiDifference(carenceAttribution.getIdentifiantPeriodeOrigine(), carenceDroitExecutable.getIdentifiantPeriodeOrigine(), p_listeDifferences, "Donnée délais report");
            
            alimenterListeSiDifference(carenceAttribution.getPeriodeApplicationCarence(), carenceDroitExecutable.getPeriodeApplicationCarence(), p_listeDifferences, "Donnée délais report");
            
            alimenterListeSiDifference(carenceAttribution.getQuantiteInitial(), carenceDroitExecutable.getQuantiteInitial(), p_listeDifferences, "Donnée délais report");
            
            alimenterListeSiDifference(carenceAttribution.getReliquat(), carenceDroitExecutable.getReliquat(), p_listeDifferences, "Donnée délais report");
          }
        }
        if (!estCarrenceTrouvee) {
          alimenterDifferences(carenceAttribution.getTypeCarence(), null, "Donnée délais report", p_listeDifferences);
        }
      }
    }
  }
  
  private void verificationSjc(Attribution p_attribution, TrancheExecutable p_trancheExecutable, ArrayList p_listeDifferences)
  {
    if (estPresenceDifferente(p_attribution.getSJC(), p_trancheExecutable.getDateSJC()))
    {
      alimenterDifferences("Sjc null", p_trancheExecutable.getDateSJC(), "Date salaire journalier conservé", p_listeDifferences);
      
      return;
    }
    if (estPresenceDifferente(p_attribution.getSJC(), p_trancheExecutable.getMontantSJC()))
    {
      alimenterDifferences("Sjc null", p_trancheExecutable.getMontantSJC(), "Montant SJC", p_listeDifferences);
      
      return;
    }
    Sjc sjcAttribution = p_attribution.getSJC();
    if (sjcAttribution != null)
    {
      alimenterListeSiDifference(sjcAttribution.getDateDepart(), p_trancheExecutable.getDateSJC(), p_listeDifferences, "Date salaire journalier conservé");
      
      alimenterListeSiDifference(sjcAttribution.getSalaire(), p_trancheExecutable.getMontantSJC().getValeur(), p_listeDifferences, "Montant SJC");
    }
    String contexteParticulierSjcAttribution = sjcAttribution.getContexteParticulier();
    String contexteParticulierSjcDroitExecutable = p_trancheExecutable.getContexteParticulierSJC();
    
    alimenterListeSiDifference(contexteParticulierSjcAttribution, contexteParticulierSjcDroitExecutable, p_listeDifferences, "Contexte particulier SJC");
  }
  
  private void verificationSji(ElementBaseIndemnisation p_elementBaseIndemnisation, TrancheExecutable p_trancheExecutable, ArrayList p_listeDifferences)
  {
    SalaireJournalierSpec salaireJournalierAttribution = p_elementBaseIndemnisation.getSalaireJournalier();
    BigDecimal montantSJRAttribution = salaireJournalierAttribution.getSalaire();
    
    alimenterListeSiDifference(p_elementBaseIndemnisation.getSalaireJournalier().getDateDepart(), p_trancheExecutable.getDateSJI(), p_listeDifferences, "Date salaire journalier");
    
    BigDecimal montantSJRDroitExecutable = p_trancheExecutable.getMontantSJI().getValeur();
    alimenterListeSiDifference(montantSJRAttribution, montantSJRDroitExecutable, p_listeDifferences, "Montant salaire journalier initial");
    
    String contexteParticulierSjiAttribution = salaireJournalierAttribution.getContexteParticulier();
    String contexteParticulierSjiDroitExecutable = p_trancheExecutable.getContexteParticulierSJI();
    
    alimenterListeSiDifference(contexteParticulierSjiAttribution, contexteParticulierSjiDroitExecutable, p_listeDifferences, "Contexte particulier SJI");
  }
  
  private void verificationDateLimiteIndemnisation(Attribution p_attribution, TrancheExecutable p_trancheExecutable, ArrayList p_listeDifferences)
  {
    Damj dateLimiteIndemnisationAttribution = p_attribution.getDateLimiteIndemnisation();
    Damj dateRepriseActivite = null;
    if (p_attribution.getElementChomageSansRupture() != null)
    {
      dateLimiteIndemnisationAttribution = p_attribution.getElementChomageSansRupture().getDateMaxIndeminisation();
      dateRepriseActivite = p_attribution.getElementChomageSansRupture().getDateRepriseActivite();
    }
    alimenterListeSiDifference(dateLimiteIndemnisationAttribution, p_trancheExecutable.getDateLimiteIndemnisation(), p_listeDifferences, "Date limite d'indemnisation");
    
    TracesBouchon.ecrireTrace("la date de reprise activité est à ajouter dans la base de donnée");
    alimenterListeSiDifference(dateRepriseActivite, null, p_listeDifferences, "Date de reprise activité");
  }
  
  private void verificationMaintienEuropeen(Attribution p_attribution, TrancheExecutable p_trancheExecutable, ArrayList p_listeDifferences)
  {
    if (estPresenceDifferente(p_attribution.getMaintienEuropeen(), p_trancheExecutable.getDateDebutMaintientEuropeen())) {
      alimenterDifferences("Maintien Europeen", p_trancheExecutable.getDateDebutMaintientEuropeen(), "Date début maintien europeen", p_listeDifferences);
    }
    if (p_attribution.getMaintienEuropeen() != null) {
      alimenterListeSiDifference(p_attribution.getMaintienEuropeen().getDepartPeriode(), p_trancheExecutable.getDateDebutMaintientEuropeen(), p_listeDifferences, "Date début maintien europeen");
    }
  }
  
  private void verificationDateAttribution(Attribution p_attribution, TrancheExecutable p_trancheExecutable, ArrayList p_listeDifferences)
  {
    alimenterListeSiDifference(p_attribution.getDateAttribution(), p_trancheExecutable.getDateAttribution(), p_listeDifferences, "Date attribution");
  }
  
  private void verificationCompetence(Attribution p_attribution, TrancheExecutable p_trancheExecutable, ArrayList p_listeDifferences)
  {
    alimenterListeSiDifference(p_attribution.getCompetenceFinanciere(), p_trancheExecutable.getCompetenceFinanciere(), p_listeDifferences, "Compétence financière");
    
    alimenterListeSiDifference(p_attribution.getCompetenceAdministrative(), p_trancheExecutable.getCompetenceAdministrative(), p_listeDifferences, "Compétence administrative");
  }
  
  private void verificationConventionGestion(Attribution p_attribution, TrancheExecutable p_trancheExecutable, ArrayList p_listeDifferences)
  {
    ConventionGestionSpec conventionGestionAttribution = p_attribution.getConventionGestion();
    String numCGAttribution = null;
    String codeAffectationAttribution = null;
    if ((p_trancheExecutable.getEtablissementFinanceurCG() != null) && (conventionGestionAttribution == null))
    {
      alimenterDifferences(conventionGestionAttribution, p_trancheExecutable.getEtablissementFinanceurCG(), "Etablissement financeur convention gestion", p_listeDifferences);
    }
    else if (conventionGestionAttribution != null)
    {
      numCGAttribution = conventionGestionAttribution.getNumeroConventionGestion();
      codeAffectationAttribution = conventionGestionAttribution.getCodeAffectation();
      
      alimenterListeSiDifference(numCGAttribution, p_trancheExecutable.getEtablissementFinanceurCG(), p_listeDifferences, "Etablissement financeur convention gestion");
      
      alimenterListeSiDifference(codeAffectationAttribution, p_trancheExecutable.getCodeAffectationCG(), p_listeDifferences, "Code affectation CG");
    }
  }
  
  private void verificationIdentifiantFaitGenerateur(Attribution p_attribution, TrancheExecutable p_trancheExecutable, ArrayList p_listeDifferences)
  {
    if (estPresenceDifferente(p_attribution.getFaitGenerateur(), p_trancheExecutable.getIdFaitGenerateur()))
    {
      alimenterDifferences("Fait générateur", p_trancheExecutable.getIdFaitGenerateur(), "Id fait générateur", p_listeDifferences);
      
      return;
    }
    if (p_attribution.getFaitGenerateur() != null) {
      alimenterListeSiDifference(p_attribution.getFaitGenerateur().getIdentifiantPeriodeFaitGenerateur(), p_trancheExecutable.getIdFaitGenerateur(), p_listeDifferences, "Id fait générateur");
    }
  }
  
  private void verificationMontantPreavis(ElementBaseIndemnisation p_elementBaseIndemnisation, TrancheExecutable p_trancheExecutable, ArrayList p_listeDifferences)
  {
    if (estPresenceDifferente(p_elementBaseIndemnisation.getMontantPreavis(), p_trancheExecutable.getMontantPreavis()))
    {
      alimenterDifferences(p_elementBaseIndemnisation.getMontantPreavis(), p_trancheExecutable.getMontantPreavis(), "Montant préavis", p_listeDifferences);
      
      return;
    }
    if (p_elementBaseIndemnisation.getMontantPreavis() != null) {
      alimenterListeSiDifference(p_elementBaseIndemnisation.getMontantPreavis(), p_trancheExecutable.getMontantPreavis().getValeur(), p_listeDifferences, "Montant préavis");
    }
  }
  
  private void verificationNatureDecision(Attribution p_attribution, TrancheExecutable p_trancheExecutable, ArrayList p_listeDifferences)
  {
    alimenterListeSiDifference(p_attribution.getNatureDecision(), p_trancheExecutable.getNatureDecision(), p_listeDifferences, "Nature décision");
  }
  
  private void verificationProduitMontantRetenu(Attribution p_attribution, TrancheExecutable p_trancheExecutable, ArrayList p_listeDifferences)
  {
    alimenterListeSiDifference(p_attribution.getProduitMontantRetenu().getCode(), p_trancheExecutable.getProduitMontantRetenu(), p_listeDifferences, "Code produit montant retenu");
  }
  
  private void verificationReglementApplicable(Attribution p_attribution, TrancheExecutable p_trancheExecutable, ArrayList p_listeDifferences)
  {
    alimenterListeSiDifference(p_attribution.getReglementApplicable().getReglement().getNomReglement(), p_trancheExecutable.getReglementApplicable(), p_listeDifferences, "Réglement applicable");
  }
  
  private void verificationEst3ansActiviteEn5ans(ElementBaseIndemnisation p_elementBaseIndemnisation, TrancheExecutable p_trancheExecutable, ArrayList p_listeDifferences)
  {
    alimenterListeSiDifference(p_elementBaseIndemnisation.isConditionCaractereSaisonnierParRythme(), p_trancheExecutable.isA3ansActiviteEn5ans(), p_listeDifferences, "A 3 ans d'inactivité dans 5 ans");
  }
  
  private void verificationEstSjrBaseSmic(ElementBaseIndemnisation p_elementBaseIndemnisation, TrancheExecutable p_trancheExecutable, ArrayList p_listeDifferences)
  {
    alimenterListeSiDifference(p_elementBaseIndemnisation.isSjrBaseSurPourcentageSMIC(), p_trancheExecutable.isEstSjrBaseSmic(), p_listeDifferences, "Est sjr sur base SMIC");
  }
  
  private void verificationEstPrecompteCRC(ElementBaseIndemnisation p_elementBaseIndemnisation, TrancheExecutable p_trancheExecutable, ArrayList p_listeDifferences)
  {
    Boolean estPrecompteCrcAttribution = p_elementBaseIndemnisation.getAvecPrecompteCRC();
    
    alimenterListeSiDifference(estPrecompteCrcAttribution, p_trancheExecutable.getPrecompteCRC(), p_listeDifferences, "Est précompte CRC");
  }
  
  private void verificationCapitalAServir(Attribution p_attribution, TrancheExecutable p_trancheExecutable, ArrayList p_listeDifferences)
  {
    Quantite capitalAServirAttribution = null;
    if ((p_attribution instanceof OdSpec))
    {
      if (p_attribution.getTypeCapitalRetenu() == 1) {
        capitalAServirAttribution = p_attribution.getConstitutionMontantsBruts().getCapitalInitialBrut();
      } else {
        capitalAServirAttribution = p_attribution.getConstitutionProduitResultant().getCapitalMax();
      }
      alimenterListeSiDifference(capitalAServirAttribution, p_trancheExecutable.getCapitalAServir(), p_listeDifferences, "Capital retenu");
    }
  }
  
  private void verificationListeDuree(Attribution p_attribution, TrancheExecutable p_trancheExecutable, ArrayList p_listeDifferences)
  {
    Quantite dureeTheoriqueAttribution = p_attribution.getDureeTheorique();
    Quantite dureeEffectiveAttribution = p_attribution.getDureeIndemnisationEffective();
    Quantite dureeProlongationTheoriqueAttribution = p_attribution.getDureeProlongationTheorique();
    Quantite dureeInitiale = p_attribution.getDureeInitiale();
    
    int tailleListeAttendue = 0;
    if (dureeTheoriqueAttribution != null) {
      tailleListeAttendue++;
    }
    if (dureeEffectiveAttribution != null) {
      tailleListeAttendue++;
    }
    if (dureeInitiale != null) {
      tailleListeAttendue++;
    }
    if (dureeProlongationTheoriqueAttribution != null) {
      tailleListeAttendue++;
    }
    List listeDureeTrancheExecutable = p_trancheExecutable.getListDurees();
    if (listeDureeTrancheExecutable == null)
    {
      alimenterDifferences(p_attribution.getListeDurees(), null, "Taille liste durée", p_listeDifferences);
      return;
    }
    if (alimenterListeSiDifference(tailleListeAttendue, listeDureeTrancheExecutable.size(), p_listeDifferences, "Taille liste durée")) {
      return;
    }
    int dureeEffectiveTrancheExecutable = 0;
    int dureeTheoriqueTrancheExecutable = 0;
    int dureeProlongationTrancheExecutable = 0;
    int dureeInitialeTrancheExecutable = 0;
    
    Iterator iteratorListeDureeTrancheExecutable = listeDureeTrancheExecutable.iterator();
    while (iteratorListeDureeTrancheExecutable.hasNext())
    {
      Duree duree = (Duree)iteratorListeDureeTrancheExecutable.next();
      switch (duree.getTypeDuree())
      {
      case 2: 
        dureeEffectiveTrancheExecutable = duree.getNombreJour().intValue();
        alimenterListeSiDifference(dureeEffectiveAttribution.getValeur().intValue(), dureeEffectiveTrancheExecutable, p_listeDifferences, "Duree effective");
        
        break;
      case 1: 
        dureeTheoriqueTrancheExecutable = duree.getNombreJour().intValue();
        alimenterListeSiDifference(dureeTheoriqueAttribution.getValeur().intValue(), dureeTheoriqueTrancheExecutable, p_listeDifferences, "Duree théorique");
        
        break;
      case 3: 
        dureeProlongationTrancheExecutable = duree.getNombreJour().intValue();
        alimenterListeSiDifference(dureeProlongationTheoriqueAttribution.getValeur().intValue(), dureeProlongationTrancheExecutable, p_listeDifferences, "Duree prolongation");
        
        break;
      case 4: 
        dureeInitialeTrancheExecutable = duree.getNombreJour().intValue();
        alimenterListeSiDifference(dureeInitiale.getValeur().intValue(), dureeInitialeTrancheExecutable, p_listeDifferences, "Duree initiale");
        
        break;
      default: 
        try
        {
          GestionnaireErreur.getInstance().genererException("PR_CALI_OBJET_NON_GERE", new Object[] { "verificationListeDuree" }, 3);
        }
        catch (CoucheLogiqueException ex) {}
      }
    }
  }
  
  private void verificationListePensionInvalidite(Attribution p_attribution, TrancheExecutable p_trancheExecutable, ArrayList p_listeDifferences)
  {
    Collection listePIAttribution = p_attribution.getListePensionInvalidite();
    
    Collection listePITrancheExecutable = p_trancheExecutable.getListePensionsInvalidites();
    if (alimenterListeSiDifference(listePIAttribution, listePITrancheExecutable, p_listeDifferences, "Liste PI")) {
      return;
    }
    Iterator iteratorListePiAttribution = listePIAttribution.iterator();
    while (iteratorListePiAttribution.hasNext())
    {
      PensionInvaliditeChainee pensionInvaliditeChaineeAttribution = (PensionInvaliditeChainee)iteratorListePiAttribution.next();
      
      int statutPiAttribution = pensionInvaliditeChaineeAttribution.getStatut();
      Periode periodePiAttribution = pensionInvaliditeChaineeAttribution.getPeriode();
      
      Iterator iteratorListePiTrancheExecutable = listePITrancheExecutable.iterator();
      boolean piDetectee = false;
      while (iteratorListePiTrancheExecutable.hasNext())
      {
        PensionInvaliditeChainee pensionInvaliditeTrancheExecutable = (PensionInvaliditeChainee)iteratorListePiTrancheExecutable.next();
        
        Periode periodePiTrancheExecutable = pensionInvaliditeTrancheExecutable.getPeriode();
        int statutPiTrancheExecutable = pensionInvaliditeTrancheExecutable.getStatut();
        if (periodePiAttribution.coincideAvec(periodePiTrancheExecutable))
        {
          piDetectee = true;
          alimenterListeSiDifference(statutPiAttribution, statutPiTrancheExecutable, p_listeDifferences, "Statut PI");
        }
      }
      if (!piDetectee) {
        alimenterDifferences(periodePiAttribution, null, "Periode PI", p_listeDifferences);
      }
    }
  }
  
  private void verificationDonneesAlimentees(Attribution p_attribution, ArrayList p_listeDifferences)
  {
    List tranchesExecutables = p_attribution.getListTranchesExecutables();
    if (tranchesExecutables.size() == 0) {
      try
      {
        GestionnaireErreur.getInstance().genererException("PR_CALI_OBJET_TYPE_ATTENDUE", new Object[] { "TrancheExecutable" }, 3);
      }
      catch (CoucheLogiqueException ex) {}
    } else if (tranchesExecutables.size() > 1) {
      try
      {
        GestionnaireErreur.getInstance().genererException("PR_CALI_UTILITAIRE_VALEUR_ATTENDUE", new Object[] { "1", "Nombre de tranches exécutable" }, 3);
      }
      catch (CoucheLogiqueException ex) {}
    }
    TrancheExecutable trancheExecutable = (TrancheExecutable)tranchesExecutables.get(0);
    
    ((Demande)p_attribution.getDemande()).desactiverTrancheExecutable();
    ElementBaseIndemnisation elementBaseIndemnisation = p_attribution.getElementBaseIndemnisation();
    ((Demande)p_attribution.getDemande()).reactiverTrancheExecutable();
    
    verificationCodeEmploiA2b(elementBaseIndemnisation, trancheExecutable, p_listeDifferences);
    
    verificationCodeProduit(p_attribution, trancheExecutable, p_listeDifferences);
    
    verificationCodeProduitReglementApplicable(p_attribution, trancheExecutable, p_listeDifferences);
    
    verificationCoefficientSaisonnier(elementBaseIndemnisation, trancheExecutable, p_listeDifferences);
    
    verificationCoefficientTp(elementBaseIndemnisation, trancheExecutable, p_listeDifferences);
    
    verificationDelaisReports(p_attribution, trancheExecutable, p_listeDifferences);
    
    verificationSjc(p_attribution, trancheExecutable, p_listeDifferences);
    
    verificationSji(elementBaseIndemnisation, trancheExecutable, p_listeDifferences);
    
    verificationDateLimiteIndemnisation(p_attribution, trancheExecutable, p_listeDifferences);
    
    verificationMaintienEuropeen(p_attribution, trancheExecutable, p_listeDifferences);
    
    verificationDateAttribution(p_attribution, trancheExecutable, p_listeDifferences);
    
    verificationCompetence(p_attribution, trancheExecutable, p_listeDifferences);
    
    verificationConventionGestion(p_attribution, trancheExecutable, p_listeDifferences);
    
    verificationIdentifiantFaitGenerateur(p_attribution, trancheExecutable, p_listeDifferences);
    
    verificationMontantPreavis(elementBaseIndemnisation, trancheExecutable, p_listeDifferences);
    
    verificationNatureDecision(p_attribution, trancheExecutable, p_listeDifferences);
    
    verificationProduitMontantRetenu(p_attribution, trancheExecutable, p_listeDifferences);
    
    verificationReglementApplicable(p_attribution, trancheExecutable, p_listeDifferences);
    
    verificationEst3ansActiviteEn5ans(elementBaseIndemnisation, trancheExecutable, p_listeDifferences);
    
    verificationEstSjrBaseSmic(elementBaseIndemnisation, trancheExecutable, p_listeDifferences);
    
    verificationEstPrecompteCRC(elementBaseIndemnisation, trancheExecutable, p_listeDifferences);
    
    verificationCapitalAServir(p_attribution, trancheExecutable, p_listeDifferences);
    
    verificationListeDuree(p_attribution, trancheExecutable, p_listeDifferences);
    
    verificationListePensionInvalidite(p_attribution, trancheExecutable, p_listeDifferences);
  }
  
  boolean estPresenceDifferente(Object p_objet1, Object p_objet2)
  {
    if (((p_objet1 == null) && (p_objet2 == null)) || ((p_objet1 != null) && (p_objet2 != null))) {
      return false;
    }
    return true;
  }
  
  protected static void alimenterDifferences(Object p_valeurAvant, Object p_valeurApres, String p_libelleElement, ArrayList p_liste)
  {
    ElementComparaisonReexamen elementDecision = new ElementComparaisonReexamen(p_libelleElement, p_valeurAvant, p_valeurApres);
    p_liste.add(elementDecision);
  }
}

/* Location:
 * Qualified Name:     TraitementControleDroitExecutable
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */