package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.EreAntecedentAssuranceEnCoursDossier;
import fr.unedic.cali.asu.dom.EreApsFdd;
import fr.unedic.cali.asu.dom.EreApsSuiteRejetAsu;
import fr.unedic.cali.asu.dom.EreAspSuiteIDE;
import fr.unedic.cali.asu.dom.EreAsrSuiteIDE;
import fr.unedic.cali.asu.dom.EreAtAfdFdd;
import fr.unedic.cali.asu.dom.EreAtAfdSuiteRejetAsu;
import fr.unedic.cali.asu.dom.EreClauseRattrapageSpectacle;
import fr.unedic.cali.asu.dom.EreDemandeApsEfe;
import fr.unedic.cali.asu.dom.EreDemandeAreEfe;
import fr.unedic.cali.asu.dom.EreDemandeAssociee;
import fr.unedic.cali.asu.dom.EreDemandeAtAfdEfe;
import fr.unedic.cali.asu.dom.EreDemandeExpresse;
import fr.unedic.cali.asu.dom.EreDvAuFilEau;
import fr.unedic.cali.asu.dom.EreFinDroitSpectacle;
import fr.unedic.cali.asu.dom.EreFinDroitSuiteRepriseNonSaisonniere;
import fr.unedic.cali.asu.dom.EreIdeAtp;
import fr.unedic.cali.asu.dom.EreIdeAtpSuiteBascule;
import fr.unedic.cali.asu.dom.EreInscriptionDemandeurEmploi;
import fr.unedic.cali.asu.dom.ErePassageCPSuiteRejetDV;
import fr.unedic.cali.asu.dom.EreRechargement;
import fr.unedic.cali.asu.dom.EreRepriseVersement;
import fr.unedic.cali.asu.dom.EreRevisionConvention2014;
import fr.unedic.cali.asu.dom.EreRevisionSuitePerteActiviteConservee;
import fr.unedic.cali.asu.dom.EreSaisieAntecedent;
import fr.unedic.cali.asu.dom.EreSuiteFinDroitAsp;
import fr.unedic.cali.asu.dom.EreSuiteFinDroitAsr;
import fr.unedic.cali.asu.dom.EreSuiteFinDroitAtp;
import fr.unedic.cali.asu.dom.FormulaireAsu;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.outilsfonctionnels.ConstructionCSOIA;
import fr.unedic.util.services.ApplicativeRuntimeException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;

public final class ConstitutionEvenementReferenceExamen
  implements OutilFonctionnel
{
  public static void constituerEvenementReferenceExamen(Demande demandeAssurance)
    throws CoucheLogiqueException
  {
    FormulaireAsu formulaire = (FormulaireAsu)demandeAssurance.getFormulaire();
    
    String typeExamen = ConstructionCSOIA.getTypeExamenDepuisV1(formulaire.getNomGamme(), formulaire.getNomLigne(), formulaire.getNomProduit(), formulaire.getMotifEnvoi());
    
    EvenementReferenceExamenSpec evt = recupererEvenementReferenceExamen(typeExamen);
    if (evt == null)
    {
      StringBuilder sb = new StringBuilder();
      sb.append("Type de formulaire non géré dans NCP. Infos du formulaire : ");
      sb.append("gamme : ");
      sb.append(formulaire.getNomGamme());
      sb.append(" - ligne : ");
      sb.append(formulaire.getNomLigne());
      sb.append(" - produit : ");
      sb.append(formulaire.getNomProduit());
      sb.append(" - type envoi : ");
      sb.append(formulaire.getMotifEnvoi());
      
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_ERE_NON_GERE", sb.toString(), null);
    }
    demandeAssurance.setEvenementReferenceExamen(evt);
  }
  
  public static EvenementReferenceExamenSpec recupererEvenementReferenceExamen(String typeExamen)
  {
    EvenementReferenceExamenSpec evt = null;
    if (typeExamen.equalsIgnoreCase("ASU_04")) {
      evt = new ErePassageCPSuiteRejetDV();
    } else if (typeExamen.equalsIgnoreCase("ASU_02")) {
      evt = new EreDemandeExpresse();
    } else if (typeExamen.equalsIgnoreCase("ASU_03")) {
      evt = new EreFinDroitSuiteRepriseNonSaisonniere();
    } else if (typeExamen.equalsIgnoreCase("ASU_01")) {
      evt = new EreInscriptionDemandeurEmploi();
    } else if (typeExamen.equalsIgnoreCase("ASU_07")) {
      evt = new EreRevisionSuitePerteActiviteConservee();
    } else if (typeExamen.equalsIgnoreCase("ASU_13")) {
      evt = new EreDemandeAreEfe();
    } else if (typeExamen.equalsIgnoreCase("ASU_08")) {
      evt = new EreFinDroitSpectacle();
    } else if (typeExamen.equalsIgnoreCase("ASU_14")) {
      evt = new EreDemandeApsEfe();
    } else if (typeExamen.equalsIgnoreCase("ASU_11")) {
      evt = new EreApsFdd();
    } else if (typeExamen.equalsIgnoreCase("ASU_09")) {
      evt = new EreApsSuiteRejetAsu();
    } else if (typeExamen.equalsIgnoreCase("ASU_15")) {
      evt = new EreDemandeAtAfdEfe();
    } else if (typeExamen.equalsIgnoreCase("ASU_12")) {
      evt = new EreAtAfdFdd();
    } else if (typeExamen.equalsIgnoreCase("ASU_10")) {
      evt = new EreAtAfdSuiteRejetAsu();
    } else if (typeExamen.equalsIgnoreCase("ASU_16")) {
      evt = new EreAsrSuiteIDE();
    } else if (typeExamen.equalsIgnoreCase("ASU_17")) {
      evt = new EreSuiteFinDroitAsr();
    } else if (typeExamen.equalsIgnoreCase("ASU_18")) {
      evt = new EreIdeAtp();
    } else if (typeExamen.equalsIgnoreCase("ASU_19")) {
      evt = new EreSuiteFinDroitAtp();
    } else if (typeExamen.equalsIgnoreCase("ASU_20")) {
      evt = new EreIdeAtpSuiteBascule();
    } else if (typeExamen.equalsIgnoreCase("ASU_21")) {
      evt = new EreDemandeAssociee();
    } else if (typeExamen.equalsIgnoreCase("ASU_22")) {
      evt = new EreSaisieAntecedent();
    } else if (typeExamen.equalsIgnoreCase("ASU_23")) {
      evt = new EreAntecedentAssuranceEnCoursDossier();
    } else if (typeExamen.equalsIgnoreCase("ASU_24")) {
      evt = new EreAspSuiteIDE();
    } else if (typeExamen.equalsIgnoreCase("ASU_25")) {
      evt = new EreSuiteFinDroitAsp();
    } else if (typeExamen.equalsIgnoreCase("ASU_29")) {
      evt = new EreRechargement();
    } else if (typeExamen.equalsIgnoreCase("ASU_28")) {
      evt = new EreRevisionConvention2014();
    } else if (typeExamen.equalsIgnoreCase("ASU_27")) {
      evt = new EreRepriseVersement();
    } else if (typeExamen.equalsIgnoreCase("ASU_30")) {
      evt = new EreDvAuFilEau();
    } else if (typeExamen.equalsIgnoreCase("ASU_31")) {
      evt = new EreClauseRattrapageSpectacle();
    }
    return evt;
  }
}

/* Location:
 * Qualified Name:     ConstitutionEvenementReferenceExamen
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */