package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.dom.ConteneurPMCSpec;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.PreavisMesureConservatoireIndemnisableSpec;
import fr.unedic.cali.asu.dom.PreavisMesureConservatoireNonIndemnisableSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.autresdoms.ga.dom.Preavis;
import fr.unedic.cali.dom.ObjetAlertesNonBloquantes;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Hashtable;

public class ConstitutionPMC
{
  public static final int NOMBRE_JOUR_MAXIMUM_PMC = 999;
  
  public static void determinerPMC(ActiviteSalarie pas, ConteneurPMCSpec conteneurPMC)
    throws CoucheLogiqueException
  {
    ActiviteSalarie periodeActivite = pas;
    if (estCDI(periodeActivite))
    {
      if (isAncienneteSuffisante(periodeActivite)) {
        if (motifRCTObligeAPreavis(periodeActivite)) {
          if (!isPreavisPayeEnTotaliteParEmployeur(periodeActivite)) {
            questionPresenceTransaction(periodeActivite, conteneurPMC);
          }
        }
      }
    }
    else if (isRuptureAnticipee(periodeActivite)) {
      if (!isRuptureJustifiee(periodeActivite))
      {
        Damj dateInitialeFCD = periodeActivite.getContrat().getDateInitialeFCD();
        if (!periodeActivite.getDateFin().coincideAvec(dateInitialeFCD)) {
          if (isPresenceDommagesInterets(periodeActivite)) {
            ajouterPmcNonIndemnisable(periodeActivite, conteneurPMC);
          } else {
            questionPresenceTransaction(periodeActivite, conteneurPMC);
          }
        }
      }
    }
  }
  
  private static void ajouterPmcNonIndemnisable(ActiviteSalarie periodeActivite, ConteneurPMCSpec conteneurPMC)
    throws CoucheLogiqueException
  {
    Periode periodeApplication = new Periode(determinerDateDebutPMC(periodeActivite), determinationTermePMC(periodeActivite));
    PreavisMesureConservatoireNonIndemnisableSpec pmc = conteneurPMC.creerPMCNonIndemnisable(periodeActivite, periodeApplication);
    conteneurPMC.setCarencePmc(pmc);
    if (conteneurPMC.getDemande() != null)
    {
      Collection listePeriodes = new ArrayList();
      
      ObjetAlertesNonBloquantes objetAlerteNonBloquante = new ObjetAlertesNonBloquantes(periodeActivite.getDateFin(), periodeActivite.getDateFin(), 999);
      
      listePeriodes.add(objetAlerteNonBloquante);
      conteneurPMC.getDemande().getAlertesNonBloquantes().put("A10MNB1", listePeriodes);
    }
  }
  
  private static void ajouterPmcIndemnisable(ActiviteSalarie periodeActivite, ConteneurPMCSpec conteneurPMC)
    throws CoucheLogiqueException
  {
    Periode periodeApplication = new Periode(determinerDateDebutPMC(periodeActivite), determinationTermePMC(periodeActivite));
    
    PreavisMesureConservatoireIndemnisableSpec pmc = conteneurPMC.creerPMCIndemnisable(periodeActivite, periodeApplication);
    conteneurPMC.setPmcIndemnisable(pmc);
  }
  
  public static void ajouterPmcForcee(ActiviteSalarie periodeActivite, boolean isIndemnisable, Damj dateFinPmc, ConteneurPMCSpec conteneurPMC)
  {
    Periode periodeApplication = new Periode(determinerDateDebutPMC(periodeActivite), dateFinPmc);
    if (isIndemnisable)
    {
      PreavisMesureConservatoireIndemnisableSpec pmc = conteneurPMC.creerPMCIndemnisable(periodeActivite, periodeApplication);
      conteneurPMC.setPmcIndemnisable(pmc);
    }
    else
    {
      PreavisMesureConservatoireNonIndemnisableSpec pmc = conteneurPMC.creerPMCNonIndemnisable(periodeActivite, periodeApplication);
      conteneurPMC.setCarencePmc(pmc);
    }
  }
  
  private static boolean isPreavisPayeEnTotaliteParEmployeur(ActiviteSalarie periodeActiviteSalarie)
  {
    boolean total = true;
    
    Preavis preavis = periodeActiviteSalarie.getContrat().getPreavis();
    if ((preavis != null) && (preavis.getPeriodeNonEffectueeNonPayee() != null)) {
      total = false;
    }
    return total;
  }
  
  private static boolean motifRCTObligeAPreavis(ActiviteSalarie periodeActiviteSalarie)
  {
    boolean oblige = false;
    
    int motifFin = periodeActiviteSalarie.getContrat().getCodeMotifFin();
    switch (motifFin)
    {
    case 1: 
    case 5: 
    case 6: 
    case 39: 
      oblige = true;
      break;
    }
    return oblige;
  }
  
  private static void questionPresenceTransaction(ActiviteSalarie periodeActiviteSalarie, ConteneurPMCSpec conteneurPMC)
    throws CoucheLogiqueException
  {
    if (isPresenceTransaction(periodeActiviteSalarie))
    {
      if (isMontantTransactionNul(periodeActiviteSalarie)) {
        OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "présence d'une transaction de montant nul, anomalie liquidation (DAJ)" });
      }
    }
    else {
      questionActionPrudhomale(periodeActiviteSalarie, conteneurPMC);
    }
  }
  
  private static void questionActionPrudhomale(ActiviteSalarie periodeActiviteSalarie, ConteneurPMCSpec conteneurPMC)
    throws CoucheLogiqueException
  {
    Preavis preavis = periodeActiviteSalarie.getContrat().getPreavis();
    boolean presenceActionPrudhomale = false;
    boolean engagementRemboursement = false;
    if ((preavis != null) && (preavis.isActionPrudhommale())) {
      presenceActionPrudhomale = true;
    }
    if (presenceActionPrudhomale)
    {
      engagementRemboursement = preavis.isEngagementRemboursement();
      if (engagementRemboursement) {
        ajouterPmcIndemnisable(periodeActiviteSalarie, conteneurPMC);
      } else {
        ajouterPmcNonIndemnisable(periodeActiviteSalarie, conteneurPMC);
      }
    }
    else
    {
      ajouterPmcNonIndemnisable(periodeActiviteSalarie, conteneurPMC);
    }
  }
  
  private static Damj determinationTermePMC(ActiviteSalarie periodeActiviteSalarie)
    throws CoucheLogiqueException
  {
    Damj terme = null;
    ContratTravail contrat = periodeActiviteSalarie.getContrat();
    if (!estCDI(periodeActiviteSalarie))
    {
      if (contrat.getDateInitialeFCD() != null) {
        terme = contrat.getDateInitialeFCD();
      } else {
        GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB11", new String[] { periodeActiviteSalarie.getDateDebut().toString(), periodeActiviteSalarie.getDateFin().toString() });
      }
    }
    else {
      terme = determinerTermePreavis(contrat.getPreavis());
    }
    return terme;
  }
  
  public static Damj determinerDateDebutPMC(ActiviteSalarie periodeActiviteSalarie)
  {
    ContratTravail contrat = periodeActiviteSalarie.getContrat();
    Damj veilleDebut = null;
    if (!estCDI(periodeActiviteSalarie))
    {
      veilleDebut = periodeActiviteSalarie.getDateFin();
    }
    else
    {
      if (contrat.getDateRuptureContratTravail() != null) {
        veilleDebut = contrat.getDateRuptureContratTravail();
      } else if ((contrat.getPreavis() != null) && (contrat.getPreavis().getPeriodeNonEffectueeNonPayee() != null)) {
        veilleDebut = contrat.getPreavis().getPeriodeNonEffectueeNonPayee().getDebut().veille();
      } else {
        veilleDebut = periodeActiviteSalarie.getDateFin();
      }
      Damj date = determineDernierJourPayePreavis(contrat.getPreavis());
      if (date != null) {
        veilleDebut = date;
      }
    }
    return veilleDebut.lendemain();
  }
  
  public static Damj determineDernierJourPayePreavis(Preavis preavis)
  {
    Damj date = null;
    if (preavis != null)
    {
      if (preavis.getPeriodeEffectuee() != null) {
        date = preavis.getPeriodeEffectuee().getFin();
      }
      if ((preavis.getPeriodeNonEffectueePayee() != null) && (
        (date == null) || (preavis.getPeriodeNonEffectueePayee().getFin().estApres(date)))) {
        date = preavis.getPeriodeNonEffectueePayee().getFin();
      }
    }
    return date;
  }
  
  public static Damj determinerTermePreavis(Preavis preavis)
  {
    Damj date = null;
    if (preavis.getPeriodeEffectuee() != null) {
      date = preavis.getPeriodeEffectuee().getFin();
    }
    if ((preavis.getPeriodeNonEffectueePayee() != null) && (
      (date == null) || (preavis.getPeriodeNonEffectueePayee().getFin().estApres(date)))) {
      date = preavis.getPeriodeNonEffectueePayee().getFin();
    }
    if ((preavis.getPeriodeNonEffectueeNonPayee() != null) && (
      (date == null) || (preavis.getPeriodeNonEffectueeNonPayee().getFin().estApres(date)))) {
      date = preavis.getPeriodeNonEffectueeNonPayee().getFin();
    }
    return date;
  }
  
  private static boolean isMontantTransactionNul(ActiviteSalarie periodeActiviteSalarie)
  {
    boolean nonNul = false;
    nonNul = ((periodeActiviteSalarie.getQuantiteEuroIndemniteTransactionnelle() != null) && (periodeActiviteSalarie.getQuantiteEuroIndemniteTransactionnelle().getValeur().compareTo(BigDecimal.ZERO) != 0)) || (periodeActiviteSalarie.getContrat().isTransactionEnCours());
    
    return !nonNul;
  }
  
  private static boolean isPresenceTransaction(ActiviteSalarie periodeActiviteSalarie)
  {
    boolean presence = false;
    presence = (periodeActiviteSalarie.getContrat().isTransactionEffective()) || (periodeActiviteSalarie.getContrat().isTransactionEnCours());
    
    return presence;
  }
  
  private static boolean isPresenceDommagesInterets(ActiviteSalarie periodeActiviteSalarie)
  {
    return false;
  }
  
  private static boolean isRuptureJustifiee(ActiviteSalarie periodeActiviteSalarie)
  {
    boolean justifie = false;
    int motifFin = periodeActiviteSalarie.getContrat().getCodeMotifFin();
    switch (motifFin)
    {
    case 22: 
    case 23: 
    case 24: 
    case 46: 
      justifie = true;
      break;
    }
    return justifie;
  }
  
  private static boolean isRuptureAnticipee(ActiviteSalarie periodeActiviteSalarie)
  {
    boolean anticipe = false;
    switch (periodeActiviteSalarie.getCodeMotifFin())
    {
    case 15: 
    case 22: 
    case 23: 
    case 24: 
    case 35: 
    case 38: 
    case 39: 
    case 46: 
      anticipe = true;
      break;
    }
    return anticipe;
  }
  
  private static boolean isAncienneteSuffisante(ActiviteSalarie periodeActiviteSalarie)
  {
    boolean isSuffisant = false;
    
    Preavis preavis = periodeActiviteSalarie.getContrat().getPreavis();
    if ((preavis != null) && (preavis.getPeriodeNonEffectueeNonPayee() != null)) {
      isSuffisant = true;
    }
    return isSuffisant;
  }
  
  private static boolean estCDI(ActiviteSalarie periodeActiviteSalarie)
  {
    boolean cdi = true;
    int nature = periodeActiviteSalarie.getContrat().getNature();
    if (nature == 2) {
      cdi = false;
    }
    return cdi;
  }
}

/* Location:
 * Qualified Name:     ConstitutionPMC
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */