package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.OdAssuranceSpec;
import fr.unedic.cali.asu.outilsfonctionnels.filtre.FiltreDemandeAsr;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDateLimiteIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.outilsfonctionnels.AppelCalculParLiquidation;
import fr.unedic.cali.outilsfonctionnels.ComparateurSurDateDeclenchementDemandeDecroissante;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieSurMemeContratGAEC;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionAsr;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreOuvertureDroitStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologieDebuts;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import fr.unedic.util.temps.UniteDuree;
import java.util.Iterator;

public final class OutilAsr
{
  private static final DureeCalendaire DEUX_ANS = new DureeCalendaire(2, 0, 0);
  private static final int PRECISION_ARRONDI_CONVERTION = 0;
  
  public static Demande getDemandeAsrPrecedente(DemandeSpec pDemande, Damj pDateRecherche)
  {
    FiltresTemporel listeFiltres = new FiltresTemporel();
    listeFiltres.ajouterFiltre(new FiltreDemandeAsr());
    
    DemandeSpec demandeRetour = null;
    Chronologie chronologieDemandes = pDemande.getDemandeur().getChronoDemandes().copier(listeFiltres);
    chronologieDemandes.setComparateur(new ComparateurSurDateDeclenchementDemandeDecroissante());
    chronologieDemandes.iterer();
    while (chronologieDemandes.encoreSuivant())
    {
      DemandeSpec demande = (DemandeSpec)chronologieDemandes.elementSuivant();
      if ((demande.estDecisionnee()) && (demande.getDateRecherche().estAvantOuCoincideAvec(pDateRecherche)))
      {
        demandeRetour = demande;
        break;
      }
    }
    return (Demande)demandeRetour;
  }
  
  public static AttributionSpec rechercherDernierDroitAsrAvecReexamen(DemandeSpec demande)
  {
    FiltreET filtreAsr = new FiltreET();
    filtreAsr.ajouterFiltre(new FiltreAttributionStandardAssurance(true, false, false, false, null));
    filtreAsr.ajouterFiltre(new FiltreAttributionAsr());
    return (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande.getDateDepot().lendemain(), filtreAsr);
  }
  
  public static AttributionSpec rechercherDernierDroitAsr(DemandeSpec demande)
  {
    FiltreET filtreAsr = new FiltreET();
    filtreAsr.ajouterFiltre(new FiltreAttributionStandardAssurance(true, true, false, false, null));
    filtreAsr.ajouterFiltre(new FiltreAttributionAsr());
    return (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande.getDateDepot().lendemain(), filtreAsr);
  }
  
  public static OdAssuranceSpec rechercherDerniereOdAsr(DemandeSpec demande)
  {
    FiltreET filtre = new FiltreET();
    filtre.ajouterFiltre(new FiltreOuvertureDroitStandardAssurance(true, true, false, false, null));
    filtre.ajouterFiltre(new FiltreAttributionAsr());
    return (OdAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande.getDateDepot().lendemain(), filtre);
  }
  
  public static Quantite calculerReliquatArePrecedentAsr(Demande demandeAsr, AttributionAssuranceSpec attributionArePrecedente)
    throws ApplicativeException
  {
    ResultatExecutionCalculSpec resultatCalcul = AppelCalculParLiquidation.executerCalculDeterminationEtatDroit(attributionArePrecedente, demandeAsr.getDateRecherche().veille(), true);
    
    return new Quantite(Mathematiques.arrondiASup(resultatCalcul.getReliquatAREAvecMaintien().getValeur(), 0), UniteDuree.JOUR);
  }
  
  public static boolean estDemandeFinAsrContexteAsrPrecSuiteCsr(Demande demande)
    throws ApplicativeException
  {
    if (!OutilDemande.estUneDemandeFinDroitAsr(demande)) {
      return false;
    }
    boolean estDemandeFinAsrContexteAsrPrecSuiteCsr = false;
    Demande demandeAsrPrec = getDemandeAsrPrecedente(demande, demande.getDateRecherche());
    if ((demandeAsrPrec != null) && (demandeAsrPrec.getContexteAffiliationValide() != null)) {
      estDemandeFinAsrContexteAsrPrecSuiteCsr = true;
    }
    return estDemandeFinAsrContexteAsrPrecSuiteCsr;
  }
  
  public static boolean estDeuxAnsAnciennetee(DemandeAssuranceSpec demande, TravailSpec dernierSinistre)
  {
    Chronologie chronoPeriodesFct = demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(new FiltreActiviteSalarieSurMemeContratGAEC(dernierSinistre));
    
    Damj minCt = null;
    Damj maxCt = null;
    Damj debutCt = null;
    Damj finCt = null;
    Periode contrat = null;
    boolean dureeCTSupA2Ans = false;
    if (!chronoPeriodesFct.estVide())
    {
      Iterator element = chronoPeriodesFct.iterer();
      while (element.hasNext())
      {
        ActiviteSalarie activiteSalarie = (ActiviteSalarie)element.next();
        debutCt = activiteSalarie.getDateDebut();
        finCt = activiteSalarie.getDateFin();
        if ((minCt == null) || (debutCt.estAvant(minCt))) {
          minCt = debutCt;
        }
        if ((maxCt == null) || (finCt.estApres(maxCt))) {
          maxCt = finCt;
        }
      }
      if ((minCt != null) && (maxCt != null)) {
        contrat = new Periode(minCt, maxCt.lendemain());
      }
    }
    if (contrat != null) {
      dureeCTSupA2Ans = contrat.getDureeCalendaire().compareTo(DEUX_ANS) >= 0;
    }
    return dureeCTSupA2Ans;
  }
  
  public static int trouverDureeADateLimiteIndemnisation(DossierExamen dossierExamen)
  {
    int dureeMaxIndemnisation = 0;
    if (dossierExamen.getConstitutionDateLimiteIndemnisation() != null)
    {
      Damj dateDebutIndemnisation = dossierExamen.getConstitutionDateLimiteIndemnisation().getDateDebutIndem();
      
      Damj dateFinIndemnisation = dossierExamen.getConstitutionDateLimiteIndemnisation().getDateLimiteIndem();
      Periode periodeIndemnisationMax = new Periode(dateDebutIndemnisation, dateFinIndemnisation);
      dureeMaxIndemnisation = periodeIndemnisationMax.getDuree();
    }
    return dureeMaxIndemnisation;
  }
  
  public static AttributionSpec rechercherAttributionAsrPrecedent(DemandeSpec demande)
  {
    return rechercherAttributionAsrPrecedent(demande, demande.getDateDeclenchementExamen().lendemain());
  }
  
  public static AttributionSpec rechercherAttributionAsrPrecedent(DemandeSpec demande, Damj date)
  {
    FiltreET filtreAsr = new FiltreET();
    filtreAsr.ajouterFiltre(new FiltreAttributionStandardAssurance(true, true, false, false, null));
    filtreAsr.ajouterFiltre(new FiltreAttributionAsr());
    return (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), date, filtreAsr);
  }
}

/* Location:
 * Qualified Name:     OutilAsr
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */