package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.PensionInvaliditeChainee;
import fr.unedic.cali.asu.dom.SousPensionInvaliditeChainee;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionMontantsBruts;
import fr.unedic.cali.autresdoms.cohab.dom.spec.IndividuCohabSpec;
import fr.unedic.cali.autresdoms.cohab.dom.spec.PeriodePensionInvaliditeChaineeSpec;
import fr.unedic.cali.autresdoms.cohab.dom.spec.PeriodeSousPensionInvaliditeChaineeSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.autresdoms.ga.dom.Incident;
import fr.unedic.cali.autresdoms.ga.dom.Preavis;
import fr.unedic.cali.autresdoms.ga.dom.spec.IndividuGaSpec;
import fr.unedic.cali.calcul.OutillageCalculADate;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreIncident;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreNaturePeriodeEvenementPersonnel;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreNaturePeriodeEvenementPersonnelAvecIntensite;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreNegation;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreOu;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreFinDansBornes;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.ObjetChronoPeriodeConcrete;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;

public class OutilPensionInvalidite
  implements OutilFonctionnel
{
  private static final BigDecimal INTENSITE = new BigDecimal("1");
  
  public static PensionInvaliditeChainee conversionDomPensionInvaliditeEnDomLiquidation(PeriodePensionInvaliditeChaineeSpec p_pensionInvalidite)
  {
    PeriodeSousPensionInvaliditeChaineeSpec sousPensionInvalidite = null;
    SousPensionInvaliditeChainee sousPensionARetourner = null;
    PensionInvaliditeChainee pensionARetourner = new PensionInvaliditeChainee();
    
    pensionARetourner.setDateDebut(p_pensionInvalidite.getDateDebut());
    pensionARetourner.setDateFin(p_pensionInvalidite.getDateFin());
    pensionARetourner.setOrganismeFinanceur(p_pensionInvalidite.getOrganismeFinanceur());
    pensionARetourner.setStatut(p_pensionInvalidite.getStatut());
    if ((p_pensionInvalidite.getListeSousPensionInvalidite() != null) && (p_pensionInvalidite.getListeSousPensionInvalidite().size() != 0))
    {
      Iterator iter = p_pensionInvalidite.getListeSousPensionInvalidite().iterator();
      while (iter.hasNext())
      {
        sousPensionARetourner = new SousPensionInvaliditeChainee();
        sousPensionInvalidite = (PeriodeSousPensionInvaliditeChaineeSpec)iter.next();
        sousPensionARetourner.setCodeNature(sousPensionInvalidite.getCodeNature());
        sousPensionARetourner.setDateDebut(sousPensionInvalidite.getDateDebut());
        sousPensionARetourner.setDateFin(sousPensionInvalidite.getDateFin());
        sousPensionARetourner.setEtat(sousPensionInvalidite.getEtat());
        sousPensionARetourner.setMontant(sousPensionInvalidite.getMontant());
        pensionARetourner.ajouterSousPensionInvalidite(sousPensionARetourner);
      }
    }
    return pensionARetourner;
  }
  
  protected static PeriodePensionInvaliditeChaineeSpec rechercherPensionInvalidite(Collection p_listePensionInvalidite, PeriodePensionInvaliditeChaineeSpec p_pensionInvalidite)
  {
    PeriodePensionInvaliditeChaineeSpec pensionARetourner = null;
    PeriodePensionInvaliditeChaineeSpec pensionInvalidite = null;
    if ((p_listePensionInvalidite != null) && (p_listePensionInvalidite.size() != 0))
    {
      Iterator iter = p_listePensionInvalidite.iterator();
      while (iter.hasNext())
      {
        pensionInvalidite = (PeriodePensionInvaliditeChaineeSpec)iter.next();
        if (pensionInvalidite.compareTo(p_pensionInvalidite) == 0) {
          pensionARetourner = pensionInvalidite;
        }
      }
    }
    return pensionARetourner;
  }
  
  public static PeriodePensionInvaliditeChaineeSpec rechercherPensionInvaliditeSurDemande(DemandeAssuranceSpec p_demande, PeriodePensionInvaliditeChaineeSpec p_pensionInvalidite)
  {
    Collection listePensionInvalidite = p_demande.getDonneesTemporaires().getListePensionInvalidite();
    
    return rechercherPensionInvalidite(listePensionInvalidite, p_pensionInvalidite);
  }
  
  public static PeriodePensionInvaliditeChaineeSpec rechercherPensionInvaliditeSurAttribution(AttributionAssuranceSpec p_attribution, PeriodePensionInvaliditeChaineeSpec p_pensionInvalidite)
  {
    Collection listePensionInvalidite = p_attribution.getListePensionInvalidite();
    
    return rechercherPensionInvalidite(listePensionInvalidite, p_pensionInvalidite);
  }
  
  public static PeriodePensionInvaliditeChaineeSpec rechercherPensionInvaliditeSurElementBaseIndemnisation(ElementBaseIndemnisation p_ebi, PeriodePensionInvaliditeChaineeSpec p_pensionInvalidite)
  {
    Collection listePensionInvalidite = p_ebi.getListePensionInvalidite();
    
    return rechercherPensionInvalidite(listePensionInvalidite, p_pensionInvalidite);
  }
  
  public static Collection determinerStatutPensionInvaliditeDroitCourant(AttributionSpec p_attribution)
    throws CoucheLogiqueException
  {
    PeriodePensionInvaliditeChaineeSpec pensionInvaliditeTrouve = null;
    ArrayList listePensionInvalidite = new ArrayList();
    PeriodePensionInvaliditeChaineeSpec pensionInvalidite = null;
    Damj dateExamen = p_attribution.getDateExamen();
    
    Chronologie chronoPeriodeActivitesalarie = recupererListeActiviteSalarieHorsSuspension(p_attribution);
    
    IndividuCohabSpec individuCohab = p_attribution.getDemande().getDemandeur();
    Chronologie listePensionsInvaliditeChainees = individuCohab.getChronoPensionsInvaliditeChainees();
    if ((listePensionsInvaliditeChainees != null) && (listePensionsInvaliditeChainees.getTaille() != 0))
    {
      Iterator iterPension = listePensionsInvaliditeChainees.iterer();
      while (iterPension.hasNext())
      {
        pensionInvalidite = (PeriodePensionInvaliditeChaineeSpec)iterPension.next();
        if ((dateExamen == null) || (!pensionInvalidite.getDateDebut().estApres(dateExamen)))
        {
          pensionInvaliditeTrouve = rechercherPensionInvaliditeSurDemande((DemandeAssuranceSpec)p_attribution.getDemande(), pensionInvalidite);
          if (pensionInvaliditeTrouve != null)
          {
            listePensionInvalidite.add(pensionInvaliditeTrouve.copie());
          }
          else
          {
            int statut = recupererStatutSousPensionInvalidite(pensionInvalidite, chronoPeriodeActivitesalarie);
            pensionInvaliditeTrouve = conversionDomPensionInvaliditeEnDomLiquidation(pensionInvalidite);
            pensionInvaliditeTrouve.setStatut(statut);
            listePensionInvalidite.add(pensionInvaliditeTrouve);
          }
        }
      }
    }
    return listePensionInvalidite;
  }
  
  private static Chronologie recupererListeActiviteSalarieHorsSuspension(AttributionSpec p_attribution)
    throws CoucheLogiqueException
  {
    Chronologie chronoActiviteSalarie = new ChronologiePeriodes();
    
    Periode pra = ((DossierAffectation)p_attribution.getDossierAffecte()).getValidationProduit().getPeriodePra();
    if (pra != null)
    {
      FiltresTemporel listeFiltres = new FiltresTemporel();
      listeFiltres.ajouterFiltre(new FiltreActiviteSalarie());
      listeFiltres.ajouterFiltre(new FiltreFinDansBornes(pra));
      chronoActiviteSalarie = p_attribution.getDemande().getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(listeFiltres);
    }
    ChronologiePeriodes chronoTravailContrat = recupererChronoTravailSurContrat(chronoActiviteSalarie);
    
    ChronologiePeriodes chronoPeriodePEP = recupererChronoPEP(p_attribution);
    if (!chronoTravailContrat.estVide()) {
      chronoTravailContrat = chronoTravailContrat.fusionnerChevauchementPeriodes();
    }
    ChronologiePeriodes chronoIntersection = new ChronologiePeriodes();
    ChronologiePeriodes chronoPeriodeActiviteSalarie = new ChronologiePeriodes();
    if (!chronoTravailContrat.estVide())
    {
      chronoTravailContrat.iterer();
      while (chronoTravailContrat.encoreSuivant())
      {
        ObjetChronoPeriode periodeActivite = (ObjetChronoPeriode)chronoTravailContrat.elementSuivant();
        
        Periode periodePas = new Periode(periodeActivite.getDateDebut(), periodeActivite.getDateFin());
        if (!chronoPeriodePEP.estVide())
        {
          chronoPeriodePEP.iterer();
          while (chronoPeriodePEP.encoreSuivant())
          {
            ObjetChronoPeriode periodeEvenement = (ObjetChronoPeriode)chronoPeriodePEP.elementSuivant();
            
            Periode periodeIntersection = periodeEvenement.periodeIntersection(periodePas);
            if (periodeIntersection != null) {
              chronoIntersection.ajouter(new Incident(periodeIntersection));
            }
          }
        }
        chronoPeriodeActiviteSalarie.ajouter(OutillageCalculADate.boucheLesTrous(chronoIntersection, ObjetChronoPeriodeConcrete.class, periodePas.getDebut(), periodePas.getFin()));
      }
    }
    FiltresTemporel filtres = new FiltresTemporel();
    FiltreIncident filtreIncident = new FiltreIncident();
    filtres.ajouterFiltre(new FiltreNegation(filtreIncident));
    
    return chronoPeriodeActiviteSalarie.copier(filtres);
  }
  
  private static ChronologiePeriodes recupererChronoPEP(AttributionSpec p_attribution)
  {
    IndividuGaSpec individu = p_attribution.getDemandeur();
    
    FiltresTemporel filtres = new FiltresTemporel();
    FiltreNaturePeriodeEvenementPersonnel filtreNaturePeriodeEvenementPersonnel = new FiltreNaturePeriodeEvenementPersonnel();
    
    filtreNaturePeriodeEvenementPersonnel.ajouterNatureEvenementPersonnel(36);
    filtreNaturePeriodeEvenementPersonnel.ajouterNatureEvenementPersonnel(37);
    filtreNaturePeriodeEvenementPersonnel.ajouterNatureEvenementPersonnel(38);
    filtreNaturePeriodeEvenementPersonnel.ajouterNatureEvenementPersonnel(39);
    filtreNaturePeriodeEvenementPersonnel.ajouterNatureEvenementPersonnel(40);
    filtreNaturePeriodeEvenementPersonnel.ajouterNatureEvenementPersonnel(41);
    filtreNaturePeriodeEvenementPersonnel.ajouterNatureEvenementPersonnel(42);
    filtreNaturePeriodeEvenementPersonnel.ajouterNatureEvenementPersonnel(43);
    filtreNaturePeriodeEvenementPersonnel.ajouterNatureEvenementPersonnel(44);
    filtreNaturePeriodeEvenementPersonnel.ajouterNatureEvenementPersonnel(45);
    filtreNaturePeriodeEvenementPersonnel.ajouterNatureEvenementPersonnel(46);
    filtreNaturePeriodeEvenementPersonnel.ajouterNatureEvenementPersonnel(47);
    filtreNaturePeriodeEvenementPersonnel.ajouterNatureEvenementPersonnel(48);
    
    FiltreNaturePeriodeEvenementPersonnelAvecIntensite filtreNaturePeriodeEvenementPersonnelAvecIntensite = new FiltreNaturePeriodeEvenementPersonnelAvecIntensite();
    filtreNaturePeriodeEvenementPersonnelAvecIntensite.ajouterNatureEvenementPersonnel(33);
    filtreNaturePeriodeEvenementPersonnelAvecIntensite.ajouterNatureEvenementPersonnel(32);
    filtreNaturePeriodeEvenementPersonnelAvecIntensite.ajouterIntensite(INTENSITE);
    
    filtreNaturePeriodeEvenementPersonnel.ajouterNatureEvenementPersonnel(21);
    filtreNaturePeriodeEvenementPersonnel.ajouterNatureEvenementPersonnel(22);
    filtreNaturePeriodeEvenementPersonnel.ajouterNatureEvenementPersonnel(23);
    filtreNaturePeriodeEvenementPersonnel.ajouterNatureEvenementPersonnel(25);
    filtreNaturePeriodeEvenementPersonnel.ajouterNatureEvenementPersonnel(26);
    filtreNaturePeriodeEvenementPersonnel.ajouterNatureEvenementPersonnel(27);
    filtreNaturePeriodeEvenementPersonnel.ajouterNatureEvenementPersonnel(28);
    
    FiltreOu filtreOu = new FiltreOu();
    filtreOu.ajouterFiltre(filtreNaturePeriodeEvenementPersonnelAvecIntensite);
    filtreOu.ajouterFiltre(filtreNaturePeriodeEvenementPersonnel);
    filtres.ajouterFiltre(filtreOu);
    
    Chronologie chronoPep = individu.getChronoPeriodePasseProfessionnelLiquidation().copier(filtres);
    
    ChronologiePeriodes chronoPeriodePep = construireChronologiePeriode(chronoPep);
    if (!chronoPeriodePep.estVide()) {
      chronoPeriodePep = chronoPeriodePep.fusionnerChevauchementPeriodes();
    }
    return chronoPeriodePep;
  }
  
  private static int recupererStatutSousPensionInvalidite(PeriodePensionInvaliditeChaineeSpec p_pensionInvalidite, Chronologie p_chronoActiviteSalarie)
  {
    PeriodeSousPensionInvaliditeChaineeSpec sousPensionInvalidite = null;
    
    Collection listeSousPension = p_pensionInvalidite.getListeSousPensionInvalidite();
    if ((listeSousPension != null) && (listeSousPension.size() != 0))
    {
      Iterator iterSousPension = listeSousPension.iterator();
      while (iterSousPension.hasNext())
      {
        sousPensionInvalidite = (PeriodeSousPensionInvaliditeChaineeSpec)iterSousPension.next();
        if (((sousPensionInvalidite.getCodeNature().equalsIgnoreCase("INV2")) || (sousPensionInvalidite.getCodeNature().equalsIgnoreCase("INV3"))) && 
        
          (p_chronoActiviteSalarie != null) && (!p_chronoActiviteSalarie.estVide()))
        {
          p_chronoActiviteSalarie.iterer();
          while (p_chronoActiviteSalarie.encoreSuivant())
          {
            ObjetChronoPeriode periode = (ObjetChronoPeriode)p_chronoActiviteSalarie.elementSuivant();
            if (periode.chevauche(sousPensionInvalidite.getPeriode())) {
              return 2;
            }
          }
        }
      }
    }
    return 1;
  }
  
  public static Collection determinerStatutPensionInvaliditeDroitResultant(AttributionSpec p_attribution)
  {
    Attribution attribution = null;
    AttributionAssuranceSpec attributionPrecedente = null;
    boolean aListePensionInvaliditeIdentique = false;
    Damj dateExamen = p_attribution.getDateExamen();
    
    PeriodePensionInvaliditeChaineeSpec pensionInvalidite = null;
    PeriodePensionInvaliditeChaineeSpec pensionInvaliditeCopie = null;
    PeriodePensionInvaliditeChaineeSpec pensionInvaliditeAttributionPrecedente = null;
    ArrayList listePensionInvaliditeRetourne = new ArrayList();
    ArrayList listePensionInvaliditeEnCoursADateAttribution = new ArrayList();
    if ((p_attribution instanceof Attribution)) {
      attribution = (Attribution)p_attribution;
    } else {
      return listePensionInvaliditeRetourne;
    }
    Collection listePensionInvalidite = attribution.getConstitutionMontantsBruts().getListePensionInvalidite();
    if ((listePensionInvalidite != null) && (listePensionInvalidite.size() != 0))
    {
      aListePensionInvaliditeIdentique = true;
      Iterator iter = listePensionInvalidite.iterator();
      while (iter.hasNext())
      {
        pensionInvalidite = (PeriodePensionInvaliditeChaineeSpec)iter.next();
        if ((dateExamen == null) || (!pensionInvalidite.getDateDebut().estApres(dateExamen)))
        {
          pensionInvaliditeCopie = conversionDomPensionInvaliditeEnDomLiquidation(pensionInvalidite);
          if (pensionInvaliditeCopie.getPeriode().contient(attribution.getDateAttribution()))
          {
            if (attribution.getAttributionPrecedente() != null)
            {
              attributionPrecedente = attribution.getAttributionPrecedente();
              pensionInvaliditeAttributionPrecedente = rechercherPensionInvaliditeSurAttribution(attributionPrecedente, pensionInvaliditeCopie);
              if ((pensionInvaliditeAttributionPrecedente == null) || (pensionInvaliditeAttributionPrecedente.getStatut() != 2)) {
                aListePensionInvaliditeIdentique = false;
              }
              listePensionInvaliditeEnCoursADateAttribution.add(pensionInvaliditeCopie);
            }
          }
          else {
            listePensionInvaliditeRetourne.add(pensionInvaliditeCopie);
          }
        }
      }
    }
    if (aListePensionInvaliditeIdentique)
    {
      Iterator iter = listePensionInvaliditeEnCoursADateAttribution.iterator();
      while (iter.hasNext())
      {
        pensionInvalidite = (PeriodePensionInvaliditeChaineeSpec)iter.next();
        pensionInvalidite.setStatut(2);
      }
    }
    listePensionInvaliditeRetourne.addAll(listePensionInvaliditeEnCoursADateAttribution);
    
    return listePensionInvaliditeRetourne;
  }
  
  public static ChronologiePeriodes fusionnerChronoPepChronoIncident(ChronologiePeriodes p_chronoPeriodeIncident, ChronologiePeriodes p_chronoPeriodePEP)
  {
    ChronologiePeriodes chronoFusionnee = new ChronologiePeriodes();
    if (p_chronoPeriodeIncident != null)
    {
      Iterator it = p_chronoPeriodeIncident.iterer();
      while (it.hasNext())
      {
        ObjetChronoPeriode periode = (ObjetChronoPeriode)it.next();
        chronoFusionnee.ajouter(periode);
      }
    }
    if (p_chronoPeriodePEP != null)
    {
      Iterator it = p_chronoPeriodePEP.iterer();
      while (it.hasNext())
      {
        ObjetChronoPeriode periode = (ObjetChronoPeriode)it.next();
        chronoFusionnee.ajouter(periode);
      }
    }
    ChronologiePeriodes chronoEvenementFusionnee = new ChronologiePeriodes();
    if (!chronoFusionnee.estVide()) {
      chronoEvenementFusionnee = chronoFusionnee.fusionnerChevauchementPeriodes();
    }
    return chronoEvenementFusionnee;
  }
  
  public static ChronologiePeriodes construireChronologiePeriode(Chronologie p_chronoActivite)
  {
    if ((p_chronoActivite instanceof ChronologiePeriodes)) {
      return (ChronologiePeriodes)p_chronoActivite;
    }
    ChronologiePeriodes resultat = new ChronologiePeriodes();
    if (p_chronoActivite != null)
    {
      Iterator it = p_chronoActivite.iterer();
      while (it.hasNext())
      {
        ObjetChronoPeriode periode = (ObjetChronoPeriode)it.next();
        resultat.ajouter(periode);
      }
    }
    return resultat;
  }
  
  private static ChronologiePeriodes recupererChronoTravailSurContrat(Chronologie p_chronoActiviteSalarie)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes chronoPeriodeRetour = new ChronologiePeriodes();
    
    FiltresTemporel filtres = new FiltresTemporel();
    FiltreNaturePeriodeEvenementPersonnel filtreNaturePeriodeEvenementPersonnel = new FiltreNaturePeriodeEvenementPersonnel();
    
    filtreNaturePeriodeEvenementPersonnel.ajouterNatureEvenementPersonnel(7);
    filtreNaturePeriodeEvenementPersonnel.ajouterNatureEvenementPersonnel(8);
    filtreNaturePeriodeEvenementPersonnel.ajouterNatureEvenementPersonnel(11);
    filtreNaturePeriodeEvenementPersonnel.ajouterNatureEvenementPersonnel(12);
    filtreNaturePeriodeEvenementPersonnel.ajouterNatureEvenementPersonnel(34);
    filtreNaturePeriodeEvenementPersonnel.ajouterNatureEvenementPersonnel(35);
    filtreNaturePeriodeEvenementPersonnel.ajouterNatureEvenementPersonnel(13);
    
    FiltreNaturePeriodeEvenementPersonnelAvecIntensite filtreNaturePeriodeEvenementPersonnelAvecIntensite = new FiltreNaturePeriodeEvenementPersonnelAvecIntensite();
    filtreNaturePeriodeEvenementPersonnelAvecIntensite.ajouterNatureEvenementPersonnel(9);
    filtreNaturePeriodeEvenementPersonnelAvecIntensite.ajouterNatureEvenementPersonnel(10);
    filtreNaturePeriodeEvenementPersonnelAvecIntensite.ajouterIntensite(INTENSITE);
    
    FiltreOu filtreOu = new FiltreOu();
    filtreOu.ajouterFiltre(filtreNaturePeriodeEvenementPersonnelAvecIntensite);
    filtreOu.ajouterFiltre(filtreNaturePeriodeEvenementPersonnel);
    filtres.ajouterFiltre(filtreOu);
    if ((p_chronoActiviteSalarie != null) && (!p_chronoActiviteSalarie.estVide()))
    {
      p_chronoActiviteSalarie.iterer();
      while (p_chronoActiviteSalarie.encoreSuivant())
      {
        ActiviteSalarie activite = (ActiviteSalarie)p_chronoActiviteSalarie.elementSuivant();
        
        ChronologiePeriodes chronoPeriodeIncident = new ChronologiePeriodes();
        ChronologiePeriodes chronoPeriodeIncidentsResultants = new ChronologiePeriodes();
        if (!activite.getListePeriodesIncident().estVide())
        {
          chronoPeriodeIncident.ajouter(activite.getListePeriodesIncident());
          
          Chronologie chronoIncident = chronoPeriodeIncident.copier(filtres);
          chronoPeriodeIncident = construireChronologiePeriode(chronoIncident);
          chronoPeriodeIncidentsResultants.ajouter(chronoPeriodeIncident);
        }
        Periode preavis = null;
        if ((activite.getContrat() != null) && (activite.getContrat().getPreavis() != null) && (activite.getContrat().getPreavis().getPeriodeNonEffectueePayee() != null)) {
          preavis = activite.getContrat().getPreavis().getPeriodeNonEffectueePayee();
        }
        if (preavis != null) {
          chronoPeriodeIncidentsResultants.ajouter(new ObjetChronoPeriodeConcrete(preavis));
        }
        if ((activite.getContrat() != null) && (activite.getContrat().getDernierJourTravaillePaye() != null) && (activite.getDateFin() != null) && (activite.getContrat().getDernierJourTravaillePaye().estAvant(activite.getDateFin()))) {
          chronoPeriodeIncidentsResultants.ajouter(new ObjetChronoPeriodeConcrete(activite.getContrat().getDernierJourTravaillePaye(), activite.getDateFin()));
        }
        chronoPeriodeRetour.ajouter(OutillageCalculADate.retourneLesTrous(chronoPeriodeIncidentsResultants, ObjetChronoPeriodeConcrete.class, activite.getPeriode().getDebut(), activite.getPeriode().getFin()));
      }
    }
    return chronoPeriodeRetour;
  }
  
  public static boolean estCasParticulierPensionInvaliditeDroitResultant(AttributionSpec p_attribution)
  {
    Attribution attribution = null;
    AttributionAssuranceSpec attributionPrecedente = null;
    boolean aListePensionInvaliditeIdentique = false;
    Damj dateExamen = p_attribution.getDateExamen();
    
    PeriodePensionInvaliditeChaineeSpec pensionInvalidite = null;
    PeriodePensionInvaliditeChaineeSpec pensionInvaliditeCopie = null;
    PeriodePensionInvaliditeChaineeSpec pensionInvaliditeAttributionPrecedente = null;
    if ((p_attribution instanceof Attribution)) {
      attribution = (Attribution)p_attribution;
    } else {
      return false;
    }
    Collection listePensionInvalidite = attribution.getConstitutionMontantsBruts().getListePensionInvalidite();
    if ((listePensionInvalidite != null) && (listePensionInvalidite.size() != 0))
    {
      aListePensionInvaliditeIdentique = true;
      Iterator iter = listePensionInvalidite.iterator();
      while (iter.hasNext())
      {
        pensionInvalidite = (PeriodePensionInvaliditeChaineeSpec)iter.next();
        if ((dateExamen == null) || (!pensionInvalidite.getDateDebut().estApres(dateExamen)))
        {
          pensionInvaliditeCopie = conversionDomPensionInvaliditeEnDomLiquidation(pensionInvalidite);
          if ((pensionInvaliditeCopie.getPeriode().contient(attribution.getDateAttribution())) && 
            (attribution.getAttributionPrecedente() != null))
          {
            attributionPrecedente = attribution.getAttributionPrecedente();
            pensionInvaliditeAttributionPrecedente = rechercherPensionInvaliditeSurAttribution(attributionPrecedente, pensionInvaliditeCopie);
            if ((pensionInvaliditeAttributionPrecedente == null) || (pensionInvaliditeAttributionPrecedente.getStatut() != 2)) {
              aListePensionInvaliditeIdentique = false;
            }
          }
        }
      }
    }
    return aListePensionInvaliditeIdentique;
  }
}

/* Location:
 * Qualified Name:     OutilPensionInvalidite
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */