package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.affectation.parametres.AccesDecorReglementaire;
import fr.unedic.cali.affectation.parametres.CriteresQualification;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.autresdoms.ga.dom.spec.PeriodeGaecSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.ConteneurAccesDecorReglementaire;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DomSimulationAffiliation;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.ResultatSimulationAffiliation;
import fr.unedic.cali.dom.affectation.DecorReglementaire;
import fr.unedic.cali.dom.affectation.ProduitAsuCge01P06;
import fr.unedic.cali.dom.affectation.ProduitAsuCge01P07;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.liquidation.pnds.StrategieDeterminationPNDSSpec;
import fr.unedic.cali.liquidation.pnds.outilsfonctionnels.FabriqueStrategieDeterminationPNDS;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreDateFinCoincideAvecDate;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.ObjetChronoPeriode;
import java.util.Collection;
import java.util.Iterator;

public class OutilSimulationAffiliation
  implements OutilFonctionnel
{
  private static final Damj DATE_PIVOT_CONTROLE_MAYOTTE = new Damj(2013, 1, 1);
  
  public static ResultatSimulationAffiliation calculAffi(DomSimulationAffiliation domSimulationAffiliation)
    throws ApplicativeException
  {
    PeriodeGaecSpec periodeW = domSimulationAffiliation.getIndividu().rechercherPeriodePasseProfessionnel(domSimulationAffiliation.getPeriodeFct());
    PeriodeGaecSpec periodeFG = domSimulationAffiliation.getIndividu().rechercherPeriodePasseProfessionnel(domSimulationAffiliation.getPeriodeFG());
    
    domSimulationAffiliation.setDateFct(periodeW.getDateFin());
    domSimulationAffiliation.setDateFgd(periodeFG.getDateFin());
    
    ActiviteSalarie contratTravail = (ActiviteSalarie)periodeW;
    if (domSimulationAffiliation.getDateFgd() == null) {
      domSimulationAffiliation.setDateFgd(domSimulationAffiliation.getDateFct());
    }
    if ((domSimulationAffiliation.getDatePra() != null) && (domSimulationAffiliation.getDateFct().estAvant(domSimulationAffiliation.getDatePra()))) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_FCT_APRES_PRA");
    }
    if ((domSimulationAffiliation.getDateFgd() != null) && (domSimulationAffiliation.getDateFgd().estAvant(domSimulationAffiliation.getDateFct()))) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_FGD_AVANT_PRA");
    }
    if ((domSimulationAffiliation.getDateFgd() != null) && (!domSimulationAffiliation.getDateFgd().coincideAvec(domSimulationAffiliation.getDateFct())) && (!verifierFctEstDansGaec(domSimulationAffiliation.getIndividu(), domSimulationAffiliation.getDateFgd()))) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ERR_FGD_PAS_DANS_GAEC");
    }
    if (contratTravail.estEnConflit()) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_FCT_CONFLIT");
    }
    if (verifierExisteFgdEnConflit(domSimulationAffiliation.getIndividu(), domSimulationAffiliation.getDateFgd())) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_FGT_CONFLIT");
    }
    if ((domSimulationAffiliation.getTypeCoordinationEuropeenne() != 0) && (!domSimulationAffiliation.getDateFct().coincideAvec(domSimulationAffiliation.getDateFgd()))) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_FCT_FGD_COORD_CEE");
    }
    ActiviteSalarie contratFgd = (ActiviteSalarie)periodeFG;
    if (((contratFgd.getCollectionOrigineInformationPAS().contains(new Integer(10))) && (contratFgd.getContrat().getPohf() == 9)) || ((contratTravail.getCollectionOrigineInformationPAS().contains(new Integer(10))) && (contratTravail.getContrat().getPohf() == 9))) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ERR_FGD_E301_HORS_FRANCE");
    }
    if (((periodeFG instanceof ActiviteSalarie)) && (((ActiviteSalarie)periodeFG).isEstPeriodeMayotte()) && (periodeFG.getDateFin().estAvant(DATE_PIVOT_CONTROLE_MAYOTTE))) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_DONNEES_FORCEES_SIMU_AFFI_FG_MAYOTTE");
    }
    domSimulationAffiliation.setActivite(contratTravail);
    
    DecorReglementaire produitsDisponibles = getDecorReglementaire(domSimulationAffiliation, (TravailSpec)periodeFG);
    
    domSimulationAffiliation.setDecor(produitsDisponibles);
    
    ProduitAsuSpec asu = determinerProduitRelatifAuSinistre(contratTravail, produitsDisponibles, contratFgd);
    
    return (ResultatSimulationAffiliation)asu.executerSimulationAffiliation(domSimulationAffiliation);
  }
  
  protected static ProduitAsuSpec determinerProduitRelatifAuSinistre(TravailSpec sinistre, DecorReglementaire decorReglementaire, ActiviteSalarie contratFgd)
    throws CoucheLogiqueException
  {
    ProduitAsuSpec produitRelatifSinistre = null;
    if ((sinistre instanceof ActiviteSalarie)) {
      produitRelatifSinistre = ConstitutionDecorReglementaire.determinerProduitSinistre((ActiviteSalarie)sinistre, decorReglementaire);
    }
    if ((contratFgd.isEstPeriodeMayotte()) && ((produitRelatifSinistre instanceof ProduitAsuCge01P07))) {
      produitRelatifSinistre = ProduitAsuCge01P06.getInstance();
    }
    return produitRelatifSinistre;
  }
  
  private static DecorReglementaire getDecorReglementaire(DomSimulationAffiliation domSimulationAffiliation, TravailSpec periodeFG)
    throws CoucheLogiqueException
  {
    ConteneurAccesDecorReglementaire conteneur = new ConteneurAccesDecorReglementaire();
    conteneur.setDateRecherche(domSimulationAffiliation.getDateFgd());
    
    DecorReglementaire decor = AccesDecorReglementaire.getInstance().getDecor(conteneur);
    
    CriteresQualification criteresQualification = new CriteresQualification(decor, periodeFG, domSimulationAffiliation.isEstCoordCee());
    
    AccesDecorReglementaire.getInstance().positionnerCriteresQualifSurPas(criteresQualification, (Individu)domSimulationAffiliation.getIndividu());
    
    return decor;
  }
  
  public static boolean verifierFctEstDansGaec(IndividuSpec individu, Damj dateFct)
  {
    boolean estDansGaec = false;
    
    ChronologiePeriodes chronoPassePro = individu.getChronoPeriodePasseProfessionnelLiquidation();
    Iterator iterPeriodes = chronoPassePro.iterer();
    while ((iterPeriodes.hasNext()) && (!estDansGaec))
    {
      ObjetChronoPeriode pas = (ObjetChronoPeriode)iterPeriodes.next();
      if (((pas instanceof ActiviteSalarie)) && (pas.getDateFin().coincideAvec(dateFct))) {
        estDansGaec = true;
      }
    }
    return estDansGaec;
  }
  
  private static boolean verifierExisteFgdEnConflit(IndividuSpec individu, Damj dateFgd)
  {
    boolean existeFgdEnConflit = false;
    
    ChronologiePeriodes chronoPassePro = individu.getChronoPeriodePasseProfessionnelLiquidation();
    
    chronoPassePro.copier(new FiltreDateFinCoincideAvecDate(dateFgd));
    Iterator it = chronoPassePro.iterer();
    while ((it.hasNext()) && (!existeFgdEnConflit))
    {
      ObjetChronoPeriode pas = (ObjetChronoPeriode)it.next();
      if (((pas instanceof ActiviteSalarie)) && (((ActiviteSalarie)pas).estEnConflit())) {
        existeFgdEnConflit = true;
      }
    }
    return existeFgdEnConflit;
  }
  
  public static void chargementListePNDSIndividu(DemandeSpec demandeCourante, Damj dateExamen)
    throws CoucheLogiqueException
  {
    Damj dateDebutRecherche = Damj.NUIT_DES_TEMPS;
    CritereStrategie critere = new CritereStrategie();
    critere.setDatePivot(dateExamen);
    StrategieDeterminationPNDSSpec strategie = FabriqueStrategieDeterminationPNDS.determinerStrategieDeterminationPNDS(critere);
    AttributionAssuranceSpec attributionAsu = ((DemandeAssuranceSpec)demandeCourante).rechercherOuvertureDroitPrecedenteDuMemeType();
    if (attributionAsu != null) {
      dateDebutRecherche = attributionAsu.getDateFaitGenerateur();
    }
    strategie.determinationPNDSPourIndividuSurPeriode(demandeCourante.getDemandeur(), dateDebutRecherche, dateExamen, demandeCourante.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation(), false);
  }
}

/* Location:
 * Qualified Name:     OutilSimulationAffiliation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */