package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.autresdoms.ga.dom.Preavis;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.RepriseSpec;
import fr.unedic.cali.dom.affectation.ContexteDemandeSpec;
import fr.unedic.cali.dom.affectation.GammeAsu;
import fr.unedic.cali.dom.affectation.LigneSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.outilsfonctionnels.ComparateurSurDateDeclenchementEtPrioriteDemande;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.RechercherDernierSinistre;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieAvecChomageTotalSansRupture;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieRuptureContratSuiteChomageSansRupture;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieSurMemeContratGAEC;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieSuspensionChomageSansRCT;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreNegation;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.services.PasAssezInformationException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologieDebuts;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreDebutApresDate;
import fr.unedic.util.temps.FiltreTemporel;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import fr.unedic.util.temps.Temporel;
import java.util.List;

public class OutilsChomageSansRCT
  implements OutilFonctionnel
{
  public static TravailSpec getPeriodeSuspension(DemandeAssuranceSpec p_demande)
    throws CoucheLogiqueException
  {
    ActiviteSalarie periodeValidationProduit = trouverDernierSinistre(p_demande);
    FiltresTemporel filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreActiviteSalarieSurMemeContratGAEC(periodeValidationProduit));
    filtres.ajouterFiltre(new FiltreDebutApresDate(periodeValidationProduit.getDateFin()));
    filtres.ajouterFiltre(new FiltreActiviteSalarieSuspensionChomageSansRCT());
    Chronologie chronoPeriodes = p_demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(filtres);
    if (chronoPeriodes.estVide())
    {
      OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "Impossible de trouver la période de suspension pour chômage sans RCT" });
      return null;
    }
    return (TravailSpec)chronoPeriodes.premierElement();
  }
  
  public static Damj getDateFinSuspension(DemandeAssuranceSpec p_demande)
  {
    TravailSpec periodeFinSuspension = trouverPeriodeDeSuspension(p_demande);
    Damj dateFinSuspension = null;
    if (periodeFinSuspension != null) {
      dateFinSuspension = periodeFinSuspension.getDateFin();
    }
    return dateFinSuspension;
  }
  
  public static Damj getDateRuptureContratGaecPourFCTRetenu(DemandeAssuranceSpec p_demande)
    throws CoucheLogiqueException
  {
    ActiviteSalarie periodeValidationProduit = trouverDernierSinistre(p_demande);
    FiltresTemporel filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreActiviteSalarieSurMemeContratGAEC(periodeValidationProduit));
    filtres.ajouterFiltre(new FiltreDebutApresDate(periodeValidationProduit.getDateFin()));
    filtres.ajouterFiltre(new FiltreActiviteSalarieRuptureContratSuiteChomageSansRupture());
    Chronologie chronoPeriodes = p_demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(filtres);
    if (chronoPeriodes.estVide())
    {
      if (Log.isTraceActive(OutilsChomageSansRCT.class, Niveau.DEBUG)) {
        Log.ecritTrace(Niveau.DEBUG, OutilsChomageSansRCT.class, "getDateRuptureContratGaecPourFCTRetenu", "Impossible de trouver la période de rupture du contrat GAEC");
      }
      return null;
    }
    return chronoPeriodes.premierElement().getDateFin();
  }
  
  public static boolean estUnContexteRuptureContratPendantSuspension(DemandeAssuranceSpec p_demande)
    throws CoucheLogiqueException
  {
    ActiviteSalarie periodeValidationProduit = trouverDernierSinistre(p_demande);
    FiltresTemporel filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreActiviteSalarieSurMemeContratGAEC(periodeValidationProduit));
    filtres.ajouterFiltre(new FiltreDebutApresDate(periodeValidationProduit.getDateFin()));
    
    Chronologie chronoMemeActiviteGaecApresDate = p_demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(filtres);
    
    filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreActiviteSalarieRuptureContratSuiteChomageSansRupture());
    Chronologie chronoPeriodesRuptureContrat = chronoMemeActiviteGaecApresDate.copier(filtres);
    if (!chronoPeriodesRuptureContrat.estVide())
    {
      ActiviteSalarie activiteSalarie = (ActiviteSalarie)chronoPeriodesRuptureContrat.premierElement();
      if (activiteSalarie.getContrat().estSuspensionChomageSansRCT()) {
        return true;
      }
      if (activiteSalarie.getContrat().getPreavis() != null)
      {
        FiltresTemporel filtreSuspension = new FiltresTemporel();
        filtreSuspension.ajouterFiltre(new FiltreActiviteSalarieSuspensionChomageSansRCT());
        
        Chronologie chronoPeriodesSuspensionSurContrat = chronoMemeActiviteGaecApresDate.copier(filtreSuspension);
        if (!chronoPeriodesSuspensionSurContrat.estVide())
        {
          ActiviteSalarie suspension = (ActiviteSalarie)chronoPeriodesSuspensionSurContrat.premierElement();
          
          Preavis preavis = activiteSalarie.getContrat().getPreavis();
          if (preavis.getPeriodeNonEffectueeNonPayee() != null) {
            return (preavis.getPeriodeNonEffectueeNonPayee().getDebut().equals(suspension.getDateFin().lendemain())) && (preavis.getPeriodeNonEffectueeNonPayee().getFin().equals(activiteSalarie.getDateFin()));
          }
          return false;
        }
      }
    }
    return false;
  }
  
  public static boolean estUnProduitCsr(DemandeSpec p_demande)
  {
    DossierAffectationSpec dossierAffectation = p_demande.getDossierAffectation();
    if ((dossierAffectation != null) && (dossierAffectation.getProduit() != null) && ("ASU_CSR04".equals(dossierAffectation.getProduit().getLigne().getNomUnique()))) {
      return true;
    }
    return false;
  }
  
  public static AttributionAssuranceSpec recupererPremiereAttributionCsr(AttributionAssuranceSpec p_attribution)
  {
    AttributionAssuranceSpec attribPrecedente = p_attribution.getAttributionPrecedente();
    if (((p_attribution instanceof RepriseSpec)) && (attribPrecedente != null) && (estUnProduitCsr(attribPrecedente.getDemande()))) {
      return recupererPremiereAttributionCsr(attribPrecedente);
    }
    return p_attribution;
  }
  
  public static Chronologie trouverActivitesSalarieSuspensionSurContratGAEC(Chronologie p_passeProfessionnelLiquidation, ActiviteSalarie p_activiteSalarieAvecChomageTotalSansRupture)
  {
    FiltresTemporel filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreActiviteSalarieSurMemeContratGAEC(p_activiteSalarieAvecChomageTotalSansRupture));
    filtres.ajouterFiltre(new FiltreActiviteSalarieSuspensionChomageSansRCT());
    Chronologie chronoPeriodes = p_passeProfessionnelLiquidation.copier(filtres);
    if (chronoPeriodes.estVide()) {
      return null;
    }
    return chronoPeriodes;
  }
  
  public static ActiviteSalarie trouverDernierSinistre(DemandeAssuranceSpec p_demande, Damj p_dateRechercherDernierSinistre)
  {
    try
    {
      Chronologie chronoPasseProfessionnel = p_demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(new FiltreNegation(new FiltreActiviteSalarieSuspensionChomageSansRCT()));
      
      chronoPasseProfessionnel = chronoPasseProfessionnel.copier(new FiltreActiviteSalarie());
      
      return (ActiviteSalarie)RechercherDernierSinistre.rechercherDernierSinistre(p_dateRechercherDernierSinistre, chronoPasseProfessionnel);
    }
    catch (PasAssezInformationException e) {}
    return null;
  }
  
  public static ActiviteSalarie trouverDernierSinistre(DemandeAssuranceSpec p_demande)
    throws CoucheLogiqueException
  {
    Damj dateRechercheDernierSinistre = p_demande.getDonneesTemporaires().getDateChomageTotalSansRupture();
    if (dateRechercheDernierSinistre == null) {
      dateRechercheDernierSinistre = p_demande.getEvenementReferenceExamen().getDateExamen(p_demande);
    }
    if (dateRechercheDernierSinistre == null) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_DATE_RECHERCHE_DERNIER_SINISTRE_CSR", new Object[] { p_demande.getDateDeclenchementExamen().toString() });
    }
    return trouverDernierSinistre(p_demande, dateRechercheDernierSinistre);
  }
  
  public static ActiviteSalarie trouverPeriodeDeSuspension(DemandeAssuranceSpec p_demande)
  {
    ActiviteSalarie periodeDeSuspension = null;
    Chronologie passeProfessionnelLiquidation = p_demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation();
    
    FiltreTemporel filtrePeriodesChomageSansRct = new FiltreActiviteSalarieAvecChomageTotalSansRupture();
    Chronologie chronoPeriodesChomageSansRct = passeProfessionnelLiquidation.copier(filtrePeriodesChomageSansRct);
    if ((chronoPeriodesChomageSansRct != null) && (!chronoPeriodesChomageSansRct.estVide()))
    {
      Damj dateRechercheDernierSinistre = null;
      
      Damj dateChomageTotalSansRuptureForce = p_demande.getDonneesTemporaires().getDateChomageTotalSansRupture();
      if (dateChomageTotalSansRuptureForce != null) {
        dateRechercheDernierSinistre = dateChomageTotalSansRuptureForce.lendemain();
      }
      if (dateRechercheDernierSinistre == null) {
        dateRechercheDernierSinistre = p_demande.getDateRecherche();
      }
      chronoPeriodesChomageSansRct.iterer();
      Damj dateReference = Damj.NUIT_DES_TEMPS;
      ActiviteSalarie activiteReference = null;
      while (chronoPeriodesChomageSansRct.encoreSuivant())
      {
        ActiviteSalarie periodesChomageSansRctTemp = (ActiviteSalarie)chronoPeriodesChomageSansRct.elementSuivant();
        Damj dateFinPeriodeTemp = periodesChomageSansRctTemp.getPeriode().getFin();
        if ((dateFinPeriodeTemp.estApres(dateReference)) && (dateFinPeriodeTemp.estAvant(dateRechercheDernierSinistre)))
        {
          dateReference = dateFinPeriodeTemp;
          activiteReference = periodesChomageSansRctTemp;
        }
      }
      if (activiteReference != null)
      {
        Chronologie chronoSuspensions = trouverActivitesSalarieSuspensionSurContratGAEC(passeProfessionnelLiquidation, activiteReference);
        if ((chronoSuspensions != null) && (!chronoSuspensions.estVide()))
        {
          chronoSuspensions.iterer();
          while (chronoSuspensions.encoreSuivant())
          {
            ActiviteSalarie periodeARetourner = (ActiviteSalarie)chronoSuspensions.elementSuivant();
            Periode periodeSupensionPeriode = new Periode(periodeARetourner.getDateDebut(), periodeARetourner.getDateFin());
            if (p_demande.getDateRecherche().estContenueDans(periodeSupensionPeriode)) {
              periodeDeSuspension = periodeARetourner;
            }
          }
        }
      }
    }
    return periodeDeSuspension;
  }
  
  public static Demande trouverPremiereDemandeSurSuspension(Demande p_demande, ActiviteSalarie p_periodeDeSuspension)
  {
    if (p_periodeDeSuspension != null)
    {
      ChronologieDebuts chronoDemandeAssurance = p_demande.getDemandeur().getChronoDemandeAssurance();
      chronoDemandeAssurance.setComparateur(new ComparateurSurDateDeclenchementEtPrioriteDemande());
      chronoDemandeAssurance.iterer();
      while (chronoDemandeAssurance.encoreSuivant())
      {
        DemandeSpec demande = (DemandeSpec)chronoDemandeAssurance.elementSuivant();
        if ((demande.getGamme() instanceof GammeAsu))
        {
          Demande demandeAssurance = (Demande)demande;
          Damj dateDeclenchementExamen = demande.getDateDeclenchementExamen();
          if ((dateDeclenchementExamen.estApresOuCoincideAvec(p_periodeDeSuspension.getDateDebut())) && (dateDeclenchementExamen.estAvantOuCoincideAvec(p_periodeDeSuspension.getDateFin())) && (((estDemandeEnContexteDeChomageEnCoursDeSuspension(demandeAssurance)) && (demandeAssurance.getAttribution() != null)) || (p_demande.getIdentifiant().equals(demande.getIdentifiant())))) {
            return (Demande)demande;
          }
        }
      }
      return p_demande;
    }
    return null;
  }
  
  public static Demande trouverPremiereDemandeSurSuspension(Demande p_demande)
  {
    ActiviteSalarie periodeDeSuspension = trouverPeriodeDeSuspension(p_demande);
    return trouverPremiereDemandeSurSuspension(p_demande, periodeDeSuspension);
  }
  
  public static void copieDonneesForceesCsr(DemandeAssuranceSpec p_demandeOrigine, DemandeAssuranceSpec p_demandeCible)
  {
    if ((p_demandeOrigine != null) && (p_demandeCible != null))
    {
      DonneesTemporaires donneesForceesCibles = p_demandeCible.getDonneesTemporaires();
      DonneesTemporaires donneesForceesOrigines = p_demandeOrigine.getDonneesTemporaires();
      
      donneesForceesCibles.setDateChomageTotalSansRupture(donneesForceesOrigines.getDateChomageTotalSansRupture());
      donneesForceesCibles.setEstDecisionCPRenseigneeChomageTotalSansRupture(donneesForceesOrigines.isDecisionCPRenseigneeChomageTotalSansRupture());
      donneesForceesCibles.setEstAvisFavorableCPChomageTotalSansRupture(donneesForceesOrigines.isAvisFavorableCPChomageTotalSansRupture());
      donneesForceesCibles.setEstSinistreOuCalamiteNaturelleChomageTotalSansRupture(donneesForceesOrigines.isSinistreOuCalamiteNaturelleChomageTotalSansRupture());
      donneesForceesCibles.setDateAttributionCPChomageTotalSansRupture(donneesForceesOrigines.getDateAttributionCPChomageTotalSansRupture());
      donneesForceesCibles.setAccordPoursuite182JoursChomageTotalSansRupture(donneesForceesOrigines.isAccordPoursuite182JoursChomageTotalSansRupture());
      donneesForceesCibles.setDateMaximumPoursuiteIndeminisationChomageTotalSansRupture(donneesForceesOrigines.getDateMaximumPoursuiteIndeminisationChomageTotalSansRupture());
      donneesForceesCibles.setLeveeCondition28JoursChomageTotalSansRupture(donneesForceesOrigines.isLeveeCondition28JoursChomageTotalSansRupture());
      donneesForceesCibles.setEstSalarieHandicapeChomageTotalSansRupture(donneesForceesOrigines.isEstSalarieHandicapeChomageTotalSansRupture());
    }
  }
  
  public static boolean estDemandeEnContexteDeChomageSansRuptureDeContrat(DemandeSpec p_demandeCourante)
  {
    Demande demandeCourante = (Demande)p_demandeCourante;
    boolean retour = false;
    retour = OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(demandeCourante.getListContexteDemande(), "CSRSUSP");
    return retour;
  }
  
  public static boolean estDemandeEnContexteDeChomageEnCoursDeSuspension(DemandeSpec p_demandeCourante)
  {
    return OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)p_demandeCourante, 4);
  }
  
  public static boolean estDemandeEnContexteDeRuptureDeContratEnCoursDeSuspension(DemandeSpec p_demandeCourante)
  {
    Demande demandeCourante = (Demande)p_demandeCourante;
    if ((demandeCourante.getAttribution() != null) && (estUnProduitDeChomageSansRupture(demandeCourante.getAttribution()))) {
      return true;
    }
    boolean retour = false;
    retour = OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(demandeCourante.getListContexteDemande(), "RUPCTRSUSP");
    return retour;
  }
  
  public static boolean estUnContexteDeChomageSansRuptureDeContrat(String p_typeDemande)
  {
    return (p_typeDemande != null) && (p_typeDemande.equals("CSRSUSP"));
  }
  
  public static boolean estUnContexteDeChomageEnCoursDeSuspension(String p_typeDemande)
  {
    return (p_typeDemande != null) && ((p_typeDemande.equals("CSRSUSP")) || (p_typeDemande.equals("RUPCTRSUSP")));
  }
  
  public static boolean estUnContexteDeChomageEnCoursDeSuspension(List<ContexteDemandeSpec> p_contexteDemande)
  {
    return (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(p_contexteDemande, "CSRSUSP")) || (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(p_contexteDemande, "RUPCTRSUSP"));
  }
  
  private static Damj trouverDateRechercheDernierSinistre(Demande p_demandeCourante, Demande p_premiereDemandeSuspension)
  {
    Damj dateRechercheDernierSinistre = p_premiereDemandeSuspension.getDonneesTemporaires().getDateChomageTotalSansRupture();
    if (dateRechercheDernierSinistre == null) {
      dateRechercheDernierSinistre = p_demandeCourante.getDateRecherche();
    }
    return dateRechercheDernierSinistre;
  }
  
  public static boolean estCsrEnCoursDeSuspension(Demande p_demandeCourante, Demande p_premiereDemandeSuspension, ActiviteSalarie p_periodeDeSuspension)
  {
    boolean estContexteDeChomageSansRupture = false;
    if (p_periodeDeSuspension != null)
    {
      Damj dateRechercheDernierSinistre = trouverDateRechercheDernierSinistre(p_demandeCourante, p_premiereDemandeSuspension);
      TravailSpec dernierSinistre = trouverDernierSinistre(p_demandeCourante, dateRechercheDernierSinistre);
      if ((dernierSinistre != null) && (dernierSinistre.estType(ActiviteSalarie.class)))
      {
        ActiviteSalarie activite = (ActiviteSalarie)dernierSinistre;
        estContexteDeChomageSansRupture = activite.getContrat().getCodeMotifFin() == 99;
      }
    }
    return estContexteDeChomageSansRupture;
  }
  
  public static boolean estUnProduitDeChomageSansRupture(AttributionSpec p_attribution)
  {
    return p_attribution.getProduit().getLigne().getNomUnique().equals("ASU_CSR04");
  }
  
  public static ActiviteSalarie trouverPeriodeActiviteTerminantLeContrat(IndividuSpec p_demandeur, ActiviteSalarie p_periodeActivite)
  {
    FiltresTemporel filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreActiviteSalarieSurMemeContratGAEC(p_periodeActivite));
    filtres.ajouterFiltre(new FiltreDebutApresDate(p_periodeActivite.getDateFin()));
    
    Chronologie chronoPeriodesTerminantASChomageSansRCT = p_demandeur.getChronoPeriodePasseProfessionnelLiquidation().copier(filtres);
    if (chronoPeriodesTerminantASChomageSansRCT.estVide()) {
      return p_periodeActivite;
    }
    return (ActiviteSalarie)chronoPeriodesTerminantASChomageSansRCT.dernierElement();
  }
}

/* Location:
 * Qualified Name:     OutilsChomageSansRCT
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */