package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.cali.asu.calcul.dom.temps.ObjetChronoPeriodeAssDemandeExpresse;
import fr.unedic.cali.asu.calcul.dom.temps.ObjetChronoPeriodeRejet;
import fr.unedic.cali.asu.calcul.dom.temps.ObjetChronoPeriodeRejetDRV;
import fr.unedic.cali.asu.calcul.dom.temps.ObjetChronoPeriodeRejetDVDemandeExpresse;
import fr.unedic.cali.asu.calcul.dom.temps.ObjetChronoPeriodeRejetDVFilEau;
import fr.unedic.cali.asu.calcul.dom.temps.ObjetChronoPeriodeRejetRevision;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.RejetSpec;
import fr.unedic.cali.dom.affectation.ProduitSolSpec;
import fr.unedic.cali.outilsfonctionnels.GestionnaireErreur;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreDateDeclenchementExamenContenueDansPeriode;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreDecisionNonEnReexamen;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologieDebuts;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.util.List;

public class RechercheDecisionsInterruptives
  implements OutilFonctionnel
{
  public static Chronologie rechercher(IndividuSpec individu, Damj dateDebutRecherche, AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    Chronologie chronoPeriodesRetournees = new ChronologiePeriodes();
    Chronologie chronologieExpress = null;
    Chronologie chronologieAssuranceRegetDVDemandeExpresse = null;
    
    chronologieExpress = rechercherSolidariteAssExpress(individu, dateDebutRecherche);
    if (chronologieExpress != null) {
      chronoPeriodesRetournees.ajouter(chronologieExpress);
    }
    chronologieAssuranceRegetDVDemandeExpresse = rechercherAssuranceRejetDVDemandeExpresseEtRejetDRV(individu, dateDebutRecherche, attribution);
    if (chronologieAssuranceRegetDVDemandeExpresse != null) {
      chronoPeriodesRetournees.ajouter(chronologieAssuranceRegetDVDemandeExpresse);
    }
    return chronoPeriodesRetournees;
  }
  
  private static Chronologie rechercherAssuranceRejetDVDemandeExpresseEtRejetDRV(IndividuSpec individu, Damj dateDebutRecherche, AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    Chronologie chronoPeriodesRetournees = new ChronologiePeriodes();
    
    Chronologie decisions = individu.getChronoDemandeAssurance().copier(new FiltreDecisionNonEnReexamen());
    
    Chronologie chronoDemandesAEtudier = decisions.copier(new FiltreDateDeclenchementExamenContenueDansPeriode(new Periode(dateDebutRecherche, Damj.FIN_DES_TEMPS)));
    
    chronoDemandesAEtudier = chronoDemandesAEtudier.copier(OutilFinDroit.getFiltreExclureFinDeDroit());
    
    chronoDemandesAEtudier.iterer();
    while (chronoDemandesAEtudier.encoreSuivant())
    {
      Demande demandeAEtudier = (Demande)chronoDemandesAEtudier.elementSuivant();
      if (estRejetDVDemandeExpresse(demandeAEtudier))
      {
        if (verifierConditionDemandeExpresse(attribution, demandeAEtudier))
        {
          Damj date = demandeAEtudier.getDateExamen();
          ObjetChronoPeriodeRejet objetChronoPeriodeRejetDVDemandeExpresse = new ObjetChronoPeriodeRejetDVDemandeExpresse(date);
          positionnerRejetDV(demandeAEtudier, objetChronoPeriodeRejetDVDemandeExpresse);
          chronoPeriodesRetournees.ajouter(objetChronoPeriodeRejetDVDemandeExpresse);
        }
      }
      else if (estRejetDRV(demandeAEtudier))
      {
        Damj date = demandeAEtudier.getDateExamen();
        ObjetChronoPeriodeRejet objetChronoPeriodeRejetDRV = new ObjetChronoPeriodeRejetDRV(date);
        positionnerRejetDV(demandeAEtudier, objetChronoPeriodeRejetDRV);
        chronoPeriodesRetournees.ajouter(objetChronoPeriodeRejetDRV);
      }
      else if (estRejetDVFilEau(demandeAEtudier))
      {
        Damj date = demandeAEtudier.getDateExamen();
        ObjetChronoPeriodeRejet objetChronoPeriodeRejetDVFilEau = new ObjetChronoPeriodeRejetDVFilEau(date);
        positionnerRejetDV(demandeAEtudier, objetChronoPeriodeRejetDVFilEau);
        chronoPeriodesRetournees.ajouter(objetChronoPeriodeRejetDVFilEau);
      }
      else if (estRejetRevision(demandeAEtudier))
      {
        Damj date = demandeAEtudier.getDateExamen();
        ObjetChronoPeriodeRejet objetChronoPeriodeRejetRevision = new ObjetChronoPeriodeRejetRevision(date);
        positionnerRejetDV(demandeAEtudier, objetChronoPeriodeRejetRevision);
        chronoPeriodesRetournees.ajouter(objetChronoPeriodeRejetRevision);
      }
    }
    return chronoPeriodesRetournees;
  }
  
  private static void positionnerRejetDV(Demande demandeAEtudier, ObjetChronoPeriodeRejet objetChronoPeriodeRejet)
  {
    if (estRejetDV(demandeAEtudier)) {
      objetChronoPeriodeRejet.setEstRejetDV(true);
    }
  }
  
  private static boolean verifierConditionDemandeExpresse(AttributionSpec attribution, Demande demandeAEtudier)
    throws CoucheLogiqueException
  {
    return (GestionDemandeDv122eJour.retrouverPremiereDemandePortantDv(attribution.getDemande()) == null) || (!GestionDemandeDv122eJour.retrouverPremiereDemandePortantDv(attribution.getDemande()).getFormulaire().getReferenceExterne().equals(demandeAEtudier.getFormulaire().getReferenceExterne()));
  }
  
  private static Chronologie rechercherSolidariteAssExpress(IndividuSpec individu, Damj dateDebutRecherche)
  {
    Chronologie chronoPeriodesRetournees = new ChronologiePeriodes();
    DemandeSpec demandeAEtudier = null;
    
    Chronologie decisions = individu.getChronoDemandeSolidarite().copier(new FiltreDecisionNonEnReexamen());
    
    Chronologie chronoDemandesAEtudier = decisions.copier(new FiltreDateDeclenchementExamenContenueDansPeriode(new Periode(dateDebutRecherche, Damj.FIN_DES_TEMPS)));
    
    chronoDemandesAEtudier.iterer();
    while (chronoDemandesAEtudier.encoreSuivant())
    {
      demandeAEtudier = (DemandeSpec)chronoDemandesAEtudier.elementSuivant();
      if (estAssDemandeExpresse(demandeAEtudier))
      {
        Damj date = ((AttributionSpec)getDossierExamen(demandeAEtudier)).getPji();
        chronoPeriodesRetournees.ajouter(new ObjetChronoPeriodeAssDemandeExpresse(date));
      }
    }
    return chronoPeriodesRetournees;
  }
  
  private static boolean estAssDemandeExpresse(DemandeSpec demande)
  {
    DossierExamenSpec dossier = getDossierExamen(demande);
    return (dossier != null) && ((dossier instanceof AttributionSpec)) && (((ProduitSolSpec)((AttributionSpec)dossier).getProduit()).estAssDemandeExpresse((AttributionSpec)dossier));
  }
  
  private static boolean estRejetDVDemandeExpresse(Demande demande)
    throws CoucheLogiqueException
  {
    return (estDemandeExpresseAssurance(demande)) && (estRejetDV(demande));
  }
  
  private static boolean estDemandeExpresseAssurance(Demande demande)
    throws CoucheLogiqueException
  {
    EvenementReferenceExamenSpec ere = demande.getEvenementReferenceExamen();
    if (ere == null) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_ERR_EVEN_REF_EXAMEN_NON_REFERENCE");
    }
    return (ere.getTypeExamen().equalsIgnoreCase("ASU_02")) || (demande.isDemandeExpresse());
  }
  
  private static boolean estRejetDV(Demande demande)
  {
    DossierExamenSpec dossier = getDossierExamen(demande);
    if ((dossier instanceof DossierExamenAssuranceSpec)) {
      return ((DossierExamenAssuranceSpec)dossier).estRejetDV();
    }
    return false;
  }
  
  private static boolean estRejetDRV(Demande demande)
  {
    DossierExamenSpec dossier = demande.getDossierExamen();
    return ("ASU_27".equalsIgnoreCase(demande.getEvenementReferenceExamen().getTypeExamen())) && ((dossier instanceof RejetSpec));
  }
  
  private static boolean estRejetDVFilEau(Demande demande)
  {
    DossierExamenSpec dossier = demande.getDossierExamen();
    return ("ASU_30".equalsIgnoreCase(demande.getEvenementReferenceExamen().getTypeExamen())) && ((dossier instanceof RejetSpec));
  }
  
  private static DossierExamenSpec getDossierExamen(DemandeSpec demande)
  {
    DossierExamenSpec dossier = null;
    List listeDossier = demande.getListeDossiersExamen();
    if ((listeDossier != null) && (!listeDossier.isEmpty())) {
      dossier = (DossierExamenSpec)listeDossier.get(0);
    }
    return dossier;
  }
  
  private static boolean estRejetRevision(Demande demande)
  {
    DossierExamenSpec dossier = demande.getDossierExamen();
    return ("ASU_28".equalsIgnoreCase(demande.getEvenementReferenceExamen().getTypeExamen())) && ((dossier instanceof DossierExamenAssuranceSpec)) && (((DossierExamenAssuranceSpec)dossier).estRejetDV());
  }
}

/* Location:
 * Qualified Name:     RechercheDecisionsInterruptives
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */