package fr.unedic.cali.asu.outilsfonctionnels.examenfileau;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.SaisieAntecedent;
import fr.unedic.cali.asu.outilsfonctionnels.filtre.FiltreDemandeAre;
import fr.unedic.cali.asu.outilsfonctionnels.filtre.FiltreDemandeAreFdd;
import fr.unedic.cali.asu.outilsfonctionnels.filtre.FiltreDemandeAreIde;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnCharge;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.Retraite;
import fr.unedic.cali.outilsfonctionnels.OutilRetraite;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreAttribution;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreClassementSansObjet;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreDecision;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreDemandesEnReexamen;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesSurFiltresExclusifs;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreRejet;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourERE;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreReexamenSurDemande;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreOU;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreDecisionARESurDecision;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologieDebuts;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreDebutApresDate;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.ObjetChronoPeriodeConcrete;
import fr.unedic.util.temps.OutilOptimisationChronologie;
import fr.unedic.util.temps.Temporel;

public class ConstructionPeriodeExamenFilEau
{
  private IndividuSpec individu = null;
  private Damj dateRetraite = null;
  private ChronologiePeriodes chronologiePeriodeExamenFilEau = null;
  private Chronologie chronologieAttributionAre = null;
  private Chronologie chronologieDroitAreFddRejete = null;
  private Chronologie chronologieDroitAreSuiteIdeRejeteOuSO = null;
  private Chronologie chronologieDroitEnReexamenOuNonDecisionne = null;
  private static final int MOTIF_PAS_DE_FIN = 0;
  private static final int MOTIF_CI = 1;
  private static final int MOTIF_NOUVEAU_DROIT_ARE_CGE = 2;
  private static final int MOTIF_NOUVEAU_DROIT_ARE_SPE = 3;
  private static final int MOTIF_DROIT_EN_REEXAMEN_OU_SO = 4;
  private int motifDeFin = 0;
  
  public ConstructionPeriodeExamenFilEau(IndividuSpec individu)
  {
    this.individu = individu;
  }
  
  public ChronologiePeriodes getChronologiePeriodeExamenFilEau()
    throws CoucheLogiqueException
  {
    if (chronologiePeriodeExamenFilEau == null) {
      chronologiePeriodeExamenFilEau = calculerPeriodeExamenFilEau();
    }
    return chronologiePeriodeExamenFilEau;
  }
  
  private ChronologiePeriodes calculerPeriodeExamenFilEau()
    throws CoucheLogiqueException
  {
    ChronologiePeriodes chronoPefe = new ChronologiePeriodes();
    Damj dateDebutPefe = null;
    Damj dateFinPefe = null;
    ObjetChronoPeriode pefe = null;
    boolean chronoPefeFinie = false;
    
    dateRetraite = OutilRetraite.getInstance().determinerRetraite(individu).getDate();
    OutilOptimisationChronologie outilOptimisationChronologie = new OutilOptimisationChronologie(chronoPefe);
    while (!chronoPefeFinie)
    {
      dateDebutPefe = getDateDebutPefe(dateFinPefe);
      if (dateDebutPefe != null)
      {
        dateFinPefe = getDateFinPefe(dateDebutPefe);
        if ((dateFinPefe.equals(dateRetraite)) || (motifDeFin == 4)) {
          chronoPefeFinie = true;
        }
        pefe = new ObjetChronoPeriodeConcrete(dateDebutPefe, dateFinPefe);
        
        outilOptimisationChronologie.ajouter(pefe);
      }
      else
      {
        chronoPefeFinie = true;
      }
    }
    return (ChronologiePeriodes)outilOptimisationChronologie.getChronologieTriee();
  }
  
  private Damj getDateDebutPefe(Damj dateFinDernierePefe)
  {
    Damj debut = null;
    if (dateFinDernierePefe == null) {
      debut = initialisationPermierePeriodePEFE();
    }
    if ((!getChronologieDroitAreFddRejete().estVide()) && (debut == null) && (dateFinDernierePefe == null)) {
      debut = getChronologieDroitAreFddRejete().premierElement().getDateDebut();
    } else if ((debut == null) && (dateFinDernierePefe != null)) {
      debut = rechercheDateReprisePEFE(dateFinDernierePefe);
    }
    debut = getDateDebutDansPecIndemnisable(debut);
    
    return debut;
  }
  
  private Damj initialisationPermierePeriodePEFE()
  {
    Damj debut = null;
    FiltreET filtreAntecedentAsu = new FiltreET();
    filtreAntecedentAsu.ajouterFiltre(new FiltreDecisionARESurDecision());
    FiltreOU filtreAntecedent = new FiltreOU();
    filtreAntecedent.ajouterFiltre(new FiltreDemandePourERE("ASU_22"));
    filtreAntecedent.ajouterFiltre(new FiltreDemandePourERE("ASU_23"));
    filtreAntecedentAsu.ajouterFiltre(filtreAntecedent);
    filtreAntecedentAsu.ajouterFiltre(new fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation(new FiltreReexamenSurDemande()));
    AttributionAssuranceSpec antecedentAsu = (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(individu.getChronoDemandesNonTriees(), Damj.FIN_DES_TEMPS, filtreAntecedentAsu);
    
    boolean estContexteAntecedent = false;
    if (antecedentAsu != null)
    {
      SaisieAntecedent saisieAntecedent = ((Demande)antecedentAsu.getDemande()).getSaisieAntecedent();
      if ((saisieAntecedent.getContexteDemande() != null) && (saisieAntecedent.getContexteDemande().intValue() == 4))
      {
        estContexteAntecedent = true;
        debut = saisieAntecedent.getDateDernierJourCalcule().lendemain();
      }
    }
    else if (individu.getDernierJourIndemnisableAreSpe() != null)
    {
      estContexteAntecedent = true;
      debut = individu.getDernierJourIndemnisableAreSpe().lendemain();
    }
    if ((estContexteAntecedent) && (OutillagePEC.getPeriodePECIndemnisableContenant(individu, debut) == null)) {
      debut = OutillagePEC.getPremierJourPECDemandeur(individu, debut);
    }
    return debut;
  }
  
  private Damj rechercheDateReprisePEFE(Damj dateFinDernierePefe)
  {
    Damj debut = getDateDebutDansPecIndemnisable(dateFinDernierePefe.lendemain());
    
    Damj dateProchainDroitAreFddRejete = null;
    if (debut != null) {
      dateProchainDroitAreFddRejete = getDateDebutElementChronoApresOuCoincideAvec(getChronologieDroitAreFddRejete(), debut);
    }
    Damj dateProchainDroitAreSuiteIdeRejeteOuSO = null;
    if (debut != null) {
      dateProchainDroitAreSuiteIdeRejeteOuSO = getDateDebutElementChronoApresOuCoincideAvec(getChronologieDroitAreSuiteIdeRejeteOuSO(), debut);
    }
    debut = dateProchainDroitAreFddRejete;
    if ((dateProchainDroitAreSuiteIdeRejeteOuSO != null) && (motifDeFin != 2)) {
      if (debut != null) {
        debut = Damj.min(debut, dateProchainDroitAreSuiteIdeRejeteOuSO);
      } else {
        debut = dateProchainDroitAreSuiteIdeRejeteOuSO;
      }
    }
    return debut;
  }
  
  private Damj getDateFinPefe(Damj dateDebutPefeEnCours)
  {
    Damj fin = dateRetraite;
    
    Damj dateProchaineCI = OutillagePEC.getPeriodePECIndemnisableContenant(individu, dateDebutPefeEnCours).getDateFin();
    
    DemandeAssuranceSpec demandeAre = (DemandeAssuranceSpec)getPremierElementChronoApresOuCoincideAvec(getChronologieAttributionAre().copier(new fr.unedic.cali.outilsfonctionnels.filtres.FiltreNegation(new FiltreDemandePourERE("ASU_31"))), dateDebutPefeEnCours);
    
    Damj dateProchainAttributionAre = null;
    if (demandeAre != null) {
      dateProchainAttributionAre = demandeAre.getDateExamen();
    }
    Damj dateProchainDroitEnReexamenOuNonDecisionne = getDateDebutElementChronoApresOuCoincideAvec(getChronologieDroitEnReexamenOuNonDecisionne(), dateDebutPefeEnCours.lendemain());
    if (dateProchaineCI != null)
    {
      fin = Damj.min(fin, dateProchaineCI);
      if (fin.coincideAvec(dateProchaineCI)) {
        motifDeFin = 1;
      }
    }
    if (dateProchainAttributionAre != null)
    {
      fin = Damj.min(fin, dateProchainAttributionAre);
      if (fin.coincideAvec(dateProchainAttributionAre)) {
        if (demandeAre.estUneDemandeAreSpe()) {
          motifDeFin = 3;
        } else {
          motifDeFin = 2;
        }
      }
    }
    if (dateProchainDroitEnReexamenOuNonDecisionne != null)
    {
      fin = Damj.min(fin, dateProchainDroitEnReexamenOuNonDecisionne);
      if (fin.coincideAvec(dateProchainDroitEnReexamenOuNonDecisionne)) {
        motifDeFin = 4;
      }
    }
    return fin;
  }
  
  private Damj getDateDebutElementChronoApresOuCoincideAvec(Chronologie chronologie, Damj date)
  {
    Damj dateRetour = null;
    
    Temporel premierElement = getPremierElementChronoApresOuCoincideAvec(chronologie, date);
    if (premierElement != null) {
      dateRetour = premierElement.getDateDebut();
    }
    return dateRetour;
  }
  
  private Temporel getPremierElementChronoApresOuCoincideAvec(Chronologie chronologie, Damj date)
  {
    Temporel elementRetour = null;
    
    FiltreDebutApresDate filtre = new FiltreDebutApresDate(date);
    Chronologie chrono = chronologie.copier(filtre);
    if (!chrono.estVide()) {
      elementRetour = chrono.premierElement();
    }
    return elementRetour;
  }
  
  private Chronologie getChronologieAttributionAre()
  {
    if (chronologieAttributionAre == null)
    {
      FiltresTemporel filtre = new FiltresTemporel();
      filtre.ajouterFiltre(new FiltreDemandeAre());
      filtre.ajouterFiltre(new FiltreAttribution());
      chronologieAttributionAre = individu.getChronoDemandeAssurance().copier(filtre);
    }
    return chronologieAttributionAre;
  }
  
  private Chronologie getChronologieDroitAreFddRejete()
  {
    if (chronologieDroitAreFddRejete == null)
    {
      FiltresTemporel filtre = new FiltresTemporel();
      filtre.ajouterFiltre(new FiltreDemandeAreFdd());
      filtre.ajouterFiltre(new FiltreRejet());
      chronologieDroitAreFddRejete = individu.getChronoDemandeAssurance().copier(filtre);
    }
    return chronologieDroitAreFddRejete;
  }
  
  private Chronologie getChronologieDroitAreSuiteIdeRejeteOuSO()
  {
    if (chronologieDroitAreSuiteIdeRejeteOuSO == null)
    {
      FiltresTemporel filtreEt = new FiltresTemporel();
      filtreEt.ajouterFiltre(new FiltreDemandeAreIde());
      
      FiltrePeriodesSurFiltresExclusifs filtreOu = new FiltrePeriodesSurFiltresExclusifs();
      filtreOu.ajouterFiltre(new FiltreRejet());
      filtreOu.ajouterFiltre(new FiltreClassementSansObjet());
      
      filtreEt.ajouterFiltre(filtreOu);
      
      chronologieDroitAreSuiteIdeRejeteOuSO = individu.getChronoDemandeAssurance().copier(filtreEt);
    }
    return chronologieDroitAreSuiteIdeRejeteOuSO;
  }
  
  private Chronologie getChronologieDroitEnReexamenOuNonDecisionne()
  {
    if (chronologieDroitEnReexamenOuNonDecisionne == null)
    {
      FiltresTemporel filtreEt = new FiltresTemporel();
      
      filtreEt.ajouterFiltre(new fr.unedic.cali.outilsfonctionnels.filtres.FiltreNegation(new FiltreDecision()));
      
      filtreEt.ajouterFiltre(new FiltreDemandesEnReexamen(false));
      
      chronologieDroitEnReexamenOuNonDecisionne = individu.getChronoDemandes().copier(filtreEt);
    }
    return chronologieDroitEnReexamenOuNonDecisionne;
  }
  
  private Damj getDateDebutDansPecIndemnisable(Damj debut)
  {
    Damj retour = debut;
    if ((debut != null) && (OutillagePEC.getPeriodePECIndemnisableContenant(individu, debut) == null))
    {
      ObjetChronoPeriodePriseEnCharge pecSuivante = OutillagePEC.getPecIndemnisableSuivante(individu, debut);
      if (pecSuivante != null) {
        retour = pecSuivante.getDateDebut();
      } else {
        retour = null;
      }
    }
    return retour;
  }
}

/* Location:
 * Qualified Name:     ConstructionPeriodeExamenFilEau
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */