package fr.unedic.cali.asu.outilsfonctionnels.examenfileau;

import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.outilsfonctionnels.filtre.FiltreDemandeAre;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.ObjetChronoPeriodeIndemnisationConcret;
import fr.unedic.cali.dom.affectation.ProduitAbstrait;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreODValidee;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologieDebuts;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.util.Iterator;

public class ControleFctExamenFilEau
{
  private static ControleFctExamenFilEau instance = null;
  
  public static ControleFctExamenFilEau getInstance()
  {
    if (instance == null) {
      instance = new ControleFctExamenFilEau();
    }
    return instance;
  }
  
  public boolean verifierFctEstDansGaec(IndividuSpec individu, Damj dateFct)
  {
    boolean estDansGaec = false;
    
    ChronologiePeriodes chronoPassePro = individu.getChronoPeriodePasseProfessionnelLiquidation();
    Iterator iterPeriodes = chronoPassePro.iterer();
    while ((iterPeriodes.hasNext()) && (!estDansGaec))
    {
      ObjetChronoPeriode pas = (ObjetChronoPeriode)iterPeriodes.next();
      if (((pas instanceof ActiviteSalarie)) && (pas.getDateFin().coincideAvec(dateFct))) {
        estDansGaec = true;
      }
    }
    return estDansGaec;
  }
  
  public boolean verifierFctEstNonLieeDroitAre(IndividuSpec individu, Damj dateFct)
  {
    boolean estNonLieeDroitAre = true;
    
    FiltresTemporel filtre = new FiltresTemporel();
    filtre.ajouterFiltre(new FiltreODValidee());
    filtre.ajouterFiltre(new FiltreDemandeAre());
    
    Chronologie demandesAre = individu.getChronoDemandeAssurance().copier(filtre);
    
    Iterator iterDemandes = demandesAre.iterer();
    while ((iterDemandes.hasNext()) && (estNonLieeDroitAre))
    {
      DemandeAssuranceSpec demande = (DemandeAssuranceSpec)iterDemandes.next();
      ProduitAsuSpec produit = (ProduitAsuSpec)demande.getDossierAffectation().getProduit();
      Damj dateFaitGenerateur = produit.getDateFaitGenerateur((AttributionSpec)demande.getDossierExamen());
      if (dateFct.coincideAvec(dateFaitGenerateur)) {
        estNonLieeDroitAre = false;
      }
    }
    return estNonLieeDroitAre;
  }
  
  public boolean verifierFctEstAvantDja(IndividuSpec individu, Damj dateFct)
  {
    boolean estAvantDja = false;
    if ((individu.getDernierJourAtteste() != null) && (dateFct.estAvantOuCoincideAvec(individu.getDernierJourAtteste()))) {
      estAvantDja = true;
    }
    return estAvantDja;
  }
  
  public boolean verifierFctEstDansPEFE(ChronologiePeriodes chronoPefe, Damj dateFct)
    throws CoucheLogiqueException
  {
    boolean estDansPefe = false;
    if ((chronoPefe != null) && (!chronoPefe.estVide()) && (new Periode(dateFct, dateFct).inter(chronoPefe) > 0)) {
      estDansPefe = true;
    }
    return estDansPefe;
  }
  
  public boolean verifierEligibilitePeriodeIndemnisee(ChronologiePeriodes periodesIndemnisees, Damj dateFct)
  {
    boolean estFctDansPeriodeEligible = false;
    if ((periodesIndemnisees != null) && (!periodesIndemnisees.estVide()))
    {
      periodesIndemnisees.iterer();
      estFctDansPeriodeEligible = etudierPeriodesIndemnisees(periodesIndemnisees, dateFct, estFctDansPeriodeEligible);
    }
    return estFctDansPeriodeEligible;
  }
  
  private boolean etudierPeriodesIndemnisees(ChronologiePeriodes periodesIndemnisees, Damj dateFct, boolean estFctDansPeriodeEligible)
  {
    boolean resultat = estFctDansPeriodeEligible;
    while (periodesIndemnisees.encoreSuivant())
    {
      ObjetChronoPeriodeIndemnisationConcret periodeIndemnisation = (ObjetChronoPeriodeIndemnisationConcret)periodesIndemnisees.elementSuivant();
      
      Periode periodeCourante = new Periode(periodeIndemnisation.getDateDebut(), periodeIndemnisation.getDateFin());
      if (dateFct.estContenueDans(periodeCourante))
      {
        resultat = true;
        if ((ProduitAbstrait.estDuType(5, periodeIndemnisation.getProduitAssociePeriode())) && (!"CR".equals(periodeIndemnisation.getCodeSousProduitAssociePeriode())))
        {
          resultat = false;
          break;
        }
      }
    }
    return resultat;
  }
}

/* Location:
 * Qualified Name:     ControleFctExamenFilEau
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */