package fr.unedic.cali.asu.outilsfonctionnels.liquidationauto;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsActiviteConserve;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.affectation.LigneSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.parametres.GestionnaireDateApplication;
import fr.unedic.cali.utilitaire.filtres.objetChronoPeriode.FiltreObjetChronoPeriodeFinADate;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;

public class OutilLiquidationAutomatiqueRevision
  extends OutilLiquidationAutomatiqueAbstrait
{
  public void demarerLiquidationAutomatique(DemandeSpec demande, Contexte contexte)
    throws CoucheLogiqueException
  {
    Demande demandeAssurance = (Demande)demande;
    Damj dateApplicationLiquidationAutoDesRevisions = GestionnaireDateApplication.getInstance().recupererDateApplication("Révision liquidées automatiquement");
    if ((demande.getDateDepot() != null) && (demande.getDateDepot().estApresOuCoincideAvec(dateApplicationLiquidationAutoDesRevisions)))
    {
      TravailSpec activiteAReviser = trouverActiviteAReviser(demandeAssurance);
      if (activiteAReviser != null)
      {
        sauvegarderEtatDemandes(demande.getDemandeur());
        demandeAssurance.getDonneesTemporaires().setIdentifiantPeriodeActiviteConserveePerdue(activiteAReviser.getIdentifiant());
        try
        {
          demande.setDecisionAuto(true);
          
          liquiderDemande(demande, true);
          
          traiterClauseDeSauvegardeSurRevisionAutomatique(demande);
          
          demande.setNotifieeCourrier(true);
          demande.setDateDerniereNotification(getDateTraitement(contexte));
          validerDecision(demande, contexte);
        }
        catch (Exception exception)
        {
          OutilFonctionnelTraitementsErreurs outilTraitementErreurs = recupererOutilTraitementErreurs();
          outilTraitementErreurs.nettoyerDemande(demande);
        }
        finally
        {
          demande.supprimerDossiersAffectations();
        }
      }
    }
  }
  
  protected void traiterClauseDeSauvegardeSurRevisionAutomatique(DemandeSpec demande)
    throws CoucheLogiqueException
  {
    DossierAffecte dossierAffecter = (DossierAffecte)demande.getDossierAffectation();
    LigneSpec ligne = dossierAffecter.getProduit().getLigne();
    traiterClauseDeSauvegardeSurRevisionAutomatique(ligne);
  }
  
  protected void traiterClauseDeSauvegardeSurRevisionAutomatique(LigneSpec ligne)
    throws CoucheLogiqueException
  {
    if ("ASU_CSA06".equals(ligne.getNomUnique())) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_CLAUSE_SV_IMPOSSIBLE");
    }
  }
  
  protected TravailSpec trouverActiviteAReviser(Demande demandeAssurance)
  {
    TravailSpec activiteConserve = null;
    
    Chronologie chronoActiviteConservees = getListeActiviteConserveesPerdues(demandeAssurance);
    if ((chronoActiviteConservees != null) && (!chronoActiviteConservees.estVide()))
    {
      Damj datePrevuePerteActiviteConservee = demandeAssurance.getDateDepot().veille();
      Chronologie activitesADateAttendue = chronoActiviteConservees.copier(new FiltreObjetChronoPeriodeFinADate(datePrevuePerteActiviteConservee));
      if ((activitesADateAttendue != null) && (!activitesADateAttendue.estVide())) {
        activiteConserve = (TravailSpec)activitesADateAttendue.premierElement();
      }
    }
    return activiteConserve;
  }
  
  protected Chronologie getListeActiviteConserveesPerdues(Demande demandeAssurance)
  {
    return OutilsActiviteConserve.getListeActiviteConserveesPerduesRevisionAdmission(demandeAssurance);
  }
}

/* Location:
 * Qualified Name:     OutilLiquidationAutomatiqueRevision
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */