package fr.unedic.cali.asu.parametres;

import fr.unedic.cali.calcul.dom.EvenementCalculSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.ObjetChronoEvenementDebut;
import java.math.BigDecimal;

public class EvenementParametre
  extends ObjetChronoEvenementDebut
  implements EvenementCalculSpec
{
  private static final long serialVersionUID = 7103703795521053035L;
  private BigDecimal m_allocationMinimale = null;
  private boolean m_nouveauAllocationMinimale = false;
  private BigDecimal m_partieFixe = null;
  private boolean m_nouveauPartieFixe = false;
  private BigDecimal m_plafond = null;
  private boolean m_nouveauPlafond = false;
  private BigDecimal m_smicHoraire = null;
  private boolean m_nouveauSmicHoraire = false;
  private BigDecimal m_revalorisationSjr = null;
  private boolean m_nouveauRevalorisationSjr = false;
  private BigDecimal m_cotisationRetraiteComplementaire = null;
  private boolean m_nouveauCotisationRetraiteComplementaire = false;
  private BigDecimal m_seuilMinimalAREF = null;
  private boolean m_nouveauSeuilMinimalAREF = false;
  private BigDecimal m_seuilMinimalAREMF = null;
  private boolean m_nouveauSeuilMinimalAREMF = false;
  private BigDecimal m_plafondMayotte = null;
  private boolean m_nouveauPlafondMayotte = false;
  private BigDecimal m_plafondASP = null;
  private boolean m_nouveauPlafondASP = false;
  private BigDecimal m_allocationMinimaleMayotte = null;
  private boolean m_nouveauAllocationMinimaleMayotte = false;
  private BigDecimal m_revalorisationSjrMayotte = null;
  private boolean m_nouveauRevalorisationSjrMayotte = false;
  private Damj m_dateDeRecherche;
  private static final String ALLOCATION_MINIMALE = "Allocation minimale";
  private static final String PARTIE_FIXE = "Partie fixe";
  private static final String PLAFOND = "Plafond mensuel applicable";
  private static final String REVALORISATION_SJR = "Revalorisation du SJR";
  private static final String SMIC_HORAIRE = "Smic horaire";
  private static final String COTISATION_RETRAITE_COMPLEMENTAIRE = "Cotisation retraite complémentaire";
  
  private EvenementParametre() {}
  
  public EvenementParametre(Damj p_dateEvenement)
  {
    super(p_dateEvenement);
    
    setDateDeRecherche(p_dateEvenement);
  }
  
  public BigDecimal getAllocationMinimale()
  {
    return getAllocationMinimale(true);
  }
  
  public BigDecimal getAllocationMinimaleMayotte()
  {
    return getAllocationMinimaleMayotte(true);
  }
  
  private void leverApplicativeRuntimeException(String p_nomParametre)
  {
    try
    {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("PR_CALI_L_ALERTE_A11MB12", new String[] { p_nomParametre, getDateDeRecherche().toString() }, 3);
    }
    catch (CoucheLogiqueException ex) {}
  }
  
  public BigDecimal getAllocationMinimale(boolean p_leverException)
  {
    if ((m_allocationMinimale == null) && (p_leverException)) {
      leverApplicativeRuntimeException("Allocation minimale");
    }
    return m_allocationMinimale;
  }
  
  public BigDecimal getAllocationMinimaleMayotte(boolean p_leverException)
  {
    if ((m_allocationMinimaleMayotte == null) && (p_leverException)) {
      leverApplicativeRuntimeException("Allocation minimale");
    }
    return m_allocationMinimaleMayotte;
  }
  
  public BigDecimal getPartieFixe()
  {
    return getPartieFixe(true);
  }
  
  public BigDecimal getPartieFixe(boolean p_leverException)
  {
    if ((m_partieFixe == null) && (p_leverException)) {
      leverApplicativeRuntimeException("Partie fixe");
    }
    return m_partieFixe;
  }
  
  public BigDecimal getPlafond()
  {
    return getPlafond(true);
  }
  
  public BigDecimal getPlafond(boolean p_leverException)
  {
    if ((m_plafond == null) && (p_leverException)) {
      leverApplicativeRuntimeException("Plafond mensuel applicable");
    }
    return m_plafond;
  }
  
  public BigDecimal getRevalorisationSjr()
  {
    return getRevalorisationSjr(true);
  }
  
  public BigDecimal getRevalorisationSjr(boolean p_leverException)
  {
    if ((m_revalorisationSjr == null) && (p_leverException)) {
      leverApplicativeRuntimeException("Revalorisation du SJR");
    }
    return m_revalorisationSjr;
  }
  
  public BigDecimal getRevalorisationSjrMayotte()
  {
    return getRevalorisationSjrMayotte(true);
  }
  
  public BigDecimal getRevalorisationSjrMayotte(boolean p_leverException)
  {
    if ((m_revalorisationSjrMayotte == null) && (p_leverException)) {
      leverApplicativeRuntimeException("Revalorisation du SJR");
    }
    return m_revalorisationSjrMayotte;
  }
  
  public BigDecimal getSmicHoraire()
  {
    return getSmicHoraire(true);
  }
  
  private BigDecimal getSmicHoraire(boolean p_leverException)
  {
    if ((m_smicHoraire == null) && (p_leverException)) {
      leverApplicativeRuntimeException("Smic horaire");
    }
    return m_smicHoraire;
  }
  
  public BigDecimal getCotisationRetraiteComplementaire()
  {
    return getCotisationRetraiteComplementaire(true);
  }
  
  public BigDecimal getCotisationRetraiteComplementaire(boolean p_leverException)
  {
    if ((m_cotisationRetraiteComplementaire == null) && (p_leverException)) {
      leverApplicativeRuntimeException("Cotisation retraite complémentaire");
    }
    return m_cotisationRetraiteComplementaire;
  }
  
  public boolean isNouveauAllocationMinimale()
  {
    return m_nouveauAllocationMinimale;
  }
  
  public boolean isNouveauAllocationMinimaleMayotte()
  {
    return m_nouveauAllocationMinimaleMayotte;
  }
  
  public boolean isNouveauPartieFixe()
  {
    return m_nouveauPartieFixe;
  }
  
  public boolean isNouveauPlafond()
  {
    return m_nouveauPlafond;
  }
  
  public boolean isNouveauRevalorisationSjr()
  {
    return m_nouveauRevalorisationSjr;
  }
  
  public boolean isNouveauRevalorisationSjrMayotte()
  {
    return m_nouveauRevalorisationSjrMayotte;
  }
  
  public boolean isNouveauSmicHoraire()
  {
    return m_nouveauSmicHoraire;
  }
  
  public boolean isNouveauCotisationRetraiteComplementaire()
  {
    return m_nouveauCotisationRetraiteComplementaire;
  }
  
  public void repercuter(EvenementParametre p_evtSource)
  {
    boolean memeDateEffet = getDateEffet().equals(p_evtSource.getDateEffet());
    if (m_allocationMinimale == null)
    {
      m_allocationMinimale = p_evtSource.getAllocationMinimale(false);
      if (memeDateEffet) {
        m_nouveauAllocationMinimale = p_evtSource.isNouveauAllocationMinimale();
      }
    }
    else
    {
      m_nouveauAllocationMinimale = true;
    }
    if (m_allocationMinimaleMayotte == null)
    {
      m_allocationMinimaleMayotte = p_evtSource.getAllocationMinimaleMayotte(false);
      if (memeDateEffet) {
        m_nouveauAllocationMinimaleMayotte = p_evtSource.isNouveauAllocationMinimaleMayotte();
      }
    }
    else
    {
      m_nouveauAllocationMinimaleMayotte = true;
    }
    if (m_partieFixe == null)
    {
      m_partieFixe = p_evtSource.getPartieFixe(false);
      if (memeDateEffet) {
        m_nouveauPartieFixe = p_evtSource.isNouveauPartieFixe();
      }
    }
    else
    {
      m_nouveauPartieFixe = true;
    }
    if (m_plafond == null)
    {
      m_plafond = p_evtSource.getPlafond(false);
      if (memeDateEffet) {
        m_nouveauPlafond = p_evtSource.isNouveauPlafond();
      }
    }
    else
    {
      m_nouveauPlafond = true;
    }
    if (m_smicHoraire == null)
    {
      m_smicHoraire = p_evtSource.getSmicHoraire(false);
      if (memeDateEffet) {
        m_nouveauSmicHoraire = p_evtSource.isNouveauSmicHoraire();
      }
    }
    else
    {
      m_nouveauSmicHoraire = true;
    }
    if (m_revalorisationSjr == null)
    {
      m_revalorisationSjr = p_evtSource.getRevalorisationSjr(false);
      if (memeDateEffet) {
        m_nouveauRevalorisationSjr = p_evtSource.isNouveauRevalorisationSjr();
      }
    }
    else
    {
      m_nouveauRevalorisationSjr = true;
    }
    if (m_revalorisationSjrMayotte == null)
    {
      m_revalorisationSjrMayotte = p_evtSource.getRevalorisationSjrMayotte(false);
      if (memeDateEffet) {
        m_nouveauRevalorisationSjrMayotte = p_evtSource.isNouveauRevalorisationSjrMayotte();
      }
    }
    else
    {
      m_nouveauRevalorisationSjrMayotte = true;
    }
    if (m_cotisationRetraiteComplementaire == null)
    {
      m_cotisationRetraiteComplementaire = p_evtSource.getCotisationRetraiteComplementaire(false);
      if (memeDateEffet) {
        m_nouveauCotisationRetraiteComplementaire = p_evtSource.isNouveauCotisationRetraiteComplementaire();
      }
    }
    else
    {
      m_nouveauCotisationRetraiteComplementaire = true;
    }
    if (m_seuilMinimalAREF == null)
    {
      m_seuilMinimalAREF = p_evtSource.getSeuilMinimalAREF();
      if (memeDateEffet) {
        m_nouveauSeuilMinimalAREF = p_evtSource.isNouveauSeuilMinimalAREF();
      }
    }
    else
    {
      m_nouveauSeuilMinimalAREF = true;
    }
    if (m_seuilMinimalAREMF == null)
    {
      m_seuilMinimalAREMF = p_evtSource.getSeuilMinimalAREMF();
      if (memeDateEffet) {
        m_nouveauSeuilMinimalAREMF = p_evtSource.isNouveauSeuilMinimalAREMF();
      }
    }
    else
    {
      m_nouveauSeuilMinimalAREMF = true;
    }
    if (m_plafondMayotte == null)
    {
      m_plafondMayotte = p_evtSource.getPlafondMayotte(false);
      if (memeDateEffet) {
        m_nouveauPlafondMayotte = p_evtSource.isNouveauPlafondMayotte();
      }
    }
    else
    {
      m_nouveauPlafondMayotte = true;
    }
    if (m_plafondASP == null)
    {
      m_plafondASP = p_evtSource.getPlafondASP(false);
      if (memeDateEffet) {
        m_nouveauPlafondASP = p_evtSource.isNouveauPlafondASP();
      }
    }
    else
    {
      m_nouveauPlafondASP = true;
    }
  }
  
  public void setAllocationMinimale(BigDecimal p_allocationMinimale)
  {
    m_allocationMinimale = p_allocationMinimale;
  }
  
  public void setAllocationMinimaleMayotte(BigDecimal p_allocationMinimaleMayotte)
  {
    m_allocationMinimaleMayotte = p_allocationMinimaleMayotte;
  }
  
  public void setNouveauAllocationMinimale(boolean p_nouveauAllocationMinimale)
  {
    m_nouveauAllocationMinimale = p_nouveauAllocationMinimale;
  }
  
  public void setNouveauAllocationMinimaleMayotte(boolean p_nouveauAllocationMinimaleMayotte)
  {
    m_nouveauAllocationMinimaleMayotte = p_nouveauAllocationMinimaleMayotte;
  }
  
  public void setNouveauPartieFixe(boolean p_nouveauPartieFixe)
  {
    m_nouveauPartieFixe = p_nouveauPartieFixe;
  }
  
  public void setNouveauPlafond(boolean p_nouveauPlafondSecuriteSocialeTrancheB)
  {
    m_nouveauPlafond = p_nouveauPlafondSecuriteSocialeTrancheB;
  }
  
  public void setNouveauRevalorisationSjr(boolean p_nouveauRevalorisationSjr)
  {
    m_nouveauRevalorisationSjr = p_nouveauRevalorisationSjr;
  }
  
  public void setNouveauRevalorisationSjrMayotte(boolean p_nouveauRevalorisationSjrMayotte)
  {
    m_nouveauRevalorisationSjrMayotte = p_nouveauRevalorisationSjrMayotte;
  }
  
  public void setNouveauSmicHoraire(boolean p_nouveauSmicHoraire)
  {
    m_nouveauSmicHoraire = p_nouveauSmicHoraire;
  }
  
  public void setNouveauCotisationRetraiteComplementaire(boolean p_nouveauCotisationRetraiteComplementaire)
  {
    m_nouveauCotisationRetraiteComplementaire = p_nouveauCotisationRetraiteComplementaire;
  }
  
  public void setPartieFixe(BigDecimal p_partieFixe)
  {
    m_partieFixe = p_partieFixe;
  }
  
  public void setPlafond(BigDecimal p_plafondSecuriteSocialeTrancheB)
  {
    m_plafond = p_plafondSecuriteSocialeTrancheB;
  }
  
  public void setRevalorisationSjr(BigDecimal p_revalorisationSjr)
  {
    m_revalorisationSjr = p_revalorisationSjr;
  }
  
  public void setRevalorisationSjrMayotte(BigDecimal p_revalorisationSjrMayotte)
  {
    m_revalorisationSjrMayotte = p_revalorisationSjrMayotte;
  }
  
  public void setSmicHoraire(BigDecimal p_smicHoraire)
  {
    m_smicHoraire = p_smicHoraire;
  }
  
  public void setCotisationRetraiteComplementaire(BigDecimal p_cotisationRetraiteComplementaire)
  {
    m_cotisationRetraiteComplementaire = p_cotisationRetraiteComplementaire;
  }
  
  public boolean isNouveauSeuilMinimalAREF()
  {
    return m_nouveauSeuilMinimalAREF;
  }
  
  public BigDecimal getSeuilMinimalAREF()
  {
    return m_seuilMinimalAREF;
  }
  
  public void setNouveauSeuilMinimalAREF(boolean p_nouveauSeuilMinimalAREF)
  {
    m_nouveauSeuilMinimalAREF = p_nouveauSeuilMinimalAREF;
  }
  
  public void setSeuilMinimalAREF(BigDecimal p_seuilMinimalAREF)
  {
    m_seuilMinimalAREF = p_seuilMinimalAREF;
  }
  
  public boolean isNouveauPlafondMayotte()
  {
    return m_nouveauPlafondMayotte;
  }
  
  public void setNouveauPlafondMayotte(boolean p_nouveauPlafondMayotte)
  {
    m_nouveauPlafondMayotte = p_nouveauPlafondMayotte;
  }
  
  public boolean isNouveauPlafondASP()
  {
    return m_nouveauPlafondASP;
  }
  
  public void setNouveauPlafondASP(boolean p_nouveauPlafondASP)
  {
    m_nouveauPlafondASP = p_nouveauPlafondASP;
  }
  
  public boolean isNouveauSeuilMinimalAREMF()
  {
    return m_nouveauSeuilMinimalAREMF;
  }
  
  public void setNouveauSeuilMinimalAREMF(boolean p_nouveauSeuilMinimalAREMF)
  {
    m_nouveauSeuilMinimalAREMF = p_nouveauSeuilMinimalAREMF;
  }
  
  public BigDecimal getPlafondMayotte()
  {
    return getPlafondMayotte(true);
  }
  
  public BigDecimal getPlafondASP()
  {
    return getPlafondASP(true);
  }
  
  public BigDecimal getPlafondMayotte(boolean p_leverException)
  {
    if ((m_plafondMayotte == null) && (p_leverException)) {
      leverApplicativeRuntimeException("Plafond mensuel applicable");
    }
    return m_plafondMayotte;
  }
  
  public BigDecimal getPlafondASP(boolean p_leverException)
  {
    if ((m_plafondASP == null) && (p_leverException)) {
      leverApplicativeRuntimeException("Plafond mensuel applicable");
    }
    return m_plafondASP;
  }
  
  public BigDecimal getSeuilMinimalAREMF(boolean p_leverException)
  {
    if ((m_seuilMinimalAREMF == null) && (p_leverException)) {
      leverApplicativeRuntimeException("Plafond mensuel applicable");
    }
    return m_seuilMinimalAREMF;
  }
  
  public void setPlafondASP(BigDecimal p_plafondASP)
  {
    m_plafondASP = p_plafondASP;
  }
  
  public void setPlafondMayotte(BigDecimal p_plafondMayotte)
  {
    m_plafondMayotte = p_plafondMayotte;
  }
  
  public BigDecimal getSeuilMinimalAREMF()
  {
    return m_seuilMinimalAREMF;
  }
  
  public void setSeuilMinimalAREMF(BigDecimal p_seuilMinimalAREMF)
  {
    m_seuilMinimalAREMF = p_seuilMinimalAREMF;
  }
  
  public ObjetMetierSpec copie()
  {
    EvenementParametre copie = new EvenementParametre();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    EvenementParametre copie = (EvenementParametre)p_copie;
    copie.setDateEvenement(getDateEvenement());
    copie.setAllocationMinimale(getAllocationMinimale(false));
    copie.setNouveauAllocationMinimale(isNouveauAllocationMinimale());
    copie.setPartieFixe(getPartieFixe(false));
    copie.setNouveauPartieFixe(isNouveauPartieFixe());
    copie.setPlafond(getPlafond(false));
    copie.setNouveauPlafond(isNouveauPlafond());
    copie.setSmicHoraire(getSmicHoraire(false));
    copie.setNouveauSmicHoraire(isNouveauSmicHoraire());
    copie.setNouveauRevalorisationSjr(isNouveauRevalorisationSjr());
    copie.setCotisationRetraiteComplementaire(getCotisationRetraiteComplementaire(false));
    copie.setNouveauCotisationRetraiteComplementaire(isNouveauCotisationRetraiteComplementaire());
    copie.setSeuilMinimalAREF(getSeuilMinimalAREF());
    copie.setNouveauSeuilMinimalAREF(isNouveauSeuilMinimalAREF());
    
    copie.setAllocationMinimaleMayotte(getAllocationMinimaleMayotte(false));
    copie.setNouveauAllocationMinimaleMayotte(isNouveauAllocationMinimaleMayotte());
    copie.setPlafondMayotte(getPlafondMayotte(false));
    copie.setNouveauPlafondMayotte(isNouveauPlafondMayotte());
    copie.setPlafondASP(getPlafondASP(false));
    copie.setNouveauPlafondASP(isNouveauPlafondASP());
    copie.setRevalorisationSjrMayotte(getRevalorisationSjrMayotte(false));
    copie.setNouveauRevalorisationSjrMayotte(isNouveauRevalorisationSjrMayotte());
    copie.setSeuilMinimalAREMF(getSeuilMinimalAREMF());
    copie.setNouveauSeuilMinimalAREMF(isNouveauSeuilMinimalAREMF());
  }
  
  public Damj getDateDeRecherche()
  {
    return m_dateDeRecherche;
  }
  
  public void setDateDeRecherche(Damj p_dateDeRecherche)
  {
    m_dateDeRecherche = p_dateDeRecherche;
  }
}

/* Location:
 * Qualified Name:     EvenementParametre
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */