package fr.unedic.cali.asu.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.EreDemandeExpresse;
import fr.unedic.cali.asu.fabriques.FabriqueStrategieFCTRetenueDemandeExpresse;
import fr.unedic.cali.asu.outilsfonctionnels.RechercherDernierSinistre;
import fr.unedic.cali.asu.outilsfonctionnels.strategies.StrategieFCTRetenueDemandeExpresseSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.CertifieSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.DeclareSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.outilsfonctionnels.RechercherPeriodeIndemnisation;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.ObjetChronoPeriode;

public class AffectationDemandeASUDemandeExpress
  extends AffectationDemandeASUClassique
{
  protected boolean rechercherDernierSinistre(DemandeAssuranceSpec p_demandeAssurance, Chronologie p_chronoPeriodesParticipantes)
    throws CoucheLogiqueException
  {
    CritereStrategie critere = new CritereStrategie();
    critere.setDemande(p_demandeAssurance);
    FabriqueStrategieFCTRetenueDemandeExpresse fabrique = FabriqueStrategieFCTRetenueDemandeExpresse.getInstance();
    StrategieFCTRetenueDemandeExpresseSpec strategie = (StrategieFCTRetenueDemandeExpresseSpec)fabrique.getStrategie(critere);
    return strategie.rechercherDernierSinistre(p_demandeAssurance, p_chronoPeriodesParticipantes);
  }
  
  protected boolean rechercherDernierSinistreCertifieQualifie(DemandeAssuranceSpec p_demandeAssurance)
  {
    TravailSpec dernierSinistre = ((DossierAffectation)p_demandeAssurance.getDossierAffectation()).getSinistre();
    if ((((dernierSinistre instanceof CertifieSpec)) && (!((CertifieSpec)dernierSinistre).estQualifiable())) || (((dernierSinistre instanceof DeclareSpec)) && (!((DeclareSpec)dernierSinistre).estJustifie()))) {
      return false;
    }
    return true;
  }
  
  protected boolean validerProduitSinistres(DemandeAssuranceSpec p_demandeAsuCourante, Chronologie p_chronoPeriodesParticipantes)
    throws ApplicativeException
  {
    boolean produitAffecte = false;
    
    DossierAffectation dossierAffectationCourant = (DossierAffectation)p_demandeAsuCourante.getDossierAffectation();
    
    ActiviteSalarie dernierSinistre = (ActiviteSalarie)dossierAffectationCourant.getSinistre();
    if (!((DomLiquidationAssurance)getDom()).isContexteOuvertureDroitAuPlusTot()) {
      produitAffecte = super.validerProduitSinistres(p_demandeAsuCourante, p_chronoPeriodesParticipantes);
    } else {
      produitAffecte = validerProduitFct(p_demandeAsuCourante, dernierSinistre);
    }
    return produitAffecte;
  }
  
  protected boolean estDemandeExpresseEnCoursIndemnisation(DemandeAssuranceSpec p_demandeAsuCourante)
  {
    boolean retour = false;
    if ((p_demandeAsuCourante.getEvenementReferenceExamen() instanceof EreDemandeExpresse))
    {
      Damj dateExamen = p_demandeAsuCourante.getDateExamen();
      
      ObjetChronoPeriode periode = RechercherPeriodeIndemnisation.rechercherPeriodeIndemniseeEffectiveAssurance(p_demandeAsuCourante.getDemandeur(), dateExamen);
      if (periode != null) {
        retour = true;
      }
    }
    return retour;
  }
  
  protected boolean recuperationDecorReglementaire(DossierAffectation p_dossierAffectation, Demande p_demandeAssurance, Chronologie p_chronoPeriodesParticipantes)
    throws CoucheLogiqueException
  {
    boolean dernierSinistreFictif = false;
    boolean rejetAffectation = false;
    if (p_dossierAffectation.getSinistre() == null)
    {
      p_dossierAffectation.setSinistre(RechercherDernierSinistre.rechercherDernierSinistre(p_demandeAssurance, p_chronoPeriodesParticipantes));
      
      dernierSinistreFictif = true;
    }
    if (p_dossierAffectation.getSinistre() != null)
    {
      recupererDecorReglementaire(p_dossierAffectation);
      rejetAffectation = !rechercherDernierSinistreCertifieQualifie(p_demandeAssurance);
    }
    if (dernierSinistreFictif) {
      p_dossierAffectation.setSinistre(null);
    }
    return rejetAffectation;
  }
}

/* Location:
 * Qualified Name:     AffectationDemandeASUDemandeExpress
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */