package fr.unedic.cali.asu.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.affectation.parametres.AccesDecorReglementaire;
import fr.unedic.cali.affectation.parametres.CriteresQualification;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.DelaiRechercheProduit;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.outilsfonctionnels.ConstitutionDecorReglementaire;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.ConteneurAccesDecorReglementaire;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.affectation.DecorReglementaire;
import fr.unedic.cali.dom.affectation.LigneAsuCge01;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionStandardAssurance;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Damj;

public class AffectationDemandeASURevision
  extends ParcoursAffectationDemandeAssurance
{
  public Resultat demarrer(Contexte p_contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    Resultat result = new Resultat();
    
    Demande demandeAssuranceExistante = getDemande(p_contexte);
    
    initialiserDemande(demandeAssuranceExistante);
    
    AttributionAssuranceSpec attributionPrecedente = (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demandeAssuranceExistante.getChronologieDemandesAssuranceSansCourante(), demandeAssuranceExistante, new FiltreAttributionStandardAssurance(true, true, false, true, demandeAssuranceExistante));
    if (attributionPrecedente != null)
    {
      AttributionAssuranceSpec attributionMaitre = null;
      
      attributionMaitre = (AttributionAssuranceSpec)attributionPrecedente.getOuvertureDroit();
      
      alimenterDossierAffecte(attributionMaitre, demandeAssuranceExistante);
      result.setEtat(0);
    }
    else
    {
      alimenterDossierAffecteParDefaut(demandeAssuranceExistante);
    }
    OutilTrace.tracerFinParcours();
    return result;
  }
  
  private void alimenterDossierAffecte(AttributionAssuranceSpec p_attributionMaitre, Demande p_demandeAsuExistante)
  {
    DossierAffecte dossierAffecteAttributionAReviser = (DossierAffecte)p_attributionMaitre.getDossierAffecte();
    
    DossierAffecte dossierAffecte = (DossierAffecte)p_demandeAsuExistante.getDossierAffectation();
    if ((dossierAffecteAttributionAReviser.getValidationProduit() != null) && (dossierAffecteAttributionAReviser.getValidationProduit().isEstProduitValide())) {
      dossierAffecte.setValidationProduit((ValidationProduit)dossierAffecteAttributionAReviser.getValidationProduit().copie());
    }
    if (dossierAffecteAttributionAReviser.getDelaiRecherche() != null) {
      dossierAffecte.setDelaiRecherche((DelaiRechercheProduit)dossierAffecteAttributionAReviser.getDelaiRecherche().copie());
    }
    dossierAffecte.setDecorReglementaire(dossierAffecteAttributionAReviser.getDecorReglementaire());
    dossierAffecte.setProduitSecours(dossierAffecteAttributionAReviser.getProduitSecours());
    dossierAffecte.setIdentifiantSinistre(dossierAffecteAttributionAReviser.getIdentifiantSinistre());
    dossierAffecte.setJustificationAffectation(dossierAffecteAttributionAReviser.getJustificationAffectation());
    
    dossierAffecte.setProduitForce(dossierAffecteAttributionAReviser.getProduitForce());
    
    CriteresQualification criteresQualification = new CriteresQualification(dossierAffecte.getDecorReglementaire(), dossierAffecte.getSinistre(), p_demandeAsuExistante.getDonneesTemporaires().isEstCoordCee());
    
    AccesDecorReglementaire.getInstance().positionnerCriteresQualifSurPas(criteresQualification, (Individu)p_demandeAsuExistante.getDemandeur());
  }
  
  private void alimenterDossierAffecteParDefaut(Demande p_demandeAsuExistante)
    throws CoucheLogiqueException
  {
    DossierAffecte dossierAffecte = (DossierAffecte)p_demandeAsuExistante.getDossierAffectation();
    
    dossierAffecte.setProduitSecours(determinerProduitParDefaut(p_demandeAsuExistante));
  }
  
  protected ProduitAsuSpec determinerProduitParDefaut(DemandeAssuranceSpec p_demande)
    throws CoucheLogiqueException
  {
    ProduitAsuSpec produitParDefaut = null;
    
    Damj dateExamen = p_demande.getDateExamen();
    
    ConteneurAccesDecorReglementaire conteneur = new ConteneurAccesDecorReglementaire();
    conteneur.setDateRecherche(dateExamen);
    conteneur.setDateFinContrat(dateExamen);
    conteneur.setBesoinCritereQualif(false);
    conteneur.setDemande(p_demande);
    DecorReglementaire decorReglementaireDateExamen = ConstitutionDecorReglementaire.recupererDecor(conteneur);
    if (decorReglementaireDateExamen == null)
    {
      StringBuffer sb = new StringBuffer();
      
      TravailSpec dernierSinistre = ((DossierAffectation)p_demande.getDossierAffectation()).getSinistre();
      if (dernierSinistre != null) {
        sb.append(dernierSinistre.getDateFin().toString());
      } else {
        sb.append("[non identifiée]");
      }
      sb.append(dateExamen.veille().toString());
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_FCT_NE_PROPOSE_PAS_DECOR_UN", sb.toString());
    }
    produitParDefaut = (ProduitAsuSpec)decorReglementaireDateExamen.determinerProduitEffectifDeLaLigne(LigneAsuCge01.getInstance());
    
    return produitParDefaut;
  }
}

/* Location:
 * Qualified Name:     AffectationDemandeASURevision
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */