package fr.unedic.cali.asu.parcours;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.affectation.GammeAsu;
import fr.unedic.cali.dom.affectation.ProduitAsuCaa14P01;
import fr.unedic.cali.dom.affectation.ProduitAsuCaa14P02;
import fr.unedic.cali.dom.affectation.ProduitAsuCva10P02;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.outilsfonctionnels.OutilAsp;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.util.List;

public class AffectationDemandeAsp
  extends AffectationDemandeCvaCaa
{
  protected ProduitAsuSpec recupererProduitActif()
  {
    return ProduitAsuCaa14P02.getInstance();
  }
  
  protected ProduitAsuSpec affecterProduitCaa(Damj dateRechercheDecor)
    throws CoucheLogiqueException
  {
    ProduitAsuSpec produit = ProduitAsuCaa14P02.getInstance();
    ProduitAsuSpec produitAsr = ProduitAsuCaa14P01.getInstance();
    if (GammeAsu.getInstance().getProduitsActifs(dateRechercheDecor).contains(produitAsr)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_PRODUIT_NON_ACTIF_DATE_EXAMEN", new Object[] { produit.getLibelleCourt(), dateRechercheDecor.toString() });
    }
    return produit;
  }
  
  protected ProduitAsuSpec affecterProduitCva(Damj dateRechercheDecor)
    throws CoucheLogiqueException
  {
    ProduitAsuSpec produit = ProduitAsuCva10P02.getInstance();
    ProduitAsuSpec produitAsr = ProduitAsuCaa14P01.getInstance();
    if (GammeAsu.getInstance().getProduitsActifs(dateRechercheDecor).contains(produitAsr)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_PRODUIT_NON_ACTIF_DATE_EXAMEN", new Object[] { produit.getLibelleCourt(), dateRechercheDecor.toString() });
    }
    return produit;
  }
  
  protected boolean verifierAncienneteSuffisante(DemandeAssuranceSpec demande, TravailSpec dernierSinistre, Damj dateEngagementProcedure)
    throws CoucheLogiqueException
  {
    return OutilAsp.aAncienneteSuperieur1An(demande, dernierSinistre);
  }
  
  protected void verifierExistanceDernierAu(DossierAffectation dossierAffectation, boolean estDernierSinistre)
    throws CoucheLogiqueException
  {}
  
  public Damj determinerDateRechercheDecor(TravailSpec dernierSinistre, DemandeSpec demande)
    throws CoucheLogiqueException
  {
    Demande demandeAssurance = (Demande)demande;
    
    Damj dateRechercheDecor = demande.getDateRecherche();
    boolean derogation = false;
    if (demandeAssurance.getDonneesTemporaires() != null) {
      derogation = demandeAssurance.getDonneesTemporaires().isEstDerogationCsp();
    }
    if (dernierSinistre != null)
    {
      dateRechercheDecor = dernierSinistre.getDateFin();
      if ((dernierSinistre instanceof ActiviteSalarie))
      {
        ActiviteSalarie activite = (ActiviteSalarie)dernierSinistre;
        if ((activite.getDateEngagementProcedureLicenciement() != null) && (!derogation) && 
          (activite.getDateEngagementProcedureLicenciement().estApresOuCoincideAvec(recupererProduitActif().getPeriodeValidite().getDebut()))) {
          dateRechercheDecor = activite.getDateEngagementProcedureLicenciement();
        }
      }
    }
    return dateRechercheDecor;
  }
  
  protected void leverAlertes(TravailSpec dernierSinistre, DemandeSpec demande)
    throws CoucheLogiqueException
  {
    if ((dernierSinistre instanceof ActiviteSalarie))
    {
      ActiviteSalarie activite = (ActiviteSalarie)dernierSinistre;
      if (activite.getDateEngagementProcedureLicenciement() != null)
      {
        if (activite.getDateEngagementProcedureLicenciement().estAvant(recupererProduitActif().getPeriodeValidite().getDebut())) {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB35");
        }
      }
      else if (activite.getDateFin().estAvant(recupererProduitActif().getPeriodeValidite().getDebut())) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("PR_CALI_L_ALERTE_A6MB8", new Object[] { recupererProduitActif().getPeriodeValidite().getDebut() });
      }
    }
  }
  
  protected void verifierDernierAuAtteste(TravailSpec dernierSinistre)
    throws CoucheLogiqueException
  {}
}

/* Location:
 * Qualified Name:     AffectationDemandeAsp
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */