package fr.unedic.cali.asu.parcours;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.outilsfonctionnels.ConstitutionDecorReglementaire;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsChomageSansRCT;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.CertifieSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.DeclareSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.ConteneurAccesDecorReglementaire;
import fr.unedic.cali.dom.affectation.DecorReglementaire;
import fr.unedic.cali.dom.affectation.LigneAsuCge01;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.RechercherDernierSinistre;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieAvecChomageTotalSansRupture;
import fr.unedic.cali.parcours.DomLiquidationDemande;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreFinDansBornes;

public abstract class ParcoursAffectationDemandeAssurance
  extends ParcoursCali
{
  protected Demande getDemande(Contexte contexte)
  {
    return (Demande)((DomLiquidationDemande)contexte.getDonnees()).getDemandeSpec();
  }
  
  protected void initialiserDemande(Demande demande)
  {
    DossierAffectation dossierAffectation = new DossierAffecte(1);
    if (demande.getDossierAffectationReprise() != null) {
      demande.supprimerDossierAffectationReprise();
    }
    demande.setDossierAffectation(dossierAffectation);
    
    demande.viderListeObjectifsExamen();
  }
  
  protected boolean rechercherDernierSinistre(DemandeAssuranceSpec demandeAssurance, Chronologie chronoPeriodesParticipantes)
    throws CoucheLogiqueException
  {
    TravailSpec dernierSinistre = null;
    if (OutilsChomageSansRCT.estDemandeEnContexteDeChomageEnCoursDeSuspension(demandeAssurance))
    {
      dernierSinistre = determinerDernierSinitrePourChomageSansRCT(demandeAssurance, chronoPeriodesParticipantes);
    }
    else
    {
      dernierSinistre = RechercherDernierSinistre.rechercherDernierSinistre(demandeAssurance.getDateExamen(), chronoPeriodesParticipantes);
      while (((dernierSinistre instanceof ActiviteSalarie)) && (((ActiviteSalarie)dernierSinistre).getChampApplication() == 2)) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_ERR_HORS_CHAMP_PAS_MORT");
      }
    }
    ((DossierAffectation)demandeAssurance.getDossierAffectation()).setSinistre(dernierSinistre);
    if (dernierSinistre == null) {
      return false;
    }
    return true;
  }
  
  protected boolean rechercherDernierSinistreCertifieQualifie(DemandeAssuranceSpec demandeAssurance)
  {
    TravailSpec dernierSinistre = ((DossierAffectation)demandeAssurance.getDossierAffectation()).getSinistre();
    if ((((dernierSinistre instanceof CertifieSpec)) && (!((CertifieSpec)dernierSinistre).estQualifiable())) || (((dernierSinistre instanceof DeclareSpec)) && (!((DeclareSpec)dernierSinistre).estJustifie()))) {
      return false;
    }
    return true;
  }
  
  protected TravailSpec determinerDernierSinitrePourChomageSansRCT(DemandeAssuranceSpec demandeAssurance, Chronologie chronoPeriodesParticipantes)
    throws CoucheLogiqueException
  {
    Damj dateRecherche = demandeAssurance.getDonneesTemporaires().getDateChomageTotalSansRupture();
    if (dateRecherche == null)
    {
      TravailSpec dernierSinistre = RechercherDernierSinistre.rechercherDernierSinistre(demandeAssurance.getDateExamen(), chronoPeriodesParticipantes);
      while (((dernierSinistre instanceof ActiviteSalarie)) && (((ActiviteSalarie)dernierSinistre).getChampApplication() == 2)) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_ERR_HORS_CHAMP_PAS_MORT");
      }
      return dernierSinistre;
    }
    Chronologie chronoChomageTotalSansRupture = chronoPeriodesParticipantes.copier(new FiltreActiviteSalarieAvecChomageTotalSansRupture());
    
    Chronologie chronoChomageTotalSansRuptureAuJourForce = chronoChomageTotalSansRupture.copier(new FiltreFinDansBornes(dateRecherche, dateRecherche));
    if (chronoChomageTotalSansRuptureAuJourForce.estVide()) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_DATE_CSR_NON_VALIDE");
    }
    return (TravailSpec)chronoChomageTotalSansRuptureAuJourForce.premierElement();
  }
  
  protected void recupererDecorReglementaire(DossierAffectation dossier)
    throws CoucheLogiqueException
  {
    DecorReglementaire decorReglementaire = null;
    
    decorReglementaire = ConstitutionDecorReglementaire.recupererDecor(dossier);
    dossier.setDecorReglementaire(decorReglementaire);
  }
  
  protected DossierAffectation preTraitementAffectationDemandeAsu(DemandeAssuranceSpec demandeAssuranceExistante)
  {
    OutilTrace.tracerDebutParcours();
    
    DossierAffectation dossierAffectation = new DossierAffecte(1);
    if (demandeAssuranceExistante.getDossierAffectationReprise() != null) {
      ((Demande)demandeAssuranceExistante).supprimerDossierAffectationReprise();
    }
    demandeAssuranceExistante.setDossierAffectation(dossierAffectation);
    
    ((Demande)demandeAssuranceExistante).viderListeObjectifsExamen();
    return dossierAffectation;
  }
  
  protected boolean recuperationDecorReglementaire(DossierAffectation dossierAffectation, Demande demandeAssurance, Chronologie chronoPeriodesParticipantes)
    throws CoucheLogiqueException
  {
    if (dossierAffectation.getSinistre() != null)
    {
      recupererDecorReglementaire(dossierAffectation);
      return !rechercherDernierSinistreCertifieQualifie(demandeAssurance);
    }
    return false;
  }
  
  protected ProduitAsuSpec determinerProduitParDefaut(DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    ProduitAsuSpec produitParDefaut = null;
    
    Damj dateExamen = demande.getDateExamen();
    
    ConteneurAccesDecorReglementaire conteneur = new ConteneurAccesDecorReglementaire();
    conteneur.setDateRecherche(dateExamen);
    conteneur.setDateFinContrat(dateExamen);
    conteneur.setBesoinCritereQualif(false);
    conteneur.setDemande(demande);
    DecorReglementaire decorReglementaireDateExamen = ConstitutionDecorReglementaire.recupererDecor(conteneur);
    if (decorReglementaireDateExamen == null)
    {
      StringBuffer sb = new StringBuffer();
      
      TravailSpec dernierSinistre = ((DossierAffectation)demande.getDossierAffectation()).getSinistre();
      if (dernierSinistre != null) {
        sb.append(dernierSinistre.getDateFin().toString());
      } else {
        sb.append("[non identifiée]");
      }
      sb.append(dateExamen.veille().toString());
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_FCT_NE_PROPOSE_PAS_DECOR_UN", new Object[] { sb.toString() });
    }
    produitParDefaut = (ProduitAsuSpec)decorReglementaireDateExamen.determinerProduitEffectifDeLaLigne(LigneAsuCge01.getInstance());
    
    demande.getDossierAffectationAdmission().setDecorReglementaire(decorReglementaireDateExamen);
    return produitParDefaut;
  }
  
  protected ProduitAsuSpec determinerProduitRelatifAuSinistre(TravailSpec sinistre, DossierAffectation dossierAffectationCourant)
    throws CoucheLogiqueException
  {
    ProduitAsuSpec produitRelatifSinistre = null;
    if ((sinistre instanceof ActiviteSalarie)) {
      produitRelatifSinistre = ConstitutionDecorReglementaire.determinerProduitSinistre((ActiviteSalarie)sinistre, dossierAffectationCourant.getDecorReglementaire());
    }
    return produitRelatifSinistre;
  }
}

/* Location:
 * Qualified Name:     ParcoursAffectationDemandeAssurance
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */