package fr.unedic.cali.asu.parcours;

import fr.pe.cali.crem.outils.OutilAjoutCremDalLiquidation;
import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.FormulaireAsu;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnChargeSansFiltre;
import fr.unedic.cali.autresdoms.cohab.outilsfonctionnels.FabriqueFormulairesCali;
import fr.unedic.cali.autresdoms.ga.services.AppelServicesGaec;
import fr.unedic.cali.calcul.pbjc.dom.IndividuPbjcNcp;
import fr.unedic.cali.dom.AgregatGaec;
import fr.unedic.cali.dom.DecisionSpec;
import fr.unedic.cali.dom.DonneesChargementGaec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.GammeSpec;
import fr.unedic.cali.outilsfonctionnels.AlimenterBaseTracker;
import fr.unedic.cali.outilsfonctionnels.AppelServicesCojac;
import fr.unedic.cali.outilsfonctionnels.EvenementReexamen;
import fr.unedic.cali.outilsfonctionnels.OutilFluxSigma;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.outilsfonctionnels.reexecution.FabriqueGestionnaireReexecution;
import fr.unedic.cali.outilsfonctionnels.reexecution.GestionnaireReexecutionSpec;
import fr.unedic.cali.outilsfonctionnels.reexecution.ResultatGestionnaireReexecutionSpec;
import fr.unedic.cali.parcours.AccesDonneesGaecException;
import fr.unedic.cali.parcours.DomCali;
import fr.unedic.cali.parcours.DomCreationDemandePrestation;
import fr.unedic.cali.parcours.DomLiquidationDemande;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.cali.parcours.ParcoursServiceAbstrait;
import fr.unedic.cali.parcours.ResultatCreationDemandePrestation;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.ContexteService;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Damj;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.Map;

public class ParcoursDecisionAutomatique
  extends ParcoursServiceAbstrait
{
  private ResultatLiquidationAssurance m_resultatRepriseRejetAutomatique;
  private Map m_etatsDemandeAvant;
  
  public void controlerContexte(Contexte contexte)
    throws ContexteException
  {
    IndividuSpec individuCourant = getIndividu(contexte);
    if (individuCourant == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_DEMANDEUR", "Individu absent du contexte");
    }
  }
  
  public IndividuSpec getIndividu(Contexte contexte)
  {
    DomCali domCali = (DomCali)contexte.getDonnees();
    return domCali.getIndividu();
  }
  
  public ContexteService getContexteService(Contexte contexte)
  {
    DomCali domCali = (DomCali)contexte.getDonnees();
    return domCali.getContexteService();
  }
  
  public Resultat demarrerParcours(Contexte contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours(Niveau.DEBUG);
    
    m_resultatRepriseRejetAutomatique = new ResultatLiquidationAssurance(2);
    
    installerNouvelleDemande(contexte);
    
    liquiderDemande(contexte);
    
    m_resultatRepriseRejetAutomatique.setDemande(getDemande(contexte));
    
    OutilTrace.tracerFinParcours(Niveau.DEBUG);
    return m_resultatRepriseRejetAutomatique;
  }
  
  private void installerNouvelleDemande(Contexte contexte)
    throws ApplicativeException
  {
    ContexteService contexteService = getContexteService(contexte);
    
    IndividuSpec individu = getIndividu(contexte);
    
    AlimenterBaseTracker.alimenterDonneesEnModeReception(contexteService);
    
    Collection listeNouveauxFormulairesNcp = null;
    
    Collection listeNouvellesDemandesNcp = null;
    
    m_etatsDemandeAvant = OutilFluxSigma.sauvegarderEtatDemandes(individu);
    
    listeNouveauxFormulairesNcp = creerNouveauxFormulairesNcp(contexte);
    if (listeNouveauxFormulairesNcp != null)
    {
      listeNouvellesDemandesNcp = creerNouvellesDemandesNcp(contexte, listeNouveauxFormulairesNcp);
      
      miseAJourDomLiquidation(contexte, listeNouvellesDemandesNcp);
      
      m_etatsDemandeAvant.put(getDemande(contexte), OutilFluxSigma.getEtatDemande(getDemande(contexte)));
      
      IndividuPbjcNcp individuPbjcNcpPersistant = getIndividu(contexte).getIndividuPbjcNcp();
      if (individuPbjcNcpPersistant == null) {
        getIndividu(contexte).setIndividuPbjcNcp(new IndividuPbjcNcp());
      }
      AppelServicesGaec.enregistrerAbonnementGaec(contexte);
    }
  }
  
  private Collection creerNouveauxFormulairesNcp(Contexte contexte)
    throws ApplicativeException
  {
    Collection listeNouveauxFormulairesNcp = null;
    Damj dateCreationDALRecue = null;
    
    ContexteService contexteService = getDonnees(contexte).getContexteService();
    Individu individu = (Individu)getIndividu(contexte);
    String numeroAllocataire = individu.getNumeroAllocataire();
    String idDemandeRecue = getDonnees(contexte).getReferenceExterneDemande();
    
    ArrayList listeDemandesCojac = new ArrayList();
    
    Collection dals = individu.getDemandesV1("DAL");
    fr.unedic.cali.autresdoms.cohab.sigma.demande.dom.spec.DemandeSpec demandeRecue = individu.getUneDemandeV1(idDemandeRecue);
    if (demandeRecue != null) {
      dateCreationDALRecue = demandeRecue.getDateDemande();
    }
    listeDemandesCojac = AppelServicesCojac.determinerDalsNonRetournees(dals, individu, "ASU", idDemandeRecue, dateCreationDALRecue);
    
    Collection listeDemandes = new ArrayList();
    listeDemandes = (Collection)listeDemandesCojac.get(0);
    if (listeDemandes.size() > 1)
    {
      StringBuffer sb = new StringBuffer();
      sb.append("Anomalie : trop de DAL retournée par l'appel Cojac (lecture de plusieurs DAL) ");
      sb.append("-- critères d'appel : ");
      sb.append("- numéro alloc. : ");
      sb.append(numeroAllocataire);
      
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_APPEL_CALI_GDP", "Problème lors de l'appel de service de CALI vers GDP-" + sb.toString());
    }
    if (!((Boolean)listeDemandesCojac.get(1)).booleanValue())
    {
      listeNouveauxFormulairesNcp = FabriqueFormulairesCali.creerFormulairesNcp(listeDemandes, getIndividu(contexte), contexteService);
      
      Iterator iterFormulaires = listeNouveauxFormulairesNcp.iterator();
      FormulaireAsu nouveauFormulaire = null;
      while (iterFormulaires.hasNext())
      {
        nouveauFormulaire = (FormulaireAsu)iterFormulaires.next();
        if (nouveauFormulaire.getDateDepot() == null)
        {
          ObjetChronoPeriodePriseEnChargeSansFiltre periode = OutillagePEC.getPeriodePEC(individu, nouveauFormulaire.getIdPec());
          if (periode != null)
          {
            Damj dateIde = periode.getDateDebut();
            nouveauFormulaire.setDateDepot(dateIde);
          }
          else if (getTypeDecisionAutomatique(contexte) == 2)
          {
            setRejetNCP(contexte);
          }
        }
      }
    }
    return listeNouveauxFormulairesNcp;
  }
  
  protected Collection creerNouvellesDemandesNcp(Contexte contexteParcours, Collection listeNouveauxFormulaires)
    throws ApplicativeException
  {
    Collection listeNouvellesDemandes = new ArrayList();
    if (listeNouveauxFormulaires != null)
    {
      ParcoursCali parcours = null;
      Contexte contexte = null;
      DomCreationDemandePrestation dom = null;
      ResultatCreationDemandePrestation resultat = null;
      
      Iterator iterFormulaires = listeNouveauxFormulaires.iterator();
      FormulaireSpec nouveauFormulaire = null;
      while (iterFormulaires.hasNext())
      {
        nouveauFormulaire = (FormulaireSpec)iterFormulaires.next();
        
        contexte = new Contexte();
        dom = new DomCreationDemandePrestation();
        dom.setFormulaire(nouveauFormulaire);
        dom.setIndividu(getIndividu(contexteParcours));
        dom.setContexteService(((DomLiquidationDemande)contexteParcours.getDonnees()).getContexteService());
        contexte.setDonnees(dom);
        
        parcours = nouveauFormulaire.getGamme().getParcoursCreationDemande();
        
        resultat = (ResultatCreationDemandePrestation)parcours.effectuerParcours(contexte);
        
        listeNouvellesDemandes.add(resultat.getDemande());
      }
    }
    return listeNouvellesDemandes;
  }
  
  protected void miseAJourDomLiquidation(Contexte contexte, Collection listeNouvellesDemandesNcp)
    throws ApplicativeException
  {
    Iterator iterDemandes = listeNouvellesDemandesNcp.iterator();
    Demande nouvelleDemande = (Demande)iterDemandes.next();
    
    nouvelleDemande.setDecisionAutomatique(getTypeDecisionAutomatique(contexte));
    nouvelleDemande.getDonneesTemporaires().setQuantiteJoursDiffereIccpConservatoire(getCarenceConservatoire(contexte));
    if (getCarenceConservatoire(contexte) != null) {
      nouvelleDemande.getDonneesTemporaires().setSaisieCasGeneralDonneesTemporaire(true);
    }
    getIndividu(contexte).ajouterDemande(nouvelleDemande);
    
    ((DomLiquidationDemande)contexte.getDonnees()).setDemande(nouvelleDemande);
    ((DomLiquidationDemande)contexte.getDonnees()).setIdDemande(nouvelleDemande.getIdentifiant());
  }
  
  protected void liquiderDemande(Contexte contexte)
    throws ApplicativeException
  {
    try
    {
      Demande demande = getDemande(contexte);
      if (demande != null) {
        if (demande.getDecisionAutomatique() != 3)
        {
          demande.rechercherAttributionPrecedenteDuMemeType();
          
          AttributionAssuranceSpec attributionAssurancePrecedente = demande.rechercherAttributionPrecedenteDuMemeType();
          if ((attributionAssurancePrecedente == null) && (getDemande(contexte).getDecisionAutomatique() == 2)) {
            throw new ContexteException("HG_PR_CALI_L_ERR_CONTEXTE", "Pas d'attribution précédente pour reprise");
          }
          ParcoursLiquidationAssurance parcours = (ParcoursLiquidationAssurance)demande.getGamme().getParcoursLiquidation(demande);
          parcours.effectuerParcours(contexte);
          if (demande.getDecisionAutomatique() == 2)
          {
            int natureDecision = ((DecisionSpec)demande.getDossierAffectationReprise().getDossierExamen()).getNatureDecision();
            if (natureDecision == 27)
            {
              getDemande(contexte).setNotifieeCourrier(true);
              
              ResultatGestionnaireReexecutionSpec resultatReexecution = validerDemande(contexte);
              
              OutilFluxSigma.notifierSigma(getIndividu(contexte), resultatReexecution.getDemandesReliquidees(), false);
            }
            else
            {
              OutilFluxSigma.notifierSigmaPourDecisionAutomatique(getDemande(contexte));
              
              supprimerDemande(contexte);
            }
          }
          else if (demande.getDecisionAutomatique() == 1)
          {
            int natureDecision = ((DecisionSpec)demande.getDossierAffectation().getDossierExamen()).getNatureDecision();
            if (natureDecision == 28)
            {
              getDemande(contexte).setNotifieeCourrier(true);
              
              ResultatGestionnaireReexecutionSpec resultatReexecution = validerDemande(contexte);
              
              OutilFluxSigma.notifierSigma(getIndividu(contexte), resultatReexecution.getDemandesReliquidees(), false);
            }
            else
            {
              OutilFluxSigma.notifierSigmaPourDecisionAutomatique(getDemande(contexte));
              
              supprimerDemande(contexte);
            }
          }
        }
        else
        {
          OutilFluxSigma.notifierSigmaPourDecisionAutomatique(getDemande(contexte));
          
          supprimerDemande(contexte);
        }
      }
    }
    catch (CoucheLogiqueException e)
    {
      if (getDemande(contexte).getDossierExamen() != null) {
        getDemande(contexte).getDossierExamen().changerEtat(0);
      }
      OutilFluxSigma.notifierSigmaPourDecisionAutomatique(getDemande(contexte));
      
      supprimerDemande(contexte);
    }
  }
  
  protected fr.unedic.cali.dom.DemandeSpec demandeAValider(Contexte contexte)
  {
    fr.unedic.cali.dom.DemandeSpec demandeAValider = getDemande(contexte);
    ContexteService contexteService = getContexteService(contexte);
    
    demandeAValider.validerDecision();
    
    demandeAValider.supprimerDossiersAffectations();
    demandeAValider.definirDateValidation(contexteService.getDateTraitement());
    
    return demandeAValider;
  }
  
  protected void notifierSigma(Contexte contexte, Collection listeDemandesCrees)
    throws ApplicativeException
  {
    OutilFluxSigma.notifierSigma(getIndividu(contexte), listeDemandesCrees, false);
  }
  
  protected ResultatGestionnaireReexecutionSpec reexecution(fr.unedic.cali.dom.DemandeSpec demande)
    throws ApplicativeException
  {
    return FabriqueGestionnaireReexecution.getGestionnaire().executerSurInstallationDemande(demande, new EvenementReexamen(demande.getDateRecherche(), "27"));
  }
  
  protected OutilAjoutCremDalLiquidation initialisationOutilAjouCREM()
  {
    return OutilAjoutCremDalLiquidation.getInstance();
  }
  
  protected ResultatGestionnaireReexecutionSpec validerDemande(Contexte contexte)
    throws ApplicativeException
  {
    fr.unedic.cali.dom.DemandeSpec demandeAValider = demandeAValider(contexte);
    
    Collection listeDemandesCrees = new ArrayList();
    listeDemandesCrees.add(demandeAValider);
    notifierSigma(contexte, listeDemandesCrees);
    
    ResultatGestionnaireReexecutionSpec resultatReexecution = reexecution(demandeAValider);
    
    OutilAjoutCremDalLiquidation outil = initialisationOutilAjouCREM();
    outil.ajouterCREMDemandesReexecutes(resultatReexecution.getDemandesReliquidees(), getIndividu(contexte));
    if (!resultatReexecution.getDemandesReliquidees().contains(demandeAValider)) {
      resultatReexecution.getDemandesReliquidees().add(demandeAValider);
    }
    return resultatReexecution;
  }
  
  private void supprimerDemande(Contexte contexte)
    throws ApplicativeException
  {
    fr.unedic.cali.dom.DemandeSpec nouvelleDemande = getDemande(contexte);
    IndividuSpec individu = getIndividu(contexte);
    individu.supprimerDemande(nouvelleDemande);
    ((DomLiquidationDemande)contexte.getDonnees()).setDemande(null);
    ((DomLiquidationDemande)contexte.getDonnees()).setIdDemande(null);
  }
  
  private DomLiquidationDecisionAutomatique getDonnees(Contexte contexte)
  {
    return (DomLiquidationDecisionAutomatique)contexte.getDonnees();
  }
  
  public Demande getDemande(Contexte contexte)
  {
    DomLiquidationDemande domCali = (DomLiquidationDemande)contexte.getDonnees();
    return (Demande)domCali.getDemandeSpec();
  }
  
  public int getTypeDecisionAutomatique(Contexte contexte)
  {
    DomLiquidationDecisionAutomatique domCali = (DomLiquidationDecisionAutomatique)contexte.getDonnees();
    return domCali.getTypeDecisionCalculeParSigma();
  }
  
  public QuantiteJour getCarenceConservatoire(Contexte contexte)
  {
    DomLiquidationDecisionAutomatique domCali = (DomLiquidationDecisionAutomatique)contexte.getDonnees();
    return domCali.getCarenceConservatoire();
  }
  
  public void setRejetNCP(Contexte contexte)
  {
    DomLiquidationDecisionAutomatique domCali = (DomLiquidationDecisionAutomatique)contexte.getDonnees();
    domCali.setTypeDecisionCalculeParSigma(3);
  }
  
  protected int getModeChargementDebrayageDossiersLourds(Individu individu)
  {
    return 2;
  }
  
  protected void alimenterAgregatGaec(Individu individu, String idDemande)
  {
    individu.getDonneesChargementGaec().getAgregatGaec().setModeAppel(2);
  }
  
  protected void controlerPostTraitement(Individu individu)
    throws AccesDonneesGaecException
  {
    controlerModeAppel(individu.getDonneesChargementGaec().getAppelGaecReduit(), 2);
  }
}

/* Location:
 * Qualified Name:     ParcoursDecisionAutomatique
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */