package fr.unedic.cali.asu.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.spec.ObjectifExamenAssuranceSpec;
import fr.unedic.cali.asu.outilsfonctionnels.OutilObjectifExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Parcours;
import fr.unedic.util.services.Resultat;
import java.util.ArrayList;

public class ParcoursObjectifRevision
  extends ParcoursCali
{
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    Resultat resultatObjectifRevision = new Resultat();
    resultatObjectifRevision.setEtat(1);
    
    DemandeAssuranceSpec demandeCourante = getDemande(contexte);
    
    ObjectifExamenAssuranceSpec objectifExamenCourant = OutilObjectifExamen.recupererObjectifCourant(contexte);
    
    boolean capRevSatisfaites = false;
    
    capRevSatisfaites = true;
    if (capRevSatisfaites)
    {
      demandeCourante.setDemandeOrigine((DemandeAssuranceSpec)((DomLiquidationAssurance)contexte.getDonnees()).getAttributionPrecedente().getDemande());
      
      executerCepRev(contexte, objectifExamenCourant);
      if (verifierCapRevSupplementaires(contexte)) {
        resultatObjectifRevision.setEtat(0);
      } else {
        demandeCourante.getDossierExamen().changerEtat(29);
      }
    }
    else
    {
      demandeCourante.getDossierExamen().changerEtat(29);
    }
    OutilTrace.tracerFinParcours();
    
    return resultatObjectifRevision;
  }
  
  private void executerCepRev(Contexte contexte, ObjectifExamenAssuranceSpec objectifExamenCourant)
    throws ApplicativeException
  {
    Demande demandeCourante = (Demande)getDemande(contexte);
    ProduitAsuSpec produitCourant = getProduit(contexte);
    
    changerEtatDossierExamenEnRevision(demandeCourante);
    
    produitCourant.constituerDateAttribution(contexte);
    
    produitCourant.constituerSalaireJournalierDeReference(contexte);
    
    produitCourant.constituerSalaireJournalierConserve(contexte);
    
    produitCourant.constituerCoefficientTempsPartiel(contexte);
    
    produitCourant.constituerDureesReglementaires(contexte);
    effectuerParcours(objectifExamenCourant.creerParcoursConstitutionDureePostPrime(), contexte);
    
    produitCourant.constituerMontantsBruts(contexte);
    
    alimenterTrancheExecutable(contexte);
    
    produitCourant.constituerDelaisReports(contexte);
    
    produitCourant.constituerPointDeDepart(contexte);
    
    nettoyerTrancheExecutable(contexte);
    
    produitCourant.constituerDureeEffective(contexte);
    
    produitCourant.constituerCapitalAvecDureeEffective(contexte);
  }
  
  protected Resultat effectuerParcours(Parcours parcours, Contexte contexte)
    throws ApplicativeException
  {
    Resultat resultat = null;
    if (parcours != null) {
      resultat = parcours.effectuerParcours(contexte);
    }
    return resultat;
  }
  
  private boolean verifierCapRevSupplementaires(Contexte contexte)
    throws ApplicativeException
  {
    boolean capRevSupplementairesSatisfaites = false;
    Resultat resultatCapRevMontant = null;
    
    ProduitAsuSpec produitCourant = getProduit(contexte);
    
    resultatCapRevMontant = produitCourant.verifierConditionMontant(contexte);
    if (resultatCapRevMontant.estSatisfait()) {
      capRevSupplementairesSatisfaites = true;
    }
    return capRevSupplementairesSatisfaites;
  }
  
  private void changerEtatDossierExamenEnRevision(DemandeAssuranceSpec demandeCourante)
    throws CoucheLogiqueException
  {
    demandeCourante.getDossierExamen().changerEtat(30);
    
    DossierExamenAssuranceSpec revision = (DossierExamenAssuranceSpec)demandeCourante.getDossierExamen();
    revision.setCompetence(null);
  }
  
  private ProduitAsuSpec getProduit(Contexte p_contexte)
  {
    DemandeAssuranceSpec demande = getDemande(p_contexte);
    if (demande == null) {
      return null;
    }
    return (ProduitAsuSpec)demande.getDossierAffectation().getProduit();
  }
  
  private DemandeAssuranceSpec getDemande(Contexte p_contexte)
  {
    return DomLiquidationAssurance.getDemande(p_contexte);
  }
  
  private void alimenterTrancheExecutable(Contexte p_contexte)
    throws ApplicativeException
  {
    Demande demande = DomLiquidationAssurance.getDemande(p_contexte);
    if ((demande.getAttribution() != null) && (demande.getAttribution().getProduit() != null))
    {
      ProduitAsuSpec produit = (ProduitAsuSpec)demande.getAttribution().getProduit();
      produit.constituerTranchesExecutables(p_contexte);
    }
  }
  
  private void nettoyerTrancheExecutable(Contexte p_contexte)
  {
    Demande demande = DomLiquidationAssurance.getDemande(p_contexte);
    if ((demande.getAttribution() != null) && (demande.getAttribution().getProduit() != null) && (((ProduitAsuSpec)demande.getAttribution().getProduit()).estTrancheActivee(demande)))
    {
      Attribution attribution = (Attribution)demande.getAttribution();
      attribution.setListeTranchesExecutables(new ArrayList());
    }
    if (demande.getAttribution() != null)
    {
      AttributionAssuranceSpec attribution = demande.getAttribution();
      attribution.viderCacheElementsChomageSansRupture();
    }
  }
}

/* Location:
 * Qualified Name:     ParcoursObjectifRevision
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */