package fr.unedic.cali.asu.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.EreDemandeApsEfe;
import fr.unedic.cali.asu.dom.EreDemandeAreEfe;
import fr.unedic.cali.asu.dom.EreDemandeAtAfdEfe;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.outilsfonctionnels.ConstructionChronologie;
import fr.unedic.cali.asu.outilsfonctionnels.GestionDemandeDv122eJour;
import fr.unedic.cali.asu.outilsfonctionnels.OutilAsr;
import fr.unedic.cali.asu.outilsfonctionnels.OutilDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsActiviteConserve;
import fr.unedic.cali.asu.outilsfonctionnels.VerificationDonneesForcees;
import fr.unedic.cali.asu.produits.liquidation.dom.Decision;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.strategies.StrategieDroitOptionElargiApres;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.strategies.StrategieDroitOptionElargiAvant;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.strategies.spec.StrategieDroitOptionElargiSpec;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnCharge;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.NaturesDecisions;
import fr.unedic.cali.dom.ObjetAlertesNonBloquantes;
import fr.unedic.cali.dom.RejetSpec;
import fr.unedic.cali.dom.SalaireJournalierSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.cali.fabriques.outilsfonctionnels.FabriqueStrategieGenerique;
import fr.unedic.cali.outilsfonctionnels.DetectionTypeChomage;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.outilsfonctionnels.RechercherPeriodeIndemnisation;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreNegation;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteSalarieeE301;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteSalarieeE301NonFrontalier;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesLiquidables;
import fr.unedic.cali.parcours.DomLiquidationDemande;
import fr.unedic.cali.parcours.ParcoursRechercheAlertes;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreOuvertureDroitSurDecision;
import fr.unedic.cali.utilitaire.filtres.objetChronoPeriode.FiltrePeriodeGaecSpecPourIncoherence;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.UniteAffiliation;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.FiltreDebutAvantDate;
import fr.unedic.util.temps.FiltreFinDansBornes;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import fr.unedic.util.temps.Temporel;
import fr.unedic.util.temps.UniteDuree;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Hashtable;
import java.util.Iterator;

public class ParcoursRechercheAlertesNonBloquantes
  extends ParcoursRechercheAlertes
  implements ParcoursAssurance
{
  private static final int NOMBRE_JOURS_POUR_RECHERCHE_DV = 91;
  private static final BigDecimal NOMBRE_JOURS_REQUIS_POUR_PRIME = new BigDecimal(61);
  private static final BigDecimal NOMBRE_HEURES_REQUIS_POUR_PRIME = new BigDecimal(305);
  private static final String MOTIF_ANNULATION_FIN_CRP = "33";
  
  public void controlerContexte(Contexte contexte)
    throws ContexteException
  {
    if (getDemande(contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null pour la recherche des alertes non bloquantes.");
    }
  }
  
  public static ParcoursRechercheAlertesNonBloquantes getInstance()
  {
    return new ParcoursRechercheAlertesNonBloquantes();
  }
  
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    Demande demande = getDemande(contexte);
    
    estEnContexteObtentionPrimeMalgreRejetAffi(demande);
    
    estDerniereActiviteConserveePerdueNonRevisee(demande);
    
    leverAlertesPraLaPlusLongue(contexte, demande);
    
    presencePeriodeFrauduleuse(demande);
    
    presenceDateDepotDansPeriodeValiditeConventionGestion(demande);
    
    presenceAlerteAD(demande);
    
    presenceIdentifiantEmployeurPublicObligatoire(demande);
    
    presenceAntecedentSpPMVS(demande);
    
    presencePndsDansCalculSJC(demande);
    
    estDroitOptionPossible(demande);
    
    afficherBilanDroitOption(demande);
    
    controlerSjrForceIpr(demande);
    
    afficherRepriseCRA(demande);
    
    detecterPjiAttributionPrecedenteApresAttributionCourante(demande);
    
    afficherAlerteBlocageLiquidationAutoCasOdSiOdPrecedenteEnCrsDispo(demande);
    
    return new Resultat();
  }
  
  private void detecterPjiAttributionPrecedenteApresAttributionCourante(Demande demande)
  {
    if ((demande.getAttribution() != null) && (demande.getAttribution().getPji() != null))
    {
      Damj pjiAttributionActuelle = demande.getAttribution().getPji();
      AttributionAssuranceSpec attributionPrecedente = demande.getAttribution().getAttributionPrecedente();
      if ((attributionPrecedente != null) && (attributionPrecedente.getPji() != null) && (pjiAttributionActuelle.estAvant(attributionPrecedente.getPji())))
      {
        Collection<ObjetAlertesNonBloquantes> listePeriodes = new ArrayList();
        
        ObjetAlertesNonBloquantes objetAlerteNonBloquante = new ObjetAlertesNonBloquantes(Damj.NUIT_DES_TEMPS, Damj.FIN_DES_TEMPS, 999);
        
        listePeriodes.add(objetAlerteNonBloquante);
        demande.getAlertesNonBloquantes().put("ANB_PJI_ATTRIB_PRECEDENTE_APRES", listePeriodes);
      }
    }
  }
  
  private void leverAlertesPraLaPlusLongue(Contexte contexte, Demande demande)
    throws CoucheLogiqueException
  {
    Chronologie listePas = demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation();
    Chronologie listePasE301 = demande.getDemandeur().getChronoPeriodePasseProfessionnel().copier(new FiltrePeriodeActiviteSalarieeE301());
    
    DossierExamenAssuranceSpec dossierExamenAssuranceSpec = (DossierExamenAssuranceSpec)demande.getDossierExamen();
    
    ChronologiePeriodes periodeParticipantesCompetence = null;
    if (dossierExamenAssuranceSpec != null)
    {
      CompetenceSpec competence = dossierExamenAssuranceSpec.getCompetence();
      if (competence != null) {
        periodeParticipantesCompetence = competence.getActivitesParticipantes();
      }
    }
    Hashtable<String, Collection<ObjetAlertesNonBloquantes>> alertesNonBloquantes = demande.getAlertesNonBloquantes();
    if (alertesNonBloquantes == null) {
      demande.setAlertesNonBloquantes(new Hashtable());
    }
    Periode praLaPlusLongue = determinerPraLaPlusLongue(demande);
    if (praLaPlusLongue != null)
    {
      if ((listePas != null) && (!listePas.estVide()))
      {
        presencePeriodeDeclareeNonJustifiee(demande, praLaPlusLongue, listePas);
        
        presencePeriodeEnConflit(demande, praLaPlusLongue, listePas);
        
        presencePeriodeNonQualifiee(demande, praLaPlusLongue, listePas);
        
        presencePeriodeQualifieeNonLiquidable(demande, praLaPlusLongue, listePas);
        
        presencePeriodeNonAttestee(demande, praLaPlusLongue, listePas);
        
        presencePeriodeFctFermetureDefinitiveEtablissement(demande, praLaPlusLongue, listePas);
        
        presencePeriodeStatutParticulier(demande, praLaPlusLongue, listePas);
        
        presenceDernierSinistreAvantCI(demande);
        
        presencePecCrpRadieeEtAttributionDevientOD(contexte, demande);
        
        presencePeriodeIncoherente(alertesNonBloquantes, periodeParticipantesCompetence);
      }
      if ((listePasE301 != null) && (!listePasE301.estVide())) {
        presencePeriodeE301(demande, praLaPlusLongue, listePasE301);
      }
    }
    if ((demande.getAlertesNonBloquantes() != null) && (demande.getAlertesNonBloquantes().isEmpty())) {
      demande.setAlertesNonBloquantes(null);
    }
  }
  
  public Periode determinerPraLaPlusLongue(Demande demande)
    throws CoucheLogiqueException
  {
    ActiviteSalarie fct = null;
    ProduitAsuSpec produit = null;
    if (demande.getDonneesTemporaires().getPeriodeFctARetenir() != null)
    {
      fct = (ActiviteSalarie)demande.getDonneesTemporaires().getPeriodeFctARetenir();
      if (fct.getReglement() != null) {
        produit = (ProduitAsuSpec)fct.getReglement().getProduit();
      }
    }
    else
    {
      if ((((DossierAffectation)demande.getDossierAffectation()).getValidationProduit() != null) && (((DossierAffectation)demande.getDossierAffectation()).getValidationProduit().isEstProduitValide()) && (((DossierAffectation)demande.getDossierAffectation()).getValidationProduit().getPeriodeValidationProduit() != null)) {
        fct = ((DossierAffectation)demande.getDossierAffectation()).getValidationProduit().getPeriodeValidationProduit();
      }
      produit = (ProduitAsuSpec)demande.getDossierAffectation().getProduit();
    }
    Damj dateFgPrecedent = demande.getDateFaitGenerateurOdPrecedente();
    Periode pra;
    if ((fct != null) && (produit != null))
    {
      Periode pra = produit.determinerPraLaPlusLongue(demande, fct);
      if ((dateFgPrecedent != null) && (pra != null)) {
        pra.setDebut(Damj.max(dateFgPrecedent.lendemain(), pra.getDebut()));
      }
    }
    else
    {
      Damj dateFin = demande.getDateExamen();
      Damj dateDebut = demande.getDateExamen().deplacerVersArriere(new DureeCalendaire(0, 36, 0));
      if (dateFgPrecedent != null) {
        dateDebut = Damj.max(dateDebut, dateFgPrecedent.lendemain());
      }
      pra = new Periode(dateDebut, dateFin);
    }
    return pra;
  }
  
  private void estDerniereActiviteConserveePerdueNonRevisee(DemandeAssuranceSpec demande)
  {
    TravailSpec activite = OutilsActiviteConserve.estDerniereActiviteConserveePerdueNonRevisee(demande);
    if (activite != null)
    {
      ArrayList<ObjetAlertesNonBloquantes> listeAlertesNonBloquantes = new ArrayList();
      listeAlertesNonBloquantes.add(new ObjetAlertesNonBloquantes(activite.getDateDebut(), activite.getDateFin(), 2));
      
      demande.getAlertesNonBloquantes().put("A6MNB1", listeAlertesNonBloquantes);
    }
  }
  
  private void presenceDernierSinistreAvantCI(DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    boolean demandeSuiteIde = demande.getEvenementReferenceExamen().getLibelle().equals("IDE");
    
    DossierAffectation dossierAffectation = (DossierAffectation)demande.getDossierAffectation();
    if (dossierAffectation != null)
    {
      ValidationProduit validationProduit = dossierAffectation.getValidationProduit();
      if ((validationProduit != null) && (validationProduit.isEstProduitValide()))
      {
        TravailSpec sinistre = dossierAffectation.getSinistre();
        if (sinistre != null)
        {
          Damj dateDernierSinistre = sinistre.getDateFin();
          
          ObjetChronoPeriode periodeIndemnisation = RechercherPeriodeIndemnisation.rechercherPeriodeIndemniseeEffectiveAssurance(demande.getDemandeur(), dateDernierSinistre);
          if (periodeIndemnisation == null)
          {
            Chronologie chronoPeriodesPecIndemnisablesPrecedentes = demande.getDemandeur().getChronologiePecFusionneesFinCI().copier(new FiltreDebutAvantDate(demande.getDateExamen()));
            if ((chronoPeriodesPecIndemnisablesPrecedentes != null) && (!chronoPeriodesPecIndemnisablesPrecedentes.estVide()))
            {
              ObjetChronoPeriodePriseEnCharge objetChronoPecPrecedente = (ObjetChronoPeriodePriseEnCharge)chronoPeriodesPecIndemnisablesPrecedentes.dernierElement();
              
              Damj derniereDateDeRadiation = objetChronoPecPrecedente.getDateFin();
              if ((dateDernierSinistre != null) && (derniereDateDeRadiation != null))
              {
                boolean dernierSinistreAvantDerniereRadiation = dateDernierSinistre.estAvant(derniereDateDeRadiation);
                
                FaitGenerateurSpec conditionFaitGenerateur = ((DossierExamenAssuranceSpec)demande.getDossierExamen()).getFaitGenerateur();
                boolean estRejetB41 = (conditionFaitGenerateur != null) && (!conditionFaitGenerateur.estSatisfait()) && (conditionFaitGenerateur.getCodeMotifEchec() == 44);
                if ((estRejetB41) && (demandeSuiteIde) && (dernierSinistreAvantDerniereRadiation))
                {
                  Collection<ObjetAlertesNonBloquantes> paramAlerteNonBloquante = new ArrayList();
                  ObjetAlertesNonBloquantes objetAlerteNonBloquante = new ObjetAlertesNonBloquantes(sinistre.getDateDebut(), sinistre.getDateFin(), 2);
                  
                  paramAlerteNonBloquante.add(objetAlerteNonBloquante);
                  demande.getAlertesNonBloquantes().put("A11MNB11", paramAlerteNonBloquante);
                }
              }
            }
          }
        }
      }
    }
  }
  
  public void presencePeriodeDeclareeNonJustifiee(DemandeAssuranceSpec demande, Periode pra, Chronologie listePas)
  {
    Periode periodeRecherche = new Periode(pra.getDebut(), pra.getFin());
    
    Chronologie periodesDeclareesNonJustifiees = ConstructionChronologie.determinerPeriodesDeclareesNonJustifiees(periodeRecherche, listePas);
    if (!periodesDeclareesNonJustifiees.estVide())
    {
      Iterator itPeriodes = periodesDeclareesNonJustifiees.iterer();
      Collection<ObjetAlertesNonBloquantes> listePeriodesResultantes = new ArrayList();
      while (itPeriodes.hasNext()) {
        listePeriodesResultantes.add(new ObjetAlertesNonBloquantes((TravailSpec)itPeriodes.next()));
      }
      demande.getAlertesNonBloquantes().put("AMNB1", listePeriodesResultantes);
    }
  }
  
  private void presencePeriodeEnConflit(DemandeAssuranceSpec demande, Periode pra, Chronologie listePas)
  {
    Chronologie periodesEnConflit = ConstructionChronologie.determinerPeriodesEnConflit(pra, listePas);
    if (!periodesEnConflit.estVide())
    {
      Iterator itPeriodes = periodesEnConflit.iterer();
      Collection<ObjetAlertesNonBloquantes> listePeriodesResultantes = new ArrayList();
      while (itPeriodes.hasNext()) {
        listePeriodesResultantes.add(new ObjetAlertesNonBloquantes((TravailSpec)itPeriodes.next()));
      }
      demande.getAlertesNonBloquantes().put("AMNB2", listePeriodesResultantes);
    }
  }
  
  private void presencePeriodeNonQualifiee(DemandeAssuranceSpec demande, Periode pra, Chronologie listePas)
  {
    Periode periodeRecherche = new Periode(pra.getDebut(), pra.getFin());
    Chronologie periodesNonQualifieesEtQualifieesNonLiquidables = ConstructionChronologie.determinerPeriodesNonQualifiees(periodeRecherche, listePas);
    if (!periodesNonQualifieesEtQualifieesNonLiquidables.estVide())
    {
      Iterator itPeriodes = periodesNonQualifieesEtQualifieesNonLiquidables.iterer();
      Collection<ObjetAlertesNonBloquantes> listePeriodesResultantes = new ArrayList();
      while (itPeriodes.hasNext()) {
        listePeriodesResultantes.add(new ObjetAlertesNonBloquantes((TravailSpec)itPeriodes.next()));
      }
      demande.getAlertesNonBloquantes().put("AMNB3", listePeriodesResultantes);
    }
  }
  
  private void presencePeriodeQualifieeNonLiquidable(DemandeAssuranceSpec demande, Periode pra, Chronologie listePas)
  {
    Periode periodeRecherche = new Periode(pra.getDebut(), pra.getFin());
    Chronologie periodesNonQualifieesEtQualifieesNonLiquidables = ConstructionChronologie.determinerPeriodesQualifieesNonLiquidables(periodeRecherche, listePas);
    if (!periodesNonQualifieesEtQualifieesNonLiquidables.estVide())
    {
      Iterator itPeriodes = periodesNonQualifieesEtQualifieesNonLiquidables.iterer();
      Collection listePeriodesResultantes = new ArrayList();
      while (itPeriodes.hasNext()) {
        listePeriodesResultantes.add(new ObjetAlertesNonBloquantes((TravailSpec)itPeriodes.next()));
      }
      demande.getAlertesNonBloquantes().put("AMNB4", listePeriodesResultantes);
    }
  }
  
  private void presencePeriodeNonAttestee(DemandeAssuranceSpec demande, Periode pra, Chronologie listePas)
  {
    Chronologie periodesNonAttestees = ConstructionChronologie.determinerPeriodesNonAttestees(pra, listePas);
    if (!periodesNonAttestees.estVide())
    {
      Iterator itPeriodes = periodesNonAttestees.iterer();
      Collection listePeriodesResultantes = new ArrayList();
      while (itPeriodes.hasNext()) {
        listePeriodesResultantes.add(new ObjetAlertesNonBloquantes((TravailSpec)itPeriodes.next()));
      }
      demande.getAlertesNonBloquantes().put("AMNB5", listePeriodesResultantes);
    }
  }
  
  private void presencePeriodeFctFermetureDefinitiveEtablissement(DemandeAssuranceSpec demande, Periode pra, Chronologie listePas)
  {
    Chronologie periodesFctFermetureEtablissement = ConstructionChronologie.determinerPeriodesFermetureDefinitiveEtablissement(pra, listePas);
    if (!periodesFctFermetureEtablissement.estVide())
    {
      Iterator itPeriodes = periodesFctFermetureEtablissement.iterer();
      Collection listePeriodesResultantes = new ArrayList();
      while (itPeriodes.hasNext()) {
        listePeriodesResultantes.add(new ObjetAlertesNonBloquantes((TravailSpec)itPeriodes.next()));
      }
      demande.getAlertesNonBloquantes().put("AMNB7", listePeriodesResultantes);
    }
  }
  
  private void presencePeriodeStatutParticulier(DemandeAssuranceSpec demande, Periode pra, Chronologie listePas)
  {
    Collection<ObjetAlertesNonBloquantes> listePeriodesResultantes = new ArrayList();
    boolean estLienParente = false;
    
    Periode periodeRecherche = new Periode(pra.getDebut(), pra.getFin());
    
    FiltresTemporel filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreChevauchePeriode(periodeRecherche));
    filtres.ajouterFiltre(new FiltrePeriodesLiquidables());
    filtres.ajouterFiltre(new FiltreActiviteSalarie());
    
    Chronologie chronoPeriodes = listePas.copier(filtres);
    if (!chronoPeriodes.estVide())
    {
      chronoPeriodes.iterer();
      while (chronoPeriodes.encoreSuivant())
      {
        ActiviteSalarie pas = (ActiviteSalarie)chronoPeriodes.elementSuivant();
        if (pas.getContrat().estLienParenteAvecChefEntreprise())
        {
          listePeriodesResultantes.add(new ObjetAlertesNonBloquantes(pas));
          estLienParente = true;
        }
      }
      if (estLienParente) {
        demande.getAlertesNonBloquantes().put("AMNB8", listePeriodesResultantes);
      }
    }
  }
  
  private void presencePeriodeE301(DemandeAssuranceSpec demande, Periode pra, Chronologie chronologiePeriodeE301)
  {
    boolean estCoorCEE = demande.getDonneesTemporaires().isEstCoordCee();
    if (!estCoorCEE)
    {
      FiltresTemporel filtresE301SurPra = new FiltresTemporel();
      filtresE301SurPra.ajouterFiltre(new FiltreChevauchePeriode(pra));
      
      Chronologie chronoPeriodesE301SurPra = chronologiePeriodeE301.copier(filtresE301SurPra);
      if ((chronoPeriodesE301SurPra != null) && (!chronoPeriodesE301SurPra.estVide()))
      {
        Iterator itPeriodes = chronoPeriodesE301SurPra.iterer();
        Collection listePeriodesResultantes = new ArrayList();
        while (itPeriodes.hasNext()) {
          listePeriodesResultantes.add(new ObjetAlertesNonBloquantes((TravailSpec)itPeriodes.next()));
        }
        demande.getAlertesNonBloquantes().put("A8MNB4", listePeriodesResultantes);
      }
      Periode periodeRecherche = new Periode(pra.getFin(), getDateBornageRechercheE301Frontalier(demande));
      FiltresTemporel listeFiltresE301EntrePraDateExamen = new FiltresTemporel();
      listeFiltresE301EntrePraDateExamen.ajouterFiltre(new FiltrePeriodeActiviteSalarieeE301());
      listeFiltresE301EntrePraDateExamen.ajouterFiltre(new FiltreNegation(new FiltrePeriodeActiviteSalarieeE301NonFrontalier()));
      listeFiltresE301EntrePraDateExamen.ajouterFiltre(new FiltreChevauchePeriode(periodeRecherche));
      Chronologie chronoE301DansEntrePraDateExamen = chronologiePeriodeE301.copier(listeFiltresE301EntrePraDateExamen);
      if ((chronoE301DansEntrePraDateExamen != null) && (!chronoE301DansEntrePraDateExamen.estVide()))
      {
        Iterator itPeriodes = chronoE301DansEntrePraDateExamen.iterer();
        Collection listePeriodesResultantes = new ArrayList();
        while (itPeriodes.hasNext()) {
          listePeriodesResultantes.add(new ObjetAlertesNonBloquantes((TravailSpec)itPeriodes.next()));
        }
        demande.getAlertesNonBloquantes().put("A8MNB4", listePeriodesResultantes);
      }
    }
  }
  
  public void presencePeriodeIncoherente(Hashtable<String, Collection<ObjetAlertesNonBloquantes>> tableAlerteNonBloquante, Chronologie chronologiePeriodeParticipantesCalculCompetence)
  {
    if ((chronologiePeriodeParticipantesCalculCompetence != null) && (!chronologiePeriodeParticipantesCalculCompetence.estVide()))
    {
      String valeurIncoherenceChampApplication = "01";
      FiltrePeriodeGaecSpecPourIncoherence filtrePeriodeGaecSpecPourIncoherence = new FiltrePeriodeGaecSpecPourIncoherence("01");
      
      Chronologie chronologiesIncoherentes = chronologiePeriodeParticipantesCalculCompetence.copier(filtrePeriodeGaecSpecPourIncoherence);
      if ((chronologiesIncoherentes != null) && (!chronologiesIncoherentes.estVide()))
      {
        Iterator<ObjetAlertesNonBloquantes> itPeriodes = chronologiesIncoherentes.iterer();
        Collection<ObjetAlertesNonBloquantes> listePeriodes = new ArrayList();
        while (itPeriodes.hasNext())
        {
          TravailSpec periode = (TravailSpec)itPeriodes.next();
          listePeriodes.add(new ObjetAlertesNonBloquantes(periode.getDateDebut(), periode.getDateFin(), 10));
        }
        tableAlerteNonBloquante.put("A14MBN3", listePeriodes);
      }
    }
  }
  
  public void presenceDVDansLes91Jours(DemandeAssuranceSpec demande, IndividuSpec individu, Damj dateFinRecherche)
  {
    if (dateFinRecherche != null)
    {
      Chronologie chronoPassePro = individu.getChronoPeriodePasseProfessionnelLiquidation();
      Collection listePeriodesResultantes = new ArrayList();
      Quantite qteJoursDeRecule = new Quantite(new BigDecimal(91), UniteDuree.JOUR);
      DureeCalendaire dureeDeRecule = DureeCalendaire.depuisQuantite(qteJoursDeRecule);
      Damj dateDebutRecherche = dateFinRecherche.deplacerVersArriere(dureeDeRecule);
      
      chronoPassePro = chronoPassePro.copier(new FiltreFinDansBornes(dateDebutRecherche, dateFinRecherche));
      if ((chronoPassePro != null) && (!chronoPassePro.estVide()))
      {
        Iterator it = chronoPassePro.iterer();
        while (it.hasNext())
        {
          ObjetChronoPeriode activite = (ObjetChronoPeriode)it.next();
          if ((activite instanceof ActiviteSalarie))
          {
            int codeMotifFin = ((ActiviteSalarie)activite).getCodeMotifFin();
            int contexteDemisison = ((ActiviteSalarie)activite).getContrat().getContexteDemission();
            if (!DetectionTypeChomage.estChomageLegitime(codeMotifFin, contexteDemisison))
            {
              ObjetAlertesNonBloquantes alerte = new ObjetAlertesNonBloquantes((ActiviteSalarie)activite);
              listePeriodesResultantes.add(alerte);
              demande.getAlertesNonBloquantes().put("PRESENCE_DV", listePeriodesResultantes);
              
              return;
            }
          }
        }
      }
    }
  }
  
  public void estEnContexteObtentionPrimeMalgreRejetAffi(DemandeAssuranceSpec demande, Quantite[] assimilations)
  {
    if ((assimilations != null) && (assimilations.length > 0)) {
      for (int i = 0; i < assimilations.length; i++)
      {
        Quantite assimilation = assimilations[i];
        if ((assimilation != null) && (((assimilation.getUnite().equals(UniteAffiliation.JOUR)) && (NOMBRE_JOURS_REQUIS_POUR_PRIME.compareTo(assimilation.getValeur()) <= 0)) || ((assimilation.getUnite().equals(UniteAffiliation.HEURE_TRAVAIL)) && (NOMBRE_HEURES_REQUIS_POUR_PRIME.compareTo(assimilation.getValeur()) <= 0))))
        {
          ObjetAlertesNonBloquantes alerte = new ObjetAlertesNonBloquantes(new Damj(), new Damj(), 999);
          
          ArrayList listeAlertes = new ArrayList();
          listeAlertes.add(alerte);
          demande.getAlertesNonBloquantes().put("AFFI_OK_POUR_PRIME", listeAlertes);
          
          return;
        }
      }
    }
  }
  
  private void estEnContexteObtentionPrimeMalgreRejetAffi(DemandeAssuranceSpec demande)
  {
    DossierExamenSpec dossierExamen = demande.getDossierExamen();
    if (!(dossierExamen instanceof RejetSpec)) {
      demande.getAlertesNonBloquantes().remove("AFFI_OK_POUR_PRIME");
    }
  }
  
  private void presencePeriodeFrauduleuse(Demande demande)
    throws CoucheLogiqueException
  {
    String codeAlerteNonBloquante = "A8MNB5";
    
    Collection listePF = new ArrayList();
    
    Chronologie listePeriodesFrauduleuses = ConstructionChronologie.determinerPeriodesFrauduleuses(demande);
    if (!listePeriodesFrauduleuses.estVide())
    {
      Iterator iterPeriodeFraude = listePeriodesFrauduleuses.iterer();
      while (iterPeriodeFraude.hasNext())
      {
        ObjetChronoPeriode periodeFraude = (ObjetChronoPeriode)iterPeriodeFraude.next();
        ObjetAlertesNonBloquantes objetAlerteNonBloquante = new ObjetAlertesNonBloquantes(periodeFraude.getDateDebut(), periodeFraude.getDateFin(), 8);
        
        listePF.add(objetAlerteNonBloquante);
      }
      demande.getAlertesNonBloquantes().put("A8MNB5", listePF);
    }
  }
  
  public void presencePeriodeAllongementDelaiForclusion(Demande demande, Chronologie listePas)
    throws CoucheLogiqueException
  {
    Collection listePeriodes = new ArrayList();
    if (!listePas.estVide())
    {
      Iterator iterPeriodes = listePas.iterer();
      while (iterPeriodes.hasNext())
      {
        Temporel periode = (Temporel)iterPeriodes.next();
        ObjetAlertesNonBloquantes objetAlerteNonBloquante = new ObjetAlertesNonBloquantes(periode.getDateDebut(), periode.getDateFin(), 999);
        
        listePeriodes.add(objetAlerteNonBloquante);
      }
      demande.getAlertesNonBloquantes().put("A8MNB6", listePeriodes);
    }
  }
  
  public void presencePecCrpRadieeEtAttributionDevientOD(Contexte contexte, DemandeAssuranceSpec demande)
  {
    String codeAlerteNonBloquante = "BORNES_PEC_A_DEPLACER";
    if (OutilDemande.estUneDemandeFinDroitAsr(demande))
    {
      Damj dateRecherche = demande.getDateFin();
      Demande demandeAsrAssociee = OutilAsr.getDemandeAsrPrecedente(demande, dateRecherche);
      Damj dateExamenDemandeAsr = demandeAsrAssociee.getDateExamen();
      
      ObjetChronoPeriodePriseEnCharge periodePEC = OutillagePEC.getPeriodePECIndemnisableContenant(demande.getDemandeur(), dateExamenDemandeAsr);
      
      boolean pecOk = (periodePEC != null) && ("33".equals(periodePEC.getMotifAnnulation()));
      
      Demande demandeAvantReexamen = (Demande)((DomLiquidationAssurance)contexte.getDonnees()).getDemandeAvantReexamen();
      Decision decisionAvantReexamen = null;
      if (demandeAvantReexamen != null) {
        decisionAvantReexamen = (Decision)demandeAvantReexamen.getDossierExamen();
      }
      boolean rejetAvantReexamen = decisionAvantReexamen instanceof RejetSpec;
      
      Decision decisionApresReexamen = (Decision)demande.getDossierExamen();
      boolean attributionApresReexamen = decisionApresReexamen instanceof AttributionSpec;
      if ((pecOk) && (rejetAvantReexamen) && (attributionApresReexamen))
      {
        Collection listeParametres = new ArrayList();
        
        ObjetAlertesNonBloquantes objetAlerteNonBloquante = new ObjetAlertesNonBloquantes(demande.getDateDebut(), demande.getDateFin(), 2);
        
        listeParametres.add(objetAlerteNonBloquante);
        
        demande.getAlertesNonBloquantes().put("BORNES_PEC_A_DEPLACER", listeParametres);
      }
    }
  }
  
  public void presenceDateDepotDansPeriodeValiditeConventionGestion(Demande demande)
    throws CoucheLogiqueException
  {
    DossierExamenAssuranceSpec dossierExamen = (DossierExamenAssuranceSpec)demande.getDossierExamen();
    
    CompetenceSpec competence = dossierExamen.getCompetence();
    if ((competence != null) && (competence.getConventionGestion() != null))
    {
      Damj dateDepot = demande.getDateDepot();
      Damj debutValidite = competence.getConventionGestion().getDebutValidite();
      Damj finValidite = competence.getConventionGestion().getFinValidite();
      if (debutValidite != null)
      {
        if (finValidite == null) {
          finValidite = Damj.FIN_DES_TEMPS;
        }
        Periode periodeValidite = new Periode(debutValidite, finValidite);
        if (!periodeValidite.contient(dateDepot))
        {
          ObjetAlertesNonBloquantes objetAlerteNonBloquante = new ObjetAlertesNonBloquantes(debutValidite, finValidite, 999);
          
          Collection listePeriodes = new ArrayList();
          listePeriodes.add(objetAlerteNonBloquante);
          demande.getAlertesNonBloquantes().put("A16MNB4", listePeriodes);
        }
      }
    }
  }
  
  private Demande getDemande(Contexte contexte)
  {
    return (Demande)((DomLiquidationDemande)contexte.getDonnees()).getDemandeSpec();
  }
  
  private Damj getDateBornageRechercheE301Frontalier(DemandeAssuranceSpec demande)
  {
    Damj dateBornageRecherche = demande.getDateExamen();
    
    EvenementReferenceExamenSpec ere = demande.getEvenementReferenceExamen();
    if (((ere instanceof EreDemandeApsEfe)) || ((ere instanceof EreDemandeAreEfe)) || ((ere instanceof EreDemandeAtAfdEfe))) {
      dateBornageRecherche = demande.getFormulaire().getDateDepot();
    }
    return dateBornageRecherche;
  }
  
  public void presenceIdentifiantEmployeurPublicObligatoire(Demande demande)
    throws CoucheLogiqueException
  {
    DossierExamenAssuranceSpec dossierExamen = (DossierExamenAssuranceSpec)demande.getDossierExamen();
    CompetenceSpec competence = dossierExamen.getCompetence();
    if ((competence != null) && (competence.estIdExterneObligatoire()) && ((competence.getIdExterneEmployeurSp() == null) || ("".equals(competence.getIdExterneEmployeurSp()))))
    {
      Collection listePeriodes = new ArrayList();
      
      ObjetAlertesNonBloquantes objetAlerteNonBloquante = new ObjetAlertesNonBloquantes(Damj.NUIT_DES_TEMPS, Damj.FIN_DES_TEMPS, 999);
      
      listePeriodes.add(objetAlerteNonBloquante);
      demande.getAlertesNonBloquantes().put("A14MNB2", listePeriodes);
    }
  }
  
  public void presenceAntecedentSpPMVS(Demande demande)
    throws CoucheLogiqueException
  {
    if ((OutilDemande.estUneDemandeAtp(demande)) || (demande.estUneDemandeFinancement())) {
      return;
    }
    boolean demandeAsuPrecedenteClasseeEnCompetenceSp = false;
    
    DemandeAssuranceSpec dernierDroit = VerificationDonneesForcees.rechercherDerniereDemandePortantDroitOuClasseeSp(demande.getDemandeur(), demande);
    
    Periode pra = null;
    if ((demande.getDossierAffectationAdmission() != null) && (demande.getDossierAffectationAdmission().getValidationProduit() != null)) {
      pra = demande.getDossierAffectationAdmission().getValidationProduit().getPeriodePra();
    }
    if (dernierDroit != null)
    {
      demandeAsuPrecedenteClasseeEnCompetenceSp = dernierDroit.estClasseeEnCompetenceSecteurPublic();
      demandeAsuPrecedenteClasseeEnCompetenceSp = (demandeAsuPrecedenteClasseeEnCompetenceSp) && (pra != null) && (pra.contient(dernierDroit.getDateDeclenchementExamen()));
      
      demandeAsuPrecedenteClasseeEnCompetenceSp = (demandeAsuPrecedenteClasseeEnCompetenceSp) && (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)dernierDroit, 2));
    }
    AttributionAssuranceSpec attributionAssurancePrecedente = (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande, new FiltreAttributionStandardAssurance(false, true, true, false, demande));
    
    boolean attributionAsuPrecedenteDeCompetenceSp = (attributionAssurancePrecedente != null) && (attributionAssurancePrecedente.getCompetence().getCompetenceAdministrative() != 1);
    attributionAsuPrecedenteDeCompetenceSp = (attributionAsuPrecedenteDeCompetenceSp) && (pra != null) && (pra.contient(attributionAssurancePrecedente.getDateAttribution()));
    
    attributionAsuPrecedenteDeCompetenceSp = (attributionAsuPrecedenteDeCompetenceSp) && (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)attributionAssurancePrecedente.getDemandeAssurance(), 2));
    if (((demandeAsuPrecedenteClasseeEnCompetenceSp) || (attributionAsuPrecedenteDeCompetenceSp)) && ((demande.getDonneesTemporaires() == null) || (demande.getDonneesTemporaires().getQuantiteAffiliation() == null)))
    {
      Collection listePeriodes = new ArrayList();
      
      ObjetAlertesNonBloquantes objetAlerteNonBloquante = new ObjetAlertesNonBloquantes(Damj.NUIT_DES_TEMPS, Damj.FIN_DES_TEMPS, 999);
      
      listePeriodes.add(objetAlerteNonBloquante);
      demande.getAlertesNonBloquantes().put("AFFI_SP_PMVS", listePeriodes);
    }
  }
  
  public void presencePndsDansCalculSJC(Demande demande)
    throws CoucheLogiqueException
  {
    if ((!demande.isPndsChargees()) && (demande.getDonneesTemporaires().getSjc() == null))
    {
      AttributionAssuranceSpec attribution = demande.getAttribution();
      if (attribution != null)
      {
        SalaireJournalierSpec sjc = attribution.getSalaireJournalierConserve();
        if ((sjc != null) && (sjc.getSalaire() != null) && (BigDecimal.ZERO.compareTo(sjc.getSalaire()) < 0))
        {
          Collection<ObjetAlertesNonBloquantes> listePeriodes = new ArrayList();
          
          ObjetAlertesNonBloquantes objetAlerteNonBloquante = new ObjetAlertesNonBloquantes(Damj.NUIT_DES_TEMPS, Damj.FIN_DES_TEMPS, 999);
          
          listePeriodes.add(objetAlerteNonBloquante);
          demande.getAlertesNonBloquantes().put("ALERTE_PNDS", listePeriodes);
        }
      }
    }
  }
  
  private void estDroitOptionPossible(Demande demande)
    throws ApplicativeException
  {
    StrategieDroitOptionElargiSpec strategie = (StrategieDroitOptionElargiSpec)FabriqueStrategieGenerique.choisirStrategie(demande.getDateExamen(), "Application du droit d'option élargi.", new StrategieDroitOptionElargiAvant(), new StrategieDroitOptionElargiApres());
    
    strategie.estDroitOptionPossible(demande);
  }
  
  private void afficherBilanDroitOption(Demande demande)
    throws CoucheLogiqueException
  {
    StrategieDroitOptionElargiSpec strategie = (StrategieDroitOptionElargiSpec)FabriqueStrategieGenerique.choisirStrategie(demande.getDateExamen(), "Application du droit d'option élargi.", new StrategieDroitOptionElargiAvant(), new StrategieDroitOptionElargiApres());
    
    strategie.afficherBilanDroitOption(demande);
  }
  
  private void controlerSjrForceIpr(Demande demande)
    throws CoucheLogiqueException
  {
    if ((demande.leverAlertePopup()) && ("ASU_04".equals(demande.getEvenementReferenceExamen().getTypeExamen())))
    {
      Demande demandeDV = GestionDemandeDv122eJour.retrouverDemandePortantDv(demande);
      if (demandeDV != null)
      {
        DonneesTemporaires donneesForceesDV = demandeDV.getDonneesTemporaires();
        DonneesTemporaires donneesForcees = demande.getDonneesTemporaires();
        if ((donneesForceesDV.getSjr() != null) && (donneesForcees.getSjr() == null))
        {
          Collection<ObjetAlertesNonBloquantes> listePeriodes = new ArrayList();
          
          ObjetAlertesNonBloquantes objetAlerteNonBloquante = new ObjetAlertesNonBloquantes(Damj.NUIT_DES_TEMPS, Damj.FIN_DES_TEMPS, 999);
          
          listePeriodes.add(objetAlerteNonBloquante);
          demande.getAlertesNonBloquantes().put("SJR_FORCE_IPR", listePeriodes);
        }
      }
    }
  }
  
  protected void afficherRepriseCRA(Demande demande)
  {
    boolean rejet = demande.getDossierExamen() instanceof RejetSpec;
    boolean ide = "ASU_01".equals(demande.getEvenementReferenceExamen().getTypeExamen());
    boolean contexteOk = OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "SORTIECRA");
    if ((rejet) && (ide) && (contexteOk))
    {
      Collection<ObjetAlertesNonBloquantes> listePeriodes = new ArrayList();
      
      ObjetAlertesNonBloquantes objetAlerteNonBloquante = new ObjetAlertesNonBloquantes(Damj.NUIT_DES_TEMPS, Damj.FIN_DES_TEMPS, 999);
      
      listePeriodes.add(objetAlerteNonBloquante);
      demande.getAlertesNonBloquantes().put("REPRISE_CRA", listePeriodes);
    }
  }
  
  protected void afficherAlerteBlocageLiquidationAutoCasOdSiOdPrecedenteEnCrsDispo(Demande demande)
  {
    boolean estOd = (demande.getAttribution() != null) && (NaturesDecisions.estdeTypeOd(demande.getAttribution().getNatureDecision()));
    if (estOd)
    {
      Demande demandePrecedente = (Demande)OutilRecherche.rechercherDemandePrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande, new FiltreOuvertureDroitSurDecision(true));
      
      boolean estContexteEnCoursDeDispoPresent = (demandePrecedente != null) && (demandePrecedente.estEnContexteDemande("COURSDISPO"));
      if (estContexteEnCoursDeDispoPresent)
      {
        Collection<ObjetAlertesNonBloquantes> listePeriodes = new ArrayList();
        
        ObjetAlertesNonBloquantes objecAlertesNonBloquantes = new ObjetAlertesNonBloquantes(Damj.NUIT_DES_TEMPS, Damj.FIN_DES_TEMPS, 999);
        
        listePeriodes.add(objecAlertesNonBloquantes);
        demande.getAlertesNonBloquantes().put("ANB_OD_AVEC_OD_PREC_EN_CRS_DISPO", listePeriodes);
      }
    }
  }
}

/* Location:
 * Qualified Name:     ParcoursRechercheAlertesNonBloquantes
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */