package fr.unedic.cali.asu.produits.liquidation.dom;

import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.gen.CompetenceGen;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.ConventionGestion;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.util.OutilDomToString;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.NonConformiteException;
import java.util.Iterator;

public class Competence
  extends CompetenceGen
  implements CompetenceSpec
{
  private transient int chargeIndemnisationDroitCourant;
  private transient String identifiantEmployeurCompetent;
  private transient ChronologiePeriodes chronoPeriodesActiviteSecteurPublicRetenues;
  private transient ChronologiePeriodes chronoPeriodesActiviteSecteurPriveRetenues;
  private transient ChronologiePeriodes chronoParticipantes;
  private transient int competenceAdministrativeDroitCourant = 0;
  private transient int competenceFinanciereDroitCourant = 0;
  private transient boolean idExterneObligatoire;
  private transient String idFctEmployeurCompetent;
  private transient boolean estCoeffTPAppliqueRAC = false;
  private transient boolean estCoeffTPAppliqueSP = false;
  private static final long serialVersionUID = -918985537763133666L;
  
  public Competence(DomPCSpec pc)
  {
    super(pc);
  }
  
  public Competence() {}
  
  public String donnerLibelleCompetence(int competence)
  {
    String libelleCompetenceRetour = null;
    switch (competence)
    {
    case 1: 
      libelleCompetenceRetour = "Assurance Chômage";
      break;
    case 2: 
      libelleCompetenceRetour = "Secteur public";
      break;
    }
    return libelleCompetenceRetour;
  }
  
  public boolean estCompetenceFinanciereSecteurPublic()
  {
    boolean competenceFinanciereSecteurPublic = false;
    if (getCompetenceFinanciere() != 0) {
      competenceFinanciereSecteurPublic = getCompetenceFinanciere() == 2;
    } else {
      competenceFinanciereSecteurPublic = getChargeIndemnisationDroitCourant() == 2;
    }
    return competenceFinanciereSecteurPublic;
  }
  
  public boolean estCompetenceAdministrativeSecteurPublic()
  {
    boolean competenceAdministrativeSecteurPublic = false;
    if (getCompetenceAdministrative() != 0) {
      competenceAdministrativeSecteurPublic = getCompetenceAdministrative() == 2;
    } else {
      competenceAdministrativeSecteurPublic = getCompetenceAdministrativeDroitCourant() == 2;
    }
    return competenceAdministrativeSecteurPublic;
  }
  
  public int getChargeIndemnisationDroitCourant()
  {
    return chargeIndemnisationDroitCourant;
  }
  
  public void setChargeIndemnisationDroitCourant(int pChargeIndemnisationDroitCourant)
  {
    chargeIndemnisationDroitCourant = pChargeIndemnisationDroitCourant;
  }
  
  public ChronologiePeriodes getChronoPeriodesActiviteSecteurPriveRetenues()
  {
    if (chronoPeriodesActiviteSecteurPriveRetenues == null) {
      chronoPeriodesActiviteSecteurPriveRetenues = new ChronologiePeriodes();
    }
    return chronoPeriodesActiviteSecteurPriveRetenues;
  }
  
  public void setChronoPeriodesActiviteSecteurPriveRetenues(ChronologiePeriodes pChronoPeriodesActiviteSecteurPriveRetenues)
  {
    chronoPeriodesActiviteSecteurPriveRetenues = pChronoPeriodesActiviteSecteurPriveRetenues;
  }
  
  public ChronologiePeriodes getChronoPeriodesActiviteSecteurPublicRetenues()
  {
    if (chronoPeriodesActiviteSecteurPublicRetenues == null) {
      chronoPeriodesActiviteSecteurPublicRetenues = new ChronologiePeriodes();
    }
    return chronoPeriodesActiviteSecteurPublicRetenues;
  }
  
  public void setChronoPeriodesActiviteSecteurPublicRetenues(ChronologiePeriodes pChronoPeriodesActiviteSecteurPublicRetenues)
  {
    chronoPeriodesActiviteSecteurPublicRetenues = pChronoPeriodesActiviteSecteurPublicRetenues;
  }
  
  public String getIdentifiantEmployeurCompetent()
  {
    return identifiantEmployeurCompetent;
  }
  
  public void setIdentifiantEmployeurCompetent(String pIdentifiantEmployeurCompetent)
  {
    identifiantEmployeurCompetent = pIdentifiantEmployeurCompetent;
  }
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
  
  /**
   * @deprecated
   */
  public void marquerGraphePersistant() {}
  
  public void ajouterPeriodeActiviteSecteurPublic(ActiviteSalarie pPeriodeActiviteSecteurPublic)
  {
    if (pPeriodeActiviteSecteurPublic != null) {
      try
      {
        getChronoPeriodesActiviteSecteurPublicRetenues().ajouter(pPeriodeActiviteSecteurPublic);
      }
      catch (NonConformiteException ex)
      {
        OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "ajouterPeriodeActiviteSecteurPublic" }, ex);
      }
    }
  }
  
  public void ajouterPeriodeActiviteSecteurPrive(ActiviteSalarie pPeriodeActiviteSecteurPrive)
  {
    if (pPeriodeActiviteSecteurPrive != null) {
      try
      {
        getChronoPeriodesActiviteSecteurPriveRetenues().ajouter(pPeriodeActiviteSecteurPrive);
      }
      catch (NonConformiteException ex)
      {
        OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "ajouterPeriodeActiviteSecteurPrive" }, ex);
      }
    }
  }
  
  public ObjetMetierSpec copie()
  {
    Competence copie = new Competence();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec pCopie)
  {
    Competence copie = (Competence)pCopie;
    
    copie.setChargeIndemnisationDroitCourant(getChargeIndemnisationDroitCourant());
    copie.setCompetenceAdministrative(getCompetenceAdministrative());
    copie.setCompetenceFinanciere(getCompetenceFinanciere());
    copie.setDureeActiviteSecteurPrive(getDureeActiviteSecteurPrive());
    copie.setDureeActiviteSecteurPriveCaCae(getDureeActiviteSecteurPriveCaCae());
    copie.setDureeActiviteSecteurPublicAffilie(getDureeActiviteSecteurPublicAffilie());
    copie.setDureeActiviteSecteurPublicAutoAssurance(getDureeActiviteSecteurPublicAutoAssurance());
    copie.setDureeActiviteSecteurPublicConventionGestion(getDureeActiviteSecteurPublicConventionGestion());
    copie.setIdentifiantEmployeurCompetent(getIdentifiantEmployeurCompetent());
    copie.setLibelleEmployeurCompetent(getLibelleEmployeurCompetent());
    copie.setNumeroConventionGestion(getNumeroConventionGestion());
    copie.setCompetenceAdministrativeDroitCourant(getCompetenceAdministrativeDroitCourant());
    copie.setCompetenceFinanciereDroitCourant(getCompetenceFinanciereDroitCourant());
    copie.setApplicationDesAides(getApplicationDesAides());
    copie.setCodeAffectationConvention(getCodeAffectationConvention());
    copie.setPrecompteCrc(isPrecompteCrc());
    copie.setSignataireConvention(getSignataireConvention());
    copie.setLibelleAffectationConventionGestion(getLibelleAffectationConventionGestion());
    copie.setEstAideArce(isEstAideArce());
    copie.setEstAideAdr(isEstAideAdr());
    copie.setEstAideCongeNonPaye(isEstAideCongeNonPaye());
    copie.setEstAideFinDroit(isEstAideFinDroit());
    copie.setEstAideAllocationDeces(isEstAideAllocationDeces());
    copie.setEstPCRCForce(isEstPCRCForce());
    if (getChronoPeriodesActiviteSecteurPublicRetenues() != null)
    {
      Iterator iter = getChronoPeriodesActiviteSecteurPublicRetenues().iterer();
      ActiviteSalarie elementPas = null;
      while (iter.hasNext())
      {
        elementPas = (ActiviteSalarie)iter.next();
        copie.ajouterPeriodeActiviteSecteurPublic((ActiviteSalarie)elementPas.copie());
      }
    }
    if (getActivitesParticipantes() != null) {
      copie.setActivitesParticipantes((ChronologiePeriodes)getActivitesParticipantes().copie());
    }
    if (getChronoPeriodesActiviteSecteurPriveRetenues() != null)
    {
      Iterator iter = getChronoPeriodesActiviteSecteurPriveRetenues().iterer();
      ActiviteSalarie elementPas = null;
      while (iter.hasNext())
      {
        elementPas = (ActiviteSalarie)iter.next();
        copie.ajouterPeriodeActiviteSecteurPrive((ActiviteSalarie)elementPas.copie());
      }
    }
    copie.setIdExterneEmployeurSp(super.getIdExterneEmployeurSp());
  }
  
  public String toString()
  {
    return OutilDomToString.toString(this);
  }
  
  public int getCompetenceFinanciereDroitCourant()
  {
    if (competenceFinanciereDroitCourant == 0) {
      return getCompetenceFinanciere();
    }
    return competenceFinanciereDroitCourant;
  }
  
  public int getCompetenceAdministrativeDroitCourant()
  {
    if (competenceAdministrativeDroitCourant == 0) {
      return getCompetenceAdministrative();
    }
    return competenceAdministrativeDroitCourant;
  }
  
  public void setCompetenceAdministrativeDroitCourant(int pCompetenceAdministrative)
  {
    competenceAdministrativeDroitCourant = pCompetenceAdministrative;
  }
  
  public void setCompetenceFinanciereDroitCourant(int pCompetenceFinanciere)
  {
    competenceFinanciereDroitCourant = pCompetenceFinanciere;
  }
  
  public ConventionGestionSpec getConventionGestion()
  {
    String numeroConventionGestion = getNumeroConventionGestion();
    ConventionGestionSpec conventionGestion = null;
    if (numeroConventionGestion != null) {
      conventionGestion = new ConventionGestion(getNumeroConventionGestion(), getCodeAffectationConvention(), isEstAideArce(), isEstAideAdr(), isEstAideCongeNonPaye(), isEstAideFinDroit(), isEstAideAllocationDeces(), getSignataireConvention(), isPrecompteCrc(), getDebutValiditeConventionGestion(), getFinValiditeConventionGestion(), getLibelleAffectationConventionGestion(), false);
    }
    return conventionGestion;
  }
  
  public boolean estIdExterneObligatoire()
  {
    return idExterneObligatoire;
  }
  
  public void setIdExterneObligatoire(boolean pIdObligatoire)
  {
    idExterneObligatoire = pIdObligatoire;
  }
  
  public String getIdFctEmployeurCompetent()
  {
    return idFctEmployeurCompetent;
  }
  
  public void setIdFctEmployeurCompetent(String pIdFctEmployeurCompetent)
  {
    idFctEmployeurCompetent = pIdFctEmployeurCompetent;
  }
  
  public String getBouchonnageAppelCaro()
  {
    return "";
  }
  
  public void setBouchonnageAppelCaro(String pBouchonnageAppelCaro) {}
  
  public Damj getDateDepotDemande()
  {
    return null;
  }
  
  public void setDateDepotDemande(Damj pDateDepotDemande) {}
  
  public ChronologiePeriodes getActivitesParticipantes()
  {
    return chronoParticipantes;
  }
  
  public void setActivitesParticipantes(ChronologiePeriodes chronologies)
  {
    chronoParticipantes = chronologies;
  }
  
  public void setEstCoeffTPAppliqueRAC(boolean estCoeffTPAppliqueRAC)
  {
    this.estCoeffTPAppliqueRAC = estCoeffTPAppliqueRAC;
  }
  
  public boolean isEstCoeffTPAppliqueRAC()
  {
    return estCoeffTPAppliqueRAC;
  }
  
  public void setEstCoeffTPAppliqueSP(boolean estCoeffTPAppliqueSP)
  {
    this.estCoeffTPAppliqueSP = estCoeffTPAppliqueSP;
  }
  
  public boolean isEstCoeffTPAppliqueSP()
  {
    return estCoeffTPAppliqueSP;
  }
}

/* Location:
 * Qualified Name:     Competence
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */