package fr.unedic.cali.asu.produits.liquidation.dom;

import fr.unedic.cali.asu.produits.liquidation.dom.gen.ConditionActiviteConserveeGen;
import fr.unedic.cali.dom.ConditionAttributionSpec;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.cali.util.OutilDomToString;
import fr.unedic.transverse.dom.spec.DomGenSpec;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Iterator;

public class ConditionActiviteConservee
  extends ConditionActiviteConserveeGen
  implements ConditionAttributionSpec
{
  public static final int SITUATION_MEME_EMPLOYEUR = 1;
  public static final int SITUATION_DEPASSEMENT_PLAFOND_HEURE = 2;
  public static final int SITUATION_DEPASSEMENT_PLAFOND_REMUNERATION = 3;
  public static final int SITUATION_ACTIVITE_CONSERVEE_ET_CONDITION_REMPLIE = 4;
  public static final int SITUATION_ARCE_AVEC_PANS_EN_COURS = 5;
  private static final long serialVersionUID = 8571274772472665777L;
  private transient JustificationPansConservees m_justificationPansConservees;
  
  public ConditionActiviteConservee(DomPCSpec p_pc)
  {
    super(p_pc);
  }
  
  public ConditionActiviteConservee() {}
  
  public boolean estSatisfait()
  {
    return getEtat() == 0;
  }
  
  public void setEtatSatisfait(boolean p_etatSatisfait)
  {
    if (p_etatSatisfait) {
      setEtat(0);
    } else {
      setEtat(1);
    }
  }
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
  
  public void marquerGraphePersistant()
  {
    DomManager.persisterEnProfondeur(super.getCollectionSjrActiviteConservee());
  }
  
  public JustificationPansConservees getJustificationPansConservees()
  {
    return m_justificationPansConservees;
  }
  
  public void setJustificationPansConservees(JustificationPansConservees p_justificationPansConservees)
  {
    m_justificationPansConservees = p_justificationPansConservees;
  }
  
  public ObjetMetierSpec copie()
  {
    throw new UnsupportedOperationException("Cette méthode ne doit pas être appelée! Appeller le méthode copieElements(ObjetMetierSpec).");
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    ConditionActiviteConservee copie = (ConditionActiviteConservee)p_copie;
    copie.setCodeMotifEchec(getCodeMotifEchec());
    copie.setEtat(getEtat());
    copie.setSituationConditionActiviteConservee(getSituationConditionActiviteConservee());
    copie.setSeuilMensuelPansConditionActiviteConservee(getSeuilMensuelPansConditionActiviteConservee());
    copie.setNombreHeuresMensuelActiviteConservee(getNombreHeuresMensuelActiviteConservee());
    copie.setMontantMensuelActiviteConservee(getMontantMensuelActiviteConservee());
    copie.setSeuilMontantMensuelActiviteConservee(getSeuilMontantMensuelActiviteConservee());
    copie.setJustificationPansConservees(getJustificationPansConservees());
    
    Iterator iter = getListeSjrActiviteConservee().iterator();
    while (iter.hasNext())
    {
      SjrActiviteConservee element = (SjrActiviteConservee)iter.next();
      copie.ajouterSjrActiviteConservee((SjrActiviteConservee)element.copie());
    }
  }
  
  public String toString()
  {
    return OutilDomToString.toString(this);
  }
  
  public void ajouterSjrActiviteConservee(SjrActiviteConservee p_sjrActiviteConservee)
  {
    if (p_sjrActiviteConservee != null) {
      super.ajouterSjrActiviteConservee(p_sjrActiviteConservee);
    }
  }
  
  public Collection getListeSjrActiviteConservee()
  {
    return super.getCollectionSjrActiviteConservee();
  }
  
  public void viderCollectionSjrActiviteConservee()
  {
    for (Iterator iter = getCollectionSjrActiviteConservee().iterator(); iter.hasNext();)
    {
      DomGenSpec item = (DomGenSpec)iter.next();
      DomManager.supprimer(item);
    }
    super.clearCollectionSjrActiviteConservee();
  }
  
  public Collection getCollectionSjrActiviteConserveePerdue()
  {
    ArrayList listeActiviteConserveePerdue = new ArrayList();
    SjrActiviteConservee activite = null;
    Iterator iter = getCollectionSjrActiviteConservee().iterator();
    while (iter.hasNext())
    {
      activite = (SjrActiviteConservee)iter.next();
      if (("P".equals(activite.getTypeActiviteConservee())) || ("R".equals(activite.getTypeActiviteConservee()))) {
        listeActiviteConserveePerdue.add(activite);
      }
    }
    return Collections.unmodifiableCollection(listeActiviteConserveePerdue);
  }
  
  public void remplacerCollectionSjrActiviteConservee(Collection collectionACopier)
  {
    for (Iterator iter = super.getCollectionSjrActiviteConservee().iterator(); iter.hasNext();)
    {
      SjrActiviteConservee element = (SjrActiviteConservee)iter.next();
      DomManager.supprimer(element);
    }
    super.remplacerCollectionSjrActiviteConservee(collectionACopier);
  }
}

/* Location:
 * Qualified Name:     ConditionActiviteConservee
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */