package fr.unedic.cali.asu.produits.liquidation.dom;

import fr.unedic.cali.asu.dom.JustificationAffiliationSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.gen.ConstitutionQuantiteAffiliationGen;
import fr.unedic.cali.dom.ConstitutionDroitSpec;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.cali.util.OutilDomToString;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.temps.Periode;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.Set;

public class ConstitutionQuantiteAffiliation
  extends ConstitutionQuantiteAffiliationGen
  implements ConstitutionDroitSpec
{
  public static final String ARTICLE3_A_2003 = "a";
  public static final String ARTICLE3_B_2003 = "b";
  public static final String ARTICLE3_C_2003 = "c";
  public static final String ARTICLE3_A_2006 = "1";
  public static final String ARTICLE3_B_2006 = "2";
  public static final String ARTICLE3_C_2006 = "3";
  public static final String ARTICLE3_D_2006 = "4";
  public static final String ARTICLE3_E_2006 = "5";
  public static final String ARTICLE3_F_2006 = "6";
  public static final String ARTICLE3_G_2006 = "7";
  public static final String ARTICLE3_A_2009 = "a";
  public static final String ARTICLE3_B_2009 = "b";
  public static final String ARTICLE3_C_2009 = "c";
  public static final String ARTICLE3_D_2009 = "d";
  public static final String ARTICLE3_E_2009 = "e";
  public static final String ARTICLE3_F_2009 = "f";
  public static final String ARTICLE3_G_EXPAT_2009 = "g";
  public static final String ARTICLE3_H_EXPAT_2009 = "h";
  public static final String ARTICLE3_I_EXPAT_2009 = "i";
  private transient Quantite m_quantiteAffiliationAcquiseSecondaire;
  private transient Quantite m_quantiteAssimilationAcquiseSecondaire;
  private transient Quantite m_quantiteAffiliationRequise;
  private transient boolean m_estEnConflit;
  private transient Map m_mapJustificationAffiliation = new HashMap();
  private static final long serialVersionUID = 201884344569667145L;
  
  public ConstitutionQuantiteAffiliation(DomPCSpec p_pc)
  {
    super(p_pc);
  }
  
  public ConstitutionQuantiteAffiliation() {}
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
  
  public ObjetMetierSpec copie()
  {
    throw new UnsupportedOperationException("Cette méthode ne doit pas être appelée! Appeller le méthode copieElements(ObjetMetierSpec).");
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    ConstitutionQuantiteAffiliation copie = (ConstitutionQuantiteAffiliation)p_copie;
    
    copie.setArticle3(getArticle3());
    copie.setDureeInitiale(getDureeInitiale());
    copie.setEnConflit(estEnConflit());
    copie.setPeriodePRA(getPeriodePRA() != null ? new Periode(getPeriodePRA().getDebut(), getPeriodePRA().getFin()) : null);
    
    copie.setQuantiteAffiliationAcquise(getQuantiteAffiliationAcquise());
    copie.setQuantiteAssimilationAcquise(getQuantiteAssimilationAcquise());
    
    copie.setQuantiteAffiliationAcquiseSecondaire(getQuantiteAffiliationAcquiseSecondaire());
    copie.setQuantiteAssimilationAcquiseSecondaire(getQuantiteAssimilationAcquiseSecondaire());
    
    Iterator it = m_mapJustificationAffiliation.keySet().iterator();
    while (it.hasNext())
    {
      Unite unite = (Unite)it.next();
      copie.ajouterJustificationAffiliation((JustificationAffiliationSpec)m_mapJustificationAffiliation.get(unite), unite);
    }
  }
  
  /**
   * @deprecated
   */
  public void marquerGraphePersistant() {}
  
  public boolean estEnConflit()
  {
    return m_estEnConflit;
  }
  
  public void setEnConflit(boolean p_estEnConflit)
  {
    m_estEnConflit = p_estEnConflit;
  }
  
  public Quantite getQuantiteAffiliationAcquiseSecondaire()
  {
    return m_quantiteAffiliationAcquiseSecondaire;
  }
  
  public void setQuantiteAffiliationAcquiseSecondaire(Quantite p_quantiteAffiliationAcquiseSecondaire)
  {
    m_quantiteAffiliationAcquiseSecondaire = p_quantiteAffiliationAcquiseSecondaire;
  }
  
  public Quantite getQuantiteAcquiseSecondaire()
  {
    Quantite qte = m_quantiteAffiliationAcquiseSecondaire;
    if (m_quantiteAssimilationAcquiseSecondaire != null) {
      qte = m_quantiteAffiliationAcquiseSecondaire.ajouter(m_quantiteAssimilationAcquiseSecondaire);
    }
    return qte;
  }
  
  public Quantite getQuantiteAssimilationAcquiseSecondaire()
  {
    return m_quantiteAssimilationAcquiseSecondaire;
  }
  
  public void setQuantiteAssimilationAcquiseSecondaire(Quantite p_quantiteAssimilationAcquiseSecondaire)
  {
    m_quantiteAssimilationAcquiseSecondaire = p_quantiteAssimilationAcquiseSecondaire;
  }
  
  public String toString()
  {
    return OutilDomToString.toString(this);
  }
  
  public Quantite getQuantiteAcquise()
  {
    return getQuantiteAffiliationAcquise().ajouter(getQuantiteAssimilationAcquise());
  }
  
  public Quantite getQuantiteRequise()
  {
    return m_quantiteAffiliationRequise;
  }
  
  public void setQuantiteRequise(Quantite p_quantiteRequise)
  {
    m_quantiteAffiliationRequise = p_quantiteRequise;
  }
  
  public void ajouterJustificationAffiliation(JustificationAffiliationSpec p_justification, Unite p_uniteJustification)
  {
    if (p_justification != null) {
      m_mapJustificationAffiliation.put(p_uniteJustification, p_justification);
    }
  }
  
  public JustificationAffiliationSpec getJustificationAffiliation(Unite p_unite)
  {
    return (JustificationAffiliationSpec)m_mapJustificationAffiliation.get(p_unite);
  }
}

/* Location:
 * Qualified Name:     ConstitutionQuantiteAffiliation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */