package fr.unedic.cali.asu.produits.liquidation.dom;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.ContributionParticuliereSpec;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.liquidation.outilsfonctionnels.DeterminationMontant;
import fr.unedic.cali.asu.produits.liquidation.dom.gen.EchecGen;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ConstitutionElementsSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.EchecSpec;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.cali.dom.OdAssuranceSpec;
import fr.unedic.cali.dom.OdSpec;
import fr.unedic.cali.dom.affectation.GammeAsuSpec;
import fr.unedic.cali.dom.conteneurs.DonneesEntreesRecuperationMontant;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.util.OutilDomToString;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;

public class Echec
  extends EchecGen
  implements EchecSpec
{
  private static final long serialVersionUID = -8097125055117685432L;
  
  public Echec(DomPCSpec p_pc)
  {
    super(p_pc);
  }
  
  public Echec() {}
  
  public Echec(Damj p_dateEvenement)
  {
    super(p_dateEvenement);
  }
  
  public ObjetMetierSpec copie()
  {
    Echec copie = new Echec();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    Echec copie = (Echec)p_copie;
    if (getConditionsAttributionAdmission() == null) {
      setConditionsAttributionAdmission(new ConditionsAttributionAdmission());
    }
    getConditionsAttributionAdmission().copieElements(copie.getConditionsAttributionAdmission());
    if (getConstitutionElementsAdmission() == null) {
      setConstitutionElementsAdmission(new ConstitutionElementsAdmission());
    }
    getConstitutionElementsAdmission().copieElements(copie.getConstitutionElementsAdmission());
    if (getConditionsAttributionReprise() == null) {
      setConditionsAttributionReprise(new ConditionsAttributionReprise());
    }
    getConditionsAttributionReprise().copieElements(copie.getConditionsAttributionReprise());
    if (getConstitutionElementsReprise() == null) {
      setConstitutionElementsReprise(new ConstitutionElementsReprise());
    }
    getConstitutionElementsReprise().copieElements(copie.getConstitutionElementsReprise());
    if (getConditionsAttributionRevision() == null) {
      setConditionsAttributionRevision(new ConditionsAttributionRevision());
    }
    getConditionsAttributionRevision().copieElements(copie.getConditionsAttributionRevision());
    if (getConstitutionElementsRevision() == null) {
      setConstitutionElementsRevision(new ConstitutionElementsRevision());
    }
    getConstitutionElementsRevision().copieElements(copie.getConstitutionElementsRevision());
    if (getCompetence() != null) {
      copie.setCompetence((Competence)getCompetence().copie());
    }
    copie.setContexteDdeExpresse(getContexteDdeExpresse());
    if (getContributionParticuliere() != null) {
      copie.setContributionParticuliere((ContributionParticuliere)getContributionParticuliere().copie());
    }
    copie.setDateEvenement(getDateEvenement());
    copie.setNatureDecision(getNatureDecision());
    copie.setAttributionPrecedente(getAttributionPrecedente());
  }
  
  public String toString()
  {
    return OutilDomToString.toString(this);
  }
  
  public Quantite getMontantAttributionPrecedente()
    throws CoucheLogiqueException
  {
    Attribution attribution = recupererAttributionPrecedente();
    if (attribution != null)
    {
      MontantBaseSpec montantPrecedent = null;
      try
      {
        GammeAsuSpec gamme = (GammeAsuSpec)attribution.getGamme();
        DonneesEntreesRecuperationMontant donneesEntree = gamme.mapperDonneesEntreesRecuperationMontant(attribution);
        donneesEntree.setDateCalculMontant(getDemande().getDateDeclenchementExamen());
        montantPrecedent = DeterminationMontant.determinerMontant(donneesEntree);
      }
      catch (ApplicativeException ex)
      {
        throw new CoucheLogiqueException(ex.getCode());
      }
      if (montantPrecedent != null) {
        return montantPrecedent.getMontantPrecompteEffectif();
      }
    }
    return null;
  }
  
  public ConstitutionSjr getConstitutionSjr()
  {
    return getConstitutionElementsActifs().getConstitutionSjr();
  }
  
  public ConstitutionSjc getConstitutionSjc()
  {
    return getConstitutionElementsRevision().getConstitutionSjc();
  }
  
  public ReglementApplicableSpec getConstitutionReglementApplicable()
  {
    Attribution attributionPrecedente = recupererAttributionPrecedente();
    if (attributionPrecedente != null) {
      return attributionPrecedente.getConstitutionReglementApplicable();
    }
    OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { " Impossible de trouver l'attribution précédente" });
    
    return null;
  }
  
  private Attribution recupererAttributionPrecedente()
  {
    if ((getAttributionPrecedente() instanceof Attribution)) {
      return (Attribution)getAttributionPrecedente();
    }
    return null;
  }
  
  public ConditionActiviteConservee getConditionActiviteConservee()
  {
    return ((DossierExamen)getOuvertureDroit()).getConditionsAttributionAdmission().getConditionActiviteConservee();
  }
  
  public boolean estRejetDV()
  {
    return false;
  }
  
  public OdSpec getOuvertureDroit()
  {
    OdAssuranceSpec ouvertureDeDroit = null;
    AttributionAssuranceSpec attributionPrecedente = getAttributionPrecedente();
    if (attributionPrecedente == null) {
      attributionPrecedente = getDemandeAssurance().rechercherAttributionPrecedenteDuMemeType();
    }
    if (attributionPrecedente != null) {
      ouvertureDeDroit = attributionPrecedente.getOuvertureDroit();
    }
    return ouvertureDeDroit;
  }
}

/* Location:
 * Qualified Name:     Echec
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */