package fr.unedic.cali.asu.produits.liquidation.dom;

import fr.unedic.cali.asu.dom.SjrActiviteConserveeSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.gen.SjcipGen;
import fr.unedic.cali.asu.produits.liquidation.dom.pc.ConstitutionElementsAdmissionPC;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.SjcipSpec;
import fr.unedic.cali.dom.ObjetPersistantSpec;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.cali.util.OutilDomToString;
import fr.unedic.transverse.dom.spec.DomGenSpec;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Iterator;

public class Sjcip
  extends SjcipGen
  implements ObjetPersistantSpec, SjcipSpec
{
  private static final long serialVersionUID = 4236891946520866421L;
  
  public Sjcip(DomPCSpec pc)
  {
    super(pc);
  }
  
  public Sjcip() {}
  
  public Sjcip(Damj dateEffet)
  {
    super(dateEffet);
  }
  
  public Collection getCollectionSjrActiviteConserveePerdue()
  {
    ArrayList listeActiviteConserveePerdue = new ArrayList();
    SjrActiviteConservee activite = null;
    Iterator iter = getCollectionSjrActiviteConservee().iterator();
    while (iter.hasNext())
    {
      activite = (SjrActiviteConservee)iter.next();
      if (("P".equals(activite.getTypeActiviteConservee())) || ("R".equals(activite.getTypeActiviteConservee()))) {
        listeActiviteConserveePerdue.add(activite);
      }
    }
    return Collections.unmodifiableCollection(listeActiviteConserveePerdue);
  }
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
  
  public void marquerGraphePersistant()
  {
    DomManager.persisterEnProfondeur(super.getCollectionSjrActiviteConservee());
  }
  
  public ObjetMetierSpec copie()
  {
    Sjcip copie = new Sjcip();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec copie)
  {
    Sjcip copieSjcip = (Sjcip)copie;
    copieSjcip.setDateEvenement(getDateEvenement());
    
    Iterator iter = getListeSjrActiviteConserve().iterator();
    while (iter.hasNext())
    {
      SjrActiviteConservee element = (SjrActiviteConservee)iter.next();
      copieSjcip.ajouterSjrActiviteConserve((SjrActiviteConservee)element.copie());
    }
    copieSjcip.setPlafond(getPlafond());
    copieSjcip.setSjcInitial(getSjcInitial());
    copieSjcip.setContexteParticulierSjc(getContexteParticulierSjc());
  }
  
  public void ajouterSjrActiviteConserve(SjrActiviteConservee sjrActiviteConservee)
  {
    if (sjrActiviteConservee != null) {
      super.ajouterSjrActiviteConservee(sjrActiviteConservee);
    }
  }
  
  public Collection getListeSjrActiviteConserve()
  {
    return super.getCollectionSjrActiviteConservee();
  }
  
  public String toString()
  {
    return OutilDomToString.toString(this);
  }
  
  public BigDecimal getSjcip()
  {
    BigDecimal valeurSjcip = new BigDecimal("0");
    if ((getSjcInitial() != null) && (getPlafond() != null)) {
      valeurSjcip = getSjcInitial().getValeur().min(getPlafond().getValeur());
    } else if (getSjcInitial() != null) {
      valeurSjcip = getSjcInitial().getValeur();
    } else if (getPlafond() != null) {
      valeurSjcip = getPlafond().getValeur();
    }
    return valeurSjcip;
  }
  
  public void viderCollectionSjrActiviteConservee()
  {
    for (Iterator iter = getCollectionSjrActiviteConservee().iterator(); iter.hasNext();)
    {
      DomGenSpec item = (DomGenSpec)iter.next();
      DomManager.supprimer(item);
    }
    super.clearCollectionSjrActiviteConservee();
  }
  
  public static Sjcip createNonPersistent()
  {
    return new Sjcip(new ConstitutionElementsAdmissionPC());
  }
  
  public void ajouterSjrActiviteConservee(SjrActiviteConserveeSpec sjrActiviteConserveeConstitutionSjc)
  {
    ajouterSjrActiviteConservee((SjrActiviteConservee)sjrActiviteConserveeConstitutionSjc);
  }
  
  public void remplacerCollectionSjrActiviteConservee(Collection collectionACopier)
  {
    for (Iterator iter = super.getCollectionSjrActiviteConservee().iterator(); iter.hasNext();)
    {
      SjrActiviteConservee element = (SjrActiviteConservee)iter.next();
      DomManager.supprimer(element);
    }
    super.remplacerCollectionSjrActiviteConservee(collectionACopier);
  }
}

/* Location:
 * Qualified Name:     Sjcip
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */