package fr.unedic.cali.asu.produits.liquidation.dom.gen;

import fr.unedic.archi.commun.exception.TechniqueException;
import fr.unedic.archi.commun.lang.ExceptionUtil;
import fr.unedic.cali.asu.dom.PensionInvaliditeChainee;
import fr.unedic.cali.asu.produits.liquidation.dom.CarencePrefixeAFixer;
import fr.unedic.cali.asu.produits.liquidation.dom.Duree;
import fr.unedic.cali.asu.produits.liquidation.dom.SousTrancheExecutable;
import fr.unedic.cali.asu.produits.liquidation.dom.pc.TrancheExecutablePC;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.transverse.dom.ContexteSuppressionEnProfondeur;
import fr.unedic.transverse.dom.spec.DomGenSpec;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;

public abstract class TrancheExecutableGen
  implements DomGenSpec
{
  protected transient DomPCSpec m_trancheExecutablePC;
  private Integer m_rang;
  private String m_reglementApplicable;
  private String m_idFaitGenerateur;
  private Quantite m_montantSJC;
  private Damj m_dateSJC;
  private Quantite m_montantSJI;
  private Damj m_dateSJI;
  private BigDecimal m_coefficientSaisonnier;
  private BigDecimal m_coefficientTempsPartiel;
  private Quantite m_montantPreavis;
  private String m_etablissementFinanceurCG;
  private String m_codeAffectationCG;
  private Damj m_dateDebutMaintientEuropeen;
  private Damj m_dateLimiteIndemnisation;
  private Integer m_dureeMaxIndemnisation;
  private Damj m_dateAttribution;
  private Quantite m_capitalAServir;
  private String m_contexteParticulierSJI;
  private String m_contexteParticulierSJC;
  private Damj m_dateRepriseActivite;
  private Damj m_dateMaxIndemnisation;
  private Damj m_dateDebutPeriodeSuspension;
  private Damj m_dateFinPeriodeSuspension;
  private String m_typeCapitalRetenu;
  private String m_typeMontantRetenu;
  private BigDecimal m_seuilMensuelPansConservees;
  private Quantite m_affiliationRequisePourPRA;
  private Periode m_prc;
  private String m_reglementApplicableMontantRetenu;
  private BigDecimal m_nombreHeuresTravailleesEtendu;
  private BigDecimal m_nombreHeuresTravailleesPlafonne;
  private String m_contexteDateLimiteIndemnisation;
  public Collection m_listeDurees;
  public Collection m_listePensionsInvalidites;
  public Collection m_listeDelaisReports;
  public Collection m_listeContextes;
  public Collection m_listeSousTrancheExecutable;
  
  public TrancheExecutableGen(DomPCSpec p_pc)
  {
    setPC(p_pc);
  }
  
  public TrancheExecutableGen()
  {
    setPC(createPC());
  }
  
  protected DomPCSpec createPC()
  {
    return new TrancheExecutablePC();
  }
  
  public DomPCSpec getPC()
  {
    return m_trancheExecutablePC;
  }
  
  public Object getGenericPC()
  {
    return getPC();
  }
  
  public void setPC(DomPCSpec p_trancheExecutablePC)
  {
    m_trancheExecutablePC = p_trancheExecutablePC;
  }
  
  protected Integer rawGetRang()
  {
    return ((TrancheExecutablePC)getPC()).getRang();
  }
  
  public Integer getRang()
  {
    return ((TrancheExecutablePC)getPC()).getRang();
  }
  
  public void setRang(Integer p_rang)
  {
    if ((m_rang == null) || (p_rang == null))
    {
      m_rang = p_rang;
      ((TrancheExecutablePC)getPC()).setRang(p_rang);
    }
    else if ((m_rang != null) && (p_rang != null) && (!p_rang.equals(m_rang)))
    {
      m_rang = p_rang;
      ((TrancheExecutablePC)getPC()).setRang(p_rang);
    }
  }
  
  protected String rawGetReglementApplicable()
  {
    return ((TrancheExecutablePC)getPC()).getReglementApplicable();
  }
  
  public String getReglementApplicable()
  {
    return ((TrancheExecutablePC)getPC()).getReglementApplicable();
  }
  
  public void setReglementApplicable(String p_reglementApplicable)
  {
    if ((m_reglementApplicable == null) || (p_reglementApplicable == null))
    {
      m_reglementApplicable = p_reglementApplicable;
      ((TrancheExecutablePC)getPC()).setReglementApplicable(p_reglementApplicable);
    }
    else if ((m_reglementApplicable != null) && (p_reglementApplicable != null) && (!p_reglementApplicable.equals(m_reglementApplicable)))
    {
      m_reglementApplicable = p_reglementApplicable;
      ((TrancheExecutablePC)getPC()).setReglementApplicable(p_reglementApplicable);
    }
  }
  
  protected int rawGetCodeProduitReglement()
  {
    return ((TrancheExecutablePC)getPC()).getCodeProduitReglement();
  }
  
  public int getCodeProduitReglement()
  {
    return ((TrancheExecutablePC)getPC()).getCodeProduitReglement();
  }
  
  public void setCodeProduitReglement(int p_codeProduitReglement)
  {
    ((TrancheExecutablePC)getPC()).setCodeProduitReglement(p_codeProduitReglement);
  }
  
  protected String rawGetIdFaitGenerateur()
  {
    return ((TrancheExecutablePC)getPC()).getIdFaitGenerateur();
  }
  
  public String getIdFaitGenerateur()
  {
    return ((TrancheExecutablePC)getPC()).getIdFaitGenerateur();
  }
  
  public void setIdFaitGenerateur(String p_idFaitGenerateur)
  {
    if ((m_idFaitGenerateur == null) || (p_idFaitGenerateur == null))
    {
      m_idFaitGenerateur = p_idFaitGenerateur;
      ((TrancheExecutablePC)getPC()).setIdFaitGenerateur(p_idFaitGenerateur);
    }
    else if ((m_idFaitGenerateur != null) && (p_idFaitGenerateur != null) && (!p_idFaitGenerateur.equals(m_idFaitGenerateur)))
    {
      m_idFaitGenerateur = p_idFaitGenerateur;
      ((TrancheExecutablePC)getPC()).setIdFaitGenerateur(p_idFaitGenerateur);
    }
  }
  
  protected Quantite rawGetMontantSJC()
  {
    return ((TrancheExecutablePC)getPC()).getMontantSJC();
  }
  
  public Quantite getMontantSJC()
  {
    return ((TrancheExecutablePC)getPC()).getMontantSJC();
  }
  
  public void setMontantSJC(Quantite p_montantSJC)
  {
    if ((m_montantSJC == null) || (p_montantSJC == null))
    {
      m_montantSJC = p_montantSJC;
      ((TrancheExecutablePC)getPC()).setMontantSJC(p_montantSJC);
    }
    else if ((m_montantSJC != null) && (p_montantSJC != null) && (!p_montantSJC.equals(m_montantSJC)))
    {
      m_montantSJC = p_montantSJC;
      ((TrancheExecutablePC)getPC()).setMontantSJC(p_montantSJC);
    }
  }
  
  protected Damj rawGetDateSJC()
  {
    return ((TrancheExecutablePC)getPC()).getDateSJC();
  }
  
  public Damj getDateSJC()
  {
    return ((TrancheExecutablePC)getPC()).getDateSJC();
  }
  
  public void setDateSJC(Damj p_dateSJC)
  {
    if ((m_dateSJC == null) || (p_dateSJC == null))
    {
      m_dateSJC = p_dateSJC;
      ((TrancheExecutablePC)getPC()).setDateSJC(p_dateSJC);
    }
    else if ((m_dateSJC != null) && (p_dateSJC != null) && (!p_dateSJC.equals(m_dateSJC)))
    {
      m_dateSJC = p_dateSJC;
      ((TrancheExecutablePC)getPC()).setDateSJC(p_dateSJC);
    }
  }
  
  protected Quantite rawGetMontantSJI()
  {
    return ((TrancheExecutablePC)getPC()).getMontantSJI();
  }
  
  public Quantite getMontantSJI()
  {
    return ((TrancheExecutablePC)getPC()).getMontantSJI();
  }
  
  public void setMontantSJI(Quantite p_montantSJI)
  {
    if ((m_montantSJI == null) || (p_montantSJI == null))
    {
      m_montantSJI = p_montantSJI;
      ((TrancheExecutablePC)getPC()).setMontantSJI(p_montantSJI);
    }
    else if ((m_montantSJI != null) && (p_montantSJI != null) && (!p_montantSJI.equals(m_montantSJI)))
    {
      m_montantSJI = p_montantSJI;
      ((TrancheExecutablePC)getPC()).setMontantSJI(p_montantSJI);
    }
  }
  
  protected Damj rawGetDateSJI()
  {
    return ((TrancheExecutablePC)getPC()).getDateSJI();
  }
  
  public Damj getDateSJI()
  {
    return ((TrancheExecutablePC)getPC()).getDateSJI();
  }
  
  public void setDateSJI(Damj p_dateSJI)
  {
    if ((m_dateSJI == null) || (p_dateSJI == null))
    {
      m_dateSJI = p_dateSJI;
      ((TrancheExecutablePC)getPC()).setDateSJI(p_dateSJI);
    }
    else if ((m_dateSJI != null) && (p_dateSJI != null) && (!p_dateSJI.equals(m_dateSJI)))
    {
      m_dateSJI = p_dateSJI;
      ((TrancheExecutablePC)getPC()).setDateSJI(p_dateSJI);
    }
  }
  
  protected BigDecimal rawGetCoefficientSaisonnier()
  {
    return ((TrancheExecutablePC)getPC()).getCoefficientSaisonnier();
  }
  
  public BigDecimal getCoefficientSaisonnier()
  {
    return ((TrancheExecutablePC)getPC()).getCoefficientSaisonnier();
  }
  
  public void setCoefficientSaisonnier(BigDecimal p_coefficientSaisonnier)
  {
    if ((m_coefficientSaisonnier == null) || (p_coefficientSaisonnier == null))
    {
      m_coefficientSaisonnier = p_coefficientSaisonnier;
      ((TrancheExecutablePC)getPC()).setCoefficientSaisonnier(p_coefficientSaisonnier);
    }
    else if ((m_coefficientSaisonnier != null) && (p_coefficientSaisonnier != null) && (!p_coefficientSaisonnier.equals(m_coefficientSaisonnier)))
    {
      m_coefficientSaisonnier = p_coefficientSaisonnier;
      ((TrancheExecutablePC)getPC()).setCoefficientSaisonnier(p_coefficientSaisonnier);
    }
  }
  
  protected int rawGetNatureCoefficientSaisonnier()
  {
    return ((TrancheExecutablePC)getPC()).getNatureCoefficientSaisonnier();
  }
  
  public int getNatureCoefficientSaisonnier()
  {
    return ((TrancheExecutablePC)getPC()).getNatureCoefficientSaisonnier();
  }
  
  public void setNatureCoefficientSaisonnier(int p_natureCoefficientSaisonnier)
  {
    ((TrancheExecutablePC)getPC()).setNatureCoefficientSaisonnier(p_natureCoefficientSaisonnier);
  }
  
  protected BigDecimal rawGetCoefficientTempsPartiel()
  {
    return ((TrancheExecutablePC)getPC()).getCoefficientTempsPartiel();
  }
  
  public BigDecimal getCoefficientTempsPartiel()
  {
    return ((TrancheExecutablePC)getPC()).getCoefficientTempsPartiel();
  }
  
  public void setCoefficientTempsPartiel(BigDecimal p_coefficientTempsPartiel)
  {
    if ((m_coefficientTempsPartiel == null) || (p_coefficientTempsPartiel == null))
    {
      m_coefficientTempsPartiel = p_coefficientTempsPartiel;
      ((TrancheExecutablePC)getPC()).setCoefficientTempsPartiel(p_coefficientTempsPartiel);
    }
    else if ((m_coefficientTempsPartiel != null) && (p_coefficientTempsPartiel != null) && (!p_coefficientTempsPartiel.equals(m_coefficientTempsPartiel)))
    {
      m_coefficientTempsPartiel = p_coefficientTempsPartiel;
      ((TrancheExecutablePC)getPC()).setCoefficientTempsPartiel(p_coefficientTempsPartiel);
    }
  }
  
  protected boolean rawIsEstSjrBaseSmic()
  {
    return ((TrancheExecutablePC)getPC()).isEstSjrBaseSmic();
  }
  
  public boolean isEstSjrBaseSmic()
  {
    return ((TrancheExecutablePC)getPC()).isEstSjrBaseSmic();
  }
  
  public void setEstSjrBaseSmic(boolean p_estSjrBaseSmic)
  {
    ((TrancheExecutablePC)getPC()).setEstSjrBaseSmic(p_estSjrBaseSmic);
  }
  
  protected int rawGetCodeEmploiA2B()
  {
    return ((TrancheExecutablePC)getPC()).getCodeEmploiA2B();
  }
  
  public int getCodeEmploiA2B()
  {
    return ((TrancheExecutablePC)getPC()).getCodeEmploiA2B();
  }
  
  public void setCodeEmploiA2B(int p_codeEmploiA2B)
  {
    ((TrancheExecutablePC)getPC()).setCodeEmploiA2B(p_codeEmploiA2B);
  }
  
  protected Quantite rawGetMontantPreavis()
  {
    return ((TrancheExecutablePC)getPC()).getMontantPreavis();
  }
  
  public Quantite getMontantPreavis()
  {
    return ((TrancheExecutablePC)getPC()).getMontantPreavis();
  }
  
  public void setMontantPreavis(Quantite p_montantPreavis)
  {
    if ((m_montantPreavis == null) || (p_montantPreavis == null))
    {
      m_montantPreavis = p_montantPreavis;
      ((TrancheExecutablePC)getPC()).setMontantPreavis(p_montantPreavis);
    }
    else if ((m_montantPreavis != null) && (p_montantPreavis != null) && (!p_montantPreavis.equals(m_montantPreavis)))
    {
      m_montantPreavis = p_montantPreavis;
      ((TrancheExecutablePC)getPC()).setMontantPreavis(p_montantPreavis);
    }
  }
  
  protected int rawGetCompetenceFinanciere()
  {
    return ((TrancheExecutablePC)getPC()).getCompetenceFinanciere();
  }
  
  public int getCompetenceFinanciere()
  {
    return ((TrancheExecutablePC)getPC()).getCompetenceFinanciere();
  }
  
  public void setCompetenceFinanciere(int p_competenceFinanciere)
  {
    ((TrancheExecutablePC)getPC()).setCompetenceFinanciere(p_competenceFinanciere);
  }
  
  protected int rawGetPrecompterCRC()
  {
    return ((TrancheExecutablePC)getPC()).getPrecompterCRC();
  }
  
  public int getPrecompterCRC()
  {
    return ((TrancheExecutablePC)getPC()).getPrecompterCRC();
  }
  
  public void setPrecompterCRC(int p_precompterCRC)
  {
    ((TrancheExecutablePC)getPC()).setPrecompterCRC(p_precompterCRC);
  }
  
  protected String rawGetEtablissementFinanceurCG()
  {
    return ((TrancheExecutablePC)getPC()).getEtablissementFinanceurCG();
  }
  
  public String getEtablissementFinanceurCG()
  {
    return ((TrancheExecutablePC)getPC()).getEtablissementFinanceurCG();
  }
  
  public void setEtablissementFinanceurCG(String p_etablissementFinanceurCG)
  {
    if ((m_etablissementFinanceurCG == null) || (p_etablissementFinanceurCG == null))
    {
      m_etablissementFinanceurCG = p_etablissementFinanceurCG;
      ((TrancheExecutablePC)getPC()).setEtablissementFinanceurCG(p_etablissementFinanceurCG);
    }
    else if ((m_etablissementFinanceurCG != null) && (p_etablissementFinanceurCG != null) && (!p_etablissementFinanceurCG.equals(m_etablissementFinanceurCG)))
    {
      m_etablissementFinanceurCG = p_etablissementFinanceurCG;
      ((TrancheExecutablePC)getPC()).setEtablissementFinanceurCG(p_etablissementFinanceurCG);
    }
  }
  
  protected String rawGetCodeAffectationCG()
  {
    return ((TrancheExecutablePC)getPC()).getCodeAffectationCG();
  }
  
  public String getCodeAffectationCG()
  {
    return ((TrancheExecutablePC)getPC()).getCodeAffectationCG();
  }
  
  public void setCodeAffectationCG(String p_codeAffectationCG)
  {
    if ((m_codeAffectationCG == null) || (p_codeAffectationCG == null))
    {
      m_codeAffectationCG = p_codeAffectationCG;
      ((TrancheExecutablePC)getPC()).setCodeAffectationCG(p_codeAffectationCG);
    }
    else if ((m_codeAffectationCG != null) && (p_codeAffectationCG != null) && (!p_codeAffectationCG.equals(m_codeAffectationCG)))
    {
      m_codeAffectationCG = p_codeAffectationCG;
      ((TrancheExecutablePC)getPC()).setCodeAffectationCG(p_codeAffectationCG);
    }
  }
  
  protected int rawGetCodeProduit()
  {
    return ((TrancheExecutablePC)getPC()).getCodeProduit();
  }
  
  public int getCodeProduit()
  {
    return ((TrancheExecutablePC)getPC()).getCodeProduit();
  }
  
  public void setCodeProduit(int p_codeProduit)
  {
    ((TrancheExecutablePC)getPC()).setCodeProduit(p_codeProduit);
  }
  
  protected Damj rawGetDateDebutMaintientEuropeen()
  {
    return ((TrancheExecutablePC)getPC()).getDateDebutMaintientEuropeen();
  }
  
  public Damj getDateDebutMaintientEuropeen()
  {
    return ((TrancheExecutablePC)getPC()).getDateDebutMaintientEuropeen();
  }
  
  public void setDateDebutMaintientEuropeen(Damj p_dateDebutMaintientEuropeen)
  {
    if ((m_dateDebutMaintientEuropeen == null) || (p_dateDebutMaintientEuropeen == null))
    {
      m_dateDebutMaintientEuropeen = p_dateDebutMaintientEuropeen;
      ((TrancheExecutablePC)getPC()).setDateDebutMaintientEuropeen(p_dateDebutMaintientEuropeen);
    }
    else if ((m_dateDebutMaintientEuropeen != null) && (p_dateDebutMaintientEuropeen != null) && (!p_dateDebutMaintientEuropeen.equals(m_dateDebutMaintientEuropeen)))
    {
      m_dateDebutMaintientEuropeen = p_dateDebutMaintientEuropeen;
      ((TrancheExecutablePC)getPC()).setDateDebutMaintientEuropeen(p_dateDebutMaintientEuropeen);
    }
  }
  
  protected Damj rawGetDateLimiteIndemnisation()
  {
    return ((TrancheExecutablePC)getPC()).getDateLimiteIndemnisation();
  }
  
  public Damj getDateLimiteIndemnisation()
  {
    return ((TrancheExecutablePC)getPC()).getDateLimiteIndemnisation();
  }
  
  public void setDateLimiteIndemnisation(Damj p_dateLimiteIndemnisation)
  {
    if ((m_dateLimiteIndemnisation == null) || (p_dateLimiteIndemnisation == null))
    {
      m_dateLimiteIndemnisation = p_dateLimiteIndemnisation;
      ((TrancheExecutablePC)getPC()).setDateLimiteIndemnisation(p_dateLimiteIndemnisation);
    }
    else if ((m_dateLimiteIndemnisation != null) && (p_dateLimiteIndemnisation != null) && (!p_dateLimiteIndemnisation.equals(m_dateLimiteIndemnisation)))
    {
      m_dateLimiteIndemnisation = p_dateLimiteIndemnisation;
      ((TrancheExecutablePC)getPC()).setDateLimiteIndemnisation(p_dateLimiteIndemnisation);
    }
  }
  
  protected Integer rawGetDureeMaxIndemnisation()
  {
    return ((TrancheExecutablePC)getPC()).getDureeMaxIndemnisation();
  }
  
  public Integer getDureeMaxIndemnisation()
  {
    return ((TrancheExecutablePC)getPC()).getDureeMaxIndemnisation();
  }
  
  public void setDureeMaxIndemnisation(Integer p_dureeMaxIndemnisation)
  {
    if ((m_dureeMaxIndemnisation == null) || (p_dureeMaxIndemnisation == null))
    {
      m_dureeMaxIndemnisation = p_dureeMaxIndemnisation;
      ((TrancheExecutablePC)getPC()).setDureeMaxIndemnisation(p_dureeMaxIndemnisation);
    }
    else if ((m_dureeMaxIndemnisation != null) && (p_dureeMaxIndemnisation != null) && (!p_dureeMaxIndemnisation.equals(m_dureeMaxIndemnisation)))
    {
      m_dureeMaxIndemnisation = p_dureeMaxIndemnisation;
      ((TrancheExecutablePC)getPC()).setDureeMaxIndemnisation(p_dureeMaxIndemnisation);
    }
  }
  
  protected int rawGetNatureDecision()
  {
    return ((TrancheExecutablePC)getPC()).getNatureDecision();
  }
  
  public int getNatureDecision()
  {
    return ((TrancheExecutablePC)getPC()).getNatureDecision();
  }
  
  public void setNatureDecision(int p_natureDecision)
  {
    ((TrancheExecutablePC)getPC()).setNatureDecision(p_natureDecision);
  }
  
  protected int rawGetProduitMontantRetenu()
  {
    return ((TrancheExecutablePC)getPC()).getProduitMontantRetenu();
  }
  
  public int getProduitMontantRetenu()
  {
    return ((TrancheExecutablePC)getPC()).getProduitMontantRetenu();
  }
  
  public void setProduitMontantRetenu(int p_produitMontantRetenu)
  {
    ((TrancheExecutablePC)getPC()).setProduitMontantRetenu(p_produitMontantRetenu);
  }
  
  protected Damj rawGetDateAttribution()
  {
    return ((TrancheExecutablePC)getPC()).getDateAttribution();
  }
  
  public Damj getDateAttribution()
  {
    return ((TrancheExecutablePC)getPC()).getDateAttribution();
  }
  
  public void setDateAttribution(Damj p_dateAttribution)
  {
    if ((m_dateAttribution == null) || (p_dateAttribution == null))
    {
      m_dateAttribution = p_dateAttribution;
      ((TrancheExecutablePC)getPC()).setDateAttribution(p_dateAttribution);
    }
    else if ((m_dateAttribution != null) && (p_dateAttribution != null) && (!p_dateAttribution.equals(m_dateAttribution)))
    {
      m_dateAttribution = p_dateAttribution;
      ((TrancheExecutablePC)getPC()).setDateAttribution(p_dateAttribution);
    }
  }
  
  protected boolean rawIsA3ansActiviteEn5ans()
  {
    return ((TrancheExecutablePC)getPC()).isA3ansActiviteEn5ans();
  }
  
  public boolean isA3ansActiviteEn5ans()
  {
    return ((TrancheExecutablePC)getPC()).isA3ansActiviteEn5ans();
  }
  
  public void setA3ansActiviteEn5ans(boolean p_a3ansActiviteEn5ans)
  {
    ((TrancheExecutablePC)getPC()).setA3ansActiviteEn5ans(p_a3ansActiviteEn5ans);
  }
  
  protected Quantite rawGetCapitalAServir()
  {
    return ((TrancheExecutablePC)getPC()).getCapitalAServir();
  }
  
  public Quantite getCapitalAServir()
  {
    return ((TrancheExecutablePC)getPC()).getCapitalAServir();
  }
  
  public void setCapitalAServir(Quantite p_capitalAServir)
  {
    if ((m_capitalAServir == null) || (p_capitalAServir == null))
    {
      m_capitalAServir = p_capitalAServir;
      ((TrancheExecutablePC)getPC()).setCapitalAServir(p_capitalAServir);
    }
    else if ((m_capitalAServir != null) && (p_capitalAServir != null) && (!p_capitalAServir.equals(m_capitalAServir)))
    {
      m_capitalAServir = p_capitalAServir;
      ((TrancheExecutablePC)getPC()).setCapitalAServir(p_capitalAServir);
    }
  }
  
  protected String rawGetContexteParticulierSJI()
  {
    return ((TrancheExecutablePC)getPC()).getContexteParticulierSJI();
  }
  
  public String getContexteParticulierSJI()
  {
    return ((TrancheExecutablePC)getPC()).getContexteParticulierSJI();
  }
  
  public void setContexteParticulierSJI(String p_contexteParticulierSJI)
  {
    if ((m_contexteParticulierSJI == null) || (p_contexteParticulierSJI == null))
    {
      m_contexteParticulierSJI = p_contexteParticulierSJI;
      ((TrancheExecutablePC)getPC()).setContexteParticulierSJI(p_contexteParticulierSJI);
    }
    else if ((m_contexteParticulierSJI != null) && (p_contexteParticulierSJI != null) && (!p_contexteParticulierSJI.equals(m_contexteParticulierSJI)))
    {
      m_contexteParticulierSJI = p_contexteParticulierSJI;
      ((TrancheExecutablePC)getPC()).setContexteParticulierSJI(p_contexteParticulierSJI);
    }
  }
  
  protected String rawGetContexteParticulierSJC()
  {
    return ((TrancheExecutablePC)getPC()).getContexteParticulierSJC();
  }
  
  public String getContexteParticulierSJC()
  {
    return ((TrancheExecutablePC)getPC()).getContexteParticulierSJC();
  }
  
  public void setContexteParticulierSJC(String p_contexteParticulierSJC)
  {
    if ((m_contexteParticulierSJC == null) || (p_contexteParticulierSJC == null))
    {
      m_contexteParticulierSJC = p_contexteParticulierSJC;
      ((TrancheExecutablePC)getPC()).setContexteParticulierSJC(p_contexteParticulierSJC);
    }
    else if ((m_contexteParticulierSJC != null) && (p_contexteParticulierSJC != null) && (!p_contexteParticulierSJC.equals(m_contexteParticulierSJC)))
    {
      m_contexteParticulierSJC = p_contexteParticulierSJC;
      ((TrancheExecutablePC)getPC()).setContexteParticulierSJC(p_contexteParticulierSJC);
    }
  }
  
  protected int rawGetCompetenceAdministrative()
  {
    return ((TrancheExecutablePC)getPC()).getCompetenceAdministrative();
  }
  
  public int getCompetenceAdministrative()
  {
    return ((TrancheExecutablePC)getPC()).getCompetenceAdministrative();
  }
  
  public void setCompetenceAdministrative(int p_competenceAdministrative)
  {
    ((TrancheExecutablePC)getPC()).setCompetenceAdministrative(p_competenceAdministrative);
  }
  
  protected Damj rawGetDateRepriseActivite()
  {
    return ((TrancheExecutablePC)getPC()).getDateRepriseActivite();
  }
  
  public Damj getDateRepriseActivite()
  {
    return ((TrancheExecutablePC)getPC()).getDateRepriseActivite();
  }
  
  public void setDateRepriseActivite(Damj p_dateRepriseActivite)
  {
    if ((m_dateRepriseActivite == null) || (p_dateRepriseActivite == null))
    {
      m_dateRepriseActivite = p_dateRepriseActivite;
      ((TrancheExecutablePC)getPC()).setDateRepriseActivite(p_dateRepriseActivite);
    }
    else if ((m_dateRepriseActivite != null) && (p_dateRepriseActivite != null) && (!p_dateRepriseActivite.equals(m_dateRepriseActivite)))
    {
      m_dateRepriseActivite = p_dateRepriseActivite;
      ((TrancheExecutablePC)getPC()).setDateRepriseActivite(p_dateRepriseActivite);
    }
  }
  
  protected int rawGetJoursDureeMaintienEuropeen()
  {
    return ((TrancheExecutablePC)getPC()).getJoursDureeMaintienEuropeen();
  }
  
  public int getJoursDureeMaintienEuropeen()
  {
    return ((TrancheExecutablePC)getPC()).getJoursDureeMaintienEuropeen();
  }
  
  public void setJoursDureeMaintienEuropeen(int p_joursDureeMaintienEuropeen)
  {
    ((TrancheExecutablePC)getPC()).setJoursDureeMaintienEuropeen(p_joursDureeMaintienEuropeen);
  }
  
  protected int rawGetMoisDureeMaintienEuropeen()
  {
    return ((TrancheExecutablePC)getPC()).getMoisDureeMaintienEuropeen();
  }
  
  public int getMoisDureeMaintienEuropeen()
  {
    return ((TrancheExecutablePC)getPC()).getMoisDureeMaintienEuropeen();
  }
  
  public void setMoisDureeMaintienEuropeen(int p_moisDureeMaintienEuropeen)
  {
    ((TrancheExecutablePC)getPC()).setMoisDureeMaintienEuropeen(p_moisDureeMaintienEuropeen);
  }
  
  protected int rawGetAnneeDureeMaintienEuropeen()
  {
    return ((TrancheExecutablePC)getPC()).getAnneeDureeMaintienEuropeen();
  }
  
  public int getAnneeDureeMaintienEuropeen()
  {
    return ((TrancheExecutablePC)getPC()).getAnneeDureeMaintienEuropeen();
  }
  
  public void setAnneeDureeMaintienEuropeen(int p_anneeDureeMaintienEuropeen)
  {
    ((TrancheExecutablePC)getPC()).setAnneeDureeMaintienEuropeen(p_anneeDureeMaintienEuropeen);
  }
  
  protected Damj rawGetDateMaxIndemnisation()
  {
    return ((TrancheExecutablePC)getPC()).getDateMaxIndemnisation();
  }
  
  public Damj getDateMaxIndemnisation()
  {
    return ((TrancheExecutablePC)getPC()).getDateMaxIndemnisation();
  }
  
  public void setDateMaxIndemnisation(Damj p_dateMaxIndemnisation)
  {
    if ((m_dateMaxIndemnisation == null) || (p_dateMaxIndemnisation == null))
    {
      m_dateMaxIndemnisation = p_dateMaxIndemnisation;
      ((TrancheExecutablePC)getPC()).setDateMaxIndemnisation(p_dateMaxIndemnisation);
    }
    else if ((m_dateMaxIndemnisation != null) && (p_dateMaxIndemnisation != null) && (!p_dateMaxIndemnisation.equals(m_dateMaxIndemnisation)))
    {
      m_dateMaxIndemnisation = p_dateMaxIndemnisation;
      ((TrancheExecutablePC)getPC()).setDateMaxIndemnisation(p_dateMaxIndemnisation);
    }
  }
  
  protected Damj rawGetDateDebutPeriodeSuspension()
  {
    return ((TrancheExecutablePC)getPC()).getDateDebutPeriodeSuspension();
  }
  
  public Damj getDateDebutPeriodeSuspension()
  {
    return ((TrancheExecutablePC)getPC()).getDateDebutPeriodeSuspension();
  }
  
  public void setDateDebutPeriodeSuspension(Damj p_dateDebutPeriodeSuspension)
  {
    if ((m_dateDebutPeriodeSuspension == null) || (p_dateDebutPeriodeSuspension == null))
    {
      m_dateDebutPeriodeSuspension = p_dateDebutPeriodeSuspension;
      ((TrancheExecutablePC)getPC()).setDateDebutPeriodeSuspension(p_dateDebutPeriodeSuspension);
    }
    else if ((m_dateDebutPeriodeSuspension != null) && (p_dateDebutPeriodeSuspension != null) && (!p_dateDebutPeriodeSuspension.equals(m_dateDebutPeriodeSuspension)))
    {
      m_dateDebutPeriodeSuspension = p_dateDebutPeriodeSuspension;
      ((TrancheExecutablePC)getPC()).setDateDebutPeriodeSuspension(p_dateDebutPeriodeSuspension);
    }
  }
  
  protected Damj rawGetDateFinPeriodeSuspension()
  {
    return ((TrancheExecutablePC)getPC()).getDateFinPeriodeSuspension();
  }
  
  public Damj getDateFinPeriodeSuspension()
  {
    return ((TrancheExecutablePC)getPC()).getDateFinPeriodeSuspension();
  }
  
  public void setDateFinPeriodeSuspension(Damj p_dateFinPeriodeSuspension)
  {
    if ((m_dateFinPeriodeSuspension == null) || (p_dateFinPeriodeSuspension == null))
    {
      m_dateFinPeriodeSuspension = p_dateFinPeriodeSuspension;
      ((TrancheExecutablePC)getPC()).setDateFinPeriodeSuspension(p_dateFinPeriodeSuspension);
    }
    else if ((m_dateFinPeriodeSuspension != null) && (p_dateFinPeriodeSuspension != null) && (!p_dateFinPeriodeSuspension.equals(m_dateFinPeriodeSuspension)))
    {
      m_dateFinPeriodeSuspension = p_dateFinPeriodeSuspension;
      ((TrancheExecutablePC)getPC()).setDateFinPeriodeSuspension(p_dateFinPeriodeSuspension);
    }
  }
  
  protected String rawGetTypeCapitalRetenu()
  {
    return ((TrancheExecutablePC)getPC()).getTypeCapitalRetenu();
  }
  
  public String getTypeCapitalRetenu()
  {
    return ((TrancheExecutablePC)getPC()).getTypeCapitalRetenu();
  }
  
  public void setTypeCapitalRetenu(String p_typeCapitalRetenu)
  {
    if ((m_typeCapitalRetenu == null) || (p_typeCapitalRetenu == null))
    {
      m_typeCapitalRetenu = p_typeCapitalRetenu;
      ((TrancheExecutablePC)getPC()).setTypeCapitalRetenu(p_typeCapitalRetenu);
    }
    else if ((m_typeCapitalRetenu != null) && (p_typeCapitalRetenu != null) && (!p_typeCapitalRetenu.equals(m_typeCapitalRetenu)))
    {
      m_typeCapitalRetenu = p_typeCapitalRetenu;
      ((TrancheExecutablePC)getPC()).setTypeCapitalRetenu(p_typeCapitalRetenu);
    }
  }
  
  protected String rawGetTypeMontantRetenu()
  {
    return ((TrancheExecutablePC)getPC()).getTypeMontantRetenu();
  }
  
  public String getTypeMontantRetenu()
  {
    return ((TrancheExecutablePC)getPC()).getTypeMontantRetenu();
  }
  
  public void setTypeMontantRetenu(String p_typeMontantRetenu)
  {
    if ((m_typeMontantRetenu == null) || (p_typeMontantRetenu == null))
    {
      m_typeMontantRetenu = p_typeMontantRetenu;
      ((TrancheExecutablePC)getPC()).setTypeMontantRetenu(p_typeMontantRetenu);
    }
    else if ((m_typeMontantRetenu != null) && (p_typeMontantRetenu != null) && (!p_typeMontantRetenu.equals(m_typeMontantRetenu)))
    {
      m_typeMontantRetenu = p_typeMontantRetenu;
      ((TrancheExecutablePC)getPC()).setTypeMontantRetenu(p_typeMontantRetenu);
    }
  }
  
  protected BigDecimal rawGetSeuilMensuelPansConservees()
  {
    return ((TrancheExecutablePC)getPC()).getSeuilMensuelPansConservees();
  }
  
  public BigDecimal getSeuilMensuelPansConservees()
  {
    return ((TrancheExecutablePC)getPC()).getSeuilMensuelPansConservees();
  }
  
  public void setSeuilMensuelPansConservees(BigDecimal p_seuilMensuelPansConservees)
  {
    if ((m_seuilMensuelPansConservees == null) || (p_seuilMensuelPansConservees == null))
    {
      m_seuilMensuelPansConservees = p_seuilMensuelPansConservees;
      ((TrancheExecutablePC)getPC()).setSeuilMensuelPansConservees(p_seuilMensuelPansConservees);
    }
    else if ((m_seuilMensuelPansConservees != null) && (p_seuilMensuelPansConservees != null) && (!p_seuilMensuelPansConservees.equals(m_seuilMensuelPansConservees)))
    {
      m_seuilMensuelPansConservees = p_seuilMensuelPansConservees;
      ((TrancheExecutablePC)getPC()).setSeuilMensuelPansConservees(p_seuilMensuelPansConservees);
    }
  }
  
  protected boolean rawIsEstSinistreOuCalamite()
  {
    return ((TrancheExecutablePC)getPC()).isEstSinistreOuCalamite();
  }
  
  public boolean isEstSinistreOuCalamite()
  {
    return ((TrancheExecutablePC)getPC()).isEstSinistreOuCalamite();
  }
  
  public void setEstSinistreOuCalamite(boolean p_estSinistreOuCalamite)
  {
    ((TrancheExecutablePC)getPC()).setEstSinistreOuCalamite(p_estSinistreOuCalamite);
  }
  
  protected boolean rawIsEstDecisionProlongation()
  {
    return ((TrancheExecutablePC)getPC()).isEstDecisionProlongation();
  }
  
  public boolean isEstDecisionProlongation()
  {
    return ((TrancheExecutablePC)getPC()).isEstDecisionProlongation();
  }
  
  public void setEstDecisionProlongation(boolean p_estDecisionProlongation)
  {
    ((TrancheExecutablePC)getPC()).setEstDecisionProlongation(p_estDecisionProlongation);
  }
  
  protected boolean rawIsEstAccordCp()
  {
    return ((TrancheExecutablePC)getPC()).isEstAccordCp();
  }
  
  public boolean isEstAccordCp()
  {
    return ((TrancheExecutablePC)getPC()).isEstAccordCp();
  }
  
  public void setEstAccordCp(boolean p_estAccordCp)
  {
    ((TrancheExecutablePC)getPC()).setEstAccordCp(p_estAccordCp);
  }
  
  protected Quantite rawGetAffiliationRequisePourPRA()
  {
    return ((TrancheExecutablePC)getPC()).getAffiliationRequisePourPRA();
  }
  
  public Quantite getAffiliationRequisePourPRA()
  {
    return ((TrancheExecutablePC)getPC()).getAffiliationRequisePourPRA();
  }
  
  public void setAffiliationRequisePourPRA(Quantite p_affiliationRequisePourPRA)
  {
    if ((m_affiliationRequisePourPRA == null) || (p_affiliationRequisePourPRA == null))
    {
      m_affiliationRequisePourPRA = p_affiliationRequisePourPRA;
      ((TrancheExecutablePC)getPC()).setAffiliationRequisePourPRA(p_affiliationRequisePourPRA);
    }
    else if ((m_affiliationRequisePourPRA != null) && (p_affiliationRequisePourPRA != null) && (!p_affiliationRequisePourPRA.equals(m_affiliationRequisePourPRA)))
    {
      m_affiliationRequisePourPRA = p_affiliationRequisePourPRA;
      ((TrancheExecutablePC)getPC()).setAffiliationRequisePourPRA(p_affiliationRequisePourPRA);
    }
  }
  
  protected int rawGetNombreJoursEmploiDansPRC()
  {
    return ((TrancheExecutablePC)getPC()).getNombreJoursEmploiDansPRC();
  }
  
  public int getNombreJoursEmploiDansPRC()
  {
    return ((TrancheExecutablePC)getPC()).getNombreJoursEmploiDansPRC();
  }
  
  public void setNombreJoursEmploiDansPRC(int p_nombreJoursEmploiDansPRC)
  {
    ((TrancheExecutablePC)getPC()).setNombreJoursEmploiDansPRC(p_nombreJoursEmploiDansPRC);
  }
  
  protected int rawGetCoefficientHoraireJour()
  {
    return ((TrancheExecutablePC)getPC()).getCoefficientHoraireJour();
  }
  
  public int getCoefficientHoraireJour()
  {
    return ((TrancheExecutablePC)getPC()).getCoefficientHoraireJour();
  }
  
  public void setCoefficientHoraireJour(int p_coefficientHoraireJour)
  {
    ((TrancheExecutablePC)getPC()).setCoefficientHoraireJour(p_coefficientHoraireJour);
  }
  
  protected Periode rawGetPrc()
  {
    return ((TrancheExecutablePC)getPC()).getPrc();
  }
  
  public Periode getPrc()
  {
    return ((TrancheExecutablePC)getPC()).getPrc();
  }
  
  public void setPrc(Periode p_prc)
  {
    if ((m_prc == null) || (p_prc == null))
    {
      m_prc = p_prc;
      ((TrancheExecutablePC)getPC()).setPrc(p_prc);
    }
    else if ((m_prc != null) && (p_prc != null) && (!p_prc.equals(m_prc)))
    {
      m_prc = p_prc;
      ((TrancheExecutablePC)getPC()).setPrc(p_prc);
    }
  }
  
  protected String rawGetReglementApplicableMontantRetenu()
  {
    return ((TrancheExecutablePC)getPC()).getReglementApplicableMontantRetenu();
  }
  
  public String getReglementApplicableMontantRetenu()
  {
    return ((TrancheExecutablePC)getPC()).getReglementApplicableMontantRetenu();
  }
  
  public void setReglementApplicableMontantRetenu(String p_reglementApplicableMontantRetenu)
  {
    if ((m_reglementApplicableMontantRetenu == null) || (p_reglementApplicableMontantRetenu == null))
    {
      m_reglementApplicableMontantRetenu = p_reglementApplicableMontantRetenu;
      ((TrancheExecutablePC)getPC()).setReglementApplicableMontantRetenu(p_reglementApplicableMontantRetenu);
    }
    else if ((m_reglementApplicableMontantRetenu != null) && (p_reglementApplicableMontantRetenu != null) && (!p_reglementApplicableMontantRetenu.equals(m_reglementApplicableMontantRetenu)))
    {
      m_reglementApplicableMontantRetenu = p_reglementApplicableMontantRetenu;
      ((TrancheExecutablePC)getPC()).setReglementApplicableMontantRetenu(p_reglementApplicableMontantRetenu);
    }
  }
  
  protected BigDecimal rawGetNombreHeuresTravailleesEtendu()
  {
    return ((TrancheExecutablePC)getPC()).getNombreHeuresTravailleesEtendu();
  }
  
  public BigDecimal getNombreHeuresTravailleesEtendu()
  {
    return ((TrancheExecutablePC)getPC()).getNombreHeuresTravailleesEtendu();
  }
  
  public void setNombreHeuresTravailleesEtendu(BigDecimal p_nombreHeuresTravailleesEtendu)
  {
    if ((m_nombreHeuresTravailleesEtendu == null) || (p_nombreHeuresTravailleesEtendu == null))
    {
      m_nombreHeuresTravailleesEtendu = p_nombreHeuresTravailleesEtendu;
      ((TrancheExecutablePC)getPC()).setNombreHeuresTravailleesEtendu(p_nombreHeuresTravailleesEtendu);
    }
    else if ((m_nombreHeuresTravailleesEtendu != null) && (p_nombreHeuresTravailleesEtendu != null) && (!p_nombreHeuresTravailleesEtendu.equals(m_nombreHeuresTravailleesEtendu)))
    {
      m_nombreHeuresTravailleesEtendu = p_nombreHeuresTravailleesEtendu;
      ((TrancheExecutablePC)getPC()).setNombreHeuresTravailleesEtendu(p_nombreHeuresTravailleesEtendu);
    }
  }
  
  protected BigDecimal rawGetNombreHeuresTravailleesPlafonne()
  {
    return ((TrancheExecutablePC)getPC()).getNombreHeuresTravailleesPlafonne();
  }
  
  public BigDecimal getNombreHeuresTravailleesPlafonne()
  {
    return ((TrancheExecutablePC)getPC()).getNombreHeuresTravailleesPlafonne();
  }
  
  public void setNombreHeuresTravailleesPlafonne(BigDecimal p_nombreHeuresTravailleesPlafonne)
  {
    if ((m_nombreHeuresTravailleesPlafonne == null) || (p_nombreHeuresTravailleesPlafonne == null))
    {
      m_nombreHeuresTravailleesPlafonne = p_nombreHeuresTravailleesPlafonne;
      ((TrancheExecutablePC)getPC()).setNombreHeuresTravailleesPlafonne(p_nombreHeuresTravailleesPlafonne);
    }
    else if ((m_nombreHeuresTravailleesPlafonne != null) && (p_nombreHeuresTravailleesPlafonne != null) && (!p_nombreHeuresTravailleesPlafonne.equals(m_nombreHeuresTravailleesPlafonne)))
    {
      m_nombreHeuresTravailleesPlafonne = p_nombreHeuresTravailleesPlafonne;
      ((TrancheExecutablePC)getPC()).setNombreHeuresTravailleesPlafonne(p_nombreHeuresTravailleesPlafonne);
    }
  }
  
  protected String rawGetContexteDateLimiteIndemnisation()
  {
    return ((TrancheExecutablePC)getPC()).getContexteDateLimiteIndemnisation();
  }
  
  public String getContexteDateLimiteIndemnisation()
  {
    return ((TrancheExecutablePC)getPC()).getContexteDateLimiteIndemnisation();
  }
  
  public void setContexteDateLimiteIndemnisation(String p_contexteDateLimiteIndemnisation)
  {
    if ((m_contexteDateLimiteIndemnisation == null) || (p_contexteDateLimiteIndemnisation == null))
    {
      m_contexteDateLimiteIndemnisation = p_contexteDateLimiteIndemnisation;
      ((TrancheExecutablePC)getPC()).setContexteDateLimiteIndemnisation(p_contexteDateLimiteIndemnisation);
    }
    else if ((m_contexteDateLimiteIndemnisation != null) && (p_contexteDateLimiteIndemnisation != null) && (!p_contexteDateLimiteIndemnisation.equals(m_contexteDateLimiteIndemnisation)))
    {
      m_contexteDateLimiteIndemnisation = p_contexteDateLimiteIndemnisation;
      ((TrancheExecutablePC)getPC()).setContexteDateLimiteIndemnisation(p_contexteDateLimiteIndemnisation);
    }
  }
  
  protected int rawGetCodeProduitExecutable()
  {
    return ((TrancheExecutablePC)getPC()).getCodeProduitExecutable();
  }
  
  public int getCodeProduitExecutable()
  {
    return ((TrancheExecutablePC)getPC()).getCodeProduitExecutable();
  }
  
  public void setCodeProduitExecutable(int p_codeProduitExecutable)
  {
    ((TrancheExecutablePC)getPC()).setCodeProduitExecutable(p_codeProduitExecutable);
  }
  
  protected boolean rawIsContextePAPPresent()
  {
    return ((TrancheExecutablePC)getPC()).isContextePAPPresent();
  }
  
  public boolean isContextePAPPresent()
  {
    return ((TrancheExecutablePC)getPC()).isContextePAPPresent();
  }
  
  public void setContextePAPPresent(boolean p_contextePAPPresent)
  {
    ((TrancheExecutablePC)getPC()).setContextePAPPresent(p_contextePAPPresent);
  }
  
  protected boolean rawIsEligibleAllongementAREF()
  {
    return ((TrancheExecutablePC)getPC()).isEligibleAllongementAREF();
  }
  
  public boolean isEligibleAllongementAREF()
  {
    return ((TrancheExecutablePC)getPC()).isEligibleAllongementAREF();
  }
  
  public void setEligibleAllongementAREF(boolean p_eligibleAllongementAREF)
  {
    ((TrancheExecutablePC)getPC()).setEligibleAllongementAREF(p_eligibleAllongementAREF);
  }
  
  private final Collection getCollectionModifiableDurees()
  {
    Iterator itCollectionPC;
    if (m_listeDurees == null)
    {
      m_listeDurees = new ArrayList();
      for (itCollectionPC = ((TrancheExecutablePC)getPC()).getCollectionDurees().iterator(); itCollectionPC.hasNext();)
      {
        DomPCSpec currentPC = (DomPCSpec)itCollectionPC.next();
        Object currentOM = currentPC.createOM();
        m_listeDurees.add(currentOM);
      }
    }
    return m_listeDurees;
  }
  
  public Collection getCollectionDurees()
  {
    return Collections.unmodifiableCollection(getCollectionModifiableDurees());
  }
  
  public List getListDurees()
  {
    return Collections.unmodifiableList((List)getCollectionModifiableDurees());
  }
  
  public void remplacerCollectionDurees(Collection p_collectionACopier)
  {
    clearCollectionDurees();
    for (Iterator i = p_collectionACopier.iterator(); i.hasNext();)
    {
      Duree objet = (Duree)i.next();
      ajouterDurees(objet);
    }
  }
  
  public void supprimerSousCollectionDurees(Collection p_collectionASupprimer)
  {
    for (Iterator i = p_collectionASupprimer.iterator(); i.hasNext();)
    {
      Duree objet = (Duree)i.next();
      supprimerDurees(objet);
    }
  }
  
  public void ajouterDurees(Duree p_durees)
    throws NullPointerException
  {
    if (p_durees == null) {
      ExceptionUtil.assertInternalNotNull("Le paramètre p_durees ne devrait pas être nul.", p_durees);
    }
    getCollectionModifiableDurees().add(p_durees);
    ((TrancheExecutablePC)getPC()).ajouterDurees(p_durees.getPC());
  }
  
  public void supprimerDurees(Duree p_durees)
    throws NullPointerException
  {
    if (p_durees == null) {
      ExceptionUtil.assertInternalNotNull("Le paramètre p_durees ne devrait pas être nul.", p_durees);
    }
    getCollectionModifiableDurees().remove(p_durees);
    ((TrancheExecutablePC)getPC()).supprimerDurees(p_durees.getPC());
  }
  
  public void recopierCollectionDureesVers(ObjetMetierSpec p_copie)
  {
    TrancheExecutableGen copie = (TrancheExecutableGen)p_copie;
    Collection listeACopier = getCollectionDurees();
    for (Iterator i = listeACopier.iterator(); i.hasNext();)
    {
      ObjetMetierSpec objet = ((ObjetMetierSpec)i.next()).copie();
      copie.ajouterDurees((Duree)objet);
    }
  }
  
  public void clearCollectionDurees()
  {
    getCollectionModifiableDurees().clear();
    ((TrancheExecutablePC)getPC()).getCollectionDurees().clear();
  }
  
  private final Collection getCollectionModifiablePensionsInvalidites()
  {
    Iterator itCollectionPC;
    if (m_listePensionsInvalidites == null)
    {
      m_listePensionsInvalidites = new ArrayList();
      for (itCollectionPC = ((TrancheExecutablePC)getPC()).getCollectionPensionsInvalidites().iterator(); itCollectionPC.hasNext();)
      {
        DomPCSpec currentPC = (DomPCSpec)itCollectionPC.next();
        Object currentOM = currentPC.createOM();
        m_listePensionsInvalidites.add(currentOM);
      }
    }
    return m_listePensionsInvalidites;
  }
  
  public Collection getCollectionPensionsInvalidites()
  {
    return Collections.unmodifiableCollection(getCollectionModifiablePensionsInvalidites());
  }
  
  public List getListPensionsInvalidites()
  {
    return Collections.unmodifiableList((List)getCollectionModifiablePensionsInvalidites());
  }
  
  public void remplacerCollectionPensionsInvalidites(Collection p_collectionACopier)
  {
    clearCollectionPensionsInvalidites();
    for (Iterator i = p_collectionACopier.iterator(); i.hasNext();)
    {
      PensionInvaliditeChainee objet = (PensionInvaliditeChainee)i.next();
      ajouterPensionsInvalidites(objet);
    }
  }
  
  public void supprimerSousCollectionPensionsInvalidites(Collection p_collectionASupprimer)
  {
    for (Iterator i = p_collectionASupprimer.iterator(); i.hasNext();)
    {
      PensionInvaliditeChainee objet = (PensionInvaliditeChainee)i.next();
      supprimerPensionsInvalidites(objet);
    }
  }
  
  public void ajouterPensionsInvalidites(PensionInvaliditeChainee p_pensionsInvalidites)
    throws NullPointerException
  {
    if (p_pensionsInvalidites == null) {
      ExceptionUtil.assertInternalNotNull("Le paramètre p_pensionsInvalidites ne devrait pas être nul.", p_pensionsInvalidites);
    }
    getCollectionModifiablePensionsInvalidites().add(p_pensionsInvalidites);
    ((TrancheExecutablePC)getPC()).ajouterPensionsInvalidites(p_pensionsInvalidites.getPC());
  }
  
  public void supprimerPensionsInvalidites(PensionInvaliditeChainee p_pensionsInvalidites)
    throws NullPointerException
  {
    if (p_pensionsInvalidites == null) {
      ExceptionUtil.assertInternalNotNull("Le paramètre p_pensionsInvalidites ne devrait pas être nul.", p_pensionsInvalidites);
    }
    getCollectionModifiablePensionsInvalidites().remove(p_pensionsInvalidites);
    ((TrancheExecutablePC)getPC()).supprimerPensionsInvalidites(p_pensionsInvalidites.getPC());
  }
  
  public void recopierCollectionPensionsInvaliditesVers(ObjetMetierSpec p_copie)
  {
    TrancheExecutableGen copie = (TrancheExecutableGen)p_copie;
    Collection listeACopier = getCollectionPensionsInvalidites();
    for (Iterator i = listeACopier.iterator(); i.hasNext();)
    {
      ObjetMetierSpec objet = ((ObjetMetierSpec)i.next()).copie();
      copie.ajouterPensionsInvalidites((PensionInvaliditeChainee)objet);
    }
  }
  
  public void clearCollectionPensionsInvalidites()
  {
    getCollectionModifiablePensionsInvalidites().clear();
    ((TrancheExecutablePC)getPC()).getCollectionPensionsInvalidites().clear();
  }
  
  private final Collection getCollectionModifiableDelaisReports()
  {
    Iterator itCollectionPC;
    if (m_listeDelaisReports == null)
    {
      m_listeDelaisReports = new ArrayList();
      for (itCollectionPC = ((TrancheExecutablePC)getPC()).getCollectionDelaisReports().iterator(); itCollectionPC.hasNext();)
      {
        DomPCSpec currentPC = (DomPCSpec)itCollectionPC.next();
        Object currentOM = currentPC.createOM();
        m_listeDelaisReports.add(currentOM);
      }
    }
    return m_listeDelaisReports;
  }
  
  public Collection getCollectionDelaisReports()
  {
    return Collections.unmodifiableCollection(getCollectionModifiableDelaisReports());
  }
  
  public List getListDelaisReports()
  {
    return Collections.unmodifiableList((List)getCollectionModifiableDelaisReports());
  }
  
  public void remplacerCollectionDelaisReports(Collection p_collectionACopier)
  {
    clearCollectionDelaisReports();
    for (Iterator i = p_collectionACopier.iterator(); i.hasNext();)
    {
      CarencePrefixeAFixer objet = (CarencePrefixeAFixer)i.next();
      ajouterDelaisReports(objet);
    }
  }
  
  public void supprimerSousCollectionDelaisReports(Collection p_collectionASupprimer)
  {
    for (Iterator i = p_collectionASupprimer.iterator(); i.hasNext();)
    {
      CarencePrefixeAFixer objet = (CarencePrefixeAFixer)i.next();
      supprimerDelaisReports(objet);
    }
  }
  
  public void ajouterDelaisReports(CarencePrefixeAFixer p_delaisReports)
    throws NullPointerException
  {
    if (p_delaisReports == null) {
      ExceptionUtil.assertInternalNotNull("Le paramètre p_delaisReports ne devrait pas être nul.", p_delaisReports);
    }
    getCollectionModifiableDelaisReports().add(p_delaisReports);
    ((TrancheExecutablePC)getPC()).ajouterDelaisReports(p_delaisReports.getPC());
  }
  
  public void supprimerDelaisReports(CarencePrefixeAFixer p_delaisReports)
    throws NullPointerException
  {
    if (p_delaisReports == null) {
      ExceptionUtil.assertInternalNotNull("Le paramètre p_delaisReports ne devrait pas être nul.", p_delaisReports);
    }
    getCollectionModifiableDelaisReports().remove(p_delaisReports);
    ((TrancheExecutablePC)getPC()).supprimerDelaisReports(p_delaisReports.getPC());
  }
  
  public void recopierCollectionDelaisReportsVers(ObjetMetierSpec p_copie)
  {
    TrancheExecutableGen copie = (TrancheExecutableGen)p_copie;
    Collection listeACopier = getCollectionDelaisReports();
    for (Iterator i = listeACopier.iterator(); i.hasNext();)
    {
      ObjetMetierSpec objet = ((ObjetMetierSpec)i.next()).copie();
      copie.ajouterDelaisReports((CarencePrefixeAFixer)objet);
    }
  }
  
  public void clearCollectionDelaisReports()
  {
    getCollectionModifiableDelaisReports().clear();
    ((TrancheExecutablePC)getPC()).getCollectionDelaisReports().clear();
  }
  
  private final Collection getCollectionModifiableContextes()
  {
    Iterator itCollectionPC;
    if (m_listeContextes == null)
    {
      m_listeContextes = new ArrayList();
      for (itCollectionPC = ((TrancheExecutablePC)getPC()).getCollectionContextes().iterator(); itCollectionPC.hasNext();)
      {
        DomPCSpec currentPC = (DomPCSpec)itCollectionPC.next();
        Object currentOM = currentPC.createOM();
        m_listeContextes.add(currentOM);
      }
    }
    return m_listeContextes;
  }
  
  public Collection getCollectionContextes()
  {
    return Collections.unmodifiableCollection(getCollectionModifiableContextes());
  }
  
  public List getListContextes()
  {
    return Collections.unmodifiableList((List)getCollectionModifiableContextes());
  }
  
  public void remplacerCollectionContextes(Collection p_collectionACopier)
  {
    clearCollectionContextes();
    for (Iterator i = p_collectionACopier.iterator(); i.hasNext();)
    {
      ContexteDemande objet = (ContexteDemande)i.next();
      ajouterContextes(objet);
    }
  }
  
  public void supprimerSousCollectionContextes(Collection p_collectionASupprimer)
  {
    for (Iterator i = p_collectionASupprimer.iterator(); i.hasNext();)
    {
      ContexteDemande objet = (ContexteDemande)i.next();
      supprimerContextes(objet);
    }
  }
  
  public void ajouterContextes(ContexteDemande p_contextes)
    throws NullPointerException
  {
    if (p_contextes == null) {
      ExceptionUtil.assertInternalNotNull("Le paramètre p_contextes ne devrait pas être nul.", p_contextes);
    }
    getCollectionModifiableContextes().add(p_contextes);
    ((TrancheExecutablePC)getPC()).ajouterContextes(p_contextes.getPC());
  }
  
  public void supprimerContextes(ContexteDemande p_contextes)
    throws NullPointerException
  {
    if (p_contextes == null) {
      ExceptionUtil.assertInternalNotNull("Le paramètre p_contextes ne devrait pas être nul.", p_contextes);
    }
    getCollectionModifiableContextes().remove(p_contextes);
    ((TrancheExecutablePC)getPC()).supprimerContextes(p_contextes.getPC());
  }
  
  public void recopierCollectionContextesVers(ObjetMetierSpec p_copie)
  {
    TrancheExecutableGen copie = (TrancheExecutableGen)p_copie;
    Collection listeACopier = getCollectionContextes();
    for (Iterator i = listeACopier.iterator(); i.hasNext();)
    {
      ObjetMetierSpec objet = ((ObjetMetierSpec)i.next()).copie();
      copie.ajouterContextes((ContexteDemande)objet);
    }
  }
  
  public void clearCollectionContextes()
  {
    getCollectionModifiableContextes().clear();
    ((TrancheExecutablePC)getPC()).getCollectionContextes().clear();
  }
  
  private final Collection getCollectionModifiableListeSousTrancheExecutable()
  {
    Iterator itCollectionPC;
    if (m_listeSousTrancheExecutable == null)
    {
      m_listeSousTrancheExecutable = new ArrayList();
      for (itCollectionPC = ((TrancheExecutablePC)getPC()).getCollectionListeSousTrancheExecutable().iterator(); itCollectionPC.hasNext();)
      {
        DomPCSpec currentPC = (DomPCSpec)itCollectionPC.next();
        Object currentOM = currentPC.createOM();
        m_listeSousTrancheExecutable.add(currentOM);
      }
    }
    return m_listeSousTrancheExecutable;
  }
  
  public Collection getCollectionListeSousTrancheExecutable()
  {
    return Collections.unmodifiableCollection(getCollectionModifiableListeSousTrancheExecutable());
  }
  
  public List getListListeSousTrancheExecutable()
  {
    return Collections.unmodifiableList((List)getCollectionModifiableListeSousTrancheExecutable());
  }
  
  public void remplacerCollectionListeSousTrancheExecutable(Collection p_collectionACopier)
  {
    clearCollectionListeSousTrancheExecutable();
    for (Iterator i = p_collectionACopier.iterator(); i.hasNext();)
    {
      SousTrancheExecutable objet = (SousTrancheExecutable)i.next();
      ajouterListeSousTrancheExecutable(objet);
    }
  }
  
  public void supprimerSousCollectionListeSousTrancheExecutable(Collection p_collectionASupprimer)
  {
    for (Iterator i = p_collectionASupprimer.iterator(); i.hasNext();)
    {
      SousTrancheExecutable objet = (SousTrancheExecutable)i.next();
      supprimerListeSousTrancheExecutable(objet);
    }
  }
  
  public void ajouterListeSousTrancheExecutable(SousTrancheExecutable p_sousTrancheExecutable)
    throws NullPointerException
  {
    if (p_sousTrancheExecutable == null) {
      ExceptionUtil.assertInternalNotNull("Le paramètre p_sousTrancheExecutable ne devrait pas être nul.", p_sousTrancheExecutable);
    }
    getCollectionModifiableListeSousTrancheExecutable().add(p_sousTrancheExecutable);
    ((TrancheExecutablePC)getPC()).ajouterListeSousTrancheExecutable(p_sousTrancheExecutable.getPC());
  }
  
  public void supprimerListeSousTrancheExecutable(SousTrancheExecutable p_sousTrancheExecutable)
    throws NullPointerException
  {
    if (p_sousTrancheExecutable == null) {
      ExceptionUtil.assertInternalNotNull("Le paramètre p_sousTrancheExecutable ne devrait pas être nul.", p_sousTrancheExecutable);
    }
    getCollectionModifiableListeSousTrancheExecutable().remove(p_sousTrancheExecutable);
    ((TrancheExecutablePC)getPC()).supprimerListeSousTrancheExecutable(p_sousTrancheExecutable.getPC());
  }
  
  public void recopierCollectionListeSousTrancheExecutableVers(ObjetMetierSpec p_copie)
  {
    TrancheExecutableGen copie = (TrancheExecutableGen)p_copie;
    Collection listeACopier = getCollectionListeSousTrancheExecutable();
    for (Iterator i = listeACopier.iterator(); i.hasNext();)
    {
      ObjetMetierSpec objet = ((ObjetMetierSpec)i.next()).copie();
      copie.ajouterListeSousTrancheExecutable((SousTrancheExecutable)objet);
    }
  }
  
  public void clearCollectionListeSousTrancheExecutable()
  {
    getCollectionModifiableListeSousTrancheExecutable().clear();
    ((TrancheExecutablePC)getPC()).getCollectionListeSousTrancheExecutable().clear();
  }
  
  public void supprimerEnProfondeur(ContexteSuppressionEnProfondeur p_contexteSuppression)
    throws TechniqueException
  {
    p_contexteSuppression.addElementEnCoursDeSuppression(this);
    for (Iterator iter = getCollectionDurees().iterator(); iter.hasNext();)
    {
      DomGenSpec item = (DomGenSpec)iter.next();
      if ((item != null) && (!p_contexteSuppression.isAlreadyEnlistedForDeletion(item))) {
        DomManager.supprimer(item, p_contexteSuppression);
      }
    }
    for (Iterator iter = getCollectionPensionsInvalidites().iterator(); iter.hasNext();)
    {
      DomGenSpec item = (DomGenSpec)iter.next();
      if ((item != null) && (!p_contexteSuppression.isAlreadyEnlistedForDeletion(item))) {
        DomManager.supprimer(item, p_contexteSuppression);
      }
    }
    for (Iterator iter = getCollectionDelaisReports().iterator(); iter.hasNext();)
    {
      DomGenSpec item = (DomGenSpec)iter.next();
      if ((item != null) && (!p_contexteSuppression.isAlreadyEnlistedForDeletion(item))) {
        DomManager.supprimer(item, p_contexteSuppression);
      }
    }
    for (Iterator iter = getCollectionContextes().iterator(); iter.hasNext();)
    {
      DomGenSpec item = (DomGenSpec)iter.next();
      if ((item != null) && (!p_contexteSuppression.isAlreadyEnlistedForDeletion(item))) {
        DomManager.supprimer(item, p_contexteSuppression);
      }
    }
    for (Iterator iter = getCollectionListeSousTrancheExecutable().iterator(); iter.hasNext();)
    {
      DomGenSpec item = (DomGenSpec)iter.next();
      if ((item != null) && (!p_contexteSuppression.isAlreadyEnlistedForDeletion(item))) {
        DomManager.supprimer(item, p_contexteSuppression);
      }
    }
  }
  
  public void copieElements(ObjetMetierSpec p_copie) {}
}

/* Location:
 * Qualified Name:     TrancheExecutableGen
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */