package fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.asu.liquidation.outilsfonctionnels.DeterminationMontant;
import fr.unedic.cali.asu.outilsfonctionnels.AppelCalculParLiquidationAsu;
import fr.unedic.cali.asu.outilsfonctionnels.OutilAsr;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilTranchesExecutables;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionMontantsBruts;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ConstitutionElementsSpec;
import fr.unedic.cali.dom.affectation.GammeAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.conteneurs.DonneesCalculMontant;
import fr.unedic.cali.dom.conteneurs.DonneesCalculMontantAsp;
import fr.unedic.cali.dom.conteneurs.DonneesEntreesRecuperationMontant;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Damj;
import java.util.Collection;

public class DeterminationMontantsBruts
  implements OutilFonctionnel
{
  public static DeterminationMontantsBruts getInstance()
  {
    return new DeterminationMontantsBruts();
  }
  
  public void determinerMontantsBruts(Demande demande)
    throws CoucheLogiqueException
  {
    Attribution attribution = (Attribution)demande.getAttribution();
    
    determinerListePensionInvalidite(attribution);
    
    determinerMontantsBruts(attribution, attribution.getDateEffet());
  }
  
  public void determinerMontantsBrutsPourRevision(Demande demande)
    throws CoucheLogiqueException
  {
    Attribution attribution = (Attribution)demande.getAttribution();
    
    determinerMontantsBruts(attribution, attribution.getDateEffet());
    
    alimentationCapitalDroitCourant(demande);
  }
  
  public void determinerMontantsBrutsPourReprise(Demande demande)
    throws CoucheLogiqueException
  {
    Attribution attribution = (Attribution)demande.getAttribution();
    
    determinerMontantsBruts(attribution, attribution.getDateEffet());
    
    alimentationCapitalDroitCourant(demande);
  }
  
  public void alimentationCapitalDroitCourant(Demande demande)
    throws CoucheLogiqueException
  {
    Attribution attribution = (Attribution)demande.getDossierExamen();
    ConstitutionMontantsBruts cepMontant = attribution.getConstitutionMontantsBruts();
    
    Quantite nbJourIndemnisesTheorique = attribution.getConstitutionDurees().getDureeIndemnisation().getDureeTheorique();
    Quantite capitalProduitCourant = AppelCalculParLiquidationAsu.calculerCapital(attribution, cepMontant.getMontantAAttribution(), attribution.getDateAttribution(), nbJourIndemnisesTheorique);
    
    cepMontant.setCapitalInitialBrut(capitalProduitCourant);
  }
  
  public void determinerMontantsBrutsFinAsr(Demande demande)
    throws CoucheLogiqueException
  {
    Attribution attributionCourante = (Attribution)demande.getAttribution();
    
    Attribution attributionAsr = (Attribution)OutilAsr.rechercherDernierDroitAsr(demande);
    if (attributionAsr.getProduit().getCode() == 36) {
      determinerMontantsBruts(attributionCourante, attributionCourante.getDateAttribution());
    } else {
      determinerMontantsBruts(attributionCourante, attributionCourante.getDateExamen());
    }
  }
  
  public void determinerListePensionInvalidite(Attribution attribution)
    throws CoucheLogiqueException
  {
    attribution.getConstitutionElementsActifs().createConstitutionMontantsBruts();
    
    ProduitAsuSpec produit = (ProduitAsuSpec)attribution.getProduit();
    Collection listePensionInvalidite = produit.determinerPensionInvaliditeDroitCourant(attribution);
    ConstitutionMontantsBruts resultatCep = attribution.getConstitutionElementsActifs().getConstitutionMontantsBruts();
    resultatCep.setListePensionInvalidite(listePensionInvalidite);
  }
  
  public void determinerMontantsBruts(Attribution attribution, Damj date)
    throws CoucheLogiqueException
  {
    if (attribution.getConstitutionElementsActifs().getConstitutionMontantsBruts() == null) {
      attribution.getConstitutionElementsActifs().createConstitutionMontantsBruts();
    }
    OutilTranchesExecutables.alimenterTrancheExecutable(attribution);
    
    DonneesEntreesRecuperationMontant donneesEntrees = ((GammeAsuSpec)attribution.getGamme()).mapperDonneesEntreesRecuperationMontant(attribution);
    
    donneesEntrees.setDateCalculMontant(date);
    if ((attribution.getDemandeAssurance() != null) && (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(((Demande)attribution.getDemandeAssurance()).getListContexteDemande(), "ARESJASPDC"))) {
      donneesEntrees.getDonneesCalculMontant().setContexteFormation(true);
    }
    if (((attribution.getDemandeAssurance() != null) && (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)attribution.getDemandeAssurance(), "ARECOURCSP"))) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)attribution.getDemandeAssurance(), "AREENTRCSP")))
    {
      donneesEntrees.getDonneesCalculMontant().setProduit(attribution.getProduitExecution());
      donneesEntrees.getDonneesCalculMontantAsp().setProduitAreSousJacent(attribution.getProduit());
    }
    MontantAsuSpec montantAAttribution = DeterminationMontant.determinerMontant(donneesEntrees);
    
    alimenterResultatCep(montantAAttribution, attribution);
  }
  
  private void alimenterResultatCep(MontantAsuSpec montant, Attribution attribution)
    throws CoucheLogiqueException
  {
    ConstitutionMontantsBruts resultatCep = attribution.getConstitutionElementsActifs().getConstitutionMontantsBruts();
    
    resultatCep.setMontantAAttribution(montant);
    
    resultatCep.setMontantJournalierBrut(montant.getMontantPrecompteEffectif());
    
    resultatCep.setMontantBrutSansDeduction(montant.getMontantBrut());
    if (montant != null)
    {
      resultatCep.setMontantBase(montant.getBase());
      resultatCep.setMontantMini(montant.getMini());
      
      Quantite miniFormation = montant.getMiniFormation();
      if (miniFormation != null) {
        resultatCep.setMiniAREF(miniFormation.getValeur());
      }
      resultatCep.setMontantPlafond(montant.getPlafond());
      resultatCep.setMontantPlancher(montant.getPlancher());
      resultatCep.setMontantBrutSansPensionInvaliditeADeduire(montant.getMontantBrutSansPensionInvaliditeADeduire());
      resultatCep.setPensionInvaliditeADeduirePriseEnCompte(montant.getPensionInvaliditeADeduirePriseEnCompte());
      resultatCep.setMontantJournalierAvantageVieillesse(montant.getMontantJournalierAvantageVieillesse());
      resultatCep.setMontantJournalierAvantageVieillesseDeduit(montant.getMontantJournalierAvantageVieillesseDeduit());
      resultatCep.setCrc(montant.getCrc());
    }
    Demande demande = (Demande)attribution.getDemandeAssurance();
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, 9)) {
      alimenterDonneesCspDC(resultatCep, montant);
    }
  }
  
  protected void alimenterDonneesCspDC(ConstitutionMontantsBruts cep, MontantAsuSpec montant)
  {
    cep.setMontantAAttribution(montant);
    cep.setMontantJournalierBrut(montant.getMontantPrecompteEffectif());
    cep.setMontantBrutSansDeduction(montant.getMontantBrut());
    if (montant.getMontantSJR() != null) {
      cep.setMontantBase(montant.getMontantSJR().getMontantPrecompteEffectif());
    }
    if (montant.getMontantAreExecute() != null) {
      cep.setMontantMini(montant.getMontantAreExecute().getMontantPrecompteEffectif());
    }
    if (montant.getMiniFormation() != null) {
      cep.setMiniAREF(montant.getMiniFormation().getValeur());
    }
    if (montant.getPlafondASP() != null) {
      cep.setMontantPlafond(new QuantiteEuro(montant.getPlafondASP()));
    }
    if (montant.getMontantAreNonExecute() != null) {
      cep.setMontantPlancher(montant.getMontantAreNonExecute().getMontantPrecompteEffectif());
    }
    cep.setSjrMontantMaxAsp(montant.getSjrMontantMax());
  }
}

/* Location:
 * Qualified Name:     DeterminationMontantsBruts
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */