package fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.EreInscriptionDemandeurEmploi;
import fr.unedic.cali.asu.produits.liquidation.dom.ResultatConditionRechercheEmploi;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnCharge;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.ResultatElementDroit;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Damj;

public class RechercheConditionRechercheEmploi
  implements OutilFonctionnel
{
  public static RechercheConditionRechercheEmploi getInstance()
  {
    return new RechercheConditionRechercheEmploi();
  }
  
  public ResultatConditionRechercheEmploi rechercherConditionRechercheEmploi(Demande demande)
    throws CoucheLogiqueException
  {
    ResultatConditionRechercheEmploi resultatConditionRechercheEmploi = new ResultatConditionRechercheEmploi();
    ResultatElementDroit resultatElementDroit = new ResultatElementDroit();
    resultatConditionRechercheEmploi.setResultatElementDroit(resultatElementDroit);
    resultatElementDroit.setEtatSatisfait(true);
    if (!estUneDemandeExpresseEnSortieCRA(demande))
    {
      Damj dateExamenDemandeCourante = demande.getDateExamen();
      ObjetChronoPeriodePriseEnCharge periodePEC = OutillagePEC.getPeriodePecDemandeurEmploiContenant(demande.getDemandeur(), dateExamenDemandeCourante);
      
      boolean estDemandeRechargement = "ASU_29".equals(demande.getEvenementReferenceExamen().getTypeExamen());
      
      resultatConditionRechercheEmploi = controlerExistancePec(periodePEC, resultatConditionRechercheEmploi, estDemandeRechargement);
      if (((demande.getEvenementReferenceExamen() instanceof EreInscriptionDemandeurEmploi)) && (resultatConditionRechercheEmploi.getResultatElementDroit().estSatisfait())) {
        controlerCoherencePec(periodePEC, demande, resultatConditionRechercheEmploi);
      }
    }
    return resultatConditionRechercheEmploi;
  }
  
  private boolean estUneDemandeExpresseEnSortieCRA(Demande demande)
  {
    return ("ASU_02".equals(demande.getEvenementReferenceExamen().getTypeExamen())) && (demande.estEnContexteDemande("SORTIECRA"));
  }
  
  public ResultatConditionRechercheEmploi controlerExistancePec(ObjetChronoPeriodePriseEnCharge periodePEC, ResultatConditionRechercheEmploi resultatConditionRechercheEmploi, boolean estDemandeRechargement)
    throws CoucheLogiqueException
  {
    if (periodePEC == null) {
      if (estDemandeRechargement)
      {
        ResultatElementDroit resultatElementDroit = resultatConditionRechercheEmploi.getResultatElementDroit();
        resultatConditionRechercheEmploi.getResultatElementDroit().setEtatSatisfait(false);
        
        resultatElementDroit.setCodeMotifEchec(11);
      }
      else
      {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_ERR_DEMANDEUR_NON_INSCRIT");
      }
    }
    return resultatConditionRechercheEmploi;
  }
  
  public void controlerCoherencePec(ObjetChronoPeriodePriseEnCharge periodePEC, Demande demande, ResultatConditionRechercheEmploi resultatConditionRechercheEmploi)
    throws CoucheLogiqueException
  {
    if (periodePEC.getIdentifiantPec() < demande.getFormulaire().getIdPec())
    {
      resultatConditionRechercheEmploi.getResultatElementDroit().setEtatSatisfait(false);
      
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_ERR_PEC_INFERIEURE");
    }
    else if (periodePEC.getIdentifiantPec() > demande.getFormulaire().getIdPec())
    {
      resultatConditionRechercheEmploi.getResultatElementDroit().setEtatSatisfait(false);
      
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_ERR_PEC_SUPERIEURE", new Object[] { Integer.toString(demande.getFormulaire().getIdPec()) });
    }
  }
}

/* Location:
 * Qualified Name:     RechercheConditionRechercheEmploi
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */