package fr.unedic.cali.asu.spe02.p03.calcul.outilsfonctionnels;

import fr.unedic.cali.asu.calcul.outilsfonctionnels.CreationPeriodeNonDeclareeSanction;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Attribution;
import fr.unedic.cali.calcul.dom.SyntheseARsurUT;
import fr.unedic.cali.calcul.dom.UniteTraitement;
import fr.unedic.cali.calcul.dom.periode.DsmTravail;
import fr.unedic.cali.calcul.dom.periode.PeriodePrime;
import fr.unedic.cali.calcul.dom.periode.PeriodeTravailJustifiee;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeCalcul;
import fr.unedic.cali.calcul.outilsfonctionnels.DeterminationActiviteConserveeReprise;
import fr.unedic.cali.calcul.outilsfonctionnels.DeterminerJustificatifsRevenusAR;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.ResultatActiviteReduite;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.UniteMonaitaire;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.UniteDuree;
import java.math.BigDecimal;
import java.util.Collection;

public class TraitementActiviteReduite
{
  public void traitementPeriodesGelantes(AttributionSpec attribution, ChronologiePeriodes periodesGelantes, UniteTraitement ut)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes periodesGelantesDeclareees = new ChronologiePeriodes();
    ChronologiePeriodes periodesGelantesJustifiees = new ChronologiePeriodes();
    
    boolean traitementActiviteReduite = preTraitementPeriodesGelantes(attribution, ut, periodesGelantes, periodesGelantesDeclareees, periodesGelantesJustifiees);
    if (traitementActiviteReduite)
    {
      if (periodesGelantesJustifiees.getTaille() != 0)
      {
        ResultatActiviteReduite resultatActiviteReduite = appelleActiviteReduite(attribution, periodesGelantesJustifiees, ut);
        
        postTraitementPeriodesGelantes(ut, resultatActiviteReduite);
        
        appliquerRegleSurUTPP(ut);
      }
      if (periodesGelantesDeclareees.getTaille() != 0)
      {
        ResultatActiviteReduite resultatActiviteReduite = appelleActiviteReduite(attribution, periodesGelantesDeclareees, ut);
        
        postTraitementPeriodesGelantes(ut, resultatActiviteReduite);
      }
    }
  }
  
  public void traitementPeriodesDecalantes(AttributionSpec attribution, ChronologiePeriodes periodesDecalantes, UniteTraitement ut)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes periodesDecalantesDeclareees = new ChronologiePeriodes();
    ChronologiePeriodes periodesDecalantesJustifiees = new ChronologiePeriodes();
    ChronologiePeriodes periodeNonDeclareeSanction = null;
    ObjetChronoPeriodeCalcul periodeTravailCalcul = null;
    Chronologie chronoPeriodesConserveesLiq = null;
    
    boolean traitementActiviteReduite = preTraitementPeriodesDecalantes(attribution, periodesDecalantes, ut, periodesDecalantesDeclareees, periodesDecalantesJustifiees, periodeNonDeclareeSanction, periodeTravailCalcul, chronoPeriodesConserveesLiq);
    if (traitementActiviteReduite)
    {
      if (periodesDecalantesJustifiees.getTaille() != 0)
      {
        ResultatActiviteReduite resultatActiviteReduite = appelleActiviteReduite(attribution, periodesDecalantesJustifiees, ut);
        
        postTraitementPeriodesDecalantes(ut, resultatActiviteReduite);
      }
      if (periodesDecalantesDeclareees.getTaille() != 0)
      {
        ResultatActiviteReduite resultatActiviteReduite = appelleActiviteReduite(attribution, periodesDecalantesDeclareees, ut);
        
        postTraitementPeriodesDecalantes(ut, resultatActiviteReduite);
        
        appliquerRegleSurUTPP(ut);
      }
    }
  }
  
  protected ResultatActiviteReduite appelleActiviteReduite(AttributionSpec attributionParam, ChronologiePeriodes periodesEmploi, UniteTraitement ut)
    throws CoucheLogiqueException
  {
    Attribution attribution = (Attribution)attributionParam;
    ActiviteReduite activiteReduite = new ActiviteReduite();
    
    DeterminerJustificatifsRevenusAR.traitementRevenusBS(periodesEmploi, ut.getDateDebut(), attributionParam);
    
    return activiteReduite.genererEvenementActiviteReduite(periodesEmploi, ut, attribution.getElementBaseIndemnisation().getReglementApplicable().getLibelleCourt());
  }
  
  protected static boolean preTraitementPeriodesDecalantes(AttributionSpec attribution, ChronologiePeriodes periodesDecalantes, UniteTraitement ut, ChronologiePeriodes periodesDecalantesDeclareees, ChronologiePeriodes periodesDecalantesJustifiees, ChronologiePeriodes periodeNonDeclareeSanction, ObjetChronoPeriodeCalcul periodeTravailCalcul, Chronologie chronoPeriodesConserveesLiq)
    throws CoucheLogiqueException
  {
    boolean traitementActiviteReduite = false;
    switch (ut.getStatut())
    {
    case 1: 
    case 2: 
      throw new CoucheLogiqueException("HG_PR_CALI_L_ACTIVITE_REDUITE_STATUT_UT_INATTENDU", "Erreur sur le statut de l'Unité de Traitement lors du traitement de l'activité réduite.", null);
    case 3: 
    case 7: 
      periodesDecalantes.iterer();
      while (periodesDecalantes.encoreSuivant())
      {
        periodeTravailCalcul = (ObjetChronoPeriodeCalcul)periodesDecalantes.elementSuivant();
        if (((periodeTravailCalcul instanceof PeriodeTravailJustifiee)) || ((periodeTravailCalcul instanceof PeriodePrime)))
        {
          chronoPeriodesConserveesLiq = ((Attribution)attribution).getListeActiviteConservee();
          
          boolean periodeAIgnorer = DeterminationActiviteConserveeReprise.determinerTypeActivite(chronoPeriodesConserveesLiq, ut, periodeTravailCalcul, attribution);
          if (!periodeAIgnorer) {
            periodesDecalantesJustifiees.ajouter(periodeTravailCalcul);
          }
        }
      }
      if (periodesDecalantesJustifiees.getTaille() != 0) {
        traitementActiviteReduite = true;
      }
      periodeNonDeclareeSanction = CreationPeriodeNonDeclareeSanction.creerPeriodeNonDeclareeSanction(attribution.getDemandeur(), ut.getDateDebut(), periodesDecalantes, false);
      
      ChronologiePeriodes pndSanctionsConverties = new ChronologiePeriodes();
      periodeNonDeclareeSanction.iterer();
      while (periodeNonDeclareeSanction.encoreSuivant())
      {
        fr.unedic.cali.asu.calcul.dom.periode.PeriodeNonDeclareeSanction pndSanctionAsu = (fr.unedic.cali.asu.calcul.dom.periode.PeriodeNonDeclareeSanction)periodeNonDeclareeSanction.elementSuivant();
        fr.unedic.cali.asu.spe02.p03.calcul.dom.periode.PeriodeNonDeclareeSanction pndSanctionProduit = new fr.unedic.cali.asu.spe02.p03.calcul.dom.periode.PeriodeNonDeclareeSanction(pndSanctionAsu);
        
        pndSanctionsConverties.ajouter(pndSanctionProduit);
      }
      if ((pndSanctionsConverties != null) && (!pndSanctionsConverties.estVide())) {
        ut.getListePNDs().add(pndSanctionsConverties);
      }
      break;
    case 4: 
      BigDecimal gains = new BigDecimal("0");
      BigDecimal heures = new BigDecimal("0");
      BigDecimal totalNbJourTravail = new BigDecimal("0");
      periodesDecalantes.iterer();
      while (periodesDecalantes.encoreSuivant())
      {
        periodeTravailCalcul = (ObjetChronoPeriodeCalcul)periodesDecalantes.elementSuivant();
        if ((periodeTravailCalcul instanceof DsmTravail))
        {
          if (((DsmTravail)periodeTravailCalcul).getGain() != null) {
            gains = gains.add(((DsmTravail)periodeTravailCalcul).getGain());
          }
          if (((DsmTravail)periodeTravailCalcul).getNombreHeures() != null) {
            heures = heures.add(((DsmTravail)periodeTravailCalcul).getNombreHeures());
          }
          totalNbJourTravail = totalNbJourTravail.add(new BigDecimal(periodeTravailCalcul.getDuree()));
        }
      }
      SyntheseARsurUT syntheseARsurUT = ut.getSyntheseARsurUT();
      syntheseARsurUT.setTotalGainUtilisePourDecalage(new QuantiteEuro(gains));
      syntheseARsurUT.setTotalHeureUtilisePourDecalage(new QuantiteEuro(heures));
      syntheseARsurUT.setCumulJourDeTravailAR(new Quantite(totalNbJourTravail, ut.getUniteParDefautQuantites()));
      break;
    case 6: 
      break;
    case 5: 
      periodesDecalantes.iterer();
      while (periodesDecalantes.encoreSuivant())
      {
        periodeTravailCalcul = (ObjetChronoPeriodeCalcul)periodesDecalantes.elementSuivant();
        if ((periodeTravailCalcul instanceof DsmTravail)) {
          periodesDecalantesDeclareees.ajouter(periodeTravailCalcul);
        }
      }
      if (periodesDecalantesDeclareees.getTaille() != 0) {
        traitementActiviteReduite = true;
      }
      break;
    default: 
      throw new CoucheLogiqueException("HG_PR_CALI_L_ACTIVITE_REDUITE_STATUT_UT_INATTENDU", "Erreur sur le statut de l'Unité de Traitement lors du traitement de l'activité réduite.", null);
    }
    return traitementActiviteReduite;
  }
  
  protected static void postTraitementPeriodesDecalantes(UniteTraitement ut, ResultatActiviteReduite resultatActiviteReduite)
    throws CoucheLogiqueException
  {
    ut.getSyntheseARsurUT().setCoefJourMajoure(resultatActiviteReduite.getCoefJourMajore());
    
    ut.getSyntheseARsurUT().setTotalGainUtilisePourDecalage(new Quantite(resultatActiviteReduite.getGainPrisEnCompte(), UniteMonaitaire.EUROS));
    ut.getSyntheseARsurUT().setTotalHeureUtilisePourDecalage(new Quantite(resultatActiviteReduite.getNbHeuresPrisesEnCompte(), UniteDuree.HEURE));
    
    ut.getSyntheseARsurUT().setCumulJourDeTravailAR(new Quantite(resultatActiviteReduite.getCumulJourDeTravail(), UniteDuree.JOUR));
    
    ut.getSyntheseARsurUT().setTotalGainActiviteReduiteJustifie(new Quantite(resultatActiviteReduite.getCumulGainJustifie(), UniteMonaitaire.EUROS));
    
    ut.getSyntheseARsurUT().setTotalNbHeureActiviteReduiteJustifie(new Quantite(resultatActiviteReduite.getCumulNbHeuresJustifiees(), UniteDuree.HEURE));
    
    Quantite qteDecalage = new Quantite(resultatActiviteReduite.getCreditDecalage(), ut.getUniteParDefautQuantites());
    ut.setCreditDecalage(ut.getCreditDecalage() == null ? qteDecalage : ut.getCreditDecalage().ajouter(qteDecalage));
    
    BigDecimal decalageDuree = resultatActiviteReduite.getDecalageDuree();
    if (decalageDuree != null)
    {
      Quantite qteDecalageDuree = new Quantite(decalageDuree, ut.getUniteParDefautQuantites());
      ut.getSyntheseARsurUT().setDecalageDureeUT(qteDecalageDuree);
      Quantite qteDecalageDureeDureeCourant = ut.getCreditDecalageDuree();
      if (qteDecalageDureeDureeCourant != null) {
        qteDecalageDuree = qteDecalageDuree.ajouter(qteDecalageDureeDureeCourant);
      }
      ut.setCreditDecalageDuree(qteDecalageDuree);
    }
  }
  
  protected static boolean preTraitementPeriodesGelantes(AttributionSpec attribution, UniteTraitement ut, ChronologiePeriodes periodesGelantes, ChronologiePeriodes periodesGelantesDeclareees, ChronologiePeriodes periodesGelantesJustifiees)
    throws CoucheLogiqueException
  {
    boolean traitementActiviteReduite = false;
    if (!ut.isTopCoherenceTravailA8A10())
    {
      ut.setNeutralisee(true);
      ut.setTypeNeutralisation(10);
    }
    switch (ut.getStatut())
    {
    case 1: 
    case 2: 
      throw new CoucheLogiqueException("HG_PR_CALI_L_ACTIVITE_REDUITE_STATUT_UT_INATTENDU", "Erreur sur le statut de l'Unité de Traitement lors du traitement de l'activité réduite.", null);
    case 3: 
    case 7: 
      periodesGelantes.iterer();
      while (periodesGelantes.encoreSuivant())
      {
        ObjetChronoPeriodeCalcul periodeTravailCalcul = (ObjetChronoPeriodeCalcul)periodesGelantes.elementSuivant();
        if (((periodeTravailCalcul instanceof PeriodeTravailJustifiee)) || ((periodeTravailCalcul instanceof PeriodePrime)))
        {
          Chronologie chronoPeriodesConserveesLiq = ((Attribution)attribution).getListeActiviteConservee();
          
          boolean periodeAIgnorer = DeterminationActiviteConserveeReprise.determinerTypeActivite(chronoPeriodesConserveesLiq, ut, periodeTravailCalcul, attribution);
          if (!periodeAIgnorer) {
            periodesGelantesJustifiees.ajouter(periodeTravailCalcul);
          }
        }
      }
      if (periodesGelantesJustifiees.getTaille() != 0) {
        traitementActiviteReduite = true;
      }
      break;
    case 4: 
      ut.setNeutralisee(true);
      ut.setTypeNeutralisation(4);
      break;
    case 5: 
      periodesGelantes.iterer();
      while (periodesGelantes.encoreSuivant())
      {
        ObjetChronoPeriodeCalcul periodeTravailCalcul = (ObjetChronoPeriodeCalcul)periodesGelantes.elementSuivant();
        if ((periodeTravailCalcul instanceof DsmTravail)) {
          periodesGelantesDeclareees.ajouter(periodeTravailCalcul);
        }
      }
      if (periodesGelantesDeclareees.getTaille() != 0) {
        traitementActiviteReduite = true;
      }
      break;
    case 6: 
      ut.setNeutralisee(true);
      ut.setTypeNeutralisation(8);
      break;
    default: 
      throw new CoucheLogiqueException("HG_PR_CALI_L_ACTIVITE_REDUITE_STATUT_UT_INATTENDU", "Erreur sur le statut de l'Unité de Traitement lors du traitement de l'activité réduite.", null);
    }
    return traitementActiviteReduite;
  }
  
  protected static void postTraitementPeriodesGelantes(UniteTraitement ut, ResultatActiviteReduite resultatActiviteReduite)
  {
    ut.setNeutralisee(resultatActiviteReduite.isNeutralise());
    ut.setTypeNeutralisation(resultatActiviteReduite.getTypeNeutralisation());
    ut.getSyntheseARsurUT().setCoefJourMajoure(resultatActiviteReduite.getCoefJourMajore());
  }
  
  protected static void appliquerRegleSurUTPP(UniteTraitement ut)
  {
    Quantite creditDecalageCalcule = ut.getCreditDecalage() != null ? ut.getCreditDecalage() : new Quantite(new BigDecimal(0), ut.getUniteParDefautQuantites());
    if (!ut.isNeutralisee())
    {
      Quantite creditDecalagePP = new Quantite(new BigDecimal(Math.floor(creditDecalageCalcule.getValeur().doubleValue())), creditDecalageCalcule.getUnite());
      
      ut.setCreditDecalage(creditDecalagePP);
    }
    else
    {
      ut.setCreditDecalage(creditDecalageCalcule);
    }
  }
}

/* Location:
 * Qualified Name:     TraitementActiviteReduite
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */