package fr.unedic.cali.asu.spe02.p03.liquidation.dom;

import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesDemandeAssociee;
import fr.unedic.cali.asu.dom.ElementBaseActiviteReduite;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.Sjm;
import fr.unedic.cali.asu.liquidation.outilsfonctionnels.DeterminationMontant;
import fr.unedic.cali.asu.mnt.dom.Accord;
import fr.unedic.cali.asu.mnt.dom.DemandeMaintien;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionEESSI;
import fr.unedic.cali.asu.outilsfonctionnels.RechercherDemandeMaintien;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.gen.AttributionGen;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.RecuperationElementIndemnisation;
import fr.unedic.cali.calcul.dom.CalendrierExecutionAvantSpec;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.MaintienEuropeen;
import fr.unedic.cali.dom.Prescription;
import fr.unedic.cali.dom.SalaireJournalierSpec;
import fr.unedic.cali.dom.affectation.FacadeLiquidationProduitAsuSpectacleSpec;
import fr.unedic.cali.dom.affectation.GammeAsuSpec;
import fr.unedic.cali.dom.affectation.GammeSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.conteneurs.DonneesEntreesRecuperationMontant;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.util.OutilDomToString;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.ApplicativeRuntimeException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.PasAssezInformationException;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public abstract class Attribution
  extends AttributionGen
  implements AttributionAssuranceSpec
{
  private static final long serialVersionUID = 1L;
  private transient ElementBaseIndemnisation ebiAttribution = null;
  private transient Damj pjiEffectif;
  private transient boolean isUnJourDiffereConsomme = false;
  private transient Damj dateFinACT;
  private transient Damj dateFinAct;
  private transient Damj dateFinAvant;
  private transient boolean aImputerReliquatAct = false;
  private transient int cumulJourAct = 0;
  private transient Collection<CarencePrefixeAFixer> carencesForcees = null;
  private transient Collection<CarencePrefixeAFixer> carencesReliquat = null;
  private transient DemandeSpec demandeSuivantePourTraitementReliquat;
  private transient MaintienEuropeen maintienEuropeen;
  
  public Attribution(DomPCSpec pc)
  {
    super(pc);
  }
  
  public Attribution() {}
  
  public Attribution(Damj dateEvenement)
  {
    super(dateEvenement);
  }
  
  public void copieElements(ObjetMetierSpec copieObjet)
  {
    Attribution copie = (Attribution)copieObjet;
    super.copieElements(copie);
    copie.setReferenceExterne(getReferenceExterne());
    copie.setTopRenoncement(isTopRenoncement());
    copie.setDemandeSuivantePourTraitementReliquat(getDemandeSuivantePourTraitementReliquat());
  }
  
  public void marquerGraphePersistant()
  {
    Demande demande = (Demande)getDemande();
    if ((demande != null) && (demande.getObjectifSatisfait() == null))
    {
      OutilTrace.ecrireTrace(Niveau.ERROR, new Object[] { "Erreur technique : Il n'existe pas d'objectif satisfait alors que nous avons une attribution" });
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_TECHNIQUE_GRAPHE_INCOHERENT", "Erreur technique : Il n'existe pas d'objectif satisfait alors que nous avons une attribution");
    }
    super.marquerGraphePersistant();
    DomManager.persisterEnProfondeur(getCalendrierExecutionCalcul());
    DomManager.persisterEnProfondeur(getCalendrierExecutionAvant());
  }
  
  protected void verifierCoherenceReferenceExterne()
  {
    if ((getReferenceExterne() == null) && (!"ASU_21".equals(getDemande().getEvenementReferenceExamen().getTypeExamen())))
    {
      OutilTrace.ecrireTrace(Niveau.ERROR, new Object[] { "Erreur technique : Le RSOD (reference externe) sur l'attribution est null" });
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_TECHNIQUE_GRAPHE_INCOHERENT", "Erreur technique : Le RSOD (reference externe) sur l'attribution est null");
    }
  }
  
  public boolean estEnReexamen()
  {
    return getDemande().estEnReExamen();
  }
  
  private boolean estNonClassementAdministratifValide()
  {
    return (getDemande().getClassementAdministratif() == null) || (((getDemande().getClassementAdministratif() instanceof Prescription)) && (!((Prescription)getDemande().getClassementAdministratif()).isValidite()));
  }
  
  public boolean estExecutable()
  {
    boolean estDemandeValide = (estNonClassementAdministratifValide()) && (!estEnReexamen()) && (estValidee());
    boolean estVisibleCalcul = (!estNeutralise()) && (getCompetence().getCompetenceAdministrative() == 1) && (!((Demande)getDemande()).isEstNonExecutable());
    
    return (estDemandeValide) && (estVisibleCalcul) && (!estTopeeRenoncement());
  }
  
  public boolean estMigree()
  {
    return getDemande().estMigree();
  }
  
  public boolean estMigreeEnSimplifiee()
  {
    return getDemande().estMigreeEnSimplifiee();
  }
  
  public boolean estNeutralise()
  {
    return getDemande().estNeutraliseeCalcul();
  }
  
  public boolean estPjiEffectif()
  {
    return pjiEffectif != null;
  }
  
  public Collection getAttributionLiees()
  {
    return null;
  }
  
  public List getListeDurees()
  {
    throw new UnsupportedOperationException("Cette méthode ne doit pas être appelée");
  }
  
  public Damj getDateExamen()
  {
    return getDemande().getDateExamen();
  }
  
  public Damj getDateFinAbonnement()
  {
    return getDemande().getDateFinAbonnement();
  }
  
  public IndividuSpec getDemandeur()
  {
    return getDemande().getDemandeur();
  }
  
  public FormuleMontantSpec getFormuleMontant(String code)
  {
    return ((ProduitAsuSpec)getDossierAffecte().getProduit()).getFormuleMontant(code);
  }
  
  public GammeSpec getGamme()
  {
    return getDemande().getGamme();
  }
  
  public String getIdentifiantDemande()
  {
    return getDemande().getIdentifiant();
  }
  
  public Damj getPji()
  {
    Damj pji = null;
    if (pjiEffectif != null) {
      pji = pjiEffectif;
    } else if (getConstitutionElementsActifs().getConstitutionPointDepartIndemnisation() != null) {
      pji = getConstitutionElementsActifs().getConstitutionPointDepartIndemnisation().getPointDepartIndemnisation();
    }
    return pji;
  }
  
  public Damj getPjiEffectif()
  {
    return pjiEffectif;
  }
  
  public ProduitSpec getProduit()
  {
    return getDossierAffecte().getProduit();
  }
  
  public String getTypeExamen()
  {
    return getDemande().getEvenementReferenceExamen().getTypeExamen();
  }
  
  public void setPjiEffectif(Damj pjiEffectif)
  {
    this.pjiEffectif = pjiEffectif;
  }
  
  public void setReexecutee(boolean estReexecute)
  {
    getDemande().setReexecutee(estReexecute);
  }
  
  public boolean estTopeeRenoncement()
  {
    return isTopRenoncement();
  }
  
  public Damj getDateFaitGenerateur()
  {
    Damj dateRetour = null;
    if (getFaitGenerateur() != null) {
      dateRetour = getFaitGenerateur().getDateFaitGenerateur();
    }
    return dateRetour;
  }
  
  public Quantite getDureeIndemnisationInitiale()
  {
    return getConstitutionElementsActifs().getConstitutionDurees().getDureeEffective();
  }
  
  public Quantite getDureeIndemnisationTheorique()
  {
    return getDureeTheorique();
  }
  
  public Quantite getDureeTheorique()
  {
    if ((getConstitutionElementsActifs().getConstitutionDurees() != null) && (getConstitutionElementsActifs().getConstitutionDurees().getDureeTheorique() != null)) {
      return getConstitutionElementsActifs().getConstitutionDurees().getDureeTheorique();
    }
    return null;
  }
  
  public ElementBaseActiviteReduite getElementBaseActiviteReduite()
  {
    return null;
  }
  
  public ElementBaseIndemnisation getElementBaseIndemnisation()
  {
    if (ebiAttribution == null) {
      ebiAttribution = RecuperationElementIndemnisation.getInstance().recupererElementBaseIndemnisation(this);
    }
    return (ElementBaseIndemnisation)ebiAttribution.copie();
  }
  
  public void supprimerCacheElementBaseIndemnisation()
  {
    ebiAttribution = null;
  }
  
  public Collection getListeCarences()
  {
    if (carencesForcees != null) {
      return carencesForcees;
    }
    Collection<CarencePrefixeAFixer> collection = new ArrayList();
    ConstitutionDelaisReport constitutionDelais = getConstitutionElementsActifs().getConstitutionDelaisReport();
    if (constitutionDelais != null) {
      collection = constitutionDelais.getListeCarencesAAppliquer();
    }
    return collection;
  }
  
  public int getNbJoursActiviteCourrierASS()
  {
    return 0;
  }
  
  public ConventionGestionSpec getConventionGestion()
  {
    return null;
  }
  
  public Damj getTermePrcActiviteConservee()
  {
    return null;
  }
  
  public boolean isUnJourDiffereConsomme()
  {
    return isUnJourDiffereConsomme;
  }
  
  public void setNbJoursActiviteCourrierASS(int nbJoursActiviteCourrierASS) {}
  
  public void setUnJourDiffereConsomme(boolean isUnJourDiffereConsomme)
  {
    this.isUnJourDiffereConsomme = isUnJourDiffereConsomme;
  }
  
  public boolean estMaintenue()
  {
    DemandeMaintien demandeMaintien = RechercherDemandeMaintien.rechercherDemandeMaintien(getDemande().getDemandeur(), this);
    
    return (demandeMaintien != null) && ((demandeMaintien.getDossierExamen() instanceof Accord)) && (!demandeMaintien.estEnReExamen());
  }
  
  public Quantite getDureeInitiale()
  {
    AttributionSpec attributionMaitre = getOuvertureDroitCapitalRetenu();
    if (attributionMaitre == this) {
      return getConstitutionElementsActifs().getConstitutionDurees().getDureeTheorique();
    }
    return ((AttributionAssuranceSpec)attributionMaitre).getDureeInitiale();
  }
  
  public void setCalendrierExecutionAvant(CalendrierExecutionAvantSpec calendrierAvant)
  {
    DomManager.supprimer(super.getCalendrierExecutionAvant(), calendrierAvant);
    super.setCalendrierExecutionAvant(calendrierAvant);
  }
  
  public void setCalendrierExecutionCalcul(CalendrierExecutionCalculSpec calendrier)
  {
    DomManager.supprimer(super.getCalendrierExecutionCalcul(), calendrier);
    super.setCalendrierExecutionCalcul(calendrier);
  }
  
  public String toString()
  {
    return OutilDomToString.toString(this);
  }
  
  public boolean isCapitalRetenuCourant()
  {
    return true;
  }
  
  public boolean estDemandeSuiteExamenFilEau()
  {
    return ((Demande)getDemande()).estUneDemandeEfe();
  }
  
  public boolean estDemandeSuiteFinDeDroit()
  {
    Demande demande = (Demande)getDemande();
    return demande.estDemandeSuiteFinDeDroit();
  }
  
  public MontantAsuSpec getMontantRecalcule(Damj dateRecalcul)
    throws CoucheLogiqueException
  {
    return recalculerMontantAttribution(dateRecalcul);
  }
  
  protected MontantAsuSpec recalculerMontantAttribution(Damj dateRecalcul)
    throws CoucheLogiqueException
  {
    GammeAsuSpec gamme = (GammeAsuSpec)getGamme();
    
    DonneesEntreesRecuperationMontant donneesEntrees = gamme.mapperDonneesEntreesRecuperationMontant(this);
    donneesEntrees.setDateCalculMontant(dateRecalcul);
    
    return DeterminationMontant.determinerMontant(donneesEntrees);
  }
  
  public ProduitAsuSpec getProduitMontantRetenu()
  {
    return (ProduitAsuSpec)getDossierAffecte().getProduit();
  }
  
  public boolean estDemandeExpresse()
  {
    return ((Demande)getDemande()).estUneDemandeExpresse();
  }
  
  public DemandeSpec getDemandeSuivantePourTraitementReliquat()
  {
    return demandeSuivantePourTraitementReliquat;
  }
  
  public void setDemandeSuivantePourTraitementReliquat(DemandeSpec demandeSuivantePourTraitementReliquat)
  {
    this.demandeSuivantePourTraitementReliquat = demandeSuivantePourTraitementReliquat;
  }
  
  public String determinerCodeSousProduitPourSigma()
  {
    return ((ProduitAsuSpec)getProduit()).determinerCodeSousProduitPourSigma(this);
  }
  
  public Quantite getDureeIndemnisationEffective()
  {
    if (getConstitutionDurees() != null) {
      return getConstitutionDurees().getDureeEffective();
    }
    return null;
  }
  
  public Damj getPremierJourIndemnisable()
  {
    return getConstitutionPointDepartIndemnisation().getPointDepartIndemnisation();
  }
  
  public Damj getDateLimiteIndemnisation()
  {
    Damj dateLimite = null;
    if (getConstitutionElementsActifs().getConstitutionDateLimiteIndemnisation() != null) {
      dateLimite = getConstitutionElementsActifs().getConstitutionDateLimiteIndemnisation().getDateLimiteIndemnisation();
    }
    return dateLimite;
  }
  
  public AttributionAssuranceSpec getAttributionFinancement()
  {
    return null;
  }
  
  public int getBassinEmploi()
  {
    return 0;
  }
  
  public boolean estPresenceDiffere()
  {
    ConstitutionDelaisReport constitutionDelaisReport = getConstitutionDelaisReport();
    if (constitutionDelaisReport != null)
    {
      Collection collectionCarences = constitutionDelaisReport.getCollectionCarence();
      Iterator iterateurC = collectionCarences.iterator();
      while (iterateurC.hasNext()) {
        if ((iterateurC.next() instanceof Differe)) {
          return true;
        }
      }
    }
    return false;
  }
  
  public BigDecimal getCumulMoisActiviteReduite()
  {
    return null;
  }
  
  public MaintienEuropeen getMaintienEuropeen()
  {
    if (maintienEuropeen == null) {
      maintienEuropeen = MaintienEuropeen.getInstanceMaintienEuropeen(this);
    }
    return maintienEuropeen;
  }
  
  public BigDecimal getNbJoursIccp()
  {
    BigDecimal jours = null;
    if (getConstitutionDelaisReport() != null) {
      jours = new BigDecimal(getConstitutionDelaisReport().getNbJoursCarenceStandard());
    }
    return jours;
  }
  
  public BigDecimal getSeuilMensuelPansConservees()
  {
    throw new UnsupportedOperationException();
  }
  
  public DemandeSpec getDemandeMontantRetenu()
  {
    return getDemande();
  }
  
  public Damj getDateEffetDecision()
  {
    return getDateAttribution();
  }
  
  public int getTypeMontantRetenu()
  {
    return 1;
  }
  
  public int getTypeCapitalRetenu()
  {
    return 1;
  }
  
  public AttributionAssuranceSpec rechercherAttributionPrecedenteDuMemeType()
  {
    AttributionAssuranceSpec attributionPrecedente = getAttributionPrecedente();
    if (attributionPrecedente == null) {
      attributionPrecedente = super.rechercherAttributionPrecedenteDuMemeType();
    }
    return attributionPrecedente;
  }
  
  public fr.unedic.cali.asu.dom.OdAssuranceSpec rechercherOuvertureDroitPrecedenteDuMemeType()
  {
    fr.unedic.cali.asu.dom.OdAssuranceSpec odAssuranceSpec = (fr.unedic.cali.asu.dom.OdAssuranceSpec)getOuvertureDroit();
    if ((odAssuranceSpec == null) || (getAttributionPrecedente() == null)) {
      odAssuranceSpec = super.rechercherOuvertureDroitPrecedenteDuMemeType();
    }
    return odAssuranceSpec;
  }
  
  public Collection getListePensionInvalidite()
  {
    return getConstitutionMontantsBruts().getListePensionInvalidite();
  }
  
  public boolean notifierEESSI()
  {
    return OutilGestionEESSI.getInstance().estAttributionAssuranceFrontaliere(this);
  }
  
  public Quantite getMontantJournalierBrut()
  {
    return getConstitutionElementsActifs().getConstitutionMontantsBruts().getMontantJournalierBrut();
  }
  
  public DemandeMaintien getDemandeMaintien()
  {
    return getDemandeAssurance().getDemandeMaintien();
  }
  
  public SalaireJournalierSpec getSalaireJournalierInitial()
  {
    if (getConstitutionSalaireJournalierMoyen() != null)
    {
      BigDecimal montant = null;
      if (getConstitutionSalaireJournalierMoyen().getMontantSalaireJournalierMoyenInitial() != null) {
        montant = getConstitutionSalaireJournalierMoyen().getMontantSalaireJournalierMoyenInitial().getValeur();
      }
      return new Sjm(montant, getConstitutionSalaireJournalierMoyen().getDateSalaireJournalierMoyenInitial());
    }
    return null;
  }
  
  public SalaireJournalierSpec getSalaireJournalierConserve()
  {
    return null;
  }
  
  public Boolean estAvecPrecompteCRC()
  {
    Attribution attributionOrigine = (Attribution)getOuvertureDroit();
    Damj dateAttribution = attributionOrigine.getDateAttribution();
    if (getDemandeAssurance().estUneDemandeAps())
    {
      if (dateAttribution.estApresOuCoincideAvec(RecuperationElementIndemnisation.DATE_PRISE_EN_COMPTE_CRC_APS)) {
        return Boolean.FALSE;
      }
      return Boolean.TRUE;
    }
    return null;
  }
  
  public BigDecimal getCoefficientSaisonnier()
  {
    BigDecimal coefficientSaisonnier = new BigDecimal("1");
    return coefficientSaisonnier;
  }
  
  public int getNatureCoefficientSaisonnier()
  {
    return -1;
  }
  
  public boolean a3ansActiviteEn5ans()
  {
    return false;
  }
  
  public BigDecimal getCoefficientTempsPartiel()
  {
    return new BigDecimal("1");
  }
  
  public boolean estSjrBaseSmic()
  {
    return isTopContratsRemuneresBaseSmic();
  }
  
  public int getCategorieEmploiA2B()
  {
    return 0;
  }
  
  public Quantite getMontantPreavis()
  {
    return null;
  }
  
  public Quantite getCapitalAServir()
  {
    Quantite retour = null;
    if (getConstitutionMontantsBruts() != null) {
      retour = getConstitutionMontantsBruts().getCapitalInitialBrut();
    }
    return retour;
  }
  
  public ReglementApplicableSpec getReglementApplicableMontantRetenu()
  {
    return getReglementApplicable();
  }
  
  public void viderCacheElementsChomageSansRupture() {}
  
  public ProduitSpec getProduitExecution()
  {
    return getProduit();
  }
  
  public Quantite getDiffereStandard(DemandeSpec demande, BigDecimal remuneration)
    throws PasAssezInformationException
  {
    return ((FacadeLiquidationProduitAsuSpectacleSpec)getProduit()).getDiffereStandard(demande, remuneration);
  }
  
  public Damj getDateFinACT()
  {
    return dateFinACT;
  }
  
  public void setDateFinACT(Damj dateFinACT)
  {
    this.dateFinACT = dateFinACT;
  }
  
  public Collection<CarencePrefixeAFixer> getCarencesForces()
  {
    if (carencesForcees == null) {
      carencesForcees = new ArrayList();
    }
    return carencesForcees;
  }
  
  public Collection<CarencePrefixeAFixer> getCarencesReliquat()
  {
    if (carencesReliquat == null) {
      carencesReliquat = new ArrayList();
    }
    return carencesReliquat;
  }
  
  public void ajouterCarenceForce(CarencePrefixeAFixer carencePrefixeAFixer)
  {
    getCarencesForces().add(carencePrefixeAFixer);
  }
  
  public void ajouterCarenceReliquat(CarencePrefixeAFixer carencePrefixeAFixer)
  {
    getCarencesReliquat().add(carencePrefixeAFixer);
  }
  
  public void viderCarencesForcees()
  {
    carencesForcees = null;
  }
  
  public boolean estAImputerReliquatAct()
  {
    return aImputerReliquatAct;
  }
  
  public void setAImputerReliquatAct(boolean imputerReliquatAct)
  {
    aImputerReliquatAct = imputerReliquatAct;
  }
  
  public int getCumulJourAct()
  {
    return cumulJourAct;
  }
  
  public void setCumulJourAct(int cumulJourAct)
  {
    this.cumulJourAct = cumulJourAct;
  }
  
  public Damj getDateFinAvant()
  {
    return dateFinAvant;
  }
  
  public void setDateFinAvant(Damj dateFinAvant)
  {
    this.dateFinAvant = dateFinAvant;
  }
  
  public Damj getDateFinAct()
  {
    return dateFinAct;
  }
  
  public void setDateFinAct(Damj dateFinAct)
  {
    this.dateFinAct = dateFinAct;
  }
  
  public String getContexteDateLimiteIndemnisation()
  {
    return null;
  }
  
  public Damj getDateDebutDelaiDecheance()
  {
    return getOuvertureDroit().getDateAttribution();
  }
  
  public Quantite getDureeTheoriquePourDelaiDecheance()
  {
    return ((AttributionAssuranceSpec)getOuvertureDroit()).getDureeTheorique();
  }
  
  public AttributionAssuranceSpec getAttributionAssociee()
  {
    Demande demande = (Demande)getDemande();
    if ((demande.getDonneesDemandeAssociee() != null) && (demande.getDonneesDemandeAssociee().getDemandeAssociee() != null) && (demande.getDonneesDemandeAssociee().getDemandeAssociee().getAttribution() != null))
    {
      Demande demandeAssociee = demande.getDonneesDemandeAssociee().getDemandeAssociee();
      return demandeAssociee.getAttribution();
    }
    return null;
  }
  
  protected MaintienEuropeen getMaintienEuropeenPrive()
  {
    return maintienEuropeen;
  }
  
  protected void setMaintienEuropeenPrive(MaintienEuropeen maintienEuropeen)
  {
    this.maintienEuropeen = maintienEuropeen;
  }
}

/* Location:
 * Qualified Name:     Attribution
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */