package fr.unedic.cali.asu.spe02.p03.liquidation.dom;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.DecisionAssuranceSpec;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.JustificationAffiliationSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.gen.RepriseGen;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.MaintienEuropeen;
import fr.unedic.cali.dom.RepriseSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.outilsfonctionnels.AppelAvant;
import fr.unedic.cali.parcours.ResultatAvant;
import fr.unedic.cali.util.OutilDomToString;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.ObjetChronoPeriode;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.List;

public class Reprise
  extends RepriseGen
  implements RepriseSpec
{
  private static final long serialVersionUID = 8616719722292033265L;
  
  public Reprise(DomPCSpec pc)
  {
    super(pc);
  }
  
  public Reprise() {}
  
  public Reprise(Damj dateEvenement)
  {
    super(dateEvenement);
  }
  
  public String getRsrp()
  {
    return getReferenceExterne();
  }
  
  public String getSituationParticuliere()
  {
    String situationParticuliere = "";
    if (getAttributionPrecedente() != null) {
      situationParticuliere = getAttributionPrecedente().getSituationParticuliere();
    }
    return situationParticuliere;
  }
  
  public String getRsod()
  {
    String rsod = "0";
    if (getAttributionPrecedente() != null) {
      rsod = getAttributionPrecedente().getRsod();
    }
    return rsod;
  }
  
  public ObjetMetierSpec copie()
  {
    Reprise copie = new Reprise();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec copieobjet)
  {
    Reprise copie = (Reprise)copieobjet;
    super.copieElements(copie);
  }
  
  public ConstitutionNbHeuresTravaillees getConstitutionNbHeuresTravaillees()
  {
    ConstitutionNbHeuresTravaillees constitutionNbHeuresTravaillees = null;
    if (getAttributionPrecedente() != null) {
      constitutionNbHeuresTravaillees = ((Attribution)getAttributionPrecedente()).getConstitutionNbHeuresTravaillees();
    }
    return constitutionNbHeuresTravaillees;
  }
  
  public ConstitutionSalaireReference getConstitutionSalaireReference()
  {
    ConstitutionSalaireReference constitutionSalaireReference = null;
    if (getAttributionPrecedente() != null) {
      constitutionSalaireReference = ((Attribution)getAttributionPrecedente()).getConstitutionSalaireReference();
    }
    return constitutionSalaireReference;
  }
  
  public ReglementApplicableSpec getConstitutionReglementApplicable()
  {
    ReglementApplicableSpec reglement = null;
    if (getAttributionPrecedente() != null) {
      reglement = getAttributionPrecedente().getReglementApplicable();
    }
    return reglement;
  }
  
  public Damj getDateFaitGenerateur()
  {
    Damj dateRetour = null;
    AttributionAssuranceSpec attributionAssurancePrecedente = getAttributionPrecedente();
    if (attributionAssurancePrecedente != null) {
      dateRetour = attributionAssurancePrecedente.getDateFaitGenerateur();
    }
    return dateRetour;
  }
  
  public JustificationAffiliationSpec getJustificationAffiliation()
  {
    return null;
  }
  
  public ConstitutionSalaireJournalierMoyen getConstitutionSalaireJournalierMoyen()
  {
    ConstitutionSalaireJournalierMoyen constitutionSalaireJournalierMoyen = null;
    if (getAttributionPrecedente() != null) {
      constitutionSalaireJournalierMoyen = ((Attribution)getAttributionPrecedente()).getConstitutionSalaireJournalierMoyen();
    }
    return constitutionSalaireJournalierMoyen;
  }
  
  public ValidationProduit getValidationProduit()
  {
    ValidationProduit validationProduit = null;
    if (getAttributionPrecedente() != null) {
      validationProduit = ((Attribution)getAttributionPrecedente()).getValidationProduit();
    }
    return validationProduit;
  }
  
  public boolean isInvestigationFraude()
  {
    if (getAttributionPrecedente() == null) {
      return false;
    }
    return getAttributionPrecedente().isInvestigationFraude();
  }
  
  public AttributionSpec getAttributionMaitre()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getAttributionMaitre();
    }
    return null;
  }
  
  public AttributionAssuranceSpec getAttributionOrigine()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getAttributionOrigine();
    }
    return null;
  }
  
  public ConditionBeneficeAutreProduit getConditionBeneficeAutreProduit()
  {
    ConditionBeneficeAutreProduit conditionBeneficeAutreProduit = null;
    if (getAttributionPrecedente() != null) {
      conditionBeneficeAutreProduit = ((Attribution)getAttributionPrecedente()).getConditionBeneficeAutreProduit();
    }
    return conditionBeneficeAutreProduit;
  }
  
  public String toString()
  {
    return OutilDomToString.toString(this);
  }
  
  public ProduitAsuSpec getProduitMontantRetenu()
  {
    return getAttributionPrecedente().getProduitMontantRetenu();
  }
  
  public FormuleMontantSpec getFormuleMontant(String code)
  {
    return getProduitMontantRetenu().getFormuleMontant(code);
  }
  
  public boolean isTopContratsRemuneresBaseSmic()
  {
    return false;
  }
  
  public Damj getDateFaitGenerateurDroit()
  {
    return getAttributionPrecedente().getDateFaitGenerateurDroit();
  }
  
  public MaintienEuropeen getMaintienEuropeen()
  {
    if ((getMaintienEuropeenPrive() == null) && (getAttributionPrecedente() != null)) {
      if (getAttributionPrecedente().getMaintienEuropeen() == null) {
        setMaintienEuropeenPrive(MaintienEuropeen.getInstanceMaintienEuropeen(this));
      } else {
        setMaintienEuropeenPrive(getAttributionPrecedente().getMaintienEuropeen());
      }
    }
    return getMaintienEuropeenPrive();
  }
  
  public boolean estMaintenue()
  {
    if (getOuvertureDroit().getNatureDecision() == 38) {
      return ((fr.unedic.cali.asu.dom.OdAssuranceSpec)getOuvertureDroit()).estMaintenue();
    }
    return super.estMaintenue();
  }
  
  public fr.unedic.cali.dom.OdAssuranceSpec getOuvertureDroit()
  {
    fr.unedic.cali.dom.OdAssuranceSpec ouvertureDeDroit = null;
    AttributionAssuranceSpec attributionPrecedente = getAttributionPrecedente();
    if (attributionPrecedente == null) {
      attributionPrecedente = getDemandeAssurance().rechercherAttributionPrecedenteDuMemeType();
    }
    if (attributionPrecedente != null) {
      ouvertureDeDroit = attributionPrecedente.getOuvertureDroit();
    }
    return ouvertureDeDroit;
  }
  
  public fr.unedic.cali.asu.dom.OdAssuranceSpec getOuvertureDroitCapitalRetenu()
  {
    fr.unedic.cali.asu.dom.OdAssuranceSpec ouvertureDeDroit = null;
    AttributionAssuranceSpec attributionPrecedente = getAttributionPrecedente();
    if (attributionPrecedente == null) {
      attributionPrecedente = getDemandeAssurance().rechercherOuvertureDroitPrecedenteDuMemeType();
    }
    if (attributionPrecedente != null) {
      ouvertureDeDroit = attributionPrecedente.getOuvertureDroitCapitalRetenu();
    }
    return ouvertureDeDroit;
  }
  
  public boolean estDemandeSuiteFinDeDroit()
  {
    return (getAttributionPrecedente() != null) && (getAttributionPrecedente().estDemandeSuiteFinDeDroit());
  }
  
  public Collection getListePensionInvalidite()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getListePensionInvalidite();
    }
    return null;
  }
  
  public ReglementApplicableSpec getReglementApplicableMontantRetenu()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getReglementApplicableMontantRetenu();
    }
    return null;
  }
  
  public ResultatAvant determinationEtatACT()
    throws CoucheLogiqueException
  {
    ResultatAvant resultatAvant = null;
    Attribution attributionPrecedente = (Attribution)getAttributionPrecedente();
    if (!attributionPrecedente.getCarencesReliquat().isEmpty())
    {
      ResultatAvant etatAct = null;
      if ((attributionPrecedente.getDateFinAct() != null) || (attributionPrecedente.getDateFinAvant() != null)) {
        etatAct = new ResultatAvant(null, (List)attributionPrecedente.getCarencesReliquat(), false);
      } else {
        etatAct = attributionPrecedente.determinationEtatACT();
      }
      miseAjourCarencesEtatACT(etatAct.getListeCarencesEffectives());
      try
      {
        resultatAvant = AppelAvant.executerCalculDeterminationEtatAvantSansDate(this);
      }
      catch (ApplicativeException ex)
      {
        throw new CoucheLogiqueException(ex.getCode());
      }
      viderCarencesForcees();
      
      setDateFinAct(resultatAvant.getPji());
      setDateFinAvant(resultatAvant.getDernierJourAvant().lendemain());
      for (Object ca : resultatAvant.getListeCarencesEffectives()) {
        if (((CarencePrefixeAFixer)ca).getReliquat().getValeur().signum() == 1) {
          ajouterCarenceReliquat((CarencePrefixeAFixer)ca);
        }
      }
    }
    return resultatAvant;
  }
  
  private void miseAjourCarencesEtatACT(List<?> listeCarencesEffectives)
  {
    CarencePrefixeAFixer cpaf = null;
    for (Object ca : listeCarencesEffectives)
    {
      if ((ca instanceof CarenceIslr))
      {
        cpaf = new CarenceIslr();
        cpaf = (CarencePrefixeAFixer)((CarenceIslr)ca).copie();
      }
      if ((ca instanceof PreavisMesureConservatoireIndemnisable))
      {
        cpaf = new PreavisMesureConservatoireIndemnisable();
        cpaf = (CarencePrefixeAFixer)((PreavisMesureConservatoireIndemnisable)ca).copie();
      }
      if ((ca instanceof PreavisMesureConservatoireNonIndemnisable))
      {
        cpaf = new PreavisMesureConservatoireNonIndemnisable();
        cpaf = (CarencePrefixeAFixer)((PreavisMesureConservatoireNonIndemnisable)ca).copie();
      }
      if ((ca instanceof CarenceStandard))
      {
        cpaf = new CarenceStandard();
        cpaf = (CarencePrefixeAFixer)((CarenceStandard)ca).copie();
      }
      if ((ca instanceof Differe))
      {
        cpaf = new Differe();
        cpaf = (CarencePrefixeAFixer)((Differe)ca).copie();
        cpaf.setReliquat(((CarencePrefixeAFixer)ca).getReliquat());
        cpaf.setOrigineReliquat(((CarencePrefixeAFixer)ca).getOrigineReliquat());
      }
      cpaf.setQuantiteInitiale(((CarencePrefixeAFixer)ca).getReliquat());
      if (cpaf.getOrigineReliquat() != null) {
        cpaf.setDateFinPeriodeOrigine(cpaf.getOrigineReliquat().getDateFin());
      }
      ajouterCarenceForce(cpaf);
    }
  }
  
  public Damj getDateDebutDelaiDecheance()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getDateDebutDelaiDecheance();
    }
    return null;
  }
  
  public ElementBaseIndemnisation getElementBaseIndemnisation()
  {
    ElementBaseIndemnisation ebi = super.getElementBaseIndemnisation();
    if (getAttributionPrecedente() != null)
    {
      ElementBaseIndemnisation ebiPrecedent = getAttributionPrecedente().getElementBaseIndemnisation();
      ebi.setMontantBrut(ebiPrecedent.getMontantBrut());
      ebi.setMontantBrutPrecompte(ebiPrecedent.getMontantBrutPrecompte());
    }
    return ebi;
  }
}

/* Location:
 * Qualified Name:     Reprise
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */