package fr.unedic.cali.asu.spe02.p03.liquidation.dom.gen;

import fr.unedic.archi.commun.exception.TechniqueException;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConditionAdhesionDispositif;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConditionAge;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConditionChomageInvolontaire;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConditionCumulPrestationFamiliale;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConditionMontantNonNul;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConditionRechercheEmploi;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConditionValiditeReliquat;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.pc.ConditionsAttributionReprisePC;
import fr.unedic.cali.dom.ConditionsAttributionAbstrait;
import fr.unedic.transverse.dom.ContexteSuppressionEnProfondeur;
import fr.unedic.transverse.dom.spec.DomGenSpec;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.ApplicativeRuntimeException;

public abstract class ConditionsAttributionRepriseGen
  extends ConditionsAttributionAbstrait
  implements DomGenSpec
{
  protected transient DomPCSpec m_conditionsAttributionReprisePC;
  private transient ConditionRechercheEmploi m_conditionRechercheEmploi = null;
  private transient ConditionAdhesionDispositif m_conditionAdhesionDispositif = null;
  private transient ConditionAge m_conditionAge = null;
  private transient ConditionChomageInvolontaire m_conditionChomageInvolontaire = null;
  private transient ConditionCumulPrestationFamiliale m_conditionCumulPrestationFamiliale = null;
  private transient ConditionMontantNonNul m_conditionMontantNonNul = null;
  private transient ConditionValiditeReliquat m_conditionValiditeReliquat = null;
  
  public ConditionsAttributionRepriseGen(DomPCSpec p_pc)
  {
    setPC(p_pc);
  }
  
  public ConditionsAttributionRepriseGen()
  {
    setPC(createPC());
  }
  
  protected DomPCSpec createPC()
  {
    return new ConditionsAttributionReprisePC();
  }
  
  public DomPCSpec getPC()
  {
    return m_conditionsAttributionReprisePC;
  }
  
  public Object getGenericPC()
  {
    return getPC();
  }
  
  public void setPC(DomPCSpec p_conditionsAttributionReprisePC)
  {
    m_conditionsAttributionReprisePC = p_conditionsAttributionReprisePC;
  }
  
  public void supprimerEnProfondeur(ContexteSuppressionEnProfondeur p_contexteSuppression)
    throws TechniqueException
  {
    p_contexteSuppression.addElementEnCoursDeSuppression(this);
    if (getConditionRechercheEmploi() != null)
    {
      getConditionRechercheEmploi().supprimerEnProfondeur(p_contexteSuppression);
      m_conditionRechercheEmploi = null;
    }
    if (getConditionAdhesionDispositif() != null)
    {
      getConditionAdhesionDispositif().supprimerEnProfondeur(p_contexteSuppression);
      m_conditionAdhesionDispositif = null;
    }
    if (getConditionAge() != null)
    {
      getConditionAge().supprimerEnProfondeur(p_contexteSuppression);
      m_conditionAge = null;
    }
    if (getConditionChomageInvolontaire() != null)
    {
      getConditionChomageInvolontaire().supprimerEnProfondeur(p_contexteSuppression);
      m_conditionChomageInvolontaire = null;
    }
    if (getConditionCumulPrestationFamiliale() != null)
    {
      getConditionCumulPrestationFamiliale().supprimerEnProfondeur(p_contexteSuppression);
      m_conditionCumulPrestationFamiliale = null;
    }
    if (getConditionMontantNonNul() != null)
    {
      getConditionMontantNonNul().supprimerEnProfondeur(p_contexteSuppression);
      m_conditionMontantNonNul = null;
    }
    if (getConditionValiditeReliquat() != null)
    {
      getConditionValiditeReliquat().supprimerEnProfondeur(p_contexteSuppression);
      m_conditionValiditeReliquat = null;
    }
  }
  
  public ConditionRechercheEmploi getConditionRechercheEmploi()
  {
    if ((((ConditionsAttributionReprisePC)getPC()).isPresenceDonneesConditionRechercheEmploi()) && (m_conditionRechercheEmploi == null)) {
      m_conditionRechercheEmploi = new ConditionRechercheEmploi(getPC());
    }
    return m_conditionRechercheEmploi;
  }
  
  public ConditionRechercheEmploi createConditionRechercheEmploi()
  {
    ((ConditionsAttributionReprisePC)getPC()).setPresenceDonneesConditionRechercheEmploi(true);
    if (m_conditionRechercheEmploi == null) {
      m_conditionRechercheEmploi = new ConditionRechercheEmploi(getPC());
    }
    try
    {
      m_conditionRechercheEmploi.initEnProfondeur();
    }
    catch (TechniqueException e)
    {
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_GENERIQUE", "Erreur inconnue dans l'exécution de l'application", e);
    }
    return m_conditionRechercheEmploi;
  }
  
  public void removeConditionRechercheEmploi()
  {
    try
    {
      m_conditionRechercheEmploi.initEnProfondeur();
    }
    catch (TechniqueException e)
    {
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_GENERIQUE", "Erreur inconnue dans l'exécution de l'application", e);
    }
    ((ConditionsAttributionReprisePC)getPC()).setPresenceDonneesConditionRechercheEmploi(false);
  }
  
  public ConditionAdhesionDispositif getConditionAdhesionDispositif()
  {
    if ((((ConditionsAttributionReprisePC)getPC()).isPresenceDonneesConditionAdhesionDispositif()) && (m_conditionAdhesionDispositif == null)) {
      m_conditionAdhesionDispositif = new ConditionAdhesionDispositif(getPC());
    }
    return m_conditionAdhesionDispositif;
  }
  
  public ConditionAdhesionDispositif createConditionAdhesionDispositif()
  {
    ((ConditionsAttributionReprisePC)getPC()).setPresenceDonneesConditionAdhesionDispositif(true);
    if (m_conditionAdhesionDispositif == null) {
      m_conditionAdhesionDispositif = new ConditionAdhesionDispositif(getPC());
    }
    try
    {
      m_conditionAdhesionDispositif.initEnProfondeur();
    }
    catch (TechniqueException e)
    {
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_GENERIQUE", "Erreur inconnue dans l'exécution de l'application", e);
    }
    return m_conditionAdhesionDispositif;
  }
  
  public void removeConditionAdhesionDispositif()
  {
    try
    {
      m_conditionAdhesionDispositif.initEnProfondeur();
    }
    catch (TechniqueException e)
    {
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_GENERIQUE", "Erreur inconnue dans l'exécution de l'application", e);
    }
    ((ConditionsAttributionReprisePC)getPC()).setPresenceDonneesConditionAdhesionDispositif(false);
  }
  
  public ConditionAge getConditionAge()
  {
    if ((((ConditionsAttributionReprisePC)getPC()).isPresenceDonneesConditionAge()) && (m_conditionAge == null)) {
      m_conditionAge = new ConditionAge(getPC());
    }
    return m_conditionAge;
  }
  
  public ConditionAge createConditionAge()
  {
    ((ConditionsAttributionReprisePC)getPC()).setPresenceDonneesConditionAge(true);
    if (m_conditionAge == null) {
      m_conditionAge = new ConditionAge(getPC());
    }
    try
    {
      m_conditionAge.initEnProfondeur();
    }
    catch (TechniqueException e)
    {
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_GENERIQUE", "Erreur inconnue dans l'exécution de l'application", e);
    }
    return m_conditionAge;
  }
  
  public void removeConditionAge()
  {
    try
    {
      m_conditionAge.initEnProfondeur();
    }
    catch (TechniqueException e)
    {
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_GENERIQUE", "Erreur inconnue dans l'exécution de l'application", e);
    }
    ((ConditionsAttributionReprisePC)getPC()).setPresenceDonneesConditionAge(false);
  }
  
  public ConditionChomageInvolontaire getConditionChomageInvolontaire()
  {
    if ((((ConditionsAttributionReprisePC)getPC()).isPresenceDonneesConditionChomageInvolontaire()) && (m_conditionChomageInvolontaire == null)) {
      m_conditionChomageInvolontaire = new ConditionChomageInvolontaire(getPC());
    }
    return m_conditionChomageInvolontaire;
  }
  
  public ConditionChomageInvolontaire createConditionChomageInvolontaire()
  {
    ((ConditionsAttributionReprisePC)getPC()).setPresenceDonneesConditionChomageInvolontaire(true);
    if (m_conditionChomageInvolontaire == null) {
      m_conditionChomageInvolontaire = new ConditionChomageInvolontaire(getPC());
    }
    try
    {
      m_conditionChomageInvolontaire.initEnProfondeur();
    }
    catch (TechniqueException e)
    {
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_GENERIQUE", "Erreur inconnue dans l'exécution de l'application", e);
    }
    return m_conditionChomageInvolontaire;
  }
  
  public void removeConditionChomageInvolontaire()
  {
    try
    {
      m_conditionChomageInvolontaire.initEnProfondeur();
    }
    catch (TechniqueException e)
    {
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_GENERIQUE", "Erreur inconnue dans l'exécution de l'application", e);
    }
    ((ConditionsAttributionReprisePC)getPC()).setPresenceDonneesConditionChomageInvolontaire(false);
  }
  
  public ConditionCumulPrestationFamiliale getConditionCumulPrestationFamiliale()
  {
    if ((((ConditionsAttributionReprisePC)getPC()).isPresenceDonneesConditionCumulPrestationFamiliale()) && (m_conditionCumulPrestationFamiliale == null)) {
      m_conditionCumulPrestationFamiliale = new ConditionCumulPrestationFamiliale(getPC());
    }
    return m_conditionCumulPrestationFamiliale;
  }
  
  public ConditionCumulPrestationFamiliale createConditionCumulPrestationFamiliale()
  {
    ((ConditionsAttributionReprisePC)getPC()).setPresenceDonneesConditionCumulPrestationFamiliale(true);
    if (m_conditionCumulPrestationFamiliale == null) {
      m_conditionCumulPrestationFamiliale = new ConditionCumulPrestationFamiliale(getPC());
    }
    try
    {
      m_conditionCumulPrestationFamiliale.initEnProfondeur();
    }
    catch (TechniqueException e)
    {
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_GENERIQUE", "Erreur inconnue dans l'exécution de l'application", e);
    }
    return m_conditionCumulPrestationFamiliale;
  }
  
  public void removeConditionCumulPrestationFamiliale()
  {
    try
    {
      m_conditionCumulPrestationFamiliale.initEnProfondeur();
    }
    catch (TechniqueException e)
    {
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_GENERIQUE", "Erreur inconnue dans l'exécution de l'application", e);
    }
    ((ConditionsAttributionReprisePC)getPC()).setPresenceDonneesConditionCumulPrestationFamiliale(false);
  }
  
  public ConditionMontantNonNul getConditionMontantNonNul()
  {
    if ((((ConditionsAttributionReprisePC)getPC()).isPresenceDonneesConditionMontantNonNul()) && (m_conditionMontantNonNul == null)) {
      m_conditionMontantNonNul = new ConditionMontantNonNul(getPC());
    }
    return m_conditionMontantNonNul;
  }
  
  public ConditionMontantNonNul createConditionMontantNonNul()
  {
    ((ConditionsAttributionReprisePC)getPC()).setPresenceDonneesConditionMontantNonNul(true);
    if (m_conditionMontantNonNul == null) {
      m_conditionMontantNonNul = new ConditionMontantNonNul(getPC());
    }
    try
    {
      m_conditionMontantNonNul.initEnProfondeur();
    }
    catch (TechniqueException e)
    {
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_GENERIQUE", "Erreur inconnue dans l'exécution de l'application", e);
    }
    return m_conditionMontantNonNul;
  }
  
  public void removeConditionMontantNonNul()
  {
    try
    {
      m_conditionMontantNonNul.initEnProfondeur();
    }
    catch (TechniqueException e)
    {
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_GENERIQUE", "Erreur inconnue dans l'exécution de l'application", e);
    }
    ((ConditionsAttributionReprisePC)getPC()).setPresenceDonneesConditionMontantNonNul(false);
  }
  
  public ConditionValiditeReliquat getConditionValiditeReliquat()
  {
    if (m_conditionValiditeReliquat == null) {
      m_conditionValiditeReliquat = new ConditionValiditeReliquat(getPC());
    }
    return m_conditionValiditeReliquat;
  }
  
  public ConditionValiditeReliquat createConditionValiditeReliquat()
  {
    if (m_conditionValiditeReliquat == null) {
      m_conditionValiditeReliquat = new ConditionValiditeReliquat(getPC());
    }
    try
    {
      m_conditionValiditeReliquat.initEnProfondeur();
    }
    catch (TechniqueException e)
    {
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_GENERIQUE", "Erreur inconnue dans l'exécution de l'application", e);
    }
    return m_conditionValiditeReliquat;
  }
  
  public void removeConditionValiditeReliquat()
  {
    try
    {
      m_conditionValiditeReliquat.initEnProfondeur();
    }
    catch (TechniqueException e)
    {
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_GENERIQUE", "Erreur inconnue dans l'exécution de l'application", e);
    }
  }
  
  public void copieElements(ObjetMetierSpec p_copie) {}
}

/* Location:
 * Qualified Name:     ConditionsAttributionRepriseGen
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */