package fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation;

import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ActiviteParticipante;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.AffiliationAssimilee;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.AffiliationSupplementaire;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.AllongementPra;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.PeriodeElementaireAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.ComportementAffiliationSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.JustifierAffiliationSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Entreprise;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeEvenementPersonnel;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeFormationAssimilable;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeMesureActivite;
import fr.unedic.cali.autresdoms.ga.dom.spec.IncidentSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.SalarieSpec;
import fr.unedic.cali.outilsfonctionnels.OutilActiviteSalarie;
import fr.unedic.util.Convertisseur;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

public class JustifierAffiliation
  implements JustifierAffiliationSpec
{
  protected static final Unite UNITE_HEURE = CalculAppartenance.UNITE_HEURE;
  protected static final Quantite ZERO = CalculAppartenance.ZERO;
  
  protected ActiviteParticipante creerActiviteParticipante()
  {
    return new ActiviteParticipante();
  }
  
  private AffiliationSupplementaire creerAffiliationSupplementaire()
  {
    return new AffiliationSupplementaire();
  }
  
  private AffiliationAssimilee creerAssimilation()
  {
    return new AffiliationAssimilee();
  }
  
  private AllongementPra creerAllongementPra()
  {
    return new AllongementPra();
  }
  
  public void ajouterAllongementPra(List p_listeAllongementPra, DureeCalendaire p_duree, int p_nature, Periode p_periode)
  {
    if (p_listeAllongementPra != null)
    {
      AllongementPra allongement = creerAllongementPra();
      allongement.setDuree(p_duree);
      allongement.setNature(p_nature);
      allongement.setPeriodeActivite(p_periode);
      p_listeAllongementPra.add(allongement);
    }
  }
  
  public void augmenterPeriodeAllongementPra(AllongementPra p_allongement, int p_nombreJoursTotalARetenir)
  {
    if ((p_allongement != null) && (p_nombreJoursTotalARetenir != 0))
    {
      DureeCalendaire nouvelleDuree = p_allongement.getDuree().ajouter(new DureeCalendaire(0, 0, p_nombreJoursTotalARetenir));
      p_allongement.setDuree(nouvelleDuree);
    }
  }
  
  public AllongementPra trouverAllongementPourPeriodeEvenementPersonnel(List p_listeAllongement, PeriodeEvenementPersonnel p_pep)
  {
    if (p_listeAllongement != null)
    {
      Iterator it = p_listeAllongement.iterator();
      while (it.hasNext())
      {
        AllongementPra allongement = (AllongementPra)it.next();
        if (estPepAssocieeAAllongementPRA(p_pep, allongement)) {
          return allongement;
        }
      }
    }
    return null;
  }
  
  public boolean estPepAssocieeAAllongementPRA(PeriodeEvenementPersonnel p_pep, AllongementPra p_allongement)
  {
    int naturePep = NatureAffiliation.determinerNatureActivite(p_pep);
    return (p_allongement.getPeriodeActivite().equals(p_pep.getPeriode())) && (naturePep == p_allongement.getNature());
  }
  
  public void ajouterAllongementPra(JustificationAffiliation p_justification, AllongementPra p_allongement)
  {
    if (p_justification != null) {
      p_justification.ajouterAllongementPra(p_allongement);
    }
  }
  
  public void ajouterPeriodeElementaire(JustificationAffiliation p_justification, PeriodeElementaireAffiliation p_periodeElementaire)
  {
    if ((p_periodeElementaire != null) && (p_justification != null)) {
      p_justification.ajouterPeriodeElementaireAffiliation(p_periodeElementaire);
    }
  }
  
  public void ajouterAffiliationSupplementaire(JustificationAffiliation p_justification, int p_natureAffiliation, Quantite p_quantite)
  {
    if ((p_justification != null) && (!p_quantite.equals(ZERO)))
    {
      AffiliationSupplementaire affiliationSupplementaire = trouverAffiliationSupplementaireAvecNature(p_justification, p_natureAffiliation);
      if (affiliationSupplementaire == null)
      {
        affiliationSupplementaire = creerAffiliationSupplementaire();
        affiliationSupplementaire.setNature(p_natureAffiliation);
        p_justification.ajouterAffiliationSupplementaire(affiliationSupplementaire);
      }
      Quantite quantiteTotal = p_quantite;
      if (affiliationSupplementaire.getQuantite() != null) {
        quantiteTotal = quantiteTotal.ajouter(affiliationSupplementaire.getQuantite());
      }
      affiliationSupplementaire.setQuantite(quantiteTotal);
    }
  }
  
  public void ajouterAssimilation(JustificationAffiliation p_justification, int p_nature, Quantite p_quantite)
  {
    if ((p_justification != null) && (!p_quantite.equals(ZERO)))
    {
      AffiliationAssimilee assimilation = trouverAssimilationAvecNature(p_justification, p_nature);
      if (assimilation == null)
      {
        assimilation = creerAssimilation();
        assimilation.setNature(p_nature);
        p_justification.ajouterAssimilation(assimilation);
      }
      Quantite quantiteTotal = p_quantite;
      if (assimilation.getQuantite() != null) {
        quantiteTotal = quantiteTotal.ajouter(assimilation.getQuantite());
      }
      assimilation.setQuantite(quantiteTotal);
    }
  }
  
  public AffiliationSupplementaire trouverAffiliationSupplementaireAvecNature(JustificationAffiliation p_justification, int p_nature)
  {
    if (p_justification != null)
    {
      Iterator itAffiliationSupplementaire = p_justification.getCollectionAffiliationSupplementaire().iterator();
      while (itAffiliationSupplementaire.hasNext())
      {
        AffiliationSupplementaire affiliationSupplementaire = (AffiliationSupplementaire)itAffiliationSupplementaire.next();
        if (affiliationSupplementaire.getNature() == p_nature) {
          return affiliationSupplementaire;
        }
      }
    }
    return null;
  }
  
  public AffiliationAssimilee trouverAssimilationAvecNature(JustificationAffiliation p_justification, int p_nature)
  {
    if (p_justification != null)
    {
      Iterator itAssimilation = p_justification.getCollectionAssimilation().iterator();
      while (itAssimilation.hasNext())
      {
        AffiliationAssimilee assimilation = (AffiliationAssimilee)itAssimilation.next();
        if (assimilation.getNature() == p_nature) {
          return assimilation;
        }
      }
    }
    return null;
  }
  
  public PeriodeElementaireAffiliation trouverPeriodeElementaireChevauchantDate(JustificationAffiliation p_justification, Damj p_dateRecherche)
  {
    if (p_justification != null)
    {
      Iterator itPeriodesElementaires = p_justification.getCollectionPeriodeElementaireAffiliation().iterator();
      while (itPeriodesElementaires.hasNext())
      {
        PeriodeElementaireAffiliation periodeElementaire = (PeriodeElementaireAffiliation)itPeriodesElementaires.next();
        if (periodeElementaire.getMois().contient(p_dateRecherche)) {
          return periodeElementaire;
        }
      }
    }
    return null;
  }
  
  public void justifierAllongementPeriodeReference(JustificationAffiliation p_justification, List p_listeAllongements)
  {
    if ((p_justification != null) && (p_listeAllongements != null))
    {
      Iterator itAllongementPeriode = p_listeAllongements.iterator();
      while (itAllongementPeriode.hasNext()) {
        ajouterAllongementPra(p_justification, (AllongementPra)itAllongementPeriode.next());
      }
    }
  }
  
  public void justifierAffiliations(ComportementAffiliationSpec p_comportementCalcul, JustificationAffiliation p_justification, Map p_chronologies)
  {
    Convertisseur convertisseurUniteAffiliation = p_comportementCalcul.getConvertisseurUniteAffiliation();
    
    justifierAffiliationBase(p_justification, p_chronologies, convertisseurUniteAffiliation);
    justifierNonExecution(p_justification, p_chronologies);
    justifierSuspension(p_justification, p_chronologies);
    if (p_comportementCalcul.estEnseignementApplicablePourReglement(p_comportementCalcul.getReglementCandidat())) {
      justifierEnseignement(p_justification, p_chronologies, convertisseurUniteAffiliation);
    }
    justifierFormation(p_justification, p_chronologies, convertisseurUniteAffiliation);
    justifierAssimilationMaterniteAdoptionAccidentTravail(p_justification, p_chronologies);
    
    justifierMaladieDansPRA(p_justification, p_chronologies);
  }
  
  protected void justifierAffiliationBase(JustificationAffiliation p_justification, Map p_chronologies, Convertisseur p_convertisseurUniteAffiliation)
  {
    Chronologie chronoPourAffiliationBase = (Chronologie)p_chronologies.get("chronoAffiBase");
    if ((p_justification != null) && (chronoPourAffiliationBase != null))
    {
      Iterator itAffiBase = chronoPourAffiliationBase.iterer();
      while (itAffiBase.hasNext())
      {
        ActiviteSalarie activite = (ActiviteSalarie)itAffiBase.next();
        int natureActivite = NatureAffiliation.determinerNatureActivite(activite);
        ActiviteParticipante activiteParticipante = creerActiviteParticipante();
        activiteParticipante.setNature(natureActivite);
        activiteParticipante.setRaisonSociale(determinerRaisonSociale(activite));
        activiteParticipante.setQuantiteTotaleTravaillee(determinerQuantiteTotaleTravaille(activite, p_convertisseurUniteAffiliation));
        activiteParticipante.setPeriodeActivite(activite.getPeriode());
        
        activiteParticipante.setPresencePNDSSurActivite(activite.isPresencePNDSDetectee());
        p_justification.ajouterActiviteParticipante(activiteParticipante);
      }
    }
  }
  
  protected void justifierSuspension(JustificationAffiliation p_justification, Map p_chronologies)
  {
    Chronologie chronoPourAffiliationSuspension = (Chronologie)p_chronologies.get("chronoAffiSuspension");
    if ((p_justification != null) && (chronoPourAffiliationSuspension != null))
    {
      Iterator itAffiSuspension = chronoPourAffiliationSuspension.iterer();
      int natureActivite = 9;
      while (itAffiSuspension.hasNext())
      {
        IncidentSpec incident = (IncidentSpec)itAffiSuspension.next();
        ActiviteParticipante activiteParticipante = creerActiviteParticipante();
        activiteParticipante.setNature(natureActivite);
        activiteParticipante.setPeriodeActivite(incident.getPeriode());
        int quantiteHeure = ParametresAffiliation.NOMBRE_HEURE_PAR_JOUR_SUSPENSION.intValue() * activiteParticipante.getPeriodeActivite().getDuree();
        
        activiteParticipante.setQuantiteTotaleTravaillee(new Quantite(new BigDecimal(quantiteHeure), UNITE_HEURE));
        p_justification.ajouterActiviteParticipante(activiteParticipante);
      }
    }
  }
  
  protected void justifierNonExecution(JustificationAffiliation p_justification, Map p_chronologies)
  {
    Chronologie chronoPourAffiliationNonExecution = (Chronologie)p_chronologies.get("chronoAffiNonExecution");
    if ((p_justification != null) && (chronoPourAffiliationNonExecution != null))
    {
      Iterator itAffiNonExecution = chronoPourAffiliationNonExecution.iterer();
      int natureActivite = 8;
      while (itAffiNonExecution.hasNext())
      {
        ActiviteSalarie activite = (ActiviteSalarie)itAffiNonExecution.next();
        ActiviteParticipante activiteParticipante = creerActiviteParticipante();
        activiteParticipante.setNature(natureActivite);
        activiteParticipante.setPeriodeActivite(OutilActiviteSalarie.getInstance().determinerPeriodeNonExecution(activite));
        int quantiteHeure = ParametresAffiliation.NOMBRE_HEURE_PAR_JOUR_NON_EXECUTION.intValue() * activiteParticipante.getPeriodeActivite().getDuree();
        
        activiteParticipante.setQuantiteTotaleTravaillee(new Quantite(new BigDecimal(quantiteHeure), UNITE_HEURE));
        p_justification.ajouterActiviteParticipante(activiteParticipante);
      }
    }
  }
  
  protected void justifierEnseignement(JustificationAffiliation p_justification, Map p_chronologies, Convertisseur p_convertisseurUniteAffiliation)
  {
    Chronologie chronoPourAssimilationEnseignant = (Chronologie)p_chronologies.get("chronoAffiEnseignement");
    if ((p_justification != null) && (chronoPourAssimilationEnseignant != null))
    {
      Iterator itAssimEnseignement = chronoPourAssimilationEnseignant.iterer();
      int natureActivite = 7;
      while (itAssimEnseignement.hasNext())
      {
        ActiviteSalarie activite = (ActiviteSalarie)itAssimEnseignement.next();
        ActiviteParticipante activiteParticipante = creerActiviteParticipante();
        activiteParticipante.setNature(natureActivite);
        activiteParticipante.setPeriodeActivite(activite.getPeriode());
        activiteParticipante.setQuantiteTotaleTravaillee(determinerQuantiteTotaleTravaille(activite, p_convertisseurUniteAffiliation));
        activiteParticipante.setRaisonSociale(determinerRaisonSociale(activite));
        
        activiteParticipante.setPresencePNDSSurActivite(activite.isPresencePNDSDetectee());
        p_justification.ajouterActiviteParticipante(activiteParticipante);
      }
    }
  }
  
  protected void justifierFormation(JustificationAffiliation p_justification, Map p_chronologies, Convertisseur p_convertisseurUniteAffiliation)
  {
    Chronologie chronoPourAssimilationFormation = (Chronologie)p_chronologies.get("chronoAffiFormation");
    if ((p_justification != null) && (chronoPourAssimilationFormation != null))
    {
      Iterator itAssimFormation = chronoPourAssimilationFormation.iterer();
      int natureActivite = 6;
      while (itAssimFormation.hasNext())
      {
        PeriodeFormationAssimilable formation = (PeriodeFormationAssimilable)itAssimFormation.next();
        ActiviteParticipante activiteParticipante = creerActiviteParticipante();
        activiteParticipante.setNature(natureActivite);
        activiteParticipante.setPeriodeActivite(formation.getPeriode());
        Enumeration enumQuantiteAppartenance = formation.getListeQuantitesAppartenance().elements();
        Quantite quantiteTotalHeure = ZERO;
        while (enumQuantiteAppartenance.hasMoreElements())
        {
          Quantite quantite = (Quantite)enumQuantiteAppartenance.nextElement();
          Quantite quantiteHeure = null;
          if (quantite.getUnite().equals(UNITE_HEURE)) {
            quantiteHeure = quantite;
          } else {
            quantiteHeure = convertir(p_convertisseurUniteAffiliation, quantite, UNITE_HEURE);
          }
          quantiteTotalHeure = quantiteTotalHeure.ajouter(quantiteHeure);
        }
        activiteParticipante.setQuantiteTotaleTravaillee(quantiteTotalHeure);
        p_justification.ajouterActiviteParticipante(activiteParticipante);
      }
    }
  }
  
  protected void justifierAssimilationMaterniteAdoptionAccidentTravail(JustificationAffiliation p_justification, Map p_chronologies)
  {
    Chronologie chronoPourAssimilationMaterniteAdoptionAccidentTravail = (Chronologie)p_chronologies.get("chronoAffiMaterAdoptionAccTravail");
    if ((p_justification != null) && (chronoPourAssimilationMaterniteAdoptionAccidentTravail != null))
    {
      Iterator itAssimMaterniteAdoptionAccidentTravail = chronoPourAssimilationMaterniteAdoptionAccidentTravail.iterer();
      while (itAssimMaterniteAdoptionAccidentTravail.hasNext())
      {
        PeriodeEvenementPersonnel pep = (PeriodeEvenementPersonnel)itAssimMaterniteAdoptionAccidentTravail.next();
        int natureActivite = NatureAffiliation.determinerNatureActivite(pep);
        ActiviteParticipante activiteParticipante = creerActiviteParticipante();
        activiteParticipante.setNature(natureActivite);
        activiteParticipante.setPeriodeActivite(pep.getPeriode());
        int quantiteHeure = ParametresAffiliation.NOMBRE_HEURE_PAR_JOUR_MATERNITE_ADOPTION_ACCIDENT_TRAVAIL.intValue() * activiteParticipante.getPeriodeActivite().getDuree();
        
        activiteParticipante.setQuantiteTotaleTravaillee(new Quantite(new BigDecimal(quantiteHeure), UNITE_HEURE));
        p_justification.ajouterActiviteParticipante(activiteParticipante);
      }
    }
  }
  
  protected void justifierMaladieDansPRA(JustificationAffiliation p_justification, Map p_chronologies)
  {
    Chronologie chronologieMaladieAffiliationSupplementaire = (Chronologie)p_chronologies.get("chronoMaladieDansPRA");
    if ((p_justification != null) && (chronologieMaladieAffiliationSupplementaire != null))
    {
      Iterator itMaladieAffiliationSupplementaire = chronologieMaladieAffiliationSupplementaire.iterer();
      while (itMaladieAffiliationSupplementaire.hasNext())
      {
        PeriodeEvenementPersonnel pep = (PeriodeEvenementPersonnel)itMaladieAffiliationSupplementaire.next();
        int natureActivite = 10;
        ActiviteParticipante activiteParticipante = creerActiviteParticipante();
        activiteParticipante.setNature(natureActivite);
        activiteParticipante.setPeriodeActivite(pep.getPeriode());
        int quantiteHeure = ParametresAffiliation.NOMBRE_HEURE_PAR_JOUR_SUSPENSION.intValue() * activiteParticipante.getPeriodeActivite().getDuree();
        
        activiteParticipante.setQuantiteTotaleTravaillee(new Quantite(new BigDecimal(quantiteHeure), UNITE_HEURE));
        p_justification.ajouterActiviteParticipante(activiteParticipante);
      }
    }
  }
  
  private String determinerRaisonSociale(ActiviteSalarie p_activite)
  {
    return p_activite.getEntreprise().getLibelleEntreprise();
  }
  
  private Quantite determinerQuantiteTotaleTravaille(SalarieSpec p_activite, Convertisseur p_convertisseurUniteAffiliation)
  {
    Quantite total = new Quantite(new BigDecimal(0), UNITE_HEURE);
    if (p_activite != null)
    {
      Chronologie listePeriodeMesureActivite = p_activite.getListePeriodesMesureActivite();
      Iterator itMesureActivite = listePeriodeMesureActivite.iterer();
      while (itMesureActivite.hasNext())
      {
        PeriodeMesureActivite pma = (PeriodeMesureActivite)itMesureActivite.next();
        Enumeration interQuantiteAffiliation = pma.getListeQuantitesAffiliation().elements();
        while (interQuantiteAffiliation.hasMoreElements())
        {
          Quantite quantiteAppartenance = (Quantite)interQuantiteAffiliation.nextElement();
          Quantite quantiteTravail = null;
          if (quantiteAppartenance.getUnite().equals(UNITE_HEURE)) {
            quantiteTravail = quantiteAppartenance;
          } else {
            quantiteTravail = convertir(p_convertisseurUniteAffiliation, quantiteAppartenance, UNITE_HEURE);
          }
          total = total.ajouter(quantiteTravail);
        }
      }
    }
    return new Quantite(Mathematiques.arrondiASup(total.getValeur(), 0), UNITE_HEURE);
  }
  
  private Quantite convertir(Convertisseur p_convertisseurUniteAffiliation, Quantite p_quantiteOrigine, Unite p_unite)
  {
    return p_convertisseurUniteAffiliation.convertir(p_quantiteOrigine, p_unite);
  }
}

/* Location:
 * Qualified Name:     JustifierAffiliation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */