package fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation;

import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeEvenementPersonnel;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeEvenementPersonnelIndemnisable;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeFormationAssimilable;
import fr.unedic.cali.autresdoms.ga.dom.spec.PeriodeGaecSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.ConstantesEnumeration;
import fr.unedic.util.services.OutilFonctionnel;

public final class NatureAffiliation
  extends ConstantesEnumeration
  implements OutilFonctionnel
{
  private static final NatureAffiliation NATURE_AFFILIATION = new NatureAffiliation();
  public static final int ACTIVITE_A8 = 1;
  public static final String LIB_ACTIVITE_A8 = "Activité A8";
  public static final int ACTIVITE_A10 = 2;
  public static final String LIB_ACTIVITE_A10 = "Activité A10";
  public static final int CONGES_MATERNITE = 3;
  public static final String LIB_CONGES_MATERNITE = "Congés maternité";
  public static final int CONGES_ADOPTION = 4;
  public static final String LIB_CONGES_ADOPTION = "Congés adoption";
  public static final int ACCIDENT_TRAVAIL = 5;
  public static final String LIB_ACCIDENT_TRAVAIL = "Accident du travail";
  public static final int FORMATION = 6;
  public static final String LIB_FORMATION = "Formation";
  public static final int ENSEIGNEMENT_SALARIE = 7;
  public static final String LIB_ENSEIGNEMENT_SALARIE = "Enseignement salarié";
  public static final int PERIODE_NON_EXECUTEE = 8;
  public static final String LIB_PERIODE_NON_EXECUTEE = "CT non exécuté";
  public static final int SUSPENSION = 9;
  public static final String LIB_SUSPENSION = "Suspension";
  public static final int MALADIE = 10;
  public static final String LIB_MALADIE = "Maladie";
  public static final int NATURE_INCONNUE = 11;
  public static final String LIB_NATURE_INCONNUE = "Nature affiliation inconnue";
  public static final int NATURE_MALADIE_LONGUE_DUREE = 12;
  public static final String LIB_NATURE_MALADIE_LONGUE_DUREE = "Maladie";
  public static final int NATURE_MALADIE_GRAVE = 13;
  public static final String LIB_NATURE_MALADIE_GRAVE = "Maladie";
  public static final int CONGES_PATERNITE = 14;
  public static final String LIB_CONGES_PATERNITE = "Congés paternité";
  
  public static NatureAffiliation getInstance()
  {
    return NATURE_AFFILIATION;
  }
  
  protected void initialiserEnumeration()
  {
    ajouterElement(1, "Activité A8");
    ajouterElement(2, "Activité A10");
    ajouterElement(3, "Congés maternité");
    ajouterElement(4, "Congés adoption");
    ajouterElement(5, "Accident du travail");
    ajouterElement(6, "Formation");
    ajouterElement(7, "Enseignement salarié");
    ajouterElement(8, "CT non exécuté");
    ajouterElement(9, "Suspension");
    ajouterElement(10, "Maladie");
    ajouterElement(12, "Maladie");
    ajouterElement(13, "Maladie");
  }
  
  public static int determinerNatureActivite(PeriodeGaecSpec activite)
  {
    if (activite.estType(ActiviteSalarie.class))
    {
      ActiviteSalarie activiteSalarie = (ActiviteSalarie)activite;
      if (activiteSalarie.getReglement().getLibelleCourt().equals("A8")) {
        return 1;
      }
      if (activiteSalarie.getReglement().getLibelleCourt().equals("A10")) {
        return 2;
      }
      if (activiteSalarie.getCategorieEmploiParticulier() == 31) {
        return 7;
      }
    }
    else if (activite.estType(PeriodeFormationAssimilable.class))
    {
      return 6;
    }
    return 11;
  }
  
  public static int determinerNatureActivite(PeriodeEvenementPersonnel pep)
  {
    int natureAffiliation;
    int natureAffiliation;
    switch (pep.getNature())
    {
    case 25: 
      natureAffiliation = 3;
      break;
    case 28: 
      natureAffiliation = 14;
      break;
    case 26: 
      natureAffiliation = 4;
      break;
    case 23: 
      natureAffiliation = 5;
      break;
    case 21: 
    case 22: 
      if (((pep instanceof PeriodeEvenementPersonnelIndemnisable)) && (((PeriodeEvenementPersonnelIndemnisable)pep).isMaladieGrave())) {
        natureAffiliation = 12;
      } else {
        natureAffiliation = 10;
      }
      break;
    case 24: 
    case 27: 
    default: 
      natureAffiliation = 11;
    }
    return natureAffiliation;
  }
}

/* Location:
 * Qualified Name:     NatureAffiliation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */