package fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.dom.EreFinDroitSpectacle;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.outilsfonctionnels.OutilCalculEligibiliteClauseRattrapage;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ActiviteParticipante;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConditionQuantiteAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConditionsAttributionAdmission;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionMontantsBruts;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationAffiliation;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Metier;
import fr.unedic.cali.autresdoms.ga.dom.RegimeRetraite;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.RejetSpec;
import fr.unedic.cali.parametres.GestionnaireDateApplication;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.List;

public class AlimentationBaseEchanges
{
  private static AlimentationBaseEchanges instance;
  
  public static AlimentationBaseEchanges getInstance()
  {
    if (instance == null) {
      instance = new AlimentationBaseEchanges();
    }
    return instance;
  }
  
  public void alimenterDonneesProduit(DossierExamenSpec dossierExamen, fr.unedic.cali.dom.echange.Decision demandeEchange)
    throws CoucheLogiqueException
  {
    demandeEchange.setLigne("ASU_SPE02");
    if (!dossierExamen.getDemande().estEnReExamen())
    {
      alimenterTopDetectionClauseRattrapage(dossierExamen, demandeEchange);
      if ((dossierExamen.getDemande().estNotifieeCourrier()) && (doitEffectuerRepriseStockSpectacle2016(dossierExamen.getDemande()))) {
        alimenterTopRepriseStock(dossierExamen, demandeEchange);
      }
    }
    if ((dossierExamen.getDemande().estNotifieeCourrier()) && (!(dossierExamen instanceof RejetSpec)))
    {
      alimenterDonneesCourrier(dossierExamen, demandeEchange);
      alimenterDonneesCourrierEcep(dossierExamen, demandeEchange);
    }
    if (((dossierExamen instanceof fr.unedic.cali.asu.spe02.p03.liquidation.dom.Decision)) && (estNotificationCourrier(dossierExamen.getDemande()))) {
      alimenterTopPNDS((fr.unedic.cali.asu.spe02.p03.liquidation.dom.Decision)dossierExamen, demandeEchange);
    }
  }
  
  private boolean estNotificationCourrier(DemandeSpec demande)
  {
    return (!demande.estEnReExamen()) && (demande.estNotifieeCourrier());
  }
  
  protected boolean doitEffectuerRepriseStockSpectacle2016(DemandeSpec demande)
    throws CoucheLogiqueException
  {
    Damj dateApplicationSpectacle2016 = GestionnaireDateApplication.getInstance().recupererDateApplication("Date d'application de la nouvelle convention Spectacle 2016");
    return ((demande.getEvenementReferenceExamen() instanceof EreFinDroitSpectacle)) && (demande.getDateExamen().estApresOuCoincideAvec(dateApplicationSpectacle2016));
  }
  
  private void alimenterTopRepriseStock(DossierExamenSpec dossierExamen, fr.unedic.cali.dom.echange.Decision demandeEchange)
    throws CoucheLogiqueException
  {
    boolean estSpectacleAvantMep = false;
    if (!((Demande)dossierExamen.getDemande()).isEstRepriseStockSpectacle2016Faite())
    {
      Damj datePremiereValidation = dossierExamen.getDemande().getDatePremiereValidation();
      Damj dateApplicationMep16SI4 = GestionnaireDateApplication.getInstance().recupererDateApplication("Date de la MEP 16SI4");
      if ((datePremiereValidation != null) && (dateApplicationMep16SI4.estApres(datePremiereValidation))) {
        estSpectacleAvantMep = true;
      }
    }
    if (estSpectacleAvantMep)
    {
      demandeEchange.setTopSpectacle2016avantMepSI4(1);
      ((Demande)dossierExamen.getDemande()).setEstRepriseStockSpectacle2016Faite(true);
    }
    else
    {
      demandeEchange.setTopSpectacle2016avantMepSI4(0);
    }
  }
  
  protected void alimenterDonneesCourrier(DossierExamenSpec dossierExamenSpec, fr.unedic.cali.dom.echange.Decision demandeEchange)
    throws CoucheLogiqueException
  {
    fr.unedic.cali.asu.spe02.p03.liquidation.dom.Decision dossierExamen = (fr.unedic.cali.asu.spe02.p03.liquidation.dom.Decision)dossierExamenSpec;
    
    ConstitutionMontantsBruts cepaMontantsBruts = dossierExamen.getConstitutionMontantsBruts();
    if (cepaMontantsBruts != null) {
      alimenterDonneesMontant(demandeEchange, cepaMontantsBruts);
    }
    ConstitutionDurees cepaDureesReglementaires = dossierExamen.getConstitutionDurees();
    if (cepaDureesReglementaires != null) {
      alimenterDonneesDuree(demandeEchange, cepaDureesReglementaires);
    }
  }
  
  private void alimenterDonneesDuree(fr.unedic.cali.dom.echange.Decision demandeEchange, ConstitutionDurees cepaDureesReglementaires)
  {
    if (cepaDureesReglementaires.getDureeTheorique() != null) {
      demandeEchange.setDureeTheoriqueDroitServiCourrier(cepaDureesReglementaires.getDureeTheorique().getValeurEntiere());
    }
    if (cepaDureesReglementaires.getDureeEffective() != null) {
      demandeEchange.setDureeRenouvellementAreCourrier(cepaDureesReglementaires.getDureeEffective().getValeurEntiere());
    }
  }
  
  private void alimenterDonneesMontant(fr.unedic.cali.dom.echange.Decision demandeEchange, ConstitutionMontantsBruts cepaMontantsBruts)
  {
    if (cepaMontantsBruts.getMontantJournalierBrut() != null) {
      if (cepaMontantsBruts.getCotisationRetraiteComplementaire() != null) {
        demandeEchange.setMontantAllocationJournalierBrutCourrier(cepaMontantsBruts.getMontantJournalierBrut().getValeur().add(cepaMontantsBruts.getCotisationRetraiteComplementaire().getValeur()));
      } else {
        demandeEchange.setMontantAllocationJournalierBrutCourrier(cepaMontantsBruts.getMontantJournalierBrut().getValeur());
      }
    }
    if (cepaMontantsBruts.getMontantBrutPensionInvaliditeDeduit() != null) {
      demandeEchange.setMontantPensionInvaliditeAreCourrier(cepaMontantsBruts.getMontantBrutPensionInvaliditeDeduit().getValeur());
    }
    if (cepaMontantsBruts.getCotisationRetraiteComplementaire() != null) {
      demandeEchange.setMontantCrcCourrier(cepaMontantsBruts.getCotisationRetraiteComplementaire().getValeur());
    }
  }
  
  private void alimenterDonneesCourrierEcep(DossierExamenSpec dossierExamenSpec, fr.unedic.cali.dom.echange.Decision demandeEchange)
    throws CoucheLogiqueException
  {
    int topCaisseInconnue = 0;
    
    fr.unedic.cali.asu.spe02.p03.liquidation.dom.Decision dossierExamen = (fr.unedic.cali.asu.spe02.p03.liquidation.dom.Decision)dossierExamenSpec;
    if (dossierExamen.getConditionFaitGenerateur() != null) {
      topCaisseInconnue = traiterListeRegimeRetraite(dossierExamen);
    }
    demandeEchange.setTopCaisseInconnue(topCaisseInconnue);
  }
  
  private int traiterListeRegimeRetraite(fr.unedic.cali.asu.spe02.p03.liquidation.dom.Decision dossierExamen)
  {
    int topCaisseInconnue = 0;
    List<?> listeRegimeRetraite = dossierExamen.getConditionFaitGenerateur().getPeriodeFaitGenerateur().getMetier().getListeRegimeRetraite();
    if (listeRegimeRetraite != null)
    {
      int nbRegimeRetraite = listeRegimeRetraite.size();
      for (int i = 0; i < nbRegimeRetraite; i++)
      {
        RegimeRetraite regimeRetraiteGa = (RegimeRetraite)listeRegimeRetraite.get(i);
        if (regimeRetraiteGa.estCaisseRetraiteAbsente()) {
          topCaisseInconnue = 1;
        }
      }
    }
    return topCaisseInconnue;
  }
  
  private void alimenterTopDetectionClauseRattrapage(DossierExamenSpec dossierExamen, fr.unedic.cali.dom.echange.Decision demandeEchange)
    throws CoucheLogiqueException
  {
    boolean estDemandeFinDeDroit = ("ASU_08".equals(dossierExamen.getDemande().getEvenementReferenceExamen().getTypeExamen())) && (dossierExamen.getDemande().getDateExamen().estApresOuCoincideAvec(GestionnaireDateApplication.getInstance().recupererDateApplication("Date d'application de la nouvelle convention Spectacle 2016")));
    
    boolean estUnRejetAffiliation = ((dossierExamen instanceof RejetSpec)) && (((DossierExamen)dossierExamen).getConditionAttributionAdmission() != null) && (((DossierExamen)dossierExamen).getConditionAttributionAdmission().getConditionQuantiteAffiliation() != null) && (!((DossierExamen)dossierExamen).getConditionAttributionAdmission().getConditionQuantiteAffiliation().estSatisfait());
    
    Quantite affiAcquise = null;
    if (((DossierAffecte)dossierExamen.getDossierAffecte()).getValidationProduit() != null) {
      affiAcquise = ((fr.unedic.cali.asu.spe02.p03.liquidation.dom.ValidationProduit)((DossierAffecte)dossierExamen.getDossierAffecte()).getValidationProduit()).getQuantiteAffiAcquiseRangInitial();
    }
    demandeEchange.setTopDetectionClauseRattrapage(OutilCalculEligibiliteClauseRattrapage.getInstance().determinerTopDectectionClauseRattrapage(estDemandeFinDeDroit, estUnRejetAffiliation, affiAcquise));
  }
  
  protected void alimenterTopPNDS(fr.unedic.cali.asu.spe02.p03.liquidation.dom.Decision decision, fr.unedic.cali.dom.echange.Decision demandeEchange)
    throws CoucheLogiqueException
  {
    boolean estPresencePNDS;
    boolean estPresencePNDS;
    if (estAffiliationForcee(recupererDonneesForcees(decision)))
    {
      estPresencePNDS = verifierPresencePNDSSurDemande((Demande)decision.getDemande());
    }
    else
    {
      JustificationAffiliation justifAffi = recupererJustificationAffiliation(decision);
      estPresencePNDS = verifierPresencePNDSSurJustifAffi(justifAffi);
    }
    if (estPresencePNDS) {
      demandeEchange.setEstPresencePNDS(1);
    }
  }
  
  protected boolean verifierPresencePNDSSurJustifAffi(JustificationAffiliation justifAffi)
  {
    boolean estPresencePNDS = false;
    if (justifAffi != null)
    {
      Collection<ActiviteParticipante> activitesParticipantes = justifAffi.getCollectionActiviteParticipante();
      for (ActiviteParticipante activiteCourante : activitesParticipantes) {
        if (activiteCourante.isPresencePNDSSurActivite())
        {
          estPresencePNDS = true;
          break;
        }
      }
    }
    return estPresencePNDS;
  }
  
  protected boolean verifierPresencePNDSSurDemande(Demande demande)
    throws CoucheLogiqueException
  {
    boolean estPresencePNDS = false;
    if (demande.getDossierAffectationAdmission().getValidationProduit() != null)
    {
      Periode pra = demande.getDossierAffectationAdmission().getValidationProduit().getPeriodePra();
      try
      {
        Chronologie chrono = demande.getChronologiePNDS(pra);
        estPresencePNDS = (chrono != null) && (!chrono.estVide());
      }
      catch (ApplicativeException ex)
      {
        throw new CoucheLogiqueException(ex.getCode(), ex.getLibelle(), ex);
      }
    }
    return estPresencePNDS;
  }
  
  protected boolean estAffiliationForcee(DonneesTemporaires donneesForcees)
  {
    return donneesForcees.getQuantiteAffiliation() != null;
  }
  
  protected JustificationAffiliation recupererJustificationAffiliation(fr.unedic.cali.asu.spe02.p03.liquidation.dom.Decision decision)
  {
    return (JustificationAffiliation)decision.getJustificationAffiliation();
  }
  
  protected DonneesTemporaires recupererDonneesForcees(fr.unedic.cali.asu.spe02.p03.liquidation.dom.Decision decision)
  {
    return ((Demande)decision.getDemande()).getDonneesTemporaires();
  }
}

/* Location:
 * Qualified Name:     AlimentationBaseEchanges
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */