package fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.AffiliationAssimilee;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.AffiliationSupplementaire;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionElementsAdmission;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionNbHeuresTravaillees;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.PeriodeElementaireAffiliation;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.services.PasAssezInformationException;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.Iterator;

public class DeterminationNombreHeuresTravaillees
  implements OutilFonctionnel
{
  public static ConstitutionNbHeuresTravaillees determinerNombreHeuresTravaillees(Demande demande)
    throws PasAssezInformationException, CoucheLogiqueException
  {
    ConstitutionNbHeuresTravaillees constitutionNbHeuresTravaillees = ((DossierExamen)demande.getDossierExamen()).getConstitutionElementsAdmission().createConstitutionNbHeuresTravaillees();
    
    Quantite nbHeuresTravailPlafonneForcees = demande.getDonneesTemporaires().getNbHeuresTravailPlafonneSpectacle();
    
    Quantite nbHeuresTravailEtenduForcees = demande.getDonneesTemporaires().getNbHeuresTravailEtenduSpectacle();
    if (nbHeuresTravailPlafonneForcees != null) {
      constitutionNbHeuresTravaillees.setNombreHeuresTravailleesPlafonne(nbHeuresTravailPlafonneForcees.getValeur());
    } else {
      constitutionNbHeuresTravaillees.setNombreHeuresTravailleesPlafonne(compterAffiliationBaseRetenue(demande));
    }
    if (nbHeuresTravailEtenduForcees != null)
    {
      constitutionNbHeuresTravaillees.setNombreHeuresTravailleesEtendu(nbHeuresTravailEtenduForcees.getValeur());
    }
    else
    {
      BigDecimal nbHeuresTravailEtendu = compterAffiliationBaseRetenue(demande);
      nbHeuresTravailEtendu = nbHeuresTravailEtendu.add(compterAffiliationSupplementaireRetenue(demande, null));
      int[] listeNatures = { 3, 4, 5 };
      
      nbHeuresTravailEtendu = nbHeuresTravailEtendu.add(compterAffiliationAssimileeRetenue(demande, listeNatures));
      constitutionNbHeuresTravaillees.setNombreHeuresTravailleesEtendu(nbHeuresTravailEtendu);
    }
    return constitutionNbHeuresTravaillees;
  }
  
  protected static BigDecimal compterAffiliationBaseRetenue(Demande demande)
  {
    BigDecimal retour = BigDecimal.ZERO;
    
    DossierExamen dossierExamen = (DossierExamen)demande.getDossierExamen();
    
    JustificationAffiliation justifAffi = (JustificationAffiliation)dossierExamen.getJustificationAffiliation();
    
    ProduitAsuSpec produit = (ProduitAsuSpec)dossierExamen.getDossierAffecte().getProduit();
    Iterator<?> it;
    if (justifAffi != null)
    {
      Collection<?> listePeriodesElementairesAffi = justifAffi.getCollectionPeriodeElementaireAffiliation();
      if ((listePeriodesElementairesAffi != null) && (!listePeriodesElementairesAffi.isEmpty())) {
        for (it = listePeriodesElementairesAffi.iterator(); it.hasNext();)
        {
          PeriodeElementaireAffiliation pea = (PeriodeElementaireAffiliation)it.next();
          if (pea.getAffiliationRetenue(produit) != null) {
            retour = retour.add(pea.getAffiliationRetenue(produit).getValeur());
          }
        }
      }
    }
    return retour;
  }
  
  protected static BigDecimal compterAffiliationSupplementaireRetenue(Demande demande, int[] listeNatures)
  {
    BigDecimal retour = BigDecimal.ZERO;
    
    JustificationAffiliation justifAffi = (JustificationAffiliation)((DossierExamen)demande.getDossierExamen()).getJustificationAffiliation();
    Iterator<?> it;
    if (justifAffi != null)
    {
      Collection<?> listePeriodesSupplementairesAffi = justifAffi.getCollectionAffiliationSupplementaire();
      if ((listePeriodesSupplementairesAffi != null) && (!listePeriodesSupplementairesAffi.isEmpty())) {
        for (it = listePeriodesSupplementairesAffi.iterator(); it.hasNext();)
        {
          AffiliationSupplementaire as = (AffiliationSupplementaire)it.next();
          if ((as.getQuantite() != null) && ((listeNatures == null) || (estNatureDansListe(as.getNature(), listeNatures)))) {
            retour = retour.add(as.getQuantite().getValeur());
          }
        }
      }
    }
    return retour;
  }
  
  protected static BigDecimal compterAffiliationAssimileeRetenue(Demande demande, int[] listeNatures)
  {
    BigDecimal retour = BigDecimal.ZERO;
    
    JustificationAffiliation justifAffi = (JustificationAffiliation)((DossierExamen)demande.getDossierExamen()).getJustificationAffiliation();
    Iterator<?> it;
    if (justifAffi != null)
    {
      Collection<?> listeAssimilation = justifAffi.getCollectionAssimilation();
      if ((listeAssimilation != null) && (!listeAssimilation.isEmpty())) {
        for (it = listeAssimilation.iterator(); it.hasNext();)
        {
          AffiliationAssimilee aa = (AffiliationAssimilee)it.next();
          if ((aa.getQuantite() != null) && ((listeNatures == null) || (estNatureDansListe(aa.getNature(), listeNatures)))) {
            retour = retour.add(aa.getQuantite().getValeur());
          }
        }
      }
    }
    return retour;
  }
  
  private static boolean estNatureDansListe(int nature, int[] listeNatures)
  {
    if ((listeNatures != null) && (listeNatures.length > 0)) {
      for (int i = 0; i < listeNatures.length; i++) {
        if (listeNatures[i] == nature) {
          return true;
        }
      }
    }
    return false;
  }
}

/* Location:
 * Qualified Name:     DeterminationNombreHeuresTravaillees
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */