package fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.Reliquat;
import fr.unedic.cali.asu.liquidation.outilsfonctionnels.DeterminationMontant;
import fr.unedic.cali.asu.parcours.ResultatTraitementReliquat;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DecisionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.cali.dom.ResultatTraitementReliquatSpec;
import fr.unedic.cali.dom.affectation.GammeAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitInrSpec;
import fr.unedic.cali.dom.conteneurs.DonneesEntreesRecuperationMontant;
import fr.unedic.cali.outilsfonctionnels.AppelCalculParLiquidation;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDecisionPourProduit;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreReexamenSurDemande;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreAttributionInrPourDateAttributionAreLiee;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import fr.unedic.util.temps.UniteDuree;
import java.math.BigDecimal;

public class OutilTraitementReliquat
  extends fr.unedic.cali.asu.outilsfonctionnels.OutilTraitementReliquat
{
  public static final BigDecimal ZERO = new BigDecimal("0");
  
  public static OutilTraitementReliquat getInstance()
  {
    return new OutilTraitementReliquat();
  }
  
  protected Quantite determinerQuantiteReliquatApresImputation(DemandeSpec p_demande, DecisionSpec p_decisionPrecedente, ResultatExecutionCalculSpec p_resultatExecutionCalcul, Damj p_dateEtude, ResultatTraitementReliquatSpec p_resultatTraitementReliquat)
    throws ApplicativeException
  {
    Quantite qteAidesImputee = new Quantite(ZERO, UniteDuree.JOUR);
    
    Quantite qteReliquatApresImputation = p_resultatExecutionCalcul.getReliquatAREAvecMaintien();
    
    String typeAide = null;
    
    Quantite nombreJoursImputes = new Quantite(ZERO, UniteDuree.JOUR);
    
    Demande demandeAsu = null;
    BigDecimal montantAideForce = null;
    if ((p_demande instanceof Demande))
    {
      demandeAsu = (Demande)p_demande;
      montantAideForce = demandeAsu.getDonneesTemporaires().getMontantAide();
    }
    if (montantAideForce != null)
    {
      Damj dateAttributionAide = demandeAsu.getDonneesTemporaires().getDateAttributionAide();
      if (dateAttributionAide == null) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ABSENCE_DATE_ATTRIBUTION_AIDE");
      } else if ((p_demande.getDateExamen() != null) && (dateAttributionAide.estApres(p_demande.getDateExamen()))) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_DATE_ATTRIBUTION_AIDE_INCORRECTE");
      }
      GammeAsuSpec gamme = (GammeAsuSpec)((AttributionAssuranceSpec)p_decisionPrecedente).getGamme();
      DonneesEntreesRecuperationMontant donneesEntreesRecuperationMontant = gamme.mapperDonneesEntreesRecuperationMontant((AttributionAssuranceSpec)p_decisionPrecedente);
      donneesEntreesRecuperationMontant.setDateCalculMontant(dateAttributionAide);
      MontantBaseSpec montant = DeterminationMontant.determinerMontant(donneesEntreesRecuperationMontant);
      
      Quantite montantBrutJournalier = montant.getMontantBrut();
      
      int joursAide = montantAideForce.divide(montantBrutJournalier.getValeur(), ZERO.intValue(), 1).intValue();
      qteAidesImputee = new Quantite(new BigDecimal(joursAide), UniteDuree.JOUR);
      
      nombreJoursImputes = nombreJoursImputes.ajouter(qteAidesImputee);
      typeAide = Reliquat.determinerTypeAide(demandeAsu.getDonneesTemporaires().getNatureMontantAide());
    }
    else
    {
      FiltreET filtreDeRechercheAttributionArce = new FiltreET();
      filtreDeRechercheAttributionArce.ajouterFiltre(new FiltreDecisionPourProduit(18));
      filtreDeRechercheAttributionArce.ajouterFiltre(new FiltreAttributionInrPourDateAttributionAreLiee(p_decisionPrecedente.getDateAttribution()));
      
      filtreDeRechercheAttributionArce.ajouterFiltre(new FiltreNegation(new FiltreReexamenSurDemande()));
      AttributionSpec attributionArce = (AttributionSpec)OutilRecherche.rechercherDecisionPrecedente(p_demande.getDemandeur().getChronoDemandeIncitationReclassement(), p_demande, filtreDeRechercheAttributionArce);
      if (attributionArce != null)
      {
        int dureeAImputer = ZERO.intValue();
        BigDecimal capitalArce = ZERO;
        
        ProduitInrSpec produit = (ProduitInrSpec)attributionArce.getDemande().getDossierAffectation().getProduit();
        
        ResultatExecutionCalculSpec resultat = AppelCalculParLiquidation.executerCalculDeterminationEtatDroit(attributionArce, p_dateEtude, true, true);
        if (resultat.getCapitalVerse() != null) {
          capitalArce = resultat.getCapitalVerse().getValeur();
        }
        BigDecimal montantArce = produit.getMontantJournalierAttributionArce(attributionArce);
        
        dureeAImputer = capitalArce.divide(montantArce, ZERO.intValue(), 1).intValue();
        qteAidesImputee = new Quantite(new BigDecimal(dureeAImputer), UniteDuree.JOUR);
        typeAide = "ARC";
        
        nombreJoursImputes = nombreJoursImputes.ajouter(qteAidesImputee);
      }
    }
    Quantite nbJoursSuspension = fr.unedic.cali.asu.outilsfonctionnels.OutilTraitementReliquat.determinerImputationPourSuppressionTemporaireRevenuDeRemplacement(p_demande, p_resultatExecutionCalcul, p_dateEtude);
    
    nombreJoursImputes = nombreJoursImputes.ajouter(nbJoursSuspension);
    
    Quantite nbJoursDonneesForcees = fr.unedic.cali.asu.outilsfonctionnels.OutilTraitementReliquat.determinerImputationNombreJoursDonneesForcees(p_demande);
    
    nombreJoursImputes = nombreJoursImputes.ajouter(nbJoursDonneesForcees);
    
    qteReliquatApresImputation = qteReliquatApresImputation.soustraire(nombreJoursImputes);
    if (qteReliquatApresImputation.getValeurEntiere() < ZERO.intValue()) {
      qteReliquatApresImputation = new Quantite(ZERO, UniteDuree.JOUR);
    }
    ((ResultatTraitementReliquat)p_resultatTraitementReliquat).setTypeAide(typeAide);
    ((ResultatTraitementReliquat)p_resultatTraitementReliquat).setQuantiteFormation(new Quantite(ZERO, UniteDuree.JOUR));
    ((ResultatTraitementReliquat)p_resultatTraitementReliquat).setQuantiteAide(qteAidesImputee);
    
    return qteReliquatApresImputation;
  }
  
  private boolean isInopposabiliteDelaiDecheance(Demande p_demandeCourante)
  {
    return p_demandeCourante.getDonneesTemporaires().isInopposabiliteDelaiDecheance();
  }
  
  private Damj getDateAttributionProduitPrecedent(DecisionSpec p_decision)
  {
    return p_decision.getDateAttribution();
  }
  
  private DureeCalendaire getDureeDecheance(DecisionSpec p_decisionPrecedente, Demande p_demandeCourante)
  {
    DureeCalendaire duree = fr.unedic.cali.asu.outilsfonctionnels.OutilTraitementReliquat.getDureeDecheance(getDureeIndemnisation(p_decisionPrecedente));
    
    DureeCalendaire allongement = p_demandeCourante.getDonneesTemporaires().getAllongementDelaiDecheance();
    if (allongement != null) {
      duree = duree.ajouter(allongement);
    }
    return duree;
  }
  
  private int getDureeIndemnisation(DecisionSpec p_decisionPrecedente)
  {
    return ((AttributionAssuranceSpec)p_decisionPrecedente).getDureeTheorique().getValeurEntiere();
  }
  
  protected Quantite determinerDureeImputationSuppressionTemporaireRevenuRemplacement(DemandeSpec p_demande, ResultatExecutionCalculSpec p_resultatExecutionCalculPrecedent, Damj p_dateEtude)
    throws CoucheLogiqueException
  {
    Quantite nbJoursSuspension = fr.unedic.cali.asu.outilsfonctionnels.OutilTraitementReliquat.determinerImputationPourSuppressionTemporaireRevenuDeRemplacement(p_demande, p_resultatExecutionCalculPrecedent, p_dateEtude);
    
    return nbJoursSuspension;
  }
  
  protected boolean preTraitement(ResultatTraitementReliquat p_resultatTraitement, DemandeSpec p_demande, DecisionSpec p_decisionPrecedente, ResultatExecutionCalculSpec p_resultatExecutionCalcul)
    throws CoucheLogiqueException
  {
    boolean retour = true;
    if (!p_resultatTraitement.getReliquatValide()) {
      retour = false;
    }
    return retour;
  }
  
  protected void postTraitement(ResultatTraitementReliquat p_resultatTraitement, ResultatExecutionCalculSpec p_resultatCalcul)
  {
    super.postTraitement(p_resultatTraitement, p_resultatCalcul);
  }
  
  protected Damj traiterDecheance(DemandeSpec p_demande, DecisionSpec p_decisionPrecedente, Damj p_dateEtude)
    throws CoucheLogiqueException
  {
    boolean produitDechu = false;
    boolean inopposabilite = false;
    Damj finDelaiDechance = null;
    if ((p_demande instanceof Demande)) {
      inopposabilite = isInopposabiliteDelaiDecheance((Demande)p_demande);
    }
    if (!inopposabilite)
    {
      AttributionAssuranceSpec attributionPrecedente = (AttributionAssuranceSpec)p_decisionPrecedente;
      AttributionAssuranceSpec attributionOrigine = (AttributionAssuranceSpec)attributionPrecedente.getOuvertureDroit();
      
      Damj debutDelaiDecheance = getDateAttributionProduitPrecedent(attributionOrigine);
      finDelaiDechance = getDateFinDelaiDecheance(attributionOrigine, p_demande);
      
      Periode delaiDecheance = new Periode(debutDelaiDecheance, finDelaiDechance);
      
      produitDechu = !p_dateEtude.lendemain().estContenueDans(delaiDecheance);
    }
    if (!produitDechu) {
      finDelaiDechance = null;
    }
    return finDelaiDechance;
  }
  
  protected Damj traiterExtinction(DemandeSpec p_demande, DecisionSpec p_decisionPrecedente, ResultatExecutionCalculSpec p_resultatExecutionCalcul, Damj p_dateEtude)
    throws CoucheLogiqueException
  {
    return getDateExtinction(p_demande, p_decisionPrecedente, p_resultatExecutionCalcul, p_dateEtude);
  }
  
  protected Damj getDateExtinction(DemandeSpec p_demande, DecisionSpec p_decisionPrecedente, ResultatExecutionCalculSpec p_resultatExecutionCalcul, Damj p_dateEtude)
    throws CoucheLogiqueException
  {
    Damj dateExtinction = null;
    
    dateExtinction = determinerExtinctionPourExclusionDefinitiveRevenuDeRemplacement(p_demande, p_resultatExecutionCalcul, p_dateEtude);
    
    return dateExtinction;
  }
  
  protected Quantite traiterImputation(DemandeSpec p_demande, DecisionSpec p_decisionPrecedente, ResultatExecutionCalculSpec p_resultatExecutionCalcul, ResultatTraitementReliquatSpec p_resultatTraitementReliquat, Damj p_dateEtude)
    throws CoucheLogiqueException, ApplicativeException
  {
    Quantite qteReliquatApresImputation = determinerQuantiteReliquatApresImputation(p_demande, p_decisionPrecedente, p_resultatExecutionCalcul, p_dateEtude, p_resultatTraitementReliquat);
    
    p_resultatTraitementReliquat.setQuantiteReliquat(qteReliquatApresImputation);
    return qteReliquatApresImputation;
  }
  
  public Damj getDateFinDelaiDecheance(AttributionSpec p_attributionOrigine, DemandeSpec p_demandeCourante)
  {
    Damj debutDelaiDecheance = null;
    DureeCalendaire dureeDecheance = null;
    Damj finDelaiDechance = null;
    if (p_attributionOrigine != null)
    {
      debutDelaiDecheance = getDateAttributionProduitPrecedent(p_attributionOrigine);
      if ((p_demandeCourante instanceof Demande)) {
        dureeDecheance = getDureeDecheance(p_attributionOrigine, (Demande)p_demandeCourante);
      } else {
        dureeDecheance = new DureeCalendaire(ZERO.intValue(), ZERO.intValue(), ZERO.intValue());
      }
      finDelaiDechance = debutDelaiDecheance.deplacerVersAvant(dureeDecheance);
    }
    return finDelaiDechance;
  }
}

/* Location:
 * Qualified Name:     OutilTraitementReliquat
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */