package fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.strategies;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.ConteneurPMCSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.PreavisMesureConservatoireIndemnisableSpec;
import fr.unedic.cali.asu.dom.PreavisMesureConservatoireNonIndemnisableSpec;
import fr.unedic.cali.asu.outilsfonctionnels.ConstitutionISLR;
import fr.unedic.cali.asu.outilsfonctionnels.ConstitutionPMC;
import fr.unedic.cali.asu.outilsfonctionnels.ConstructionChronologieCarences;
import fr.unedic.cali.asu.outilsfonctionnels.OutilCarence;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Attribution;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.CarenceIslr;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.CarencePrefixeAFixer;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.CarenceStandard;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionDelaisReport;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionElementsSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionPointDepartIndemnisation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionSalaireJournalierMoyen;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionSalaireReference;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConteneurPMC;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Differe;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationDiffere;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.PeriodeRetenue;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.PreavisMesureConservatoireIndemnisable;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.PreavisMesureConservatoireNonIndemnisable;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.OutilDeterminationDelaisReportSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.formules.FormuleCarenceIndemnisationStandard;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.formules.FormuleCarenceSpecifique;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.formules.FormuleSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.formules.FormuleTexteSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.formules.ParametresCarenceSpecifique;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.spec.ParametresCarenceIndemnisationStandardSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.autresdoms.ga.dom.Entreprise;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.ObjetAlertesNonBloquantes;
import fr.unedic.cali.dom.ResultatRemunerationsParNature;
import fr.unedic.cali.dom.affectation.ProduitAsuSpectacleSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.DeterminationRemuneration;
import fr.unedic.cali.outilsfonctionnels.RechercherDernierSinistre;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.parametres.EvenementParametre;
import fr.unedic.cali.parametres.ParametresIndemnisation;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreOuvertureDroitStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreDecisionARESurDecision;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.CalculDelais;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.FiltreFinDansBornes;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.ObjetChronoPeriodeConcrete;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.List;

public class StrategieDelaisReportAvant1erDecembre2010
  implements StrategieDelaisReportSpec
{
  private static final int DELAIS_READ_ET_ATTRIB_PREC_SS_DIFFERE = 12;
  private static final BigDecimal ZERO = new BigDecimal(0);
  private static StrategieDelaisReportAvant1erDecembre2010 instance = null;
  
  public static OutilDeterminationDelaisReportSpec getInstance()
  {
    if (instance == null) {
      instance = new StrategieDelaisReportAvant1erDecembre2010();
    }
    return instance;
  }
  
  public void determinerCarencePourAdmission(DemandeAssuranceSpec demande)
    throws ApplicativeException
  {
    ConstitutionDelaisReport cepDelaisReport = recupererDelaisReportActifs(demande);
    
    determinerCarencePMC(demande, cepDelaisReport);
    
    determinerCarenceStandard(demande, cepDelaisReport);
    
    determinerCarenceSpecifique(demande, cepDelaisReport);
    
    determinerDiffere(demande, cepDelaisReport);
  }
  
  public void determinerCarencePourReprise(DemandeAssuranceSpec demande, List listeReliquatCarence)
    throws CoucheLogiqueException
  {
    ConstitutionDelaisReport cepDelaisReport = recupererDelaisReportActifs(demande);
    
    determinerCarencePMC(demande, cepDelaisReport);
    
    determinerCarenceSpecifique(demande, cepDelaisReport);
    
    determinerReliquatCarence(demande, cepDelaisReport, listeReliquatCarence);
  }
  
  private void determinerReliquatCarence(DemandeAssuranceSpec demande, ConstitutionDelaisReport cepDelaisReport, List<?> listeReliquatCarence)
    throws CoucheLogiqueException
  {
    Attribution attributionPrecedente = (Attribution)demande.getDemandeOrigine().getDossierExamen();
    boolean estUnJourDiffereConsomme = attributionPrecedente.isUnJourDiffereConsomme();
    Damj dateAttribution = demande.getDossierExamen().getDateAttribution();
    Damj pjiAttributionPrecedente = attributionPrecedente.getConstitutionElementsActifs().getConstitutionPointDepartIndemnisation().getPointDepartIndemnisation();
    
    Differe reliquatDiffere = null;
    if (listeReliquatCarence != null)
    {
      Iterator<?> itReliquatCarence = listeReliquatCarence.iterator();
      while (itReliquatCarence.hasNext())
      {
        CarencePrefixeAFixer carenceOrigine = (CarencePrefixeAFixer)itReliquatCarence.next();
        
        reliquatDiffere = traiterCarence(cepDelaisReport, reliquatDiffere, carenceOrigine);
      }
    }
    alimenterCEPPourCarence(cepDelaisReport, recupererReliquatCarencePMCIndemnisable(demande));
    if ((reliquatDiffere != null) && ((!estUnJourDiffereConsomme) || (dateAttribution.estAvant(pjiAttributionPrecedente)))) {
      if (!estUnJourDiffereConsomme)
      {
        Quantite quantiteJour = new QuantiteJour(new BigDecimal(7));
        alimenterCEPPourCarence(cepDelaisReport, recupererReliquatDiffere(quantiteJour));
      }
      else if (dateAttribution.estAvant(pjiAttributionPrecedente))
      {
        int reliquatARetenirALaDateAttribution = dateAttribution.joursEntre(pjiAttributionPrecedente);
        
        reliquatARetenirALaDateAttribution = Math.min(reliquatARetenirALaDateAttribution, reliquatDiffere.getReliquat().getValeurEntiere());
        if (reliquatARetenirALaDateAttribution > 0)
        {
          QuantiteJour quantiteReliquat = new QuantiteJour(new BigDecimal(reliquatARetenirALaDateAttribution));
          alimenterCEPPourCarence(cepDelaisReport, recupererReliquatDiffere(quantiteReliquat));
        }
      }
    }
  }
  
  private Differe traiterCarence(ConstitutionDelaisReport cepDelaisReport, Differe reliquat, CarencePrefixeAFixer carenceOrigine)
  {
    Differe reliquatDiffere = reliquat;
    if (carenceOrigine.getReliquat().getValeur().intValue() > ZERO.intValue()) {
      if (carenceOrigine.getTypeCarence().equals("5")) {
        reliquatDiffere = (Differe)carenceOrigine;
      } else if (carenceOrigine.getTypeCarence().equals("3")) {
        alimenterCEPPourCarence(cepDelaisReport, creerReliquatCarenceSpecifique(carenceOrigine));
      } else if (carenceOrigine.getTypeCarence().equals("1")) {
        alimenterCEPPourCarence(cepDelaisReport, creerReliquatCarencePMCNonIndemnisable(carenceOrigine));
      } else if (carenceOrigine.getTypeCarence().equals("4")) {
        alimenterCEPPourCarence(cepDelaisReport, creerReliquatCarenceStandard(carenceOrigine));
      }
    }
    return reliquatDiffere;
  }
  
  private CarenceIslr creerReliquatCarenceSpecifique(CarencePrefixeAFixer carenceOrigine)
  {
    CarenceIslr carence = null;
    if (carenceOrigine.getReliquat() != null)
    {
      carence = new CarenceIslr();
      
      alimenterReliquatCarence(carence, carenceOrigine);
    }
    return carence;
  }
  
  private PreavisMesureConservatoireNonIndemnisable creerReliquatCarencePMCNonIndemnisable(CarencePrefixeAFixer carenceOrigine)
  {
    PreavisMesureConservatoireNonIndemnisable pmcNI = null;
    if (carenceOrigine.getReliquat() != null)
    {
      pmcNI = new PreavisMesureConservatoireNonIndemnisable();
      
      alimenterReliquatCarence(pmcNI, carenceOrigine);
    }
    return pmcNI;
  }
  
  private CarenceStandard creerReliquatCarenceStandard(CarencePrefixeAFixer carenceOrigine)
  {
    CarenceStandard carence = null;
    if (carenceOrigine.getReliquat() != null)
    {
      carence = new CarenceStandard();
      
      alimenterReliquatCarence(carence, carenceOrigine);
    }
    return carence;
  }
  
  private Differe recupererReliquatDiffere(Quantite reliquatCarence)
  {
    Differe differe = null;
    if (reliquatCarence != null)
    {
      differe = new Differe();
      differe.setQuantiteInitiale(reliquatCarence);
    }
    return differe;
  }
  
  private void alimenterReliquatCarence(CarencePrefixeAFixer nouvelleCarence, CarencePrefixeAFixer reliquatCarence)
  {
    if (reliquatCarence.getReliquat() != null)
    {
      nouvelleCarence.setOrigine(reliquatCarence.getOrigineReliquat());
      nouvelleCarence.setQuantiteInitiale(reliquatCarence.getReliquat());
    }
  }
  
  private PreavisMesureConservatoireIndemnisable recupererReliquatCarencePMCIndemnisable(DemandeAssuranceSpec demande)
  {
    PreavisMesureConservatoireIndemnisable pmc = null;
    
    Attribution attributionPrecedente = (Attribution)demande.getDemandeOrigine().getDossierExamen();
    
    Damj dateDebutPMCIndemnisable = attributionPrecedente.getConstitutionDelaisReport().getDebutPMCIndemn();
    Damj dateFinPMCIndemnisable = attributionPrecedente.getConstitutionDelaisReport().getTermePMCIndemn();
    if (dateDebutPMCIndemnisable != null)
    {
      pmc = new PreavisMesureConservatoireIndemnisable();
      pmc.setOrigine(new ObjetChronoPeriodeConcrete(dateDebutPMCIndemnisable.veille(), dateDebutPMCIndemnisable.veille()));
      pmc.setPeriodeApplicationCarence(new Periode(dateDebutPMCIndemnisable, dateFinPMCIndemnisable));
      pmc.setQuantiteInitiale(new QuantiteJour(new BigDecimal(pmc.getPeriodeApplicationCarence().getDuree())));
    }
    return pmc;
  }
  
  public void alimenterCEPAvecResultatCalcul(DemandeAssuranceSpec demande, ResultatExecutionCalculSpec resultatCalcul)
  {
    ConstitutionDelaisReport cepDelaisReport = ((DossierExamen)demande.getDossierExamen()).getConstitutionElementsActifs().getConstitutionDelaisReport();
    if (resultatCalcul.getListeCarencesEffectives() != null)
    {
      Iterator itListeCarencesEffectives = resultatCalcul.getListeCarencesEffectives().iterator();
      while (itListeCarencesEffectives.hasNext())
      {
        CarencePrefixeAFixer carence = (CarencePrefixeAFixer)itListeCarencesEffectives.next();
        if (OutilCarence.estCarenceDeType(carence, "1"))
        {
          cepDelaisReport.setDebutPMCNonIndemn(carence.getPeriodeApplicationCarence().getDebut());
          cepDelaisReport.setTermePMCNonIndemn(carence.getPeriodeApplicationCarence().getFin());
          cepDelaisReport.setNbJoursPMCNonIndemn(carence.getQuantiteInitiale().getValeurEntiere());
        }
        else if (OutilCarence.estCarenceDeType(carence, "4"))
        {
          cepDelaisReport.setDebutCarenceStandard(carence.getPeriodeApplicationCarence().getDebut());
          cepDelaisReport.setTermeCarenceStandard(carence.getPeriodeApplicationCarence().getFin());
          cepDelaisReport.setNbJoursCarenceStandard(carence.getQuantiteInitiale().getValeurEntiere());
        }
        else if (OutilCarence.estCarenceDeType(carence, "3"))
        {
          cepDelaisReport.setDebutCarenceISLR(carence.getPeriodeApplicationCarence().getDebut());
          cepDelaisReport.setTermeCarenceISLR(carence.getPeriodeApplicationCarence().getFin());
          cepDelaisReport.setNbJoursCarenceISLR(carence.getQuantiteInitiale().getValeurEntiere());
          
          CarenceIslr carenceIslr = (CarenceIslr)carence;
          if (carenceIslr.isPresenceTransaction()) {
            leverAlerteA11MNB4SurCarenceIslr(demande, carenceIslr.getOrigine());
          }
        }
        else if (OutilCarence.estCarenceDeType(carence, "5"))
        {
          cepDelaisReport.setDebutDelaiReport(carence.getPeriodeApplicationCarence().getDebut());
          cepDelaisReport.setTermeDelaiReport(carence.getPeriodeApplicationCarence().getFin());
          cepDelaisReport.setNbJoursDelaiReport(carence.getQuantiteInitiale().getValeurEntiere());
        }
      }
    }
    PreavisMesureConservatoireIndemnisable pmc = rechercherPMCIndemnisableSeTerminantLePlusTard(cepDelaisReport);
    if (pmc != null)
    {
      cepDelaisReport.setDebutPMCIndemn(pmc.getPeriodeApplicationCarence().getDebut());
      cepDelaisReport.setTermePMCIndemn(pmc.getPeriodeApplicationCarence().getFin());
      cepDelaisReport.setNbJoursPMCIndemn(pmc.getQuantiteInitiale().getValeurEntiere());
    }
  }
  
  private static void leverAlerteA11MNB4SurCarenceIslr(DemandeAssuranceSpec demande, ObjetChronoPeriode objetChronoPeriode)
  {
    if ((objetChronoPeriode instanceof ActiviteSalarie))
    {
      ActiviteSalarie periodeActiviteSalarieCourante = (ActiviteSalarie)objetChronoPeriode;
      Collection listeActivitesSalariees = null;
      
      String codeAlerteNonBloquante = "A11MNB4";
      if (demande.getAlertesNonBloquantes().containsKey(codeAlerteNonBloquante))
      {
        listeActivitesSalariees = (Collection)demande.getAlertesNonBloquantes().get(codeAlerteNonBloquante);
        
        ObjetAlertesNonBloquantes objetAlertesNonBloquantes = new ObjetAlertesNonBloquantes(periodeActiviteSalarieCourante);
        if (!listeActivitesSalariees.contains(objetAlertesNonBloquantes)) {
          listeActivitesSalariees.add(objetAlertesNonBloquantes);
        }
      }
      else
      {
        listeActivitesSalariees = new ArrayList();
        
        listeActivitesSalariees.add(new ObjetAlertesNonBloquantes(periodeActiviteSalarieCourante));
        demande.getAlertesNonBloquantes().put(codeAlerteNonBloquante, listeActivitesSalariees);
      }
    }
  }
  
  private static PreavisMesureConservatoireIndemnisable rechercherPMCIndemnisableSeTerminantLePlusTard(ConstitutionDelaisReport cepDelaisReport)
  {
    List<?> listePMCIndemnisable = OutilCarence.trouverCarences(cepDelaisReport.getListCarence(), "2");
    PreavisMesureConservatoireIndemnisable pmcMax = null;
    if ((listePMCIndemnisable != null) && (listePMCIndemnisable.size() > 0))
    {
      Iterator<?> itPMCIndemnisable = listePMCIndemnisable.iterator();
      while (itPMCIndemnisable.hasNext())
      {
        PreavisMesureConservatoireIndemnisable pmc = (PreavisMesureConservatoireIndemnisable)itPMCIndemnisable.next();
        if ((pmcMax == null) || (pmcMax.getPeriodeApplicationCarence().getFin().estAvant(pmc.getPeriodeApplicationCarence().getFin()))) {
          pmcMax = pmc;
        }
      }
    }
    return pmcMax;
  }
  
  private static void determinerCarencePMC(DemandeAssuranceSpec demande, ConstitutionDelaisReport cepDelaisReport)
    throws CoucheLogiqueException
  {
    Periode periodeReferencePMC = determinerPeriodeReferencePMC(demande);
    
    Chronologie chronoActivitesParticipantes = ConstructionChronologieCarences.determinerChronoActivitesParticipantCarences(periodeReferencePMC, (Demande)demande);
    
    Iterator<?> itChrono = chronoActivitesParticipantes.iterer();
    while (itChrono.hasNext())
    {
      ActiviteSalarie periodeTraitee = (ActiviteSalarie)itChrono.next();
      
      ConteneurPMCSpec conteneurPMC = ConteneurPMC.createInstance();
      
      determinerCarencePmc(demande, periodeTraitee, conteneurPMC);
      
      alimenterCEPPourPMC(cepDelaisReport, conteneurPMC);
    }
  }
  
  private static void alimenterCEPPourPMC(ConstitutionDelaisReport cepDelaisReport, ConteneurPMCSpec carencePMC)
  {
    alimenterCEPPourCarence(cepDelaisReport, carencePMC.getCarencePmcIndemnisable());
    
    alimenterCEPPourCarence(cepDelaisReport, carencePMC.getCarencePmcNonIndemnisable());
  }
  
  private static void determinerCarencePmc(DemandeAssuranceSpec demande, ActiviteSalarie periodeActiviteSalarie, ConteneurPMCSpec ensembleCarences)
    throws CoucheLogiqueException
  {
    if ((presenceDonneesForceesPMC(demande)) && (estPMCForceePourActivite(demande, periodeActiviteSalarie)))
    {
      ajouterCarencePmcForcee(demande, ensembleCarences);
    }
    else
    {
      ensembleCarences.setDemande(demande);
      ConstitutionPMC.determinerPMC(periodeActiviteSalarie, ensembleCarences);
    }
  }
  
  private static boolean presenceDonneesForceesPMC(DemandeAssuranceSpec demande)
  {
    boolean presencePmcForcee = (demande.getDonneesTemporaires().getIndentifiantFctPMC() != null) && (demande.getDonneesTemporaires().getFinPmc() != null);
    
    return presencePmcForcee;
  }
  
  private static boolean estPMCForceePourActivite(DemandeAssuranceSpec demande, ActiviteSalarie periodeActiviteSalarie)
  {
    return periodeActiviteSalarie.getIdentifiant().equalsIgnoreCase(demande.getDonneesTemporaires().getIndentifiantFctPMC());
  }
  
  private static void ajouterCarencePmcForcee(DemandeAssuranceSpec demande, ConteneurPMCSpec ensembleCarences)
  {
    ActiviteSalarie periodeFct = (ActiviteSalarie)demande.getDemandeur().rechercherPeriodePasseProfessionnel(demande.getDonneesTemporaires().getIndentifiantFctPMC());
    
    ConstitutionPMC.ajouterPmcForcee(periodeFct, demande.getDonneesTemporaires().isPmcIndemnisable(), demande.getDonneesTemporaires().getFinPmc(), ensembleCarences);
  }
  
  private static void determinerCarenceStandard(DemandeAssuranceSpec demande, ConstitutionDelaisReport cepDelaisReport)
    throws CoucheLogiqueException
  {
    JustificationDiffere justificationDiffere = cepDelaisReport.createJustificationDiffere();
    
    CarenceStandard carenceStandard = calculerCarenceStandard(demande, justificationDiffere);
    
    alimenterCEPPourCarenceStandard(cepDelaisReport, carenceStandard);
  }
  
  private static CarenceStandard calculerCarenceStandard(DemandeAssuranceSpec demande, JustificationDiffere justificationDiffere)
    throws CoucheLogiqueException
  {
    CarenceStandard carenceStandard = null;
    
    ParametresCarenceIndemnisationStandardSpec parametres = (ParametresCarenceIndemnisationStandardSpec)((ProduitAsuSpectacleSpec)((Attribution)demande.getDossierExamen()).getProduit()).recupererParametresCarenceIndemnisationDiffereStandard();
    
    FormuleTexteSpec formuleCalculCarence = new FormuleCarenceIndemnisationStandard();
    DossierExamen dossierExamen = (DossierExamen)demande.getDossierExamen();
    
    justificationDiffere.setFormule(formuleCalculCarence.getFormule(parametres));
    
    Periode periodeRechercheCalcul = dossierExamen.getConstitutionSalaireReference().getPrc();
    EvenementParametre elementActifAFinPRC = ParametresIndemnisation.getParametresIndemnisation().getElementActif(periodeRechercheCalcul.getFin());
    
    QuantiteEuro montantSJM = dossierExamen.getConstitutionElementsActifs().getConstitutionSalaireJournalierMoyen().getMontantSalaireJournalierMoyenRevalorisePlafonne();
    
    parametres.setMontantSMIC(elementActifAFinPRC.getSmicMensuelBase35h());
    parametres.setMontantSMICJournalier(elementActifAFinPRC.getSmicJournalierBase35h());
    parametres.setSalaireJournalierMoyen(montantSJM.getValeur());
    parametres.setMontantSalaires(calculMontantTotalSalaires(justificationDiffere, demande, periodeRechercheCalcul));
    
    justificationDiffere.setSmicJournalier(new QuantiteEuro(parametres.getMontantSMICJournalier()));
    justificationDiffere.setSmicMensuel(new QuantiteEuro(parametres.getMontantSMIC()));
    justificationDiffere.setTotalSalairesNonPlafonnes(new QuantiteEuro(parametres.getMontantSalaires()));
    
    Quantite dureeCarenceStandard = (Quantite)formuleCalculCarence.appliquerFormule(parametres);
    if ((dureeCarenceStandard != null) && (dureeCarenceStandard.getValeurEntiere() > ZERO.intValue()))
    {
      carenceStandard = new CarenceStandard();
      
      Damj veilleDateAttribution = demande.getDossierExamen().getDateAttribution().veille();
      ObjetChronoPeriodeConcrete periodeOrigine = new ObjetChronoPeriodeConcrete(veilleDateAttribution, veilleDateAttribution);
      carenceStandard.setOrigine(periodeOrigine);
      carenceStandard.setQuantiteInitiale(dureeCarenceStandard);
    }
    return carenceStandard;
  }
  
  private static void alimenterCEPPourCarenceStandard(ConstitutionDelaisReport cepDelaisReport, CarenceStandard carenceStandard)
  {
    alimenterCEPPourCarence(cepDelaisReport, carenceStandard);
  }
  
  private static BigDecimal calculMontantTotalSalaires(JustificationDiffere justification, DemandeAssuranceSpec demande, Periode periodeRecherche)
  {
    BigDecimal total = new BigDecimal(0);
    QuantiteEuro sripNonPlafonne = demande.getDonneesTemporaires().getTotalRemunerationDansPRC();
    if (sripNonPlafonne != null)
    {
      total = sripNonPlafonne.getValeur();
    }
    else
    {
      Chronologie chronoActivites = ConstructionChronologieCarences.determinerChronoActiviteToutReglementPourSalaireDiffereStandard(periodeRecherche, demande);
      
      Iterator<?> itChrono = chronoActivites.iterer();
      while (itChrono.hasNext())
      {
        ActiviteSalarie activite = (ActiviteSalarie)itChrono.next();
        
        ResultatRemunerationsParNature resultatRemuneration = new ResultatRemunerationsParNature();
        BigDecimal remunerationPourActivite = DeterminationRemuneration.determinerRemunerationActiviteSalarie(activite, periodeRecherche, resultatRemuneration);
        
        total = total.add(remunerationPourActivite);
        
        alimenterJustificationSalaire(justification, activite, resultatRemuneration);
      }
    }
    return total;
  }
  
  private static void alimenterJustificationSalaire(JustificationDiffere justification, ActiviteSalarie activite, ResultatRemunerationsParNature resultatRemuneration)
  {
    PeriodeRetenue periodeRetenue = new PeriodeRetenue();
    periodeRetenue.setCodeProduitReglement(activite.getReglement().getProduit().getCode());
    periodeRetenue.setNomReglement(activite.getReglement().getNomReglement());
    periodeRetenue.setPeriode(activite.getPeriode());
    periodeRetenue.setRaisonSociale(activite.getEntreprise().getLibelleEntreprise());
    periodeRetenue.setReglement(activite.getReglement());
    
    Quantite quantiteSalaire = resultatRemuneration.recupererRemuneration(1);
    
    Quantite quantitePrimeNormal = resultatRemuneration.recupererRemuneration(2);
    
    Quantite quantitePrimeExceptionnelles = resultatRemuneration.recupererRemuneration(3);
    if (quantiteSalaire != null)
    {
      PeriodeRetenue periodeRetenueSalaires = (PeriodeRetenue)periodeRetenue.copie();
      periodeRetenueSalaires.setMontantRetenu((QuantiteEuro)quantiteSalaire);
      periodeRetenueSalaires.setNature(1);
      justification.ajouterPeriodeRetenue(periodeRetenueSalaires);
    }
    if (quantitePrimeNormal != null)
    {
      PeriodeRetenue periodeRetenuePrimesNormales = (PeriodeRetenue)periodeRetenue.copie();
      periodeRetenuePrimesNormales.setMontantRetenu((QuantiteEuro)quantitePrimeNormal);
      periodeRetenuePrimesNormales.setNature(2);
      justification.ajouterPeriodeRetenue(periodeRetenuePrimesNormales);
    }
    if (quantitePrimeExceptionnelles != null)
    {
      PeriodeRetenue periodeRetenuePrimesExceptionnelles = (PeriodeRetenue)periodeRetenue.copie();
      periodeRetenuePrimesExceptionnelles.setMontantRetenu((QuantiteEuro)quantitePrimeExceptionnelles);
      periodeRetenuePrimesExceptionnelles.setNature(3);
      justification.ajouterPeriodeRetenue(periodeRetenuePrimesExceptionnelles);
    }
  }
  
  private static void determinerCarenceSpecifique(DemandeAssuranceSpec demande, ConstitutionDelaisReport cepDelaisReport)
    throws CoucheLogiqueException
  {
    CarenceIslr carenceIslr = calculerCarenceSpecifique(demande);
    
    alimenterCEPPourCarenceSpecifique(cepDelaisReport, carenceIslr);
  }
  
  private static void alimenterCEPPourCarenceSpecifique(ConstitutionDelaisReport cepDelaisReport, CarenceIslr carenceIslr)
  {
    alimenterCEPPourCarence(cepDelaisReport, carenceIslr);
  }
  
  private static CarenceIslr calculerCarenceSpecifique(DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    ParametresCarenceSpecifique parametres = new ParametresCarenceSpecifique();
    FormuleSpec formuleCalculCarence = new FormuleCarenceSpecifique();
    DossierExamen dossierExamen = (DossierExamen)demande.getDossierExamen();
    CarenceIslr carenceIslr = null;
    boolean presenceTransaction = false;
    
    ActiviteSalarie periodeFG = recupererActiviteSalariePourCarenceSpecifique(demande);
    if (periodeFG != null)
    {
      boolean presenceAutreIndemnite = determinerMontantIslr(periodeFG, periodeFG.getDateFin());
      QuantiteEuro montantSJM = dossierExamen.getConstitutionElementsActifs().getConstitutionSalaireJournalierMoyen().getMontantSalaireJournalierMoyenRevalorisePlafonne();
      
      parametres.setMontantISLR(periodeFG.getQuantiteEuroIslr().getValeur());
      parametres.setSalaireJournalierMoyen(montantSJM.getValeur());
      if (periodeFG.getContrat().isTransactionEnCours())
      {
        carenceIslr = new CarenceIslr();
        carenceIslr.setOrigine(periodeFG);
        carenceIslr.setQuantiteInitiale(new QuantiteJour(parametres.getPlafondCarence()));
        presenceTransaction = true;
      }
      else if ((parametres.getMontantISLR() != null) && (parametres.getMontantISLR().compareTo(ZERO) > 0))
      {
        QuantiteJour quantiteJoursARetenir = (QuantiteJour)formuleCalculCarence.appliquerFormule(parametres);
        if ((quantiteJoursARetenir != null) && (quantiteJoursARetenir.getNombreJours() > 0))
        {
          carenceIslr = new CarenceIslr();
          carenceIslr.setOrigine(periodeFG);
          carenceIslr.setQuantiteInitiale(quantiteJoursARetenir);
        }
      }
      if (carenceIslr != null)
      {
        carenceIslr.setPresenceAutreIndemnite(presenceAutreIndemnite);
        carenceIslr.setPresenceTransaction(presenceTransaction);
      }
    }
    return carenceIslr;
  }
  
  private static ActiviteSalarie recupererActiviteSalariePourCarenceSpecifique(DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    DossierExamen dossierExamen = (DossierExamen)demande.getDossierExamen();
    if (dossierExamen.getFaitGenerateur() != null) {
      return dossierExamen.getFaitGenerateur().getPeriodeFaitGenerateur();
    }
    Periode periodeRecherche = determinerPeriodeReference(demande);
    FiltresTemporel filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreFinDansBornes(periodeRecherche));
    filtres.ajouterFiltre(new FiltreActiviteSalarie());
    Chronologie chronoPassePro = demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(filtres);
    
    return (ActiviteSalarie)RechercherDernierSinistre.rechercherDernierSinistre(demande.getDateExamen(), chronoPassePro);
  }
  
  private static boolean determinerMontantIslr(ActiviteSalarie periode, Damj dateFaitGenerateurOuDernierSinistre)
    throws CoucheLogiqueException
  {
    try
    {
      periode.setQuantiteEuroIslr(ConstitutionISLR.getInstance().calculeISLR(periode.getListeIndemnites(), periode.getCodeMotifFin(), periode.getCategorieEmploiParticulier(), dateFaitGenerateurOuDernierSinistre));
      
      return false;
    }
    catch (CoucheLogiqueException clex)
    {
      if (clex.getMessage().equals("ASU_PR_CALI_L_CEPA05_AUTRES_INDEMNITES_LEGALES")) {
        return true;
      }
      throw clex;
    }
  }
  
  private static void determinerDiffere(DemandeAssuranceSpec demande, ConstitutionDelaisReport cepDelaisReport)
    throws CoucheLogiqueException
  {
    Differe differe = calculerDiffere(demande);
    
    alimenterCEPPourDiffere(cepDelaisReport, differe);
  }
  
  private static Differe calculerDiffere(DemandeAssuranceSpec demande)
  {
    boolean creationDiffere = false;
    Differe differe = null;
    
    Attribution attributionCourante = (Attribution)demande.getDossierExamen();
    
    FiltreET filtreOdPourDelaisReport = new FiltreET();
    filtreOdPourDelaisReport.ajouterFiltre(new FiltreDecisionARESurDecision());
    filtreOdPourDelaisReport.ajouterFiltre(new FiltreOuvertureDroitStandardAssurance(true, true, true, false, demande));
    
    AttributionAssuranceSpec odPrecedente = (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande, filtreOdPourDelaisReport);
    if (odPrecedente != null)
    {
      Damj termePeriode = attributionCourante.getDateDebut();
      DureeCalendaire duree12Mois = new DureeCalendaire(0, 12, 0);
      Periode periode12MoisSurOdCourante = CalculDelais.determinerDelai(termePeriode, duree12Mois);
      periode12MoisSurOdCourante.setDebut(periode12MoisSurOdCourante.getDebut().lendemain());
      if (periode12MoisSurOdCourante.estApres(odPrecedente.getDateEffet())) {
        creationDiffere = true;
      }
    }
    else
    {
      creationDiffere = true;
    }
    if (creationDiffere) {
      differe = new Differe(7);
    }
    return differe;
  }
  
  private static void alimenterCEPPourDiffere(ConstitutionDelaisReport cepDelaisReport, Differe differe)
  {
    alimenterCEPPourCarence(cepDelaisReport, differe);
  }
  
  private static ConstitutionDelaisReport recupererDelaisReportActifs(DemandeAssuranceSpec demande)
  {
    return ((DossierExamen)demande.getDossierExamen()).getConstitutionElementsActifs().createConstitutionDelaisReport();
  }
  
  private static void alimenterCEPPourCarence(ConstitutionDelaisReport cepDelaisReport, CarencePrefixeAFixer carence)
  {
    if (carence != null) {
      cepDelaisReport.ajouterCarence(carence);
    }
  }
  
  private static void alimenterCEPPourCarence(ConstitutionDelaisReport cepDelaisReport, PreavisMesureConservatoireIndemnisableSpec carence)
  {
    if (carence != null) {
      cepDelaisReport.ajouterCarence(carence);
    }
  }
  
  private static void alimenterCEPPourCarence(ConstitutionDelaisReport cepDelaisReport, PreavisMesureConservatoireNonIndemnisableSpec carence)
  {
    if (carence != null) {
      cepDelaisReport.ajouterCarence(carence);
    }
  }
  
  private static Periode determinerPeriodeReference(DemandeAssuranceSpec demande)
  {
    Damj dateDebutPeriode = Damj.NUIT_DES_TEMPS;
    
    Damj dateFGOdPrecedente = demande.getDateFaitGenerateurOdPrecedente();
    if (dateFGOdPrecedente != null) {
      dateDebutPeriode = dateFGOdPrecedente.lendemain();
    }
    Damj dateFinPeriode = demande.getDateExamen();
    return new Periode(dateDebutPeriode, dateFinPeriode);
  }
  
  private static Periode determinerPeriodeReferencePMC(DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    Damj dateDebutPeriode = Damj.NUIT_DES_TEMPS;
    
    AttributionSpec attributionAssurancePrecedente = demande.rechercherAttributionPrecedenteDuMemeType();
    if ((attributionAssurancePrecedente != null) && (((Demande)attributionAssurancePrecedente.getDemande()).getDateFaitGenerateurOuDernierSinistre() != null)) {
      dateDebutPeriode = ((Demande)attributionAssurancePrecedente.getDemande()).getDateFaitGenerateurOuDernierSinistre().lendemain();
    }
    Damj dateFinPeriode = demande.getDateExamen();
    return new Periode(dateDebutPeriode, dateFinPeriode);
  }
}

/* Location:
 * Qualified Name:     StrategieDelaisReportAvant1erDecembre2010
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */