package fr.unedic.cali.asu.spe02.p03.migration.graphes;

import fr.unedic.cali.affectation.parametres.AccesDecorReglementaire;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.migration.graphes.GrapheAssurance;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.CarenceIslr;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.CarenceStandard;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConditionFaitGenerateur;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionDateAttribution;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionDelaisReport;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionElementsSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionMontantsBruts;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionNbHeuresTravaillees;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionPointDepartIndemnisation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionReglementApplicable;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionSalaireJournalierMoyen;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionSalaireReference;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Decision;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Differe;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.PreavisMesureConservatoireNonIndemnisable;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ValidationProduit;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.ParametresAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.dom.ParametresCalculAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.ParametresAffiliationSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.DeterminationDureeEffective;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.DeterminationSalaireJournalierMoyen;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.DeterminationSalaireReference;
import fr.unedic.cali.asu.spe02.p03.migration.graphes.recalcul.RecalculerCapitalDroitCourant;
import fr.unedic.cali.asu.spe02.p03.migration.graphes.recalcul.RecalculerMontantBrutDroitCourant;
import fr.unedic.cali.autresdoms.cohab.dom.CodesErreursMigration;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.PeriodeGaecSpec;
import fr.unedic.cali.dom.ConteneurAccesDecorReglementaire;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.affectation.Parametres;
import fr.unedic.cali.dom.affectation.ProduitAsuSpe02P03;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.parcours.ContexteParcoursCali;
import fr.unedic.cohabitation.sigma.migration.dom.DecisionMigreeAsuV1;
import fr.unedic.cohabitation.sigma.migration.dom.DemandeMigreeAsuV1;
import fr.unedic.cohabitation.sigma.migration.dom.DemandeMigreeV1;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Collection;

public abstract class GrapheDecision
  extends GrapheAssurance
{
  private final String indexPeriodeGaec = "-0";
  private static final ParametresAffiliationSpec PARAMETRES_AFFILIATION = new ParametresAffiliation();
  
  protected abstract void lireIdentifiant(Decision paramDecision, DecisionMigreeAsuV1 paramDecisionMigreeAsuV1);
  
  protected abstract DossierAffectation creerDossierAffectation();
  
  protected abstract void creerCaps(DossierExamen paramDossierExamen);
  
  protected abstract void creerCeps(DossierExamen paramDossierExamen);
  
  protected abstract Decision creerDecision(int paramInt);
  
  protected abstract void alimenterCaps(DecisionMigreeAsuV1 paramDecisionMigreeAsuV1, DossierExamen paramDossierExamen);
  
  protected abstract void alimenterCeps(DecisionMigreeAsuV1 paramDecisionMigreeAsuV1, DossierExamen paramDossierExamen);
  
  protected abstract void alimenterIdentifiant(DecisionMigreeAsuV1 paramDecisionMigreeAsuV1, Decision paramDecision);
  
  protected abstract void lireCaps(Decision paramDecision, DecisionMigreeAsuV1 paramDecisionMigreeAsuV1);
  
  protected abstract void lireCeps(Decision paramDecision, DecisionMigreeAsuV1 paramDecisionMigreeAsuV1);
  
  protected DemandeSpec construireGraphe(DemandeMigreeV1 demandeV1)
  {
    DemandeSpec demande = super.construireGraphe(demandeV1);
    
    DemandeMigreeAsuV1 demandeTemporaireSigma = (DemandeMigreeAsuV1)demandeV1;
    
    Demande demandeAsu = (Demande)demande;
    
    demandeAsu.setDossierAffectation(creerDossierAffectation());
    
    int natureDecision = demandeTemporaireSigma.getDecision().getNatureDecision();
    
    demandeAsu.getDossierAffectation().setDossierExamen(creerDecision(natureDecision));
    
    DossierExamen dossierExamen = (DossierExamen)demandeAsu.getDossierAffectation().getDossierExamen();
    
    creerCaps(dossierExamen);
    
    creerCeps(dossierExamen);
    
    return demande;
  }
  
  protected void lireValidationProduit(Decision decision, DecisionMigreeAsuV1 decisionLue)
  {
    ValidationProduit validationProduit = decision.getValidationProduit();
    
    decisionLue.setIdPeriodeValidation(validationProduit.getIdentifiantPeriodeValidationProduit());
    decisionLue.setDateValidationProduit(validationProduit.getDateFinPeriode());
    
    decisionLue.setReglementApplicable(validationProduit.getReglementApplicable().getNomReglement());
    decisionLue.getDemandeMigree().setCodeProduit(validationProduit.getProduitValide().getNomUnique());
    
    decisionLue.setQteAffiliation1(validationProduit.getQteAcquise().getValeur());
    decisionLue.setUniteAffiliation1(validationProduit.getQteAcquise().getUnite().getCode());
    
    ProduitSpec produit = Parametres.getProduit(validationProduit.getCodeProduitValide());
    decisionLue.getDemandeMigree().setCodeProduit(produit.getNom());
  }
  
  protected void lireDecision(Decision decision, DecisionMigreeAsuV1 decisionLue)
  {
    decisionLue.setNatureDecision(new BigDecimal(decision.getNatureDecision()));
  }
  
  protected void lireDonneesSimples(Decision decision, DecisionMigreeAsuV1 decisionLue)
  {
    decisionLue.setDateDerniereValidation(decision.getDemande().getDateDerniereValidation());
  }
  
  protected void lireCompetences(Decision decision, DecisionMigreeAsuV1 decisionLue)
  {
    if (decision.getCompetence() != null)
    {
      decisionLue.setCompetenceAdministrative(new BigDecimal(decision.getCompetence().getCompetenceAdministrative()));
      decisionLue.setCompetenceFinanciere(new BigDecimal(decision.getCompetence().getCompetenceFinanciere()));
    }
  }
  
  public DemandeMigreeV1 lireDonnees(DemandeSpec demande)
  {
    DemandeMigreeAsuV1 demandeLue = (DemandeMigreeAsuV1)super.lireDonnees(demande);
    DecisionMigreeAsuV1 decisionLue = demandeLue.getDecision();
    
    Demande demandeAsu = (Demande)demande;
    Decision decision = (Decision)demandeAsu.getDossierAffectation().getDossierExamen();
    
    lireValidationProduit(decision, decisionLue);
    
    lireDecision(decision, decisionLue);
    
    lireDonneesSimples(decision, decisionLue);
    
    lireCompetences(decision, decisionLue);
    
    lireIdentifiant(decision, decisionLue);
    
    lireCaps(decision, decisionLue);
    
    lireCeps(decision, decisionLue);
    
    return demandeLue;
  }
  
  protected void lireConditionFaitGenerateur(Decision decision, DecisionMigreeAsuV1 decisionLue)
  {
    ConditionFaitGenerateur conditionFg = (ConditionFaitGenerateur)decision.getConditionFaitGenerateur();
    if (conditionFg != null)
    {
      decisionLue.setIdPeriodeFgd(conditionFg.getIdentifiantPeriodeFG());
      decisionLue.setDateFgd(conditionFg.getDateFaitGenerateur());
    }
  }
  
  protected void lireConstitutionMontantsBruts(Decision decision, DecisionMigreeAsuV1 decisionLue)
  {
    if (decision.getConstitutionMontantsBruts().getMontantJournalierBrut() != null) {
      decisionLue.setMontantBrut(decision.getConstitutionMontantsBruts().getMontantJournalierBrut().getValeur());
    }
    if (decision.getConstitutionMontantsBruts().getCapitalInitialBrut() != null) {
      decisionLue.setCapitalOdCourante(decision.getConstitutionMontantsBruts().getCapitalInitialBrut().getValeur());
    }
  }
  
  protected void lireConstitutionDurees(Decision decision, DecisionMigreeAsuV1 decisionLue)
  {
    if (decision.getConstitutionDurees().getDureeTheorique() != null) {
      decisionLue.setDureeTheoriqueDroitCourant(decision.getConstitutionDurees().getDureeTheorique().getValeur());
    }
    if (decision.getConstitutionDurees().getDureeEffective() != null) {
      decisionLue.setDureeEffectiveDroitCourant(decision.getConstitutionDurees().getDureeEffective().getValeur());
    }
  }
  
  protected void lireConstitutionDelaisReport(Decision decision, DecisionMigreeAsuV1 decisionLue)
  {
    ConstitutionDelaisReport cepaDelaisReport = decision.getConstitutionDelaisReport();
    decisionLue.setDateDebutDiffereStandard(cepaDelaisReport.getDebutCarenceStandard());
    decisionLue.setDateFinDiffereStandard(cepaDelaisReport.getTermeCarenceStandard());
    decisionLue.setNbJoursDiffereStandard(new BigDecimal(cepaDelaisReport.getNbJoursCarenceStandard()));
    
    decisionLue.setDebutCarencePMC(cepaDelaisReport.getDebutPMCNonIndemn());
    decisionLue.setFinCarencePMC(cepaDelaisReport.getTermePMCNonIndemn());
    decisionLue.setNbJoursCarencePMC(new BigDecimal(cepaDelaisReport.getNbJoursPMCNonIndemn()));
    
    decisionLue.setDebutDiffere(cepaDelaisReport.getDebutDelaiReport());
    decisionLue.setFinDiffere(cepaDelaisReport.getTermeDelaiReport());
    decisionLue.setNbJoursDiffere(new BigDecimal(cepaDelaisReport.getNbJoursDelaiReport()));
    
    decisionLue.setDebutCarenceISLR(cepaDelaisReport.getDebutCarenceISLR());
    decisionLue.setFinCarenceISLR(cepaDelaisReport.getTermeCarenceISLR());
    decisionLue.setNbJoursCarenceISLR(new BigDecimal(cepaDelaisReport.getNbJoursCarenceISLR()));
  }
  
  protected void lireConstitutionReglementApplicable(Decision decision, DecisionMigreeAsuV1 decisionLue)
  {
    decisionLue.setReglementApplicable(decision.getConstitutionReglementApplicable().getReglement().getNomReglement());
  }
  
  protected void lireConstitutionDateAttribution(Decision decision, DecisionMigreeAsuV1 decisionLue)
  {
    decisionLue.setDateAttribution(decision.getConstitutionDateAttribution().getDateAttribution());
  }
  
  protected void lireConstitutionPji(Decision decision, DecisionMigreeAsuV1 decisionLue)
  {
    decisionLue.setPji(decision.getConstitutionPointDepartIndemnisation().getPointDepartIndemnisation());
  }
  
  protected void lireConstitutionSr(Decision decision, DecisionMigreeAsuV1 decisionLue)
  {
    ConstitutionSalaireReference cepaSr = decision.getConstitutionSalaireReference();
    if (cepaSr.getSalaireReferenceInitial() != null) {
      decisionLue.setMontantSRInitial(cepaSr.getSalaireReferenceInitial().getValeur());
    }
    if (cepaSr.getSalaireReferenceInitialPlafonne() != null) {
      decisionLue.setMontantSRInitialPlafonne(cepaSr.getSalaireReferenceInitialPlafonne().getValeur());
    }
    Periode prc = cepaSr.getPrc();
    if (prc != null)
    {
      decisionLue.setDateDebutPrcSjrInitialDroitCourant(prc.getDebut());
      decisionLue.setDateFinPrcSjrInitialDroitCourant(prc.getFin());
    }
    int nombreJoursEmploiDansPRC = cepaSr.getNombreJoursEmploiDansPRC();
    if (nombreJoursEmploiDansPRC != 0) {
      ((DemandeMigreeAsuV1)decisionLue.getDemandeMigree()).setNbJoursEmploi(new BigDecimal(nombreJoursEmploiDansPRC));
    }
  }
  
  protected void lireConstitutionSjm(Decision decision, DecisionMigreeAsuV1 decisionLue)
  {
    ConstitutionSalaireJournalierMoyen cepaSjm = decision.getConstitutionSalaireJournalierMoyen();
    if (cepaSjm.getMontantSalaireJournalierMoyenInitial() != null) {
      decisionLue.setMontantSalaireJournalierMoyenInitial(cepaSjm.getMontantSalaireJournalierMoyenInitial().getValeur());
    }
  }
  
  protected void lireConstitutionNbreHeuresTravaillees(Decision decision, DecisionMigreeAsuV1 decisionLue)
  {
    ConstitutionNbHeuresTravaillees cepaNbHeuresTrav = decision.getConstitutionNbHeuresTravaillees();
    decisionLue.setNbHeuresTravailleesEtendu(cepaNbHeuresTrav.getNombreHeuresTravailleesEtendu());
    decisionLue.setNbHeuresTravailleesPlafonne(cepaNbHeuresTrav.getNombreHeuresTravailleesPlafonne());
  }
  
  protected void reinitialiseConstitutionDurees(DossierExamen dossierExamen)
  {
    dossierExamen.getConstitutionElementsActifs().createConstitutionDurees();
  }
  
  protected void alimenterDonnees(DemandeMigreeV1 demandeV1, DemandeSpec demande)
  {
    super.alimenterDonnees(demandeV1, demande);
    
    Decision decisionAsu = (Decision)demande.getDossierAffectation().getDossierExamen();
    
    DemandeMigreeAsuV1 demandeTemporaireSigma = (DemandeMigreeAsuV1)demandeV1;
    DecisionMigreeAsuV1 decisionTemporaireSigma = demandeTemporaireSigma.getDecision();
    
    alimenterValidationProduit(demandeTemporaireSigma, decisionAsu);
    
    alimenterDonneesSimples(decisionTemporaireSigma, decisionAsu);
    
    alimenterIdentifiant(decisionTemporaireSigma, decisionAsu);
    
    DossierExamen dossierExamen = (DossierExamen)demande.getDossierAffectation().getDossierExamen();
    
    alimenterCaps(decisionTemporaireSigma, dossierExamen);
    
    alimenterCeps(decisionTemporaireSigma, dossierExamen);
  }
  
  protected void alimenterValidationProduit(DemandeMigreeAsuV1 demandeTemporaireSource, Decision decision)
  {
    ValidationProduit validationProduit = decision.getValidationProduit();
    
    String idPeriodeValidation = demandeTemporaireSource.getDecision().getIdPeriodeValidation();
    if (idPeriodeValidation == null)
    {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_PERIO_VALID"));
    }
    else if (isPeriodeValidationProduitValide(idPeriodeValidation))
    {
      validationProduit.setIdentifiantPeriodeValidationProduit(idPeriodeValidation);
      
      ActiviteSalarie periodeValidation = validationProduit.getPeriodeValidationProduit();
      if (periodeValidation == null)
      {
        validationProduit.setIdentifiantPeriodeValidationProduit(idPeriodeValidation + "-0");
        
        periodeValidation = validationProduit.getPeriodeValidationProduit();
        if (periodeValidation == null) {
          getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_PERIO_VALID"));
        } else {
          validationProduit.setPeriodeValidationProduit(periodeValidation);
        }
      }
      else
      {
        validationProduit.setPeriodeValidationProduit(periodeValidation);
      }
    }
    else
    {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_PER_INVALIDE"));
    }
    ProduitSpec produit = Parametres.getProduit(demandeTemporaireSource.getCodeProduit());
    validationProduit.setProduitValide(produit);
    validationProduit.setEstProduitValide(true);
    
    DecisionMigreeAsuV1 decisionMigreeAsuV1 = demandeTemporaireSource.getDecision();
    if (decisionMigreeAsuV1.getQteAffiliation1() == null) {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_QTE_AFFI_1"));
    }
    if (decisionMigreeAsuV1.getUniteAffiliation1() == null) {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_UNITE_AFFI_1"));
    }
    if ((decisionMigreeAsuV1.getQteAffiliation1() != null) && (decisionMigreeAsuV1.getUniteAffiliation1() != null))
    {
      Unite uniteAffiliation1 = null;
      try
      {
        uniteAffiliation1 = Unite.getParCode(decisionMigreeAsuV1.getUniteAffiliation1());
      }
      catch (NullPointerException e) {}
      if (uniteAffiliation1 == null) {
        getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_UNITE_AFFI_1", decisionMigreeAsuV1.getUniteAffiliation1()));
      } else {
        validationProduit.setQuantiteAcquise(new Quantite(demandeTemporaireSource.getDecision().getQteAffiliation1(), uniteAffiliation1));
      }
    }
    if ((demandeTemporaireSource.getDecision().getReglementApplicable() != null) || (produit.getReglement(demandeTemporaireSource.getDecision().getReglementApplicable()) != null)) {
      validationProduit.setReglementApplicable(produit.getReglement(demandeTemporaireSource.getDecision().getReglementApplicable()));
    } else {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_RA"));
    }
    if (validationProduit.getPeriodeValidationProduit() != null)
    {
      ConteneurAccesDecorReglementaire conteneur = new ConteneurAccesDecorReglementaire();
      conteneur.setDateRecherche(validationProduit.getPeriodeValidationProduit().getDateFin());
      try
      {
        ((DossierAffectation)decision.getDossierAffecte()).setDecorReglementaire(AccesDecorReglementaire.getInstance().getDecor(conteneur));
      }
      catch (CoucheLogiqueException ex) {}
    }
    validationProduit.setRangAllongement(demandeTemporaireSource.getDecision().getRangAllongement());
    if (((demandeTemporaireSource.getDecision().getReglementApplicable() != null) || (produit.getReglement(demandeTemporaireSource.getDecision().getReglementApplicable()) != null)) && (validationProduit.getPeriodeValidationProduit() != null))
    {
      ParametresCalculAffiliation parametres = new ParametresCalculAffiliation();
      
      parametres.setFaitGenerateurDroit(validationProduit.getPeriodeValidationProduit());
      parametres.setRangEtude(validationProduit.getRangAllongement());
      parametres.setReglementEtudie(validationProduit.getReglementApplicable());
      
      BigDecimal qte = PARAMETRES_AFFILIATION.determinerQuantiteAffiliationRequise(parametres);
      Quantite heuresRequisesPra = new Quantite(qte, Unite.getParCode("3"));
      validationProduit.setHeuresRequises(heuresRequisesPra);
      
      Periode pra = new Periode();
      DecisionMigreeAsuV1 decisionTemporaireSource = demandeTemporaireSource.getDecision();
      if ((decisionTemporaireSource != null) && (decisionTemporaireSource.getDateDebutPrcSjrInitialDroitCourant() != null) && (decisionTemporaireSource.getDateFinPrcSjrInitialDroitCourant() != null))
      {
        pra.setDebut(decisionTemporaireSource.getDateDebutPrcSjrInitialDroitCourant());
        pra.setFin(decisionTemporaireSource.getDateFinPrcSjrInitialDroitCourant());
      }
      else
      {
        Damj debutPra = validationProduit.getDateFinPeriode();
        Damj finPra = debutPra;
        DureeCalendaire dureePra = PARAMETRES_AFFILIATION.determinerDureePeriodeReference(parametres);
        debutPra = debutPra.deplacerVersArriere(dureePra);
        pra.setDebut(debutPra);
        pra.setFin(finPra);
      }
      validationProduit.setPeriodePra(pra);
    }
  }
  
  private boolean isPeriodeValidationProduitValide(String idPeriodeValidation)
  {
    Individu individuCourant = ContexteParcoursCali.getIndividuCourant();
    
    PeriodeGaecSpec periode = individuCourant.rechercherPeriodePasseProfessionnel(idPeriodeValidation);
    if (periode == null) {
      periode = individuCourant.rechercherPeriodePasseProfessionnel(idPeriodeValidation + "-0");
    }
    return periode instanceof ActiviteSalarie;
  }
  
  protected void alimenterDonneesSimples(DecisionMigreeAsuV1 decisionTemporaireSource, Decision decisionInstallee)
  {
    Damj dateDerniereValidation = decisionTemporaireSource.getDateDerniereValidation();
    if (dateDerniereValidation == null)
    {
      getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_DATE_VALID"));
    }
    else
    {
      decisionInstallee.getDemande().setDateDerniereValidation(dateDerniereValidation);
      
      decisionInstallee.setValidee(true);
    }
  }
  
  protected void alimenterConditionFaitGenerateur(DecisionMigreeAsuV1 decisionTemporaireSource, DossierExamen dossierExamen)
  {
    ConditionFaitGenerateur capaFg = (ConditionFaitGenerateur)dossierExamen.getFaitGenerateur();
    
    String idPeriodeFgd = decisionTemporaireSource.getIdPeriodeFgd();
    if (idPeriodeFgd == null)
    {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_ID_PERIO_FGD"));
    }
    else if (isPeriodeValidationProduitValide(idPeriodeFgd))
    {
      capaFg.setIdentifiantPeriodeFG(idPeriodeFgd);
      
      Individu individuCourant = ContexteParcoursCali.getIndividuCourant();
      ActiviteSalarie periodeFgd = (ActiviteSalarie)individuCourant.rechercherPeriodePasseProfessionnel(idPeriodeFgd);
      if (periodeFgd == null)
      {
        periodeFgd = (ActiviteSalarie)individuCourant.rechercherPeriodePasseProfessionnel(idPeriodeFgd + "-0");
        if (periodeFgd == null)
        {
          getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_PERIO_FGD"));
        }
        else
        {
          capaFg.setPeriodeFaitGenerateur(periodeFgd);
          
          ((DossierAffecte)dossierExamen.getDossierAffecte()).setSinistre(periodeFgd);
        }
      }
      else
      {
        capaFg.setPeriodeFaitGenerateur(periodeFgd);
        
        ((DossierAffecte)dossierExamen.getDossierAffecte()).setSinistre(periodeFgd);
      }
    }
    else
    {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_PER_FGD"));
    }
    capaFg.setEtatSatisfait(true);
  }
  
  protected void alimenterConstitutionMontantsBruts(DecisionMigreeAsuV1 decisionTemporaireSource, DossierExamen dossierExamen)
  {
    ConstitutionMontantsBruts cepaMontantsBruts = dossierExamen.getConstitutionMontantsBruts();
    if (decisionTemporaireSource.getCapitalOdCourante() == null)
    {
      cepaMontantsBruts.setCapitalInitialBrut(new QuantiteEuro("0"));
      getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_CAPITAL_DC"));
    }
    else
    {
      cepaMontantsBruts.setCapitalInitialBrut(decisionTemporaireSource.getCapitalOdCourante());
    }
    if (decisionTemporaireSource.getMontantBrut() == null)
    {
      cepaMontantsBruts.setMontantJournalierBrut(new QuantiteEuro("0"));
      getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_MONTANT_BRUT"));
    }
    else
    {
      cepaMontantsBruts.setMontantJournalierBrut(decisionTemporaireSource.getMontantBrut());
    }
  }
  
  protected void alimenterConstitutionDurees(DecisionMigreeAsuV1 decisionTemporaireSource, DossierExamen dossierExamen)
  {
    ConstitutionDurees cepaDuree = dossierExamen.getConstitutionDurees();
    if (decisionTemporaireSource.getDureeTheoriqueDroitCourant() != null)
    {
      cepaDuree.setDureeEffective(decisionTemporaireSource.getDureeEffectiveDroitCourant());
      cepaDuree.setDureeTheorique(decisionTemporaireSource.getDureeTheoriqueDroitCourant());
      cepaDuree.setDureeImputation(new Quantite(DeterminationDureeEffective.ZERO, DeterminationDureeEffective.UNITE_DEFAUT));
    }
    else
    {
      getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_DUREE_THEOR"));
    }
  }
  
  protected void alimenterConstitutionSr(DecisionMigreeAsuV1 decisionTemporaireSource, DossierExamen dossierExamen)
  {
    ConstitutionSalaireReference cepaSR = dossierExamen.getConstitutionSalaireReference();
    
    boolean montantSRInitial = false;
    if (decisionTemporaireSource.getMontantSRInitial() != null)
    {
      cepaSR.setSalaireReferenceInitial(new QuantiteEuro(decisionTemporaireSource.getMontantSRInitial()));
      montantSRInitial = true;
    }
    else
    {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_MT_SJRI"));
    }
    boolean montantSRInitialPlafonne = false;
    if (decisionTemporaireSource.getMontantSRInitialPlafonne() != null)
    {
      cepaSR.setSalaireReferenceInitialPlafonne(new QuantiteEuro(decisionTemporaireSource.getMontantSRInitialPlafonne()));
      montantSRInitialPlafonne = true;
    }
    else
    {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_MT_SJRIP"));
    }
    boolean nombreJoursEmploiSurPra = false;
    int nbreEmploiPrc = 0;
    BigDecimal nbJourContratSurPraSpectacle = ((DemandeMigreeAsuV1)decisionTemporaireSource.getDemandeMigree()).getNbJoursEmploi();
    if (nbJourContratSurPraSpectacle != null)
    {
      nbreEmploiPrc = nbJourContratSurPraSpectacle.intValue();
      cepaSR.setNombreJoursEmploiDansPRC(nbreEmploiPrc);
      nombreJoursEmploiSurPra = true;
    }
    else
    {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_NBJ_EMPLOI"));
    }
    boolean dateDebutPrcSjrInitialDroitCourant = false;
    boolean dateFinPrcSjrInitialDroitCourant = false;
    Periode prc = new Periode();
    if (decisionTemporaireSource.getDateDebutPrcSjrInitialDroitCourant() != null)
    {
      prc.setDebut(decisionTemporaireSource.getDateDebutPrcSjrInitialDroitCourant());
      dateDebutPrcSjrInitialDroitCourant = true;
    }
    if (decisionTemporaireSource.getDateFinPrcSjrInitialDroitCourant() != null)
    {
      prc.setFin(decisionTemporaireSource.getDateFinPrcSjrInitialDroitCourant());
      dateFinPrcSjrInitialDroitCourant = true;
    }
    if ((nombreJoursEmploiSurPra) && (montantSRInitial) && (montantSRInitialPlafonne) && (dateDebutPrcSjrInitialDroitCourant) && (dateFinPrcSjrInitialDroitCourant))
    {
      cepaSR.setPrc(prc);
      
      Damj dateAttribution = decisionTemporaireSource.getDateAttribution();
      cepaSR.setMontantPlafond(new QuantiteEuro(DeterminationSalaireReference.determinerPlafondSrr(nbreEmploiPrc, dateAttribution)));
      
      cepaSR.setSalaireReferenceRevalorisePlafonne(DeterminationSalaireReference.determinerSrrp(cepaSR, dateAttribution));
    }
    else
    {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_PRC"));
    }
  }
  
  protected void alimenterConstitutionReglementApplicable(DecisionMigreeAsuV1 decisionTemporaireSource, DossierExamen dossierExamen)
  {
    ConstitutionReglementApplicable cepaReglementApplicable = (ConstitutionReglementApplicable)dossierExamen.getConstitutionReglementApplicable();
    if ((decisionTemporaireSource.getReglementApplicable() != null) || (ProduitAsuSpe02P03.getInstance().contientReglement(decisionTemporaireSource.getReglementApplicable()))) {
      cepaReglementApplicable.setReglement(ProduitAsuSpe02P03.getInstance().getReglement(decisionTemporaireSource.getReglementApplicable()));
    } else {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_RA"));
    }
  }
  
  protected void alimenterConstitutionDateAttribution(DecisionMigreeAsuV1 decisionTemporaireSource, DossierExamen dossierExamen)
  {
    ConstitutionDateAttribution cepaDateAttribution = dossierExamen.getConstitutionDateAttribution();
    if (decisionTemporaireSource.getDateAttribution() != null) {
      cepaDateAttribution.setDateAttribution(decisionTemporaireSource.getDateAttribution());
    } else {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_HG_DATE_ATTRIB"));
    }
  }
  
  protected void alimenterConstitutionPji(DecisionMigreeAsuV1 decisionTemporaireSource, DossierExamen dossierExamen)
  {
    ConstitutionPointDepartIndemnisation cepaPji = dossierExamen.getConstitutionPointDepartIndemnisation();
    if (decisionTemporaireSource.getPji() != null) {
      cepaPji.setPointDepartIndemnisation(decisionTemporaireSource.getPji());
    } else {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_HG_PJI"));
    }
  }
  
  protected void reinitialiserCarences(ConstitutionDelaisReport cepaDelaisReport)
  {
    cepaDelaisReport.clearCollectionCarence();
    
    cepaDelaisReport.setDebutCarenceStandard(null);
    cepaDelaisReport.setTermeCarenceStandard(null);
    cepaDelaisReport.setNbJoursCarenceStandard(0);
    
    cepaDelaisReport.setDebutCarenceISLR(null);
    cepaDelaisReport.setTermeCarenceISLR(null);
    cepaDelaisReport.setNbJoursCarenceISLR(0);
    
    cepaDelaisReport.setDebutDelaiReport(null);
    cepaDelaisReport.setTermeDelaiReport(null);
    cepaDelaisReport.setNbJoursDelaiReport(0);
    
    cepaDelaisReport.setDebutPMCNonIndemn(null);
    cepaDelaisReport.setTermePMCNonIndemn(null);
    cepaDelaisReport.setNbJoursPMCNonIndemn(0);
  }
  
  protected void alimenterConstitutionDelaisReport(DecisionMigreeAsuV1 decisionTemporaireSource, DossierExamen dossierExamen)
  {
    ConstitutionDelaisReport cepaDelaisReport = dossierExamen.getConstitutionDelaisReport();
    
    reinitialiserCarences(cepaDelaisReport);
    if ((decisionTemporaireSource.getNbJoursDiffereStandard() == null) || (decisionTemporaireSource.getDateDebutDiffereStandard() == null) || (decisionTemporaireSource.getDateFinDiffereStandard() == null))
    {
      if (decisionTemporaireSource.getNbJoursDiffereStandard() == null) {
        getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_NBJ_DIFF_STD"));
      } else if (decisionTemporaireSource.getNbJoursDiffereStandard().intValue() == -1) {
        getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_NBJ_DIFF_STD"));
      }
      if (decisionTemporaireSource.getDateDebutDiffereStandard() == null) {
        getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_DEB_DIFF_STD"));
      }
      if (decisionTemporaireSource.getDateFinDiffereStandard() == null) {
        getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_FIN_DIFF_STD"));
      }
    }
    else
    {
      CarenceStandard carenceStandard = new CarenceStandard();
      
      cepaDelaisReport.setNbJoursCarenceStandard(decisionTemporaireSource.getNbJoursDiffereStandard().intValue());
      carenceStandard.setQuantiteInitiale(new QuantiteJour(decisionTemporaireSource.getNbJoursDiffereStandard()));
      
      carenceStandard.setPeriodeApplicationCarence(new Periode(decisionTemporaireSource.getDateDebutDiffereStandard(), decisionTemporaireSource.getDateFinDiffereStandard()));
      
      cepaDelaisReport.setDebutCarenceStandard(decisionTemporaireSource.getDateDebutDiffereStandard());
      cepaDelaisReport.setTermeCarenceStandard(decisionTemporaireSource.getDateFinDiffereStandard());
      
      cepaDelaisReport.ajouterCarence(carenceStandard);
    }
    if ((decisionTemporaireSource.getNbJoursCarenceISLR() == -1) || (decisionTemporaireSource.getDebutCarenceISLR() == null) || (decisionTemporaireSource.getFinCarenceISLR() == null))
    {
      if (decisionTemporaireSource.getNbJoursCarenceISLR() == -1) {
        getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_NB_JRS_ISLR"));
      }
      if (decisionTemporaireSource.getDebutCarenceISLR() == null) {
        getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_DEBUT_ISLR"));
      }
      if (decisionTemporaireSource.getFinCarenceISLR() == null) {
        getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_FIN_ISLR"));
      }
    }
    else
    {
      CarenceIslr carenceIslr = new CarenceIslr();
      
      cepaDelaisReport.setNbJoursCarenceISLR(decisionTemporaireSource.getNbJoursCarenceISLR());
      carenceIslr.setQuantiteInitiale(new QuantiteJour(new BigDecimal(decisionTemporaireSource.getNbJoursCarenceISLR())));
      
      carenceIslr.setPeriodeApplicationCarence(new Periode(decisionTemporaireSource.getDebutCarenceISLR(), decisionTemporaireSource.getFinCarenceISLR()));
      
      cepaDelaisReport.setDebutCarenceISLR(decisionTemporaireSource.getDebutCarenceISLR());
      cepaDelaisReport.setTermeCarenceISLR(decisionTemporaireSource.getFinCarenceISLR());
      
      cepaDelaisReport.ajouterCarence(carenceIslr);
    }
    if ((decisionTemporaireSource.getNbJoursDiffere() == -1) || (decisionTemporaireSource.getDebutDiffere() == null) || (decisionTemporaireSource.getFinDiffere() == null))
    {
      if (decisionTemporaireSource.getNbJoursDiffere() == -1) {
        getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_NB_JRS_DIFF"));
      }
      if (decisionTemporaireSource.getDebutDiffere() == null) {
        getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_DEBUT_DIFF"));
      }
      if (decisionTemporaireSource.getFinDiffere() == null) {
        getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_FIN_DIFFERE"));
      }
    }
    else
    {
      Differe carenceDiffere = new Differe();
      
      cepaDelaisReport.setNbJoursDelaiReport(decisionTemporaireSource.getNbJoursDiffere());
      carenceDiffere.setQuantiteInitiale(new QuantiteJour(new BigDecimal(decisionTemporaireSource.getNbJoursDiffere())));
      
      carenceDiffere.setPeriodeApplicationCarence(new Periode(decisionTemporaireSource.getDebutDiffere(), decisionTemporaireSource.getFinDiffere()));
      
      cepaDelaisReport.setDebutDelaiReport(decisionTemporaireSource.getDebutDiffere());
      cepaDelaisReport.setTermeDelaiReport(decisionTemporaireSource.getFinDiffere());
      
      cepaDelaisReport.ajouterCarence(carenceDiffere);
    }
    if ((decisionTemporaireSource.getNbJoursCarencePMC() == -1) || (decisionTemporaireSource.getDebutCarencePMC() == null) || (decisionTemporaireSource.getFinCarencePMC() == null))
    {
      if (decisionTemporaireSource.getNbJoursCarencePMC() == -1) {
        getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_NB_JOURS_PMC"));
      }
      if (decisionTemporaireSource.getDebutCarencePMC() == null) {
        getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_DEBUT_PMC"));
      }
      if (decisionTemporaireSource.getFinCarencePMC() == null) {
        getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_FIN_PMC"));
      }
    }
    else
    {
      PreavisMesureConservatoireNonIndemnisable carencePmc = new PreavisMesureConservatoireNonIndemnisable();
      
      cepaDelaisReport.setNbJoursPMCNonIndemn(decisionTemporaireSource.getNbJoursCarencePMC());
      
      carencePmc.setPeriodeApplicationCarence(new Periode(decisionTemporaireSource.getDebutCarencePMC(), decisionTemporaireSource.getFinCarencePMC()));
      
      cepaDelaisReport.setDebutPMCNonIndemn(decisionTemporaireSource.getDebutCarencePMC());
      cepaDelaisReport.setTermePMCNonIndemn(decisionTemporaireSource.getFinCarencePMC());
      
      cepaDelaisReport.ajouterCarence(carencePmc);
    }
  }
  
  protected void alimenterConstitutionNbreHeuresTravaillees(DecisionMigreeAsuV1 decisionTemporaireSource, DossierExamen dossierExamen)
  {
    ConstitutionNbHeuresTravaillees cepaNbHeures = dossierExamen.getConstitutionNbHeuresTravaillees();
    BigDecimal nbHeuresTravaillesEtendu = decisionTemporaireSource.getNbHeuresTravailleesEtendu();
    BigDecimal nbHeuresTravaillesPlafonne = decisionTemporaireSource.getNbHeuresTravailleesPlafonne();
    if (nbHeuresTravaillesEtendu != null) {
      cepaNbHeures.setNombreHeuresTravailleesEtendu(nbHeuresTravaillesEtendu);
    } else {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_NBH_ETENDU"));
    }
    if (nbHeuresTravaillesPlafonne != null)
    {
      if ((nbHeuresTravaillesPlafonne != null) && (nbHeuresTravaillesPlafonne.longValue() == 0L))
      {
        decisionTemporaireSource.setNbHeuresTravailleesPlafonne(nbHeuresTravaillesEtendu);
        cepaNbHeures.setNombreHeuresTravailleesPlafonne(nbHeuresTravaillesEtendu);
      }
      else
      {
        cepaNbHeures.setNombreHeuresTravailleesPlafonne(nbHeuresTravaillesPlafonne);
      }
    }
    else
    {
      decisionTemporaireSource.setNbHeuresTravailleesPlafonne(nbHeuresTravaillesEtendu);
      cepaNbHeures.setNombreHeuresTravailleesPlafonne(nbHeuresTravaillesEtendu);
    }
  }
  
  protected void alimenterConstitutionSjm(DossierExamen dossierExamen)
  {
    QuantiteEuro srrp = dossierExamen.getConstitutionSalaireReference().getSalaireReferenceRevalorisePlafonne();
    BigDecimal nbHeuresTravaillesEtendu = dossierExamen.getConstitutionNbHeuresTravaillees().getNombreHeuresTravailleesEtendu();
    if ((srrp != null) && (nbHeuresTravaillesEtendu != null)) {
      DeterminationSalaireJournalierMoyen.getInstance().determinerSalaireJournalierMoyen((Demande)dossierExamen.getDemande());
    }
  }
  
  protected void alimenterDonneesImposees(DemandeMigreeV1 demandeV1, DemandeSpec demande)
  {
    DossierExamen dossierExamen = (DossierExamen)demande.getDossierAffectation().getDossierExamen();
    DecisionMigreeAsuV1 decisionAsu = ((DemandeMigreeAsuV1)demandeV1).getDecision();
    
    alimenterConstitutionMontantsBruts(decisionAsu, dossierExamen);
    
    reinitialiseConstitutionDurees(dossierExamen);
    alimenterConstitutionDurees(decisionAsu, dossierExamen);
    
    alimenterSrip(decisionAsu);
    
    alimenterConstitutionSr(decisionAsu, dossierExamen);
    alimenterConstitutionNbreHeuresTravaillees(decisionAsu, dossierExamen);
    alimenterConstitutionDateAttribution(decisionAsu, dossierExamen);
    alimenterConstitutionSjm(dossierExamen);
    alimenterConstitutionDelaisReport(decisionAsu, dossierExamen);
    alimenterConstitutionReglementApplicable(decisionAsu, dossierExamen);
    alimenterConstitutionPji(decisionAsu, dossierExamen);
  }
  
  protected void alimenterDonneesForcage(DemandeMigreeV1 demandeV1, DemandeSpec demande)
  {
    super.alimenterDonneesForcage(demandeV1, demande);
    alimenterDonneesImposees(demandeV1, demande);
  }
  
  protected void alimenterSrip(DecisionMigreeAsuV1 decisionTemporaireSource)
  {
    decisionTemporaireSource.setMontantSRInitialPlafonne(decisionTemporaireSource.getMontantSRInitial());
  }
  
  protected Collection getListRecalcule()
  {
    Collection listeRecalcul = super.getListRecalcule();
    listeRecalcul.add(new RecalculerMontantBrutDroitCourant());
    listeRecalcul.add(new RecalculerCapitalDroitCourant());
    
    return listeRecalcul;
  }
}

/* Location:
 * Qualified Name:     GrapheDecision
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */