package fr.unedic.cali.asu.spe02.p03.migration.graphes;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConditionsAttributionAdmission;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionElementsAdmission;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Decision;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Od;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ValidationProduit;
import fr.unedic.cali.autresdoms.cohab.dom.CodesErreursMigration;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.affectation.Parametres;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cohabitation.sigma.migration.dom.DecisionMigreeAsuV1;
import fr.unedic.cohabitation.sigma.migration.dom.DemandeMigreeAsuV1;
import fr.unedic.cohabitation.sigma.migration.dom.DemandeMigreeV1;
import java.math.BigDecimal;
import java.util.Collection;

public class GrapheOd
  extends GrapheDecision
{
  protected void creerCaps(DossierExamen p_dossierExamen)
  {
    p_dossierExamen.getConditionAttributionAdmission().createConditionFaitGenerateur();
  }
  
  protected void creerCeps(DossierExamen p_dossierExamen)
  {
    ConstitutionElementsAdmission constitutionElementsAdmission = p_dossierExamen.getConstitutionElementsAdmission();
    if (constitutionElementsAdmission != null)
    {
      constitutionElementsAdmission.createConstitutionMontantsBruts();
      constitutionElementsAdmission.createConstitutionDurees();
      constitutionElementsAdmission.createConstitutionSalaireReference();
      constitutionElementsAdmission.createConstitutionNbHeuresTravaillees();
      constitutionElementsAdmission.createConstitutionDateAttribution();
      constitutionElementsAdmission.createConstitutionSalaireJournalierMoyen();
      constitutionElementsAdmission.createConstitutionDelaisReport();
      constitutionElementsAdmission.createConstitutionReglementApplicable();
      constitutionElementsAdmission.createConstitutionPointDepartIndemnisation();
    }
  }
  
  protected ObjectifExamen creerObjectifDecision(DemandeMigreeAsuV1 p_demandeTemporaireSource)
  {
    ObjectifExamen objectifExamen = null;
    ProduitAsuSpec produitAsu = (ProduitAsuSpec)Parametres.getProduit(p_demandeTemporaireSource.getCodeProduit());
    if (produitAsu != null)
    {
      objectifExamen = (ObjectifExamen)produitAsu.creerObjectifExamen(10, null);
      objectifExamen.setEtat(23);
    }
    return objectifExamen;
  }
  
  protected Decision creerDecision(int p_natureDecision)
  {
    Decision nouvelleDecision = new Od();
    nouvelleDecision.setNatureDecision(10);
    return nouvelleDecision;
  }
  
  protected DossierAffectation creerDossierAffectation()
  {
    DossierAffectation dossierAffectation = new DossierAffecte(1);
    ValidationProduit validation = new ValidationProduit();
    dossierAffectation.setValidationProduit(validation);
    return dossierAffectation;
  }
  
  protected void alimenterIdentifiant(DecisionMigreeAsuV1 p_decisionTemporaireSource, Decision p_decisionInstallee)
  {
    BigDecimal idAdmission = p_decisionTemporaireSource.getIdAdmission();
    if (idAdmission != null)
    {
      Od decisionOd = (Od)p_decisionInstallee;
      decisionOd.setReferenceExterne(idAdmission.toString());
    }
    else
    {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_ID_ADMISSION"));
    }
  }
  
  protected void alimenterCaps(DecisionMigreeAsuV1 p_decisionTemporaireSource, DossierExamen p_dossierExamen)
  {
    alimenterConditionFaitGenerateur(p_decisionTemporaireSource, p_dossierExamen);
  }
  
  protected void alimenterCeps(DecisionMigreeAsuV1 p_decisionTemporaireSource, DossierExamen p_dossierExamen)
  {
    alimenterConstitutionMontantsBruts(p_decisionTemporaireSource, p_dossierExamen);
    alimenterConstitutionDurees(p_decisionTemporaireSource, p_dossierExamen);
    alimenterConstitutionSr(p_decisionTemporaireSource, p_dossierExamen);
    alimenterConstitutionNbreHeuresTravaillees(p_decisionTemporaireSource, p_dossierExamen);
    alimenterConstitutionReglementApplicable(p_decisionTemporaireSource, p_dossierExamen);
    alimenterConstitutionDateAttribution(p_decisionTemporaireSource, p_dossierExamen);
    alimenterConstitutionSjm(p_dossierExamen);
    alimenterConstitutionDelaisReport(p_decisionTemporaireSource, p_dossierExamen);
    alimenterConstitutionPji(p_decisionTemporaireSource, p_dossierExamen);
  }
  
  protected void lireIdentifiant(Decision p_decision, DecisionMigreeAsuV1 p_decisionLue)
  {
    p_decisionLue.setIdAdmission(new BigDecimal(((Od)p_decision).getReferenceExterne()));
  }
  
  protected void lireCaps(Decision p_decision, DecisionMigreeAsuV1 p_decisionLue)
  {
    lireConditionFaitGenerateur(p_decision, p_decisionLue);
  }
  
  protected void lireCeps(Decision p_decision, DecisionMigreeAsuV1 p_decisionLue)
  {
    lireConstitutionMontantsBruts(p_decision, p_decisionLue);
    lireConstitutionDurees(p_decision, p_decisionLue);
    lireConstitutionSr(p_decision, p_decisionLue);
    lireConstitutionNbreHeuresTravaillees(p_decision, p_decisionLue);
    lireConstitutionReglementApplicable(p_decision, p_decisionLue);
    lireConstitutionDateAttribution(p_decision, p_decisionLue);
    lireConstitutionSjm(p_decision, p_decisionLue);
    lireConstitutionDelaisReport(p_decision, p_decisionLue);
    lireConstitutionPji(p_decision, p_decisionLue);
  }
  
  public DemandeMigreeV1 lireDonnees(DemandeSpec p_demande)
  {
    DemandeMigreeAsuV1 demandeLue = (DemandeMigreeAsuV1)super.lireDonnees(p_demande);
    DecisionMigreeAsuV1 decisionLue = demandeLue.getDecision();
    
    alimenterListePeriodesFCT((Demande)p_demande, decisionLue);
    
    return demandeLue;
  }
  
  protected void alimenterDonneesForcage(DemandeMigreeV1 p_demandeV1, DemandeSpec p_demande)
  {
    super.alimenterDonneesForcage(p_demandeV1, p_demande);
    alimenterPeriodeForcee(p_demandeV1, p_demande);
  }
}

/* Location:
 * Qualified Name:     GrapheOd
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */