package fr.unedic.cali.asu.spe02.p05.liquidation.dom;

import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.parcours.ParcoursObjectifReprise;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ObjectifExamenSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.ConstitutionDateAttributionPourReprise;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.ConstitutionPointDepartIndemnisation;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.ConstitutionReglementApplicablePourReprise;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.DeterminationConditionAgePourReprise;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.DeterminationConditionChomageInvolontaire;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.DeterminationConditionCumulPrestationFamiliale;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.DeterminationConditionMontantProduitNonNulPourReprise;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.DeterminationConditionRechercheEmploi;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.DeterminationConditionValiditeReliquat;
import fr.unedic.cali.asu.spe02.p05.liquidation.dom.gen.ObjectifExamenRepriseGen;
import fr.unedic.cali.asu.spe02.p05.liquidation.parcours.ParcoursConstitutionDateLimiteIndemnisationPourReprise;
import fr.unedic.cali.asu.spe02.p05.liquidation.parcours.ParcoursConstitutionDelaisReportsPourReprise;
import fr.unedic.cali.asu.spe02.p05.liquidation.parcours.cep.montant.ParcoursConstitutionMontantBrutPourReprise;
import fr.unedic.cali.asu.spe02.p05.liquidation.parcours.cep.sjm.ParcoursConstitutionSjmPourReprise;
import fr.unedic.cali.dom.affectation.ContexteDemandeSpec;
import fr.unedic.cali.parcours.ParcoursTraitementSatisfait;
import fr.unedic.cali.util.OutilDomToString;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Parcours;
import java.util.List;

public class ObjectifExamenReprise
  extends ObjectifExamenRepriseGen
  implements ObjectifExamenSpec
{
  private static final long serialVersionUID = 1L;
  private List<ContexteDemandeSpec> contexteDemande;
  
  public ObjectifExamenReprise(DomPCSpec pc)
  {
    super(pc);
  }
  
  public ObjectifExamenReprise() {}
  
  public ObjectifExamenReprise(List<ContexteDemandeSpec> contexteDemande)
  {
    this.contexteDemande = contexteDemande;
  }
  
  public ObjetMetierSpec copie()
  {
    ObjectifExamenReprise copie = new ObjectifExamenReprise();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec pcopie)
  {
    ObjectifExamenReprise copie = (ObjectifExamenReprise)pcopie;
    super.copieElements(copie);
  }
  
  public void marquerGraphePersistant() {}
  
  public Parcours creerParcoursObjectif()
  {
    return new ParcoursObjectifReprise();
  }
  
  public ObjectifExamen getObjectifSauvegarde()
    throws CoucheLogiqueException
  {
    ObjectifExamen objectif = null;
    objectif = (ObjectifExamen)copie();
    return objectif;
  }
  
  public int getType()
  {
    return 2;
  }
  
  public Parcours creerParcoursConditionAffiliation()
  {
    return null;
  }
  
  public Parcours creerParcoursConditionAge()
  {
    return new DeterminationConditionAgePourReprise();
  }
  
  public Parcours creerParcoursConditionChomageInvolontaire()
  {
    Parcours parcoursRetour;
    Parcours parcoursRetour;
    if (OutilGestionContexteDemande.estContextePresentDansRegroupement(contexteDemande, 8)) {
      parcoursRetour = new ParcoursTraitementSatisfait();
    } else {
      parcoursRetour = new DeterminationConditionChomageInvolontaire();
    }
    return parcoursRetour;
  }
  
  public Parcours creerParcoursConditionCumulPrestationFamiliale()
  {
    return new DeterminationConditionCumulPrestationFamiliale();
  }
  
  public Parcours creerParcoursConditionFaitGenerateur()
  {
    return null;
  }
  
  public Parcours creerParcoursConditionMontantProduitNonNul()
  {
    return new DeterminationConditionMontantProduitNonNulPourReprise();
  }
  
  public Parcours creerParcoursConditionRechercheEmploi()
  {
    return new DeterminationConditionRechercheEmploi();
  }
  
  public Parcours creerParcoursConditionValiditeReliquat()
  {
    return new DeterminationConditionValiditeReliquat();
  }
  
  public Parcours creerParcoursConditionDureeNonNulle()
  {
    return null;
  }
  
  public Parcours creerParcoursDateAttribution()
  {
    return new ConstitutionDateAttributionPourReprise();
  }
  
  public Parcours creerParcoursDelaisReports()
  {
    return new ParcoursConstitutionDelaisReportsPourReprise();
  }
  
  public Parcours creerParcoursDurees()
  {
    return null;
  }
  
  public Parcours creerParcoursMontantsBruts()
  {
    return new ParcoursConstitutionMontantBrutPourReprise();
  }
  
  public Parcours creerParcoursNbHeuresTravaillees()
  {
    return null;
  }
  
  public Parcours creerParcoursPointDeDepart()
  {
    return new ConstitutionPointDepartIndemnisation();
  }
  
  public Parcours creerParcoursReglementApplicable()
  {
    return new ConstitutionReglementApplicablePourReprise();
  }
  
  public Parcours creerParcoursSalaireJournalierMoyen()
  {
    return new ParcoursConstitutionSjmPourReprise();
  }
  
  public Parcours creerParcoursDureeEffective()
  {
    return null;
  }
  
  public Parcours creerParcoursCapitalAvecDureeEffective()
  {
    return null;
  }
  
  public String toString()
  {
    return OutilDomToString.toString(this);
  }
  
  public Parcours creerParcoursConditionBeneficeAutreProduit()
  {
    return null;
  }
  
  public Parcours creerParcoursConstitutionDureePostPrime()
  {
    return null;
  }
  
  public List<ContexteDemandeSpec> getContexteDemande()
  {
    return contexteDemande;
  }
  
  public void setContexteDemande(List<ContexteDemandeSpec> contexteDemande)
  {
    this.contexteDemande = contexteDemande;
  }
  
  public Parcours creerParcoursDateLimiteIndemnisation()
  {
    return new ParcoursConstitutionDateLimiteIndemnisationPourReprise();
  }
}

/* Location:
 * Qualified Name:     ObjectifExamenReprise
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */