package fr.unedic.cali.asu.spe02.p05.liquidation.outilsaffiliation;

import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.PeriodeElementaireAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.PeriodeElementaireEmployeur;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.OutilPeriodeAffiliation;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Entreprise;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeMesureActivite;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.pnds.PeriodeNonDeclareeSanction;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeTravailDeclareAvecUnite;
import fr.unedic.util.Convertisseur;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.List;

public class OutilPeriodeElementaire
  extends fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.OutilPeriodeElementaire
{
  private static OutilPeriodeElementaire instance = null;
  
  public static synchronized OutilPeriodeElementaire getInstance()
  {
    if (instance == null) {
      instance = new OutilPeriodeElementaire();
    }
    return instance;
  }
  
  public void calculerQuantiteTravail(IndividuSpec individu, PeriodeElementaireAffiliation periodeElementaire, ActiviteSalarie activite, Damj dateCalcul, Collection<?> collectionAlertesNonBloquante, Damj dateExamen, Convertisseur convertisseurUniteAffiliation)
    throws CoucheLogiqueException
  {
    PeriodeNonDeclareeSanction pnds = determinerPNDS(individu, activite, dateCalcul, dateExamen);
    if ((pnds != null) && (pnds.getChronoPeriodePNDS() != null) && (!pnds.getChronoPeriodePNDS().estVide()))
    {
      OutilPeriodeAffiliation.alimenterCollectionAlertesPNDS(pnds.getChronoPeriodePNDS(), collectionAlertesNonBloquante);
      activite.setPresencePNDSDetectee(true);
    }
    FiltrePeriodeTravailDeclareAvecUnite filtreTravailExclusivementDeclareEnHeure = new FiltrePeriodeTravailDeclareAvecUnite(periodeElementaire.getMois(), true);
    
    filtreTravailExclusivementDeclareEnHeure.ajouterUnite(UNITE_HEURE);
    boolean activiteUniquementEnHeureSurPeriodeTempsEtudiee = filtreTravailExclusivementDeclareEnHeure.accepter(activite);
    
    String libelleCourtReglement = activite.getReglement().getLibelleCourt();
    
    Chronologie listePeriodeMesureActivite = decouperPMAPourMoisCivil(activite.getListePeriodesMesureActivite(), periodeElementaire.getMois());
    
    Iterator<?> itPeriodeMesureActivite = listePeriodeMesureActivite.iterer();
    while (itPeriodeMesureActivite.hasNext())
    {
      PeriodeMesureActivite pma = (PeriodeMesureActivite)itPeriodeMesureActivite.next();
      if (pma.getPeriode().chevauche(periodeElementaire.getMois()))
      {
        Hashtable<?, ?> listeQuantiteAffi = pma.getListeQuantitesAffiliation();
        Enumeration<?> enumQuantiteAffi = listeQuantiteAffi.elements();
        while (enumQuantiteAffi.hasMoreElements())
        {
          Quantite quantiteAffi = (Quantite)enumQuantiteAffi.nextElement();
          
          BigDecimal quantiteARetenirSurPeriode = determinerQuantiteSurPeriode(pma, periodeElementaire, pnds, quantiteAffi);
          
          ajouterQuantite(quantiteARetenirSurPeriode, libelleCourtReglement, periodeElementaire, activite, quantiteAffi, convertisseurUniteAffiliation, activiteUniquementEnHeureSurPeriodeTempsEtudiee);
        }
      }
    }
  }
  
  public void ajouterQuantiteTravailEmployeur(PeriodeElementaireAffiliation periodeElementaire, String libelleCourtReglement, Entreprise entreprise, BigDecimal quantiteARetenirSurPeriode, boolean derogation)
    throws CoucheLogiqueException
  {
    List<PeriodeElementaireEmployeur> listePeriodeElementaireEmployeur = periodeElementaire.getListPeriodeElementaireEmployeur();
    boolean creerEntreprise = true;
    String identifiantEntreprise = recupererIdentifiantEntreprise(entreprise);
    for (PeriodeElementaireEmployeur periodeEmployeur : listePeriodeElementaireEmployeur) {
      if (periodeEmployeur.getNumeroSiret().equals(identifiantEntreprise))
      {
        ajoutHeureEntreprise(periodeEmployeur, libelleCourtReglement, quantiteARetenirSurPeriode);
        if (!periodeEmployeur.isDerogation()) {
          periodeEmployeur.setDerogation(derogation);
        }
        creerEntreprise = false;
      }
    }
    if (creerEntreprise)
    {
      PeriodeElementaireEmployeur nouvelEmployeur = new PeriodeElementaireEmployeur();
      nouvelEmployeur.setNumeroAffiliation(entreprise.getNumeroAffiliation());
      nouvelEmployeur.setNumeroSiret(identifiantEntreprise);
      nouvelEmployeur.setRaisonSociale(entreprise.getLibelleEntreprise());
      nouvelEmployeur.setDerogation(derogation);
      ajoutHeureEntreprise(nouvelEmployeur, libelleCourtReglement, quantiteARetenirSurPeriode);
      periodeElementaire.ajouterPeriodeElementaireEmployeur(nouvelEmployeur);
    }
  }
  
  public static String recupererIdentifiantEntreprise(Entreprise entreprise)
  {
    String identifiant = entreprise.getSiren();
    if (identifiant == null) {
      if (entreprise.getNumeroGuso() != null) {
        identifiant = entreprise.getNumeroGuso();
      } else if (entreprise.getIdentifiantBNE() != null) {
        identifiant = entreprise.getIdentifiantBNE();
      } else {
        identifiant = entreprise.getLibelleEntreprise().substring(0, Math.min(13, entreprise.getLibelleEntreprise().length()));
      }
    }
    return identifiant;
  }
  
  protected BigDecimal calculerQuantiteHeureARetenir(PeriodeElementaireAffiliation periodeElementaire, Convertisseur convertisseurUniteAffiliation)
  {
    BigDecimal quantiteHeureExercee = BigDecimal.ZERO;
    
    BigDecimal heuresA8 = periodeElementaire.getHeuresA8();
    BigDecimal heuresA10 = periodeElementaire.getHeuresA10();
    BigDecimal heurePlafonneeMonoEmployeur = periodeElementaire.getHeuresApresPlafonnementMonoEmployeur();
    BigDecimal heuresCachetGroupeA8 = convertirCachetGroupeEnHeure(convertisseurUniteAffiliation, periodeElementaire.getCachetGroupeA8());
    BigDecimal heuresCachetIsoleA8 = convertirCachetIsoleEnHeure(convertisseurUniteAffiliation, periodeElementaire.getCachetIsoleA8());
    if (heuresA8 != null) {
      quantiteHeureExercee = quantiteHeureExercee.add(heuresA8);
    }
    if (heuresA10 != null) {
      quantiteHeureExercee = quantiteHeureExercee.add(heuresA10);
    }
    if (heuresCachetGroupeA8 != null) {
      quantiteHeureExercee = quantiteHeureExercee.add(heuresCachetGroupeA8);
    }
    if (heuresCachetIsoleA8 != null) {
      quantiteHeureExercee = quantiteHeureExercee.add(heuresCachetIsoleA8);
    }
    periodeElementaire.setQuantiteHeureExercee(quantiteHeureExercee);
    if (heurePlafonneeMonoEmployeur != null)
    {
      periodeElementaire.setQuantiteHeureExercee(heurePlafonneeMonoEmployeur);
      periodeElementaire.setHeuresApresPlafonnementMultiEmployeur(heurePlafonneeMonoEmployeur.min(periodeElementaire.getMontantPlafondHeures()));
    }
    return determinerQuantiteHeureARetenir(periodeElementaire);
  }
  
  private void ajouterQuantite(BigDecimal quantiteARetenirSurPeriode, String libelleCourtReglement, PeriodeElementaireAffiliation periodeElementaire, ActiviteSalarie activite, Quantite quantiteAffi, Convertisseur convertisseurUniteAffiliation, boolean activiteUniquementEnHeureSurPeriodeTempsEtudiee)
    throws CoucheLogiqueException
  {
    if (libelleCourtReglement.equals("A8"))
    {
      if (quantiteAffi.getUnite().equals(UNITE_HEURE))
      {
        periodeElementaire.ajouterQuantiteHeureA8(quantiteARetenirSurPeriode);
        ajouterQuantiteTravailEmployeur(periodeElementaire, libelleCourtReglement, activite.getEntreprise(), quantiteARetenirSurPeriode, activite.isDerogationPlafondMensuel());
      }
      else if (quantiteAffi.getUnite().equals(UNITE_CACHET_GROUPE))
      {
        periodeElementaire.ajouterQuantiteCachetGroupeA8(quantiteARetenirSurPeriode);
        ajouterQuantiteTravailEmployeur(periodeElementaire, libelleCourtReglement, activite.getEntreprise(), convertirCachetGroupeEnHeure(convertisseurUniteAffiliation, quantiteARetenirSurPeriode), activite.isDerogationPlafondMensuel());
      }
      else if (quantiteAffi.getUnite().equals(UNITE_CACHET_ISOLE))
      {
        periodeElementaire.ajouterQuantiteCachetIsoleA8(quantiteARetenirSurPeriode);
        ajouterQuantiteTravailEmployeur(periodeElementaire, libelleCourtReglement, activite.getEntreprise(), convertirCachetIsoleEnHeure(convertisseurUniteAffiliation, quantiteARetenirSurPeriode), activite.isDerogationPlafondMensuel());
      }
    }
    else if (libelleCourtReglement.equals("A10"))
    {
      if (quantiteAffi.getUnite().equals(UNITE_HEURE))
      {
        if (activiteUniquementEnHeureSurPeriodeTempsEtudiee)
        {
          periodeElementaire.ajouterQuantiteHeureA10(quantiteARetenirSurPeriode);
          ajouterQuantiteTravailEmployeur(periodeElementaire, libelleCourtReglement, activite.getEntreprise(), quantiteARetenirSurPeriode, activite.isDerogationPlafondMensuel());
        }
        else
        {
          periodeElementaire.ajouterQuantiteHeureA10Complementaire(quantiteARetenirSurPeriode);
        }
      }
      else if (quantiteAffi.getUnite().equals(UNITE_CACHET_GROUPE)) {
        periodeElementaire.ajouterQuantiteCachetGroupeA10(quantiteARetenirSurPeriode);
      } else if (quantiteAffi.getUnite().equals(UNITE_CACHET_ISOLE)) {
        periodeElementaire.ajouterQuantiteCachetIsoleA10(quantiteARetenirSurPeriode);
      }
    }
    else {
      OutilTrace.ecrireTrace(Niveau.ERROR, new Object[] { "\t\t         Cette activité ne possède pas un règlement A8/A10 ", "et ne devrait donc pas être prise dans le calcul affiliation ", "         \n" });
    }
  }
  
  private void ajoutHeureEntreprise(PeriodeElementaireEmployeur employeur, String libelleCourtReglement, BigDecimal quantiteARetenirSurPeriode)
  {
    if (libelleCourtReglement.equals("A8"))
    {
      if (employeur.getHeuresA8Totales() != null) {
        employeur.setHeuresA8Totales(employeur.getHeuresA8Totales().add(quantiteARetenirSurPeriode));
      } else {
        employeur.setHeuresA8Totales(quantiteARetenirSurPeriode);
      }
    }
    else if (libelleCourtReglement.equals("A10")) {
      if (employeur.getHeuresA10Totales() != null) {
        employeur.setHeuresA10Totales(employeur.getHeuresA10Totales().add(quantiteARetenirSurPeriode));
      } else {
        employeur.setHeuresA10Totales(quantiteARetenirSurPeriode);
      }
    }
  }
}

/* Location:
 * Qualified Name:     OutilPeriodeElementaire
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */