package fr.unedic.cali.asu.spe02.p05.liquidation.outilsfonctionnels;

import fr.pe.cali.liquidation.outilsfonctionnels.dom.ResultatImputationSuiteArce;
import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.spec.IProduitInrArce;
import fr.unedic.cali.outilsfonctionnels.AppelCalculParLiquidation;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDecisionPourProduit;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreReexamenSurDemande;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreAttributionInrPourDateAttributionAreLiee;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import java.math.BigDecimal;

public class OutilDeterminationImputationSuiteArce
  implements OutilFonctionnel
{
  public static OutilDeterminationImputationSuiteArce getInstance()
  {
    return new OutilDeterminationImputationSuiteArce();
  }
  
  public ResultatImputationSuiteArce traiterImputationSuiteArce(AttributionAssuranceSpec attributionPrecedente, Damj dateCalcul)
    throws ApplicativeException
  {
    ResultatImputationSuiteArce resultat = new ResultatImputationSuiteArce();
    AttributionSpec attributionArce = rechercherAttributionArce(attributionPrecedente, dateCalcul);
    if (attributionArce != null)
    {
      BigDecimal capitalPaye = recupererCapitalPaye(attributionArce, dateCalcul);
      if (capitalPaye.compareTo(BigDecimal.ZERO) > 0)
      {
        BigDecimal capitalAttribue = recupererCapitalAttribue(attributionArce);
        boolean isDeuxVersementEffectue = isDeuxVersementEffectuee(capitalAttribue, capitalPaye);
        ResultatExecutionCalculSpec resultatCalcul = getOutilGestionArce().executerAttribution(attributionPrecedente, dateCalcul);
        int reliquatDelaiAttente = getOutilGestionArce().determinerReliquatDelaiAttente(resultatCalcul, dateCalcul);
        int reliquatFranchiseCP = getOutilGestionArce().determinerReliquatFranchiseCP(resultatCalcul);
        int reliquatFranchiseSalaire = getOutilGestionArce().determinerReliquatFranchiseSalaire(resultatCalcul);
        resultat.setDeuxVersementEffectue(isDeuxVersementEffectue);
        resultat.setNouvelleDateLimiteIndemnisation(traiterImputation(capitalPaye, attributionPrecedente.getDateLimiteIndemnisation(), attributionPrecedente.getElementBaseIndemnisation().getMontantBrut(), reliquatDelaiAttente, reliquatFranchiseCP, reliquatFranchiseSalaire, isDeuxVersementEffectue));
        
        resultat.setDateLimiteImputee(true);
      }
    }
    return resultat;
  }
  
  protected AttributionSpec rechercherAttributionArce(AttributionAssuranceSpec attributionPrecedente, Damj dateExamen)
  {
    FiltreET filtreDeRechercheAttributionArce = new FiltreET();
    filtreDeRechercheAttributionArce.ajouterFiltre(new FiltreDecisionPourProduit(18));
    filtreDeRechercheAttributionArce.ajouterFiltre(new FiltreAttributionInrPourDateAttributionAreLiee(attributionPrecedente.getDateAttribution()));
    filtreDeRechercheAttributionArce.ajouterFiltre(new FiltreNegation(new FiltreReexamenSurDemande()));
    return (AttributionSpec)OutilRecherche.rechercherDecisionPrecedente(attributionPrecedente.getDemande().getDemandeur().getChronoDemandeIncitationReclassement(), dateExamen, filtreDeRechercheAttributionArce);
  }
  
  protected BigDecimal recupererCapitalAttribue(AttributionSpec attribution)
  {
    return ((IProduitInrArce)attribution.getProduit()).recupererCapitalAttribue(attribution);
  }
  
  protected BigDecimal recupererCapitalPaye(AttributionSpec attribution, Damj dateExamen)
    throws ApplicativeException
  {
    BigDecimal capitalPaye = BigDecimal.ZERO;
    ResultatExecutionCalculSpec resultat = AppelCalculParLiquidation.executerCalculDeterminationEtatDroit(attribution, dateExamen, true);
    if ((resultat != null) && (resultat.getCapitalVerse() != null)) {
      capitalPaye = resultat.getCapitalVerse().getValeur();
    }
    return capitalPaye;
  }
  
  protected boolean isDeuxVersementEffectuee(BigDecimal capitalAttribue, BigDecimal capitalPaye)
  {
    return capitalAttribue.compareTo(capitalPaye) == 0;
  }
  
  protected Damj traiterImputation(BigDecimal capitalPaye, Damj dateLimiteIndemnisation, BigDecimal montantAttributionPrecedente, int reliquatDelaiAttente, int reliquatFranchiseCP, int reliquatFranchiseSalaire, boolean isDeuxVersementEffectue)
  {
    int dureeVerseeEnArce = capitalPaye.divide(montantAttributionPrecedente, 0, 1).intValue();
    int imputationReliquatDelaisReports = 0;
    if (!isDeuxVersementEffectue)
    {
      imputationReliquatDelaisReports = reliquatDelaiAttente + reliquatFranchiseCP + reliquatFranchiseSalaire;
      imputationReliquatDelaisReports = BigDecimal.valueOf(imputationReliquatDelaisReports).divide(BigDecimal.valueOf(2L), 0, 1).intValue();
    }
    int dureeAImputer = dureeVerseeEnArce + imputationReliquatDelaisReports;
    
    DureeCalendaire imputation = new DureeCalendaire(0, 0, dureeAImputer);
    return dateLimiteIndemnisation.deplacerVersArriere(imputation);
  }
  
  protected OutilGestionArce getOutilGestionArce()
  {
    return OutilGestionArce.getInstance();
  }
}

/* Location:
 * Qualified Name:     OutilDeterminationImputationSuiteArce
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */