package fr.unedic.cali.asu.spe02.p05.liquidation.parcours;

import fr.pe.cali.reglementaire.dom.impl.CriteresFabriqueReglementaire;
import fr.pe.cali.reglementaire.regles.assurance.cep.delaisreports.dom.DetailJoursTravaillesJustificationFranchiseCP;
import fr.pe.cali.reglementaire.regles.assurance.cep.delaisreports.dom.DonneesEntreesDelaisReportsSpectacle;
import fr.pe.cali.reglementaire.regles.assurance.cep.delaisreports.dom.JustificationFranchiseCP;
import fr.pe.cali.reglementaire.regles.assurance.cep.delaisreports.dom.MoisCivilJustificationFranchiseCP;
import fr.pe.cali.reglementaire.regles.assurance.cep.delaisreports.dom.ResultatDelaisReportsSpectacle;
import fr.pe.cali.reglementaire.regles.assurance.cep.delaisreports.fabrique.FabriqueCorpsRegleConstitutionDelaisReports;
import fr.pe.cali.reglementaire.regles.assurance.cep.delaisreports.outils.spec.IOutilConstitutionDelaisReportsSpectacle;
import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Attribution;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.CarencePrefixeAFixer;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Differe;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationFranchiseCongesPayes;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.MoisCivil;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.PeriodeSurMoisCivil;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.OutilDeterminationDelaisReportSpec;
import fr.unedic.cali.asu.spe02.p05.liquidation.outilsfonctionnels.OutilDelaisReport;
import fr.unedic.cali.asu.spe02.p05.liquidation.outilsfonctionnels.RechercheDiffere;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

public class ParcoursConstitutionDelaisReports
  extends fr.unedic.cali.asu.spe02.p03.liquidation.parcours.ConstitutionDelaisReport
{
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    Demande demande = DomLiquidationAssurance.getDemande(contexte);
    Attribution attribution = (Attribution)demande.getDossierExamen();
    
    Resultat resultat = super.demarrer(contexte);
    
    calculerFranchiseCP(attribution);
    
    mensualiserFranchiseCP(attribution);
    
    mensualiserFranchiseSalaire(attribution);
    
    calculerDiffere(attribution);
    
    return resultat;
  }
  
  protected void calculerFranchiseCP(Attribution attribution)
  {
    IOutilConstitutionDelaisReportsSpectacle outilDelaisReports = recupererOutilReglementaire(attribution);
    DonneesEntreesDelaisReportsSpectacle donneesEntree = new DonneesEntreesDelaisReportsSpectacle();
    Demande demande = (Demande)attribution.getDemande();
    donneesEntree.setPasseProfessionnel(demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation());
    donneesEntree.setPra(demande.getDossierAffectationAdmission().getValidationProduit().getPeriodePra());
    donneesEntree.setNombreJoursTravaillesForces(demande.getDonneesTemporaires().getNombreJourTotalA8A10Force());
    ResultatDelaisReportsSpectacle resultatCalculFranchiseCP = outilDelaisReports.calculerFranchiseCP(donneesEntree);
    mettreAJourCepPourFranchiseCP(attribution.getConstitutionDelaisReport(), resultatCalculFranchiseCP);
  }
  
  protected IOutilConstitutionDelaisReportsSpectacle recupererOutilReglementaire(AttributionSpec attribution)
  {
    CriteresFabriqueReglementaire criteres = recupererCriteresFabriqueReglementaire(attribution);
    return (IOutilConstitutionDelaisReportsSpectacle)getFabriqueCorpsRegleConstitutionDelaisReports().recupererOutilCorpsRegle(criteres);
  }
  
  protected FabriqueCorpsRegleConstitutionDelaisReports getFabriqueCorpsRegleConstitutionDelaisReports()
  {
    return FabriqueCorpsRegleConstitutionDelaisReports.getInstance();
  }
  
  protected CriteresFabriqueReglementaire recupererCriteresFabriqueReglementaire(AttributionSpec attribution)
  {
    CriteresFabriqueReglementaire criteres = new CriteresFabriqueReglementaire();
    criteres.setCodeProduit(attribution.getProduit().getNomUnique());
    criteres.setDate(attribution.getDateAttribution());
    List<String> contextesReglementaires = new ArrayList();
    if (estContexteEntreeClauseRattrapagePresent(attribution)) {
      contextesReglementaires.add("DateLimiteContexteEntreeClauseRattrapage");
    }
    criteres.setListeContextesReglementaires(contextesReglementaires);
    return criteres;
  }
  
  protected boolean estContexteEntreeClauseRattrapagePresent(AttributionSpec attribution)
  {
    return OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)attribution.getDemande(), "ENTREECRA");
  }
  
  protected void mettreAJourCepPourFranchiseCP(fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionDelaisReport delaisReports, ResultatDelaisReportsSpectacle resultat)
  {
    delaisReports.setFranchiseCongesPayes(resultat.getNombreJoursFranchiseCP());
    if (resultat.getJustification() != null)
    {
      JustificationFranchiseCongesPayes justification = new JustificationFranchiseCongesPayes();
      delaisReports.setJustificationFranchiseCongesPayes(justification);
      justification.setFormule(resultat.getJustification().getFormuleUtilisee());
      justification.setNbJoursTravaillesRetenus(resultat.getJustification().getNombreJoursTravaillesRetenusDansPra());
      justification.setPeriodeCalculFranchiseCp(resultat.getJustification().getPeriodeCalculFranchiseCp());
      mettreAJourJustificationMoisCivil(justification, resultat.getJustification().getListeMoisCivils());
    }
  }
  
  protected void mettreAJourJustificationMoisCivil(JustificationFranchiseCongesPayes justification, List<MoisCivilJustificationFranchiseCP> listeMoisCivil)
  {
    if (listeMoisCivil != null) {
      for (MoisCivilJustificationFranchiseCP moisCivilCourant : listeMoisCivil)
      {
        MoisCivil moisCivil = new MoisCivil();
        moisCivil.setPeriode(moisCivilCourant.getMoisCivil());
        moisCivil.setNbJoursRetenus(moisCivilCourant.getNombreJoursTravaillesRetenus());
        moisCivil.setNbJoursTravailles(moisCivilCourant.getNombreJoursTravailles());
        mettreAJourJustificationDetailMoisCivil(moisCivil, moisCivilCourant.getDetails());
        justification.ajouterMoisCivil(moisCivil);
      }
    }
  }
  
  protected void mettreAJourJustificationDetailMoisCivil(MoisCivil moisCivil, List<DetailJoursTravaillesJustificationFranchiseCP> details)
  {
    if (details != null) {
      for (DetailJoursTravaillesJustificationFranchiseCP detail : details)
      {
        PeriodeSurMoisCivil periodeSurMoisCivil = new PeriodeSurMoisCivil();
        periodeSurMoisCivil.setJoursTravailles(detail.getNombresJoursTravaillesAttestes());
        periodeSurMoisCivil.setPeriode(detail.getPeriodeContrat());
        periodeSurMoisCivil.setRaisonSociale(detail.getRaisonSociale());
        moisCivil.ajouterPeriodeSurMoisCivil(periodeSurMoisCivil);
      }
    }
  }
  
  protected void mensualiserFranchiseCP(Attribution attribution)
  {
    fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionDelaisReport cep = attribution.getConstitutionDelaisReport();
    int franchiseCP = cep.getFranchiseCongesPayes();
    if (franchiseCP > 0)
    {
      IOutilConstitutionDelaisReportsSpectacle outil = recupererOutilReglementaire(attribution);
      int quantiteMensuelFranchiseCP = outil.calculerMensualisationFranchiseCP(franchiseCP);
      cep.setQuantiteFranchiseCPMensuelle(new QuantiteJour(BigDecimal.valueOf(quantiteMensuelFranchiseCP)));
    }
  }
  
  protected void mensualiserFranchiseSalaire(Attribution attribution)
  {
    fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionDelaisReport cep = attribution.getConstitutionDelaisReport();
    mettreAJourFranchiseSalaireSurCEP(cep);
    int franchiseSalaire = cep.getNbJoursCarenceStandard();
    if (franchiseSalaire > 0)
    {
      IOutilConstitutionDelaisReportsSpectacle outil = recupererOutilReglementaire(attribution);
      Damj dateLimite = attribution.getDateLimiteIndemnisation();
      int quantiteMensuelFranchiseSalaire = outil.calculerMensualisationFranchiseSalaire(franchiseSalaire, getPjiSuiteAppelCalcul(), dateLimite);
      
      cep.setQuantiteFranchiseSalaireMensuelle(new QuantiteJour(BigDecimal.valueOf(quantiteMensuelFranchiseSalaire)));
    }
  }
  
  protected void mettreAJourFranchiseSalaireSurCEP(fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionDelaisReport cep)
  {
    List<CarencePrefixeAFixer> listeCarences = cep.getListCarence();
    int nbJoursFranchiseSalaire = 0;
    for (CarencePrefixeAFixer carence : listeCarences) {
      if ("4".equals(carence.getTypeCarence())) {
        nbJoursFranchiseSalaire = carence.getQuantiteInitiale().getValeurEntiere();
      }
    }
    cep.setNbJoursCarenceStandard(nbJoursFranchiseSalaire);
  }
  
  protected void calculerDiffere(Attribution attribution)
    throws ApplicativeException
  {
    fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionDelaisReport cep = attribution.getConstitutionDelaisReport();
    
    Boolean estDelaiAttenteForce = attribution.getDemandeAssurance().getDonneesTemporaires().isDelaiAttenteForce();
    if (estDelaiAttenteForce != null)
    {
      if (estDelaiAttenteForce.booleanValue()) {
        ajouterDiffere(cep);
      }
    }
    else
    {
      IOutilConstitutionDelaisReportsSpectacle outilDelaisReports = recupererOutilReglementaire(attribution);
      RechercheDiffere outilFonctionnel = new RechercheDiffere();
      outilFonctionnel.setPointDepartRecherche(attribution.getDemande());
      outilFonctionnel.setChronoDemandes(attribution.getDemandeAssurance().getChronologieDemandesAssuranceSansCourante());
      DonneesEntreesDelaisReportsSpectacle donneesEntree = new DonneesEntreesDelaisReportsSpectacle();
      
      donneesEntree.setOutilRechercheDiffere(outilFonctionnel);
      
      donneesEntree.setDebutTheoriqueDelaiAttente(getPjiSuiteAppelCalcul());
      
      ResultatDelaisReportsSpectacle resultat = outilDelaisReports.estDiffereApplicable(donneesEntree);
      if (resultat.isAppliquerDiffere()) {
        ajouterDiffere(cep);
      }
      cep.setPeriodeApplicationDifferePrecedent(resultat.getDelaiAttentePrecedent());
    }
  }
  
  private void ajouterDiffere(fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionDelaisReport cep)
  {
    Differe differe = new Differe(7);
    cep.ajouterCarence(differe);
    cep.setNbJoursDelaiReport(differe.getQuantiteInitiale().getValeurEntiere());
  }
  
  protected OutilDeterminationDelaisReportSpec getOutilDeterminationDelaisReport(Demande demande)
    throws CoucheLogiqueException
  {
    return OutilDelaisReport.getInstance();
  }
}

/* Location:
 * Qualified Name:     ParcoursConstitutionDelaisReports
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */