package fr.unedic.cali.asu.ssp07.p03.calcul;

import fr.unedic.cali.asu.calcul.outilsfonctionnels.RecuperationPensionInvaliditeAvantDate;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisationAREF;
import fr.unedic.cali.asu.dom.SalaireReference;
import fr.unedic.cali.asu.dom.Sjm;
import fr.unedic.cali.asu.spe02.p03.calcul.outilsfonctionnels.RevalorisationSalaire;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.DeterminationSalaireReference;
import fr.unedic.cali.asu.spe02.p03.parametres.ParametresIndemnisation;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.calcul.dom.periode.PeriodeAvantageVieillesse;
import fr.unedic.cali.calcul.outilsfonctionnels.RecuperationAvantageVieillesseAvantPJI;
import fr.unedic.cali.dom.Competences;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.cali.dom.conteneurs.DonneesCalculMontant;
import fr.unedic.cali.dom.conteneurs.DonneesCalculMontantSpectacle;
import fr.unedic.cali.dom.conteneurs.DonneesEntreesRecuperationMontant;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;

public class FacadeCalculProduitPourLiquidationImpl
  extends fr.unedic.cali.asu.fps.calcul.FacadeCalculProduitPourLiquidationImpl
{
  private static final int DIX = 10;
  
  public MontantBaseSpec determinerMontant(DonneesEntreesRecuperationMontant p_donneesEntreesRecuperationMontant, Competences p_competences)
    throws CoucheLogiqueException
  {
    FormuleMontantSpec fm = null;
    ConstituantsIndemnisation constituantsIndemnisation = initialiserConstituantsIndemnisation(p_donneesEntreesRecuperationMontant);
    DonneesCalculMontant donneesCalculMontant = p_donneesEntreesRecuperationMontant.getDonneesCalculMontant();
    if (donneesCalculMontant.getFormuleMontant() != null) {
      fm = donneesCalculMontant.getFormuleMontant();
    } else if (donneesCalculMontant.isContexteFormation()) {
      fm = getFormuleMontantEnFormation();
    } else {
      fm = getFormuleMontant();
    }
    return fm.calculer(constituantsIndemnisation, p_donneesEntreesRecuperationMontant.getDateCalculMontant());
  }
  
  private ConstituantsIndemnisation initialiserConstituantsIndemnisation(DonneesEntreesRecuperationMontant p_donneesEntreesRecuperationMontant)
    throws CoucheLogiqueException
  {
    Damj dateCalcul = p_donneesEntreesRecuperationMontant.getDateCalculMontant();
    Damj dateAttribution = null;
    IndividuSpec individu = p_donneesEntreesRecuperationMontant.getIndividu();
    DonneesCalculMontant donneesCalculMontant = p_donneesEntreesRecuperationMontant.getDonneesCalculMontant();
    DonneesCalculMontantSpectacle donneesCalculMontantSpectacle = p_donneesEntreesRecuperationMontant.getDonneesCalculMontantSpectacle();
    
    ConstituantsIndemnisation constituantsIndemnisation = new ConstituantsIndemnisation();
    ElementBaseIndemnisation elementBaseIndemnisationCourant = new ElementBaseIndemnisation();
    constituantsIndemnisation.setElementBaseIndemnisationCourant(elementBaseIndemnisationCourant);
    ParametresIndemnisation parametresIndemnisation = ParametresIndemnisation.getParametresIndemnisation();
    
    elementBaseIndemnisationCourant.setNbJoursEmploiSurPrc(donneesCalculMontantSpectacle.getNbJoursEmploiSurPrc());
    
    BigDecimal plafondSR = DeterminationSalaireReference.determinerPlafondSrr(elementBaseIndemnisationCourant.getNbJoursEmploiSurPrc(), dateCalcul);
    
    BigDecimal sr = RevalorisationSalaire.revaloriserSrip(elementBaseIndemnisationCourant.getSalaireReference(), plafondSR, dateCalcul);
    SalaireReference srRevalorise = new SalaireReference(sr, dateCalcul);
    elementBaseIndemnisationCourant.setSalaireReference(srRevalorise);
    
    SalaireReference srrp = RevalorisationSalaire.determinerSrrp(elementBaseIndemnisationCourant.getSalaireReference(), elementBaseIndemnisationCourant.getNbJoursEmploiSurPrc(), dateCalcul);
    
    Sjm sjmrp = RevalorisationSalaire.determinerSjmrp(srrp, elementBaseIndemnisationCourant.getCoefficientHoraireJour(), elementBaseIndemnisationCourant.getNombreHeuresTravailleesPlafonnees(), dateCalcul);
    if (donneesCalculMontant.isPriseEnComptePensionInvalidite())
    {
      Boolean gerePensionInvalidite = elementBaseIndemnisationCourant.getEstProduitGerantPensionInvalidite();
      if ((gerePensionInvalidite != null) && (gerePensionInvalidite.booleanValue()))
      {
        elementBaseIndemnisationCourant.setListePensionInvalidite(donneesCalculMontant.getListePensionInvalidite());
        
        elementBaseIndemnisationCourant.setMontantPensionInvaliditeADeduire(RecuperationPensionInvaliditeAvantDate.recuperationMontantPIChainees(elementBaseIndemnisationCourant, individu, dateCalcul, dateAttribution));
      }
      else
      {
        elementBaseIndemnisationCourant.setMontantPensionInvaliditeADeduire(RecuperationPensionInvaliditeAvantDate.recuperationMontantPI(individu, dateCalcul));
      }
    }
    else
    {
      elementBaseIndemnisationCourant.setMontantPensionInvaliditeADeduire(new BigDecimal("0.00"));
    }
    if (donneesCalculMontant.isPriseEnCompteAvantageVieillesse())
    {
      PeriodeAvantageVieillesse periodeAvCourante = RecuperationAvantageVieillesseAvantPJI.recupererPeriodeAvADate(individu, dateCalcul);
      
      BigDecimal montantAV = new BigDecimal(0);
      if (periodeAvCourante != null)
      {
        montantAV = periodeAvCourante.getQuantiteEuro().getValeur();
        
        elementBaseIndemnisationCourant.setDateEffetAV(dateCalcul);
      }
      BigDecimal coeffAV = new BigDecimal("0.00");
      if ((sjmrp != null) && (sjmrp.getSalaire() != null) && (!sjmrp.getSalaire().equals(new BigDecimal("0.00")))) {
        coeffAV = montantAV.divide(sjmrp.getSalaire(), 10, 4);
      }
      elementBaseIndemnisationCourant.setCoefficientAvantageVieillesse(coeffAV);
      elementBaseIndemnisationCourant.setMontantAvantageVieillesse(coeffAV.multiply(sjmrp.getSalaire()));
      
      BigDecimal tauxavantageVieillesse = parametresIndemnisation.getTauxAvantageViellesse(individu.getAgeALaDate(dateCalcul));
      if (tauxavantageVieillesse != null) {
        elementBaseIndemnisationCourant.setTauxAvantageVieillesse(tauxavantageVieillesse);
      }
    }
    else
    {
      elementBaseIndemnisationCourant.setCoefficientAvantageVieillesse(new BigDecimal("0.00"));
      elementBaseIndemnisationCourant.setTauxAvantageVieillesse(new BigDecimal("0.00"));
      elementBaseIndemnisationCourant.setMontantAvantageVieillesse(new BigDecimal("0.00"));
    }
    elementBaseIndemnisationCourant.setCoefficientSanctionReduction(new BigDecimal("1.00"));
    if (donneesCalculMontant.isContexteFormation())
    {
      ElementBaseIndemnisationAREF ebiAREF = new ElementBaseIndemnisationAREF(elementBaseIndemnisationCourant);
      constituantsIndemnisation.setElementBaseIndemnisationCourant(ebiAREF);
    }
    return constituantsIndemnisation;
  }
}

/* Location:
 * Qualified Name:     FacadeCalculProduitPourLiquidationImpl
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */