package fr.unedic.cali.asu.caa14.p02.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDateLimiteIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionPointDepartIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.Reprise;
import fr.unedic.util.Quantite;
import fr.unedic.util.UniteAffiliation;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.PasAssezInformationException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;

public class DeterminationDureeEffective
  extends fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.DeterminationDureeEffective
{
  public static fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.DeterminationDureeEffective getInstance()
  {
    return new DeterminationDureeEffective();
  }
  
  public DureeIndemnisation determinerDureeEffective(Demande p_demande)
    throws PasAssezInformationException, CoucheLogiqueException, ApplicativeException
  {
    DureeIndemnisation dureeIndemnisation = super.determinerDureeEffective(p_demande);
    
    int dureeEffectiveBornee = bornerDureeEffectiveADateLimiteIndemnisation(p_demande, dureeIndemnisation.getDureeEffective().getValeurEntiere());
    
    dureeIndemnisation.setDureeEffective(new Quantite(dureeEffectiveBornee, UniteAffiliation.JOUR));
    return dureeIndemnisation;
  }
  
  public DureeIndemnisation determinerDureeEffectivePourReprise(Demande p_demande)
    throws PasAssezInformationException, CoucheLogiqueException, ApplicativeException
  {
    Reprise reprise = (Reprise)p_demande.getDossierExamen();
    DossierExamen ouvertureDeDroit = (DossierExamen)reprise.getOuvertureDroit();
    DureeIndemnisation dureeIndemnisation = super.determinerDureeEffectivePourReprise(p_demande);
    
    int dureeEffectiveBornee = bornerDureeEffectiveADateLimiteIndemnisation(ouvertureDeDroit, reprise, dureeIndemnisation.getDureeEffective().getValeurEntiere());
    
    dureeIndemnisation.setDureeEffective(new Quantite(dureeEffectiveBornee, UniteAffiliation.JOUR));
    
    return dureeIndemnisation;
  }
  
  public int bornerDureeEffectiveADateLimiteIndemnisation(DossierExamen p_dossierExamenDemandeOrigine, DossierExamen p_dossierExamenDemandeCourante, int p_dureeEffectiveNonBornee)
  {
    int dureeEffectiveBornee = p_dureeEffectiveNonBornee;
    int dureeMaxIndemnisation = 0;
    if (p_dossierExamenDemandeOrigine.getConstitutionDateLimiteIndemnisation() != null)
    {
      Damj dateFinIndemnisation = p_dossierExamenDemandeOrigine.getConstitutionDateLimiteIndemnisation().getDateLimiteIndem();
      Damj dateDebutIndemnisation = p_dossierExamenDemandeCourante.getConstitutionPointDepartIndemnisation().getPji();
      dureeMaxIndemnisation = new Periode(dateDebutIndemnisation, dateFinIndemnisation).getDuree();
      if (p_dureeEffectiveNonBornee > dureeMaxIndemnisation) {
        dureeEffectiveBornee = dureeMaxIndemnisation;
      }
    }
    return dureeEffectiveBornee;
  }
}

/* Location:
 * Qualified Name:     DeterminationDureeEffective
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */