package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.FormuleSpec;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.produits.liquidation.dom.BaseCarence;
import fr.unedic.cali.asu.produits.liquidation.dom.BaseCarenceMontant;
import fr.unedic.cali.parametres.EvenementParametre;
import fr.unedic.cali.parametres.ParametresIndemnisation;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.PasAssezInformationException;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;

public class FormuleCarenceIccpMontant
  implements FormuleSpec
{
  public Object appliquerFormule(BaseCarence baseFormule)
    throws CoucheLogiqueException
  {
    QuantiteJour quantiteJourCalculee = null;
    if (baseFormule == null) {
      throw new IllegalArgumentException("La BaseCarenceMontant est nulle : impossible d'appliquer la formule CarenceICCPMontant.");
    }
    try
    {
      QuantiteEuro quantiteEuroIccp = ((BaseCarenceMontant)baseFormule).getQuantiteEuroIccp();
      if (quantiteEuroIccp == null) {
        throw new PasAssezInformationException("ASU_SC_L_ES_ED_CDR08_ABSENCE_MONTANT_FORMULE_ICCP", "MontantIccp null dans BaseFormule passé en paramètre: impossible d'appliquer la formule CarenceICCPMontant.");
      }
      BigDecimal valeurMontant = quantiteEuroIccp.getValeurMontant();
      
      Sjr salaireJournalierReference = ((BaseCarenceMontant)baseFormule).getSjrrp();
      if (salaireJournalierReference == null) {
        throw new PasAssezInformationException("ASU_SC_L_ES_ED_CDR08_ABSENCE_SJRRP_FORMULE_ICCP", "SJRRP null dans BaseFormule passé en paramètre: impossible d'appliquer la formule CarenceICCPMontant.");
      }
      BigDecimal valeurSjrrp = salaireJournalierReference.getSalaire();
      if (valeurSjrrp.compareTo(BigDecimal.ZERO) == 0) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_SC_L_ES_ED_CDR08_INCOHERENCE_SJRRP_ICCP", "SJR égal à zéro.", 2);
      }
      BigDecimal resultatFormule = null;
      if (((BaseCarenceMontant)baseFormule).estTopContratsRemuneresBaseSmic())
      {
        Damj dateDebutAnnee = new Damj(salaireJournalierReference.getDateDepart());
        BigDecimal valeurSmicJournalier = ParametresIndemnisation.getParametresIndemnisation().getElementActif(dateDebutAnnee).getSmicJournalierBase35h();
        if ((valeurSmicJournalier != null) && (valeurSmicJournalier.compareTo(valeurSjrrp) > 0)) {
          resultatFormule = Mathematiques.diviseParDefaut(valeurMontant, valeurSmicJournalier);
        } else {
          resultatFormule = Mathematiques.diviseParDefaut(valeurMontant, valeurSjrrp);
        }
      }
      else
      {
        resultatFormule = Mathematiques.diviseParDefaut(valeurMontant, valeurSjrrp);
      }
      quantiteJourCalculee = new QuantiteJour(Mathematiques.tronque(resultatFormule, 0).toString());
    }
    catch (ClassCastException ex)
    {
      throw new IllegalArgumentException("La BaseFormule n'est pas une BaseCarenceMontant: imp. d'appliquer la formule CarenceICCPMontant.");
    }
    return quantiteJourCalculee;
  }
}

/* Location:
 * Qualified Name:     FormuleCarenceIccpMontant
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */