package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.FormuleDelaiReportSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.BaseDelaiReportAbstrait;
import fr.unedic.cali.outilsfonctionnels.DetectionTypeChomage;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.PasAssezInformationException;
import java.math.BigDecimal;

public class FormuleDiffereISLR14
  implements FormuleDelaiReportSpec
{
  public static final int DUREE_MAX_ISLR_MOTIF_ECO = 75;
  public static final int DUREE_MAX_ISLR_MOTIF_NON_ECO = 180;
  private static final BigDecimal DIVISEUR_ISLR = new BigDecimal("90");
  
  public Object appliquerFormule(BaseDelaiReportAbstrait baseFormule)
    throws CoucheLogiqueException
  {
    QuantiteJour quantiteJourCalculee = null;
    if (baseFormule == null) {
      throw new IllegalArgumentException("La BaseFormule passée en paramètre est égale à null : impossible d'appliquer la formule CarenceISLR.");
    }
    try
    {
      QuantiteEuro quantiteEuroIslr = baseFormule.getQuantiteEuroIslr();
      if (quantiteEuroIslr == null) {
        throw new PasAssezInformationException("ASU_SC_L_ES_ED_CDR08_ABSENCE_MONTANT_FORMULE_ISLR", "QuantiteEuro ISLR null dans BaseFormule passé en paramètre: impossible d'appliquer la formule CarenceISLR.");
      }
      BigDecimal valeurMontant = quantiteEuroIslr.getValeurMontant();
      
      BigDecimal resultatFormule = Mathematiques.diviseParDefaut(valeurMontant, DIVISEUR_ISLR);
      
      quantiteJourCalculee = new QuantiteJour(new BigDecimal(recupererPlafondISLR(baseFormule)).min(Mathematiques.tronque(resultatFormule, 0)).toString());
    }
    catch (ClassCastException ex)
    {
      throw new IllegalArgumentException("La BaseFormule n'est pas une BaseCarenceMontant : impossible d'appliquer la formule CarenceISLR.");
    }
    return quantiteJourCalculee;
  }
  
  public int recupererPlafondISLR(BaseDelaiReportAbstrait baseFormule)
  {
    if (DetectionTypeChomage.estChomageEconomique(baseFormule.getMotifRupture())) {
      return 75;
    }
    return 180;
  }
}

/* Location:
 * Qualified Name:     FormuleDiffereISLR14
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */