package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.cge01.parametres.ParametragePRAM;
import fr.unedic.cali.asu.cge01.parametres.ParametragePRAPourDV;
import fr.unedic.cali.asu.cge01.parametres.ParametragePraCouvertureSuiteDv;
import fr.unedic.cali.asu.cge01.parametres.ParametragePraOppositionDv;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.produits.liquidation.parametres.CleAccesPRA;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DonneesEntreeDeterminationListePra;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.spec.PraSpec;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;

public abstract class OutilConstructionPRA
{
  public static final int AGE_50_ANS = 50;
  public static final int AGE_53_ANS = 53;
  public static final int AGE_57_ANS = 57;
  public static final int INF_50ANS = 1;
  public static final int SUP_EGAL_50ANS = 2;
  public static final int SUP_EGAL_57ANS = 3;
  public static final int SUP_EGAL_53ANS = 4;
  public static final int CENT_TRIMESTRES_ACQUIS = 1;
  
  public PraSpec determinerPram(String reglement)
  {
    CleAccesPRA cle = new CleAccesPRA(reglement);
    
    return ParametragePRAM.getInstance().getPram(cle);
  }
  
  public PraSpec determinerPraPourDV(String reglement)
  {
    CleAccesPRA cle = new CleAccesPRA(reglement);
    
    return ParametragePRAPourDV.getInstance().getPram(cle);
  }
  
  protected CleAccesPRA construireCleAccesPRA(DonneesEntreeDeterminationListePra donneesEntreeDeterminationListePra)
  {
    String nomReglement = donneesEntreeDeterminationListePra.getActiviteSalarie().getReglement().getNomReglement();
    Demande demande = (Demande)donneesEntreeDeterminationListePra.getDemande();
    int codeAge = getCodeAge(donneesEntreeDeterminationListePra.getAgeIndividu());
    int[] listeAge = { codeAge };
    int codeNombreTrimestres = getCodeNombreTrimestres(demande);
    CleAccesPRA cAccess = new CleAccesPRA(nomReglement, listeAge, codeNombreTrimestres, recupererContexteMayotte(demande));
    if (recupererContexteMayotte(demande) != null) {
      cAccess.setDateRecherche(donneesEntreeDeterminationListePra.getDateFgd());
    }
    return cAccess;
  }
  
  private String recupererContexteMayotte(DemandeSpec demandeSpec)
  {
    Demande demande = (Demande)demandeSpec;
    String contexteAretourner = null;
    if (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(demande.getListContexteDemande(), "AREMAYOTTE")) {
      contexteAretourner = "AREMAYOTTE";
    }
    return contexteAretourner;
  }
  
  protected static int getCodeNombreTrimestres(Demande demande)
  {
    int codeCentTrimestres = -1;
    Damj dateFG = demande.getDateDeclenchementExamen();
    if ((demande.getDemandeur().getDateCentTrimestres() != null) && 
      (demande.getDemandeur().getDateCentTrimestres().estAvantOuCoincideAvec(dateFG))) {
      codeCentTrimestres = 1;
    }
    return codeCentTrimestres;
  }
  
  protected int getCodeAge(DureeCalendaire age)
  {
    if (age.getAnnees() < 50) {
      return 1;
    }
    if (age.getAnnees() >= 57) {
      return 3;
    }
    return 2;
  }
  
  public PraSpec determinerPraCouvertureSuiteDV(String reglement)
  {
    CleAccesPRA cle = new CleAccesPRA(reglement);
    
    return ParametragePraCouvertureSuiteDv.getInstance().getPram(cle);
  }
  
  public PraSpec determinerPraOppositionDV(String reglement, Damj dateRecherche)
  {
    CleAccesPRA cle = new CleAccesPRA(reglement);
    cle.setDateRecherche(dateRecherche);
    
    return ParametragePraOppositionDv.getInstance().getPram(cle);
  }
}

/* Location:
 * Qualified Name:     OutilConstructionPRA
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */