package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation;

import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.ApplicativeRuntimeException;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

public class OutilQuantiteAffiliation
{
  private static OutilQuantiteAffiliation s_singleton = new OutilQuantiteAffiliation();
  private List m_listeCodeUniteTypeJour = new ArrayList();
  private List m_listeCodeUniteTypeHeure = new ArrayList();
  public static final int UNITE_TYPE_INDETERMINE = 0;
  public static final int UNITE_TYPE_JOUR = 1;
  public static final int UNITE_TYPE_HEURE = 2;
  
  public OutilQuantiteAffiliation()
  {
    m_listeCodeUniteTypeJour.add("4");
    m_listeCodeUniteTypeJour.add("11");
    m_listeCodeUniteTypeJour.add("33");
    m_listeCodeUniteTypeJour.add("16");
    m_listeCodeUniteTypeJour.add("17");
    
    m_listeCodeUniteTypeHeure.add("3");
    m_listeCodeUniteTypeHeure.add("18");
    m_listeCodeUniteTypeHeure.add("31");
    m_listeCodeUniteTypeHeure.add("13");
    m_listeCodeUniteTypeHeure.add("14");
    m_listeCodeUniteTypeHeure.add("15");
  }
  
  public static OutilQuantiteAffiliation getInstance()
  {
    return s_singleton;
  }
  
  public Quantite proratiserQuantite(Quantite p_quantite, float p_nombreJourTotal, int p_nombreJourProrata)
  {
    if (p_quantite != null)
    {
      BigDecimal resultatProrata = Mathematiques.proratiser(p_quantite.getValeur(), new BigDecimal(p_nombreJourProrata), new BigDecimal(p_nombreJourTotal));
      
      return new Quantite(resultatProrata, p_quantite.getUnite());
    }
    return null;
  }
  
  public Quantite regrouperQuantitesAffiliation(Quantite p_quantite1, Quantite p_quantite2)
  {
    int typeUniteQuantite = determinerTypeUniteAffiliation(p_quantite1.getUnite());
    
    return appliquerRegroupementPourTypeUnite(p_quantite1, p_quantite2, typeUniteQuantite);
  }
  
  public Quantite appliquerRegroupementPourTypeUnite(Quantite p_quantite1, Quantite p_quantite2, int p_typeUnite)
  {
    if (2 == p_typeUnite) {
      return p_quantite1.ajouter(p_quantite2);
    }
    if (1 == p_typeUnite) {
      return p_quantite1.max(p_quantite2);
    }
    if (0 == p_typeUnite) {
      throw new ApplicativeRuntimeException("ASU_PR_CALI_L_ERR_REGROUPEMENT_QUANTITE", "Impossible d'effectuer un regroupement d'unité pour l'unité : " + p_quantite1.getUnite());
    }
    return null;
  }
  
  public int determinerTypeUniteAffiliation(Unite p_unite)
  {
    if (m_listeCodeUniteTypeJour.contains(p_unite.getCode())) {
      return 1;
    }
    if (m_listeCodeUniteTypeHeure.contains(p_unite.getCode())) {
      return 2;
    }
    return 0;
  }
  
  public Quantite arrondirQuantite(Quantite p_quantite)
  {
    BigDecimal valeur = p_quantite.getValeur();
    BigDecimal valeurArrondi = valeur.setScale(2, 4);
    return new Quantite(valeurArrondi, p_quantite.getUnite());
  }
  
  public Quantite arrondirQuantiteEntiere(Quantite quantite)
  {
    Quantite retour = null;
    if (quantite != null)
    {
      BigDecimal valeur = quantite.getValeur();
      BigDecimal valeurArrondi = valeur.setScale(0, 1);
      retour = new Quantite(valeurArrondi, quantite.getUnite());
    }
    return retour;
  }
}

/* Location:
 * Qualified Name:     OutilQuantiteAffiliation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */