package fr.unedic.cali.asu.cge01.liquidation.parcours;

import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.FabriqueOutilFonctionnelDeterminationSjrSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.OutilDeterminationSjcSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.Sjcip;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeComportementSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDemandeDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDeterminationSjrSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;

public class ParcoursConstitutionSjc
  extends ParcoursConstitutionSjcAbstrait
{
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(p_contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null: constitution du Sjc impossible.");
    }
    DossierExamen dossierExamenCourant = (DossierExamen)DomLiquidationAssurance.getDemande(p_contexte).getDossierExamen();
    if (dossierExamenCourant == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_OD", "L'attribution courante est null: constitution du Sjc impossible.");
    }
    if (dossierExamenCourant.getReglementApplicable() == null) {
      throw new ContexteException("ASU_SC_L_ES_ED_CONTEXTE_ABSENCE_RA", "Le règlement applicable de l'ouverture de droits courante est null: constitution du Sjc impossible.");
    }
    if (dossierExamenCourant.getConstitutionSjr().getSjrip() == null) {
      throw new ContexteException("ASU_SC_L_ES_ED_CONTEXTE_ABSENCE_SJRIP", "Le SJRIP de l'ouverture de droits courante est null: constitution du Sjc impossible.");
    }
  }
  
  protected Sjcip verifierSjcipForce(Damj p_dateEffetSjc, BigDecimal p_plafondSjc, Chronologie p_chronoGlobaleActivitesConservees, DonneesEntreeDeterminationSjrSpec p_donneesEntree)
    throws CoucheLogiqueException
  {
    Sjcip sjcipRetourne = null;
    
    Quantite sjcForce = p_donneesEntree.getDonneesEntreeDemande().getDonneeForceeSjc();
    if (sjcForce != null)
    {
      BigDecimal resultatSjc = sjcForce.getValeur();
      if (p_chronoGlobaleActivitesConservees.estVide()) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_L_CEPA10_SJCIP_FORCE_A_TORT");
      }
      sjcipRetourne = construireSjcip(p_dateEffetSjc, p_plafondSjc, resultatSjc, null);
      
      FabriqueOutilFonctionnelDeterminationSjrSpec fabriqueOutilFonctionnel = (FabriqueOutilFonctionnelDeterminationSjrSpec)p_donneesEntree.getDonneesEntreeComportement().getFabriqueOutilFonctionnel();
      
      fabriqueOutilFonctionnel.getOutilDeterminationSjc().completerSjcipAvecActivitesConserveesNonRetenues(p_donneesEntree, sjcipRetourne, p_chronoGlobaleActivitesConservees, true);
    }
    return sjcipRetourne;
  }
}

/* Location:
 * Qualified Name:     ParcoursConstitutionSjc
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */