package fr.unedic.cali.asu.cge01.p02.liquidation.dom;

import fr.unedic.cali.asu.cge01.p02.liquidation.dom.gen.CarenceIslrGen;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import org.apache.commons.lang.builder.EqualsBuilder;

public class CarenceIslr
  extends CarenceIslrGen
{
  private static final long serialVersionUID = 6943011496046314955L;
  
  public CarenceIslr() {}
  
  public CarenceIslr(DomPCSpec p_pc)
  {
    super(p_pc);
  }
  
  public CarenceIslr(int p_jours)
  {
    super(p_jours);
  }
  
  public CarenceIslr(ObjetChronoPeriode p_periodeOrigine, int p_nombreJours)
  {
    super(p_nombreJours);
    setOrigine(p_periodeOrigine);
  }
  
  public Periode getPeriodeApplicationCarence()
  {
    if (super.getPeriodeApplicationCarence() == null)
    {
      Damj dateDebutCarence = null;
      Damj dateLendemainFinCarence = null;
      if (getCarencePrecedente() != null) {
        dateDebutCarence = getCarencePrecedente().getPeriodeApplicationCarence().getFin().lendemain();
      } else {
        dateDebutCarence = getDateFinPeriodeOrigine().lendemain();
      }
      dateLendemainFinCarence = dateDebutCarence.veille().deplacerVersAvant(new DureeCalendaire(0, 0, getQuantiteInitialJour()));
      super.setPeriodeApplicationCarence(new Periode(dateDebutCarence, dateLendemainFinCarence));
    }
    return super.getPeriodeApplicationCarence();
  }
  
  public String getTypeCarence()
  {
    return "ISLR";
  }
  
  public boolean peutEtreFixee()
  {
    return getCarencePrecedente() == null;
  }
  
  public String toString()
  {
    StringBuffer chaineRetour = new StringBuffer();
    
    chaineRetour.append("Période d'origine: " + getOrigine() + "\n");
    chaineRetour.append("Nombre initial de jours: " + getQuantiteInitialJour() + "\n");
    
    return chaineRetour.toString();
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    CarenceIslr copie = (CarenceIslr)p_copie;
    
    super.copieElements(copie);
  }
  
  public ObjetMetierSpec copie()
  {
    CarenceIslr copie = new CarenceIslr();
    copieElements(copie);
    return copie;
  }
  
  public void jdoPreDelete()
  {
    super.jdoPreDelete();
  }
  
  public CarencePrefixeAFixer getCarencePrecedente()
  {
    CarencePrefixeAFixer precedente = null;
    if (getEnsembleCarences().getCarenceIccp() != null) {
      precedente = getEnsembleCarences().getCarenceIccp();
    } else if (getEnsembleCarences().getCarencePmc() != null) {
      precedente = getEnsembleCarences().getCarencePmc();
    }
    return precedente;
  }
  
  public CarencePrefixeAFixer getCarenceSuivante()
  {
    return null;
  }
  
  public boolean estIdentiqueA(CarencePrefixeAFixer p_carence)
  {
    if ((p_carence == null) || (!(p_carence instanceof CarenceIslr))) {
      return false;
    }
    CarenceIslr aComparer = (CarenceIslr)p_carence;
    
    EqualsBuilder eqb = new EqualsBuilder();
    return eqb.append(getPeriodeApplicationCarence().getDebut(), aComparer.getPeriodeApplicationCarence().getDebut()).append(getPeriodeApplicationCarence().getFin(), aComparer.getPeriodeApplicationCarence().getFin()).append(getQuantiteInitial(), aComparer.getQuantiteInitial()).append(getIdentifiantPeriodeOrigine(), aComparer.getIdentifiantPeriodeOrigine()).isEquals();
  }
}

/* Location:
 * Qualified Name:     CarenceIslr
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */