package fr.unedic.cali.asu.cve13.p01.calcul.dom;

import fr.unedic.cali.asu.cve13.p01.calcul.outilsfonctionnels.CotisationRetraiteComplementaire;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.parametres.EvenementParametre;
import fr.unedic.cali.asu.parametres.ParametresIndemnisation;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;

public class FormuleMontantATP
  implements FormuleMontantATPSpec
{
  private static final BigDecimal COEFFICIENT = new BigDecimal(0.8D);
  private static final BigDecimal ZERO = new BigDecimal(0);
  
  public static String getCode()
  {
    return "1";
  }
  
  public MontantBaseSpec calculer(ConstituantsIndemnisation p_constituantsIndemnisation, Damj p_dateCalcul)
    throws CoucheLogiqueException
  {
    Montant montant = new Montant();
    
    EvenementParametre parametres = ParametresIndemnisation.getParametresIndemnisation().getElementActif(p_dateCalcul);
    
    ElementBaseIndemnisation ebi = (ElementBaseIndemnisation)p_constituantsIndemnisation.getElementBaseIndemnisationCourant();
    if ((ebi != null) && (ebi.getSjrATP() != null))
    {
      Sjr sjrnpr = ebi.getSjrATP();
      BigDecimal montantBrut = COEFFICIENT.multiply(sjrnpr.getSalaire());
      
      boolean estAvecCRC = ebi.getAvecPrecompteCRC() != null ? ebi.getAvecPrecompteCRC().booleanValue() : true;
      
      Quantite crc = new QuantiteEuro(ZERO);
      BigDecimal montantBrutInitial = ZERO;
      if (estAvecCRC) {
        crc = CotisationRetraiteComplementaire.getCotisationEffective(montant, ebi.getSjrATP().getSalaire(), parametres.getCotisationRetraiteComplementaire());
      }
      if ((ebi.estMontantReduit()) && 
        (ebi.getTotalGainSurUt() != null) && (ebi.getNbJourIndemnisee() != null) && (ebi.getNbJourIndemnisee().compareTo(ZERO) > 0))
      {
        BigDecimal totalGainsJournaliers = Mathematiques.diviseASup(ebi.getTotalGainSurUt(), ebi.getNbJourIndemnisee(), 2);
        
        montantBrutInitial = ZERO.max(Mathematiques.arrondiASup(montantBrut.subtract(crc.getValeur()).subtract(totalGainsJournaliers), 2));
        if (montantBrutInitial.compareTo(ZERO) > 0) {
          montantBrut = ZERO.max(montantBrut.subtract(totalGainsJournaliers));
        } else {
          montantBrut = ZERO;
        }
      }
      montant.setMontantBrut(new QuantiteEuro(Mathematiques.arrondiASup(montantBrut, 2)));
      if (estAvecCRC)
      {
        if (montantBrut.compareTo(ZERO) > 0)
        {
          montant.setAvecPrecompteCRC(estAvecCRC);
          montant.setCrc(crc);
        }
        else
        {
          montant.setCrc(new QuantiteEuro(ZERO));
          montant.setTauxCrc(parametres.getCotisationRetraiteComplementaire());
        }
      }
      else {
        montant.setCrc(new QuantiteEuro(ZERO));
      }
    }
    return montant;
  }
  
  public void setFormuleMontantDroitAssocie(FormuleMontantSpec p_formuleMontantDroitAssocie) {}
  
  public void setFormuleMontantApplicable(int p_formuleMontantApplicable) {}
}

/* Location:
 * Qualified Name:     FormuleMontantATP
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */