package fr.unedic.cali.asu.cve13.p01.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesDemandeAssociee;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.GammeSpec;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.DomLiquidationDemande;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.cali.parcours.ParcoursLiquidation;
import fr.unedic.cali.parcours.ResultatServiceDemande;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;

public class ParcoursLiquidationFinancement
  extends ParcoursCali
{
  private static final String PREFIXE_FINANCEMENT = "Financement ATP : ";
  
  public Resultat demarrer(Contexte p_contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    Resultat resultat = new Resultat();
    resultat.setEtat(1);
    
    Demande demande = DomLiquidationAssurance.getDemande(p_contexte);
    
    resultat = liquiderDemandeFinancement(demande);
    
    resultat.setEtat(0);
    
    OutilTrace.tracerFinParcours();
    
    return resultat;
  }
  
  private Resultat liquiderDemandeFinancement(Demande p_demande)
    throws ApplicativeException
  {
    DomLiquidationDemande domContexte = null;
    Contexte contexteParcours = null;
    ParcoursLiquidation parcoursLiquidationDemande = null;
    ResultatServiceDemande resultatLiquidation = null;
    
    Demande demandeAtp = p_demande;
    DemandeAssuranceSpec demandeFinancement = demandeAtp.getDonneesDemandeAssociee().getDemandeAssociee();
    
    domContexte = demandeFinancement.getGamme().creerDomLiquidationDemande();
    domContexte.setDemande(demandeFinancement);
    domContexte.setIdDemande(demandeFinancement.getIdentifiant());
    domContexte.setIndividu(demandeFinancement.getDemandeur());
    domContexte.setContexteService(demandeFinancement.getDemandeur().getContexteService());
    contexteParcours = new Contexte();
    contexteParcours.setDonnees(domContexte);
    
    String identifiantFct = ((DossierExamen)demandeAtp.getDossierExamen()).getFaitGenerateur().getPeriodeFaitGenerateur().getIdentifiant();
    demandeFinancement.getDonneesTemporaires().setIdentifiantPeriodeFctARetenir(identifiantFct);
    demandeFinancement.getDonneesTemporaires().setIndentifiantFctPMC(identifiantFct);
    try
    {
      parcoursLiquidationDemande = demandeFinancement.getGamme().getParcoursLiquidation(demandeFinancement);
      
      resultatLiquidation = (ResultatServiceDemande)parcoursLiquidationDemande.effectuerParcours(contexteParcours);
    }
    catch (CoucheLogiqueException ex)
    {
      throw new CoucheLogiqueException(ex.getCode(), "Financement ATP : ".concat(ex.getLibelle()), ex);
    }
    return resultatLiquidation;
  }
}

/* Location:
 * Qualified Name:     ParcoursLiquidationFinancement
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */