package fr.unedic.cali.asu.ddm16.p01.liquidation.dom;

import fr.unedic.cali.ari.dom.ElementDroit;
import fr.unedic.cali.ari.outilsfonctionnels.OutilElementDroit;
import fr.unedic.cali.asu.ddm16.p01.calcul.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.ddm16.p01.liquidation.dom.gen.AdmissionGen;
import fr.unedic.cali.asu.ddm16.p01.liquidation.outilsfonctionnels.RecuperationElementIndemnisation;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculSpec;
import fr.unedic.cali.dom.OdSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;
import java.util.Collection;

public class Admission
  extends AdmissionGen
  implements OdSpec
{
  private static final long serialVersionUID = 1738816388134178916L;
  protected transient ElementBaseIndemnisation m_ebiAdmission = null;
  
  public Admission(DomPCSpec p_pc)
  {
    super(p_pc);
    setNatureDecision(10);
    setCodeProduit(43);
  }
  
  public Admission()
  {
    setNatureDecision(10);
    setCodeProduit(43);
  }
  
  public ObjetMetierSpec copie()
  {
    Admission copie = new Admission();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    Admission copie = (Admission)p_copie;
    super.copieElements(copie);
  }
  
  public void setCalendrierExecutionCalcul(CalendrierExecutionCalculSpec p_calendrier)
  {
    DomManager.supprimer(super.getCalendrierExecutionCalcul(), p_calendrier);
    super.setCalendrierExecutionCalcul(p_calendrier);
  }
  
  private ElementDroit recupererElementDroit(String p_nomElement)
  {
    Collection collectionElementDroit = getCollectionElementsDroits();
    ElementDroit element = null;
    try
    {
      element = OutilElementDroit.rechercherElement(collectionElementDroit, new String[] { p_nomElement });
    }
    catch (CoucheLogiqueException ex) {}
    return element;
  }
  
  public Damj getPji()
  {
    ElementDroit pji = recupererElementDroit("PJI");
    if (pji != null) {
      return pji.getDate1Generique();
    }
    return null;
  }
  
  public BigDecimal getSjr()
  {
    ElementDroit sjr = recupererElementDroit("SALAIRE_JOURNALIER_REFERENCE");
    if (sjr != null) {
      return sjr.getQuantiteGenerique().getValeur();
    }
    return null;
  }
  
  public BigDecimal getCoefficientTP()
  {
    ElementDroit coefficientTP = recupererElementDroit("COEFFICIENT_TEMPS_PARTIEL");
    if (coefficientTP != null) {
      return coefficientTP.getQuantiteGenerique().getValeur();
    }
    return new BigDecimal("1");
  }
  
  public BigDecimal getMontant()
  {
    ElementDroit montant = recupererElementDroit("MONTANT_J_CALCULE");
    if (montant != null) {
      return montant.getQuantiteGenerique().getValeur();
    }
    return null;
  }
  
  public Damj getTermePRC()
  {
    ElementDroit termePRC = recupererElementDroit("TERME_PRC");
    if (termePRC != null) {
      return termePRC.getDate1Generique();
    }
    return null;
  }
  
  public ElementBaseIndemnisation getElementBaseIndemnisation()
    throws CoucheLogiqueException
  {
    if (m_ebiAdmission == null) {
      m_ebiAdmission = RecuperationElementIndemnisation.recupererElementBaseIndemnisation(this);
    }
    return m_ebiAdmission;
  }
  
  public ProduitSpec getProduitExecution()
  {
    return getProduit();
  }
  
  public void marquerGraphePersistant()
  {
    super.marquerGraphePersistant();
    DomManager.persisterEnProfondeur(super.getCalendrierExecutionCalcul());
  }
}

/* Location:
 * Qualified Name:     Admission
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */