package fr.unedic.cali.asu.dom;

import fr.unedic.cali.asu.dom.gen.ReliquatGen;
import fr.unedic.cali.dom.ObjetPersistantSpec;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.temps.UniteDuree;
import java.math.BigDecimal;

public class Reliquat
  extends ReliquatGen
  implements ObjetPersistantSpec
{
  private static final long serialVersionUID = -7669052553583932026L;
  public static final String AIDE_DIFF_RECLASSEMENT = "ADR";
  public static final String AIDE_SPEC_COMPL_RETOUR_EMPLOI = "ASC";
  public static final String AIDE_REPRISE_CREATION_ENTREPRISE = "ARC";
  public static final int CODE_AIDE_DIFF_RECLASSEMENT = 1;
  public static final int CODE_AIDE_SPEC_COMPL_RETOUR_EMPLOI = 3;
  public static final int CODE_AIDE_REPRISE_CREATION_ENTREPRISE = 2;
  private transient String typeAide;
  
  public Reliquat(DomPCSpec pc)
  {
    super(pc);
  }
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
  
  public void jdoPostLoad() {}
  
  public void jdoPreClear() {}
  
  public void jdoPreDelete() {}
  
  public void marquerGraphePersistant() {}
  
  public void jdoPreStore() {}
  
  public boolean estReliquatValide()
  {
    return super.isReliquatValide();
  }
  
  public Quantite getQuantiteAide()
  {
    if (super.getQuantiteAide() != null) {
      return new Quantite(super.getQuantiteAide().getValeur().setScale(0), super.getQuantiteAide().getUnite());
    }
    return null;
  }
  
  public Quantite getQuantiteImputee()
  {
    Quantite qteTotaleImputee = new Quantite(0, UniteDuree.JOUR);
    if (getQuantiteAide() != null) {
      qteTotaleImputee = qteTotaleImputee.ajouter(getQuantiteAide());
    }
    if (getQuantiteFormation() != null) {
      qteTotaleImputee = qteTotaleImputee.ajouter(getQuantiteFormation());
    }
    if (getQuantiteJourImputationDonneesForcees() != null) {
      qteTotaleImputee = qteTotaleImputee.ajouter(getQuantiteJourImputationDonneesForcees());
    }
    return qteTotaleImputee;
  }
  
  public ObjetMetierSpec copie()
  {
    throw new UnsupportedOperationException("Cette méthode ne doit pas être appelée! Appeller le méthode copieElements(ObjetMetierSpec).");
  }
  
  public void copieElements(ObjetMetierSpec copie)
  {
    Reliquat reliquat = (Reliquat)copie;
    
    reliquat.setQuantiteFormation(getQuantiteFormation());
    reliquat.setQuantiteReliquat(getQuantiteReliquat());
    reliquat.setReliquatValide(estReliquatValide());
    reliquat.setQuantiteAide(getQuantiteAide());
    reliquat.setCumulMoisActiviteReduite(getCumulMoisActiviteReduite());
    reliquat.setQuantiteReliquatRenouvellement(getQuantiteReliquatRenouvellement());
    reliquat.setQuantiteJourImputationDonneesForcees(getQuantiteJourImputationDonneesForcees());
    reliquat.setMontantJournalierReliquat(getMontantJournalierReliquat());
    reliquat.setCapitalReliquat(getCapitalReliquat());
    reliquat.setDureePostPrime(getDureePostPrime());
    reliquat.setDateFinDispositifCSP(getDateFinDispositifCSP());
    reliquat.setReliquatAllongementArefPossible(getReliquatAllongementArefPossible());
  }
  
  public String getTypeAide()
  {
    return typeAide;
  }
  
  public void setTypeAide(String typeAide)
  {
    this.typeAide = typeAide;
  }
  
  public static String determinerTypeAide(int code)
  {
    String typeAide = null;
    switch (code)
    {
    case 1: 
      typeAide = "ADR";
      break;
    case 2: 
      typeAide = "ARC";
      break;
    case 3: 
      typeAide = "ASC";
    }
    return typeAide;
  }
}

/* Location:
 * Qualified Name:     Reliquat
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */