package fr.unedic.cali.asu.fds12.p02.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionSalaireReference;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Decision;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Od;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Reprise;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ValidationProduit;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.JustificationAppelGaecReduit;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;

public class DeterminationDateMinPraPrcPrs
  implements OutilFonctionnel
{
  public static final int DUREE_PRS_TROIS = 3;
  private static final int DUREE_PRA = 22;
  private static final String MESSAGE_GAEC_NON_CHARGE = "L'individu GAEC n'a pas été chargé en début de service.";
  
  public static JustificationAppelGaecReduit calculerDateMinimum(DemandeSpec p_demande)
  {
    String justification = null;
    Demande demande = (Demande)p_demande;
    Decision decisionAssurance = (Decision)demande.getDossierExamen();
    Damj dateDebutPrc = null;
    Damj dateDebutPra = null;
    
    Damj dateRetour = null;
    
    ValidationProduit validationProduit = (ValidationProduit)((DossierAffectation)decisionAssurance.getDossierAffecte()).getValidationProduit();
    if ((decisionAssurance instanceof Reprise))
    {
      dateRetour = getDateFaitGenerateurOdPrecedente(demande);
      justification = "Fgd OD précédente";
    }
    else if ((decisionAssurance instanceof Od))
    {
      dateDebutPra = validationProduit.getPeriodePra().getDebut();
      if ((decisionAssurance.getConstitutionSalaireReference() != null) && 
        (decisionAssurance.getConstitutionSalaireReference().getPrc() != null)) {
        dateDebutPrc = decisionAssurance.getConstitutionSalaireReference().getPrc().getDebut();
      }
      if (dateDebutPrc != null)
      {
        if (dateDebutPra.estAvant(dateDebutPrc))
        {
          dateRetour = dateDebutPra;
          justification = "Pra";
        }
        else
        {
          dateRetour = dateDebutPrc;
          justification = "Prc";
        }
      }
      else
      {
        dateRetour = dateDebutPra;
        justification = "Pra";
      }
    }
    return new JustificationAppelGaecReduit(dateRetour, justification, p_demande.getIdentifiant());
  }
  
  private static Damj getDateFaitGenerateurOdPrecedente(Demande p_demande)
  {
    Damj dateFgdPrecedent = null;
    try
    {
      dateFgdPrecedent = p_demande.getDateFaitGenerateurOdPrecedente();
    }
    catch (UnsupportedOperationException ex)
    {
      if (!"L'individu GAEC n'a pas été chargé en début de service.".equals(ex.getMessage())) {
        throw ex;
      }
    }
    return dateFgdPrecedent;
  }
}

/* Location:
 * Qualified Name:     DeterminationDateMinPraPrcPrs
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */