package fr.unedic.cali.asu.parametres;

import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologieStandard;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.util.Iterator;
import java.util.ListIterator;

public class ParametresIndemnisationA2B
{
  private ChronologieStandard m_chronoEvenementsCategorieA2b = null;
  private static ParametresIndemnisationA2B s_parametreIndemnisation = new ParametresIndemnisationA2B();
  private static ThreadLocal s_initHolder = new ThreadLocal();
  private boolean m_initialisationOK = false;
  
  private void dedoublonner()
  {
    ListIterator iterateur = m_chronoEvenementsCategorieA2b.iterer();
    EvenementCategorieA2B evtCourant = null;
    EvenementCategorieA2B evtSuivant = null;
    Damj dateEvtCourant = null;
    Damj dateEvtSuivant = null;
    if (iterateur.hasNext())
    {
      evtCourant = (EvenementCategorieA2B)iterateur.next();
      dateEvtCourant = evtCourant.getDateEffet();
    }
    while (iterateur.hasNext())
    {
      evtSuivant = (EvenementCategorieA2B)iterateur.next();
      dateEvtSuivant = evtSuivant.getDateEffet();
      if (dateEvtCourant.coincideAvec(dateEvtSuivant))
      {
        iterateur.previous();
        iterateur.previous();
        iterateur.remove();
        iterateur.next();
      }
      evtCourant = evtSuivant;
      dateEvtCourant = dateEvtSuivant;
    }
  }
  
  public EvenementCategorieA2B getElementActif(Damj p_date)
  {
    EvenementCategorieA2B evtCourant = null;
    
    Iterator it = m_chronoEvenementsCategorieA2b.iterer();
    while (it.hasNext())
    {
      EvenementCategorieA2B evt = (EvenementCategorieA2B)it.next();
      if (!evt.getDateEffet().estAvantOuCoincideAvec(p_date)) {
        break;
      }
      evtCourant = evt;
    }
    return evtCourant;
  }
  
  public Chronologie getParametresActifs(Periode p_periode)
  {
    return m_chronoEvenementsCategorieA2b.elementsDeDebutDans(p_periode);
  }
  
  public static ParametresIndemnisationA2B getParametresIndemnisation()
  {
    if (s_initHolder.get() == null) {
      synchronized (ParametresIndemnisationA2B.class)
      {
        if (!s_parametreIndemnisation.isInitialisationOK()) {
          s_parametreIndemnisation.initialiser();
        }
        s_initHolder.set(Boolean.TRUE);
      }
    }
    return s_parametreIndemnisation;
  }
  
  private void initialiser()
  {
    m_chronoEvenementsCategorieA2b = new ChronologieStandard();
    m_chronoEvenementsCategorieA2b.ajouter(AccesSalaireForfaitaireJournalierCategorieA2B.getInstance().getChronoValeursParametre());
    
    Iterator iterateurChrono = m_chronoEvenementsCategorieA2b.iterer();
    EvenementCategorieA2B evtCourant = null;
    EvenementCategorieA2B evtPrecedent = null;
    if (iterateurChrono.hasNext())
    {
      evtPrecedent = (EvenementCategorieA2B)iterateurChrono.next();
    }
    else
    {
      m_initialisationOK = true;
      return;
    }
    while (iterateurChrono.hasNext())
    {
      evtCourant = (EvenementCategorieA2B)iterateurChrono.next();
      evtCourant.repercuter(evtPrecedent);
      evtPrecedent = evtCourant;
    }
    dedoublonner();
    
    m_initialisationOK = true;
  }
  
  public boolean isInitialisationOK()
  {
    return m_initialisationOK;
  }
  
  public void setInitialisationOK(boolean p_initialisationOK)
  {
    m_initialisationOK = p_initialisationOK;
  }
}

/* Location:
 * Qualified Name:     ParametresIndemnisationA2B
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */