package fr.unedic.cali.asu.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.SaisieAntecedent;
import fr.unedic.cali.dom.AgregatGaec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DonneesChargementGaec;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.IndividuIdSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.parcours.AccesDonneesGaecException;
import fr.unedic.cali.parcours.DomCali;
import fr.unedic.cali.parcours.DomLiquidationDemande;
import fr.unedic.cali.parcours.ParcoursServiceAbstrait;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.Parcours;
import fr.unedic.util.services.Resultat;

public class ParcoursEnregistrerDemandeAssurance
  extends ParcoursServiceAbstrait
{
  protected void alimenterAgregatGaec(Individu p_individu, String p_idDemande)
  {
    if (p_individu != null) {
      p_individu.getDonneesChargementGaec().getAgregatGaec().setModeAppel(2);
    }
  }
  
  protected void controlerPostTraitement(Individu p_individu)
    throws AccesDonneesGaecException
  {
    controlerModeAppel(p_individu.getDonneesChargementGaec().getAppelGaecReduit(), 2);
  }
  
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    if (p_contexte != null)
    {
      DomLiquidationDemande dom = (DomLiquidationDemande)p_contexte.getDonnees();
      Demande demandeTemporaire = (Demande)dom.getDemandeSpec();
      
      String idDemande = getIdDemande(p_contexte);
      IndividuSpec demandeur = getIndividu(p_contexte);
      if ((demandeur.getIndividuId() == null) || (demandeur.getIndividuId().getId() == null) || (demandeur.getIndividuId().getId().equals(""))) {
        throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_ID_INDIVIDU", "La demande ne peut être rattachée à aucun individu.");
      }
      if (((idDemande == null) || ("".equalsIgnoreCase(idDemande))) && ((demandeTemporaire.getSaisieAntecedent().getReferenceExterne() == null) || ("".equalsIgnoreCase(demandeTemporaire.getSaisieAntecedent().getReferenceExterne())))) {
        throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_ID_DEMANDE", "La demande recherchée en base n'a pas d'identifiant.");
      }
    }
    else
    {
      throw new ContexteException("HG_PR_CALI_L_ERR_CONTEXTE_ABSENT");
    }
  }
  
  protected Resultat demarrerParcours(Contexte p_contexte)
    throws ApplicativeException
  {
    Parcours parcours = null;
    
    Demande demandeTemporaire = (Demande)getDemande(p_contexte);
    if ((demandeTemporaire.getSaisieAntecedent() != null) && (!"".equalsIgnoreCase(demandeTemporaire.getSaisieAntecedent().getReferenceExterne()))) {
      parcours = new EnregistrerAntecedentMigration();
    } else {
      parcours = new EnregistrerDemandeAssurance();
    }
    return parcours.effectuerParcours(p_contexte);
  }
  
  protected int getModeChargementDebrayageDossiersLourds(Individu p_individu)
  {
    return 2;
  }
  
  protected DemandeSpec getDemande(Contexte p_contexte)
  {
    return ((DomLiquidationDemande)p_contexte.getDonnees()).getDemandeSpec();
  }
  
  protected String getIdDemande(Contexte p_contexte)
  {
    return ((DomLiquidationDemande)p_contexte.getDonnees()).getIdDemande();
  }
  
  public IndividuSpec getIndividu(Contexte p_contexte)
  {
    DomCali domCali = (DomCali)p_contexte.getDonnees();
    return domCali.getIndividu();
  }
}

/* Location:
 * Qualified Name:     ParcoursEnregistrerDemandeAssurance
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */