package fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Attribution;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionSalaireJournalierMoyen;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionSalaireReference;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationDiffere;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.formules.FormuleCarenceIndemnisationStandard;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.formules.FormuleTexteSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.spec.OutilCalculDiffereStandardSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.spec.ParametresCarenceIndemnisationStandardSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpectacleSpec;
import fr.unedic.cali.parametres.EvenementParametre;
import fr.unedic.cali.parametres.ParametresIndemnisation;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.PasAssezInformationException;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public class OutilCalculDiffereStandard
  implements OutilCalculDiffereStandardSpec
{
  public Quantite calculerDiffereStandard(DemandeAssuranceSpec demande, JustificationDiffere justificationDiffere, BigDecimal montantTotalRemunerationsPrc)
    throws PasAssezInformationException
  {
    ParametresCarenceIndemnisationStandardSpec parametres = (ParametresCarenceIndemnisationStandardSpec)((ProduitAsuSpectacleSpec)((Attribution)demande.getDossierExamen()).getProduit()).recupererParametresCarenceIndemnisationDiffereStandard();
    FormuleTexteSpec formuleCalculCarence = new FormuleCarenceIndemnisationStandard();
    DossierExamen dossierExamen = (DossierExamen)demande.getDossierExamen();
    
    justificationDiffere.setFormule(formuleCalculCarence.getFormule(parametres));
    
    Periode periodeRechercheCalcul = recupererPeriodeRechercheCarences(dossierExamen);
    EvenementParametre elementActifAFinPRC = ParametresIndemnisation.getParametresIndemnisation().getElementActif(periodeRechercheCalcul.getFin());
    BigDecimal montantSJM = recupererMontantSJMRP(dossierExamen);
    
    parametres.setMontantSMIC(elementActifAFinPRC.getSmicMensuelBase35h());
    parametres.setMontantSMICJournalier(elementActifAFinPRC.getSmicJournalierBase35h());
    parametres.setSalaireJournalierMoyen(montantSJM);
    parametres.setMontantSalaires(montantTotalRemunerationsPrc);
    
    justificationDiffere.setSmicJournalier(new QuantiteEuro(parametres.getMontantSMICJournalier()));
    justificationDiffere.setSmicMensuel(new QuantiteEuro(parametres.getMontantSMIC()));
    justificationDiffere.setTotalSalairesNonPlafonnes(new QuantiteEuro(parametres.getMontantSalaires()));
    
    return (Quantite)formuleCalculCarence.appliquerFormule(parametres);
  }
  
  protected Periode recupererPeriodeRechercheCarences(DossierExamen dossierExamen)
  {
    return dossierExamen.getConstitutionSalaireReference().getPrc();
  }
  
  protected BigDecimal recupererMontantSJMRP(DossierExamen dossierExamen)
  {
    return dossierExamen.getConstitutionSalaireJournalierMoyen().getMontantSalaireJournalierMoyenRevalorisePlafonne().getValeur();
  }
}

/* Location:
 * Qualified Name:     OutilCalculDiffereStandard
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */