package fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.formules;

import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.spec.ParametresCarenceIndemnisationStandardSpec;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.PasAssezInformationException;
import java.math.BigDecimal;

public class FormuleCarenceIndemnisationStandard
  implements FormuleTexteSpec
{
  private static final String PARAM_FORFAIT = "%FORFAIT%";
  private static final String FORMULE = "[(SALAIRES PRC / Smic mensuel) x (SJM / (3 x Smic journalier))] - %FORFAIT% jours";
  
  private void verifierParametresPourCalcul(ParametresFormuleSpec parametresFormule)
    throws PasAssezInformationException
  {
    if ((parametresFormule instanceof ParametresCarenceIndemnisationStandardSpec))
    {
      ParametresCarenceIndemnisationStandardSpec parametresCarence = (ParametresCarenceIndemnisationStandardSpec)parametresFormule;
      if (parametresCarence.getMontantSalaires() == null) {
        throw new PasAssezInformationException("ASU_ERR_PARAMETRES_FORMULE_INCOMPATIBLE", "La somme des salaires n'est pas spécifiée.");
      }
      if (parametresCarence.getMontantSMIC() == null) {
        throw new PasAssezInformationException("ASU_ERR_PARAMETRES_FORMULE_INCOMPATIBLE", "Le montant du SMIC n'est pas spécifié.");
      }
      if (parametresCarence.getSalaireJournalierMoyen() == null) {
        throw new PasAssezInformationException("ASU_ERR_PARAMETRES_FORMULE_INCOMPATIBLE", "Le salaire journalier moyen n'est pas spécifié.");
      }
      if (parametresCarence.getMontantSMICJournalier() == null) {
        throw new PasAssezInformationException("ASU_ERR_PARAMETRES_FORMULE_INCOMPATIBLE", "Le SMIC journalier n'est pas spécifié.");
      }
    }
    else
    {
      throw new PasAssezInformationException("ASU_ERR_PARAMETRES_FORMULE_INCOMPATIBLE", "Les paramètre passés en paramètre sont incompatibles avec le calcul de la formule souhaitée.");
    }
  }
  
  public Object appliquerFormule(ParametresFormuleSpec parametresFormule)
    throws PasAssezInformationException
  {
    verifierParametresPourCalcul(parametresFormule);
    
    ParametresCarenceIndemnisationStandardSpec parametresCarence = (ParametresCarenceIndemnisationStandardSpec)parametresFormule;
    
    BigDecimal quotientSalairesSurSMICMensuel = Mathematiques.diviseParDefaut(parametresCarence.getMontantSalaires(), parametresCarence.getMontantSMIC());
    
    BigDecimal diviseur = parametresCarence.getFacteurMultiplicationSMICJour().multiply(parametresCarence.getMontantSMICJournalier());
    
    BigDecimal quotientSJMSurSMICJournalier = Mathematiques.diviseParDefaut(parametresCarence.getSalaireJournalierMoyen(), diviseur);
    
    BigDecimal multiplicationQuotients = quotientSalairesSurSMICMensuel.multiply(quotientSJMSurSMICJournalier);
    
    BigDecimal calculSuiteForfait30Jours = Mathematiques.tronque(multiplicationQuotients.subtract(parametresCarence.getForfait()), 0);
    
    BigDecimal quantiteARetenir = calculSuiteForfait30Jours.max(parametresCarence.getQuantiteJourMin());
    
    return new QuantiteJour(quantiteARetenir);
  }
  
  public String getFormule(ParametresFormuleSpec parametresFormule)
  {
    ParametresCarenceIndemnisationStandardSpec parametresCarence = (ParametresCarenceIndemnisationStandardSpec)parametresFormule;
    return "[(SALAIRES PRC / Smic mensuel) x (SJM / (3 x Smic journalier))] - %FORFAIT% jours".replaceAll("%FORFAIT%", String.valueOf(parametresCarence.getForfait().intValue()));
  }
}

/* Location:
 * Qualified Name:     FormuleCarenceIndemnisationStandard
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */