package fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.formules;

import fr.unedic.util.Mathematiques;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.PasAssezInformationException;
import java.math.BigDecimal;

public class FormuleCarenceSpecifique
  implements FormuleSpec
{
  private void verifierParametresPourCalcul(ParametresFormuleSpec p_parametresFormule)
    throws PasAssezInformationException
  {
    if ((p_parametresFormule instanceof ParametresCarenceSpecifique))
    {
      ParametresCarenceSpecifique parametresCarence = (ParametresCarenceSpecifique)p_parametresFormule;
      if (parametresCarence.getMontantISLR() == null) {
        throw new PasAssezInformationException("ASU_ERR_PARAMETRES_FORMULE_INCOMPATIBLE", "Le montant ISLR n'est pas spécifiée.");
      }
      if (parametresCarence.getPlafondCarence() == null) {
        throw new PasAssezInformationException("ASU_ERR_PARAMETRES_FORMULE_INCOMPATIBLE", "Le plafond carence n'est pas spécifié.");
      }
      if (parametresCarence.getSalaireJournalierMoyen() == null) {
        throw new PasAssezInformationException("ASU_ERR_PARAMETRES_FORMULE_INCOMPATIBLE", "Le salaire journalier moyen n'est pas spécifié.");
      }
    }
    else
    {
      throw new PasAssezInformationException("ASU_ERR_PARAMETRES_FORMULE_INCOMPATIBLE", "Les paramètre passés en paramètre sont incompatibles avec le calcul de la formule souhaitée.");
    }
  }
  
  public Object appliquerFormule(ParametresFormuleSpec p_parametresFormule)
    throws PasAssezInformationException
  {
    verifierParametresPourCalcul(p_parametresFormule);
    
    ParametresCarenceSpecifique parametresCarence = (ParametresCarenceSpecifique)p_parametresFormule;
    
    BigDecimal quotientISLRSurSJM = parametresCarence.getMontantISLR().divide(parametresCarence.getSalaireJournalierMoyen(), parametresCarence.getArrondiCalcul());
    
    BigDecimal partiEntiereCalcul = Mathematiques.tronque(quotientISLRSurSJM, 0);
    
    BigDecimal quantiteARetenir = partiEntiereCalcul.min(parametresCarence.getPlafondCarence());
    
    return new QuantiteJour(quantiteARetenir);
  }
}

/* Location:
 * Qualified Name:     FormuleCarenceSpecifique
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */