package fr.unedic.cali.asu.spe02.p05.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ValidationProduit;
import fr.unedic.cali.asu.spe02.p04.liquidation.outilsfonctionnels.AlimentationBasePivot;
import fr.unedic.cali.dom.pivot.Decision;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public class AlimentationBasePivotSpectacle2016
  extends AlimentationBasePivot
{
  public static AlimentationBasePivotSpectacle2016 getInstance()
  {
    return new AlimentationBasePivotSpectacle2016();
  }
  
  protected void renseigneAffiliation(Decision decision, DossierExamen dossier)
    throws CoucheLogiqueException
  {
    if ((estRejetAffiliation(dossier)) && (!presenceDonneesForceesValidationProduit(dossier.getDemandeAssurance()))) {
      renseignerAffiliationPourRejetAffi(decision, dossier);
    } else {
      super.renseigneAffiliation(decision, dossier);
    }
    alimenterEtatPnds(decision, dossier.getConditionQuantiteAffiliation());
  }
  
  private boolean estRejetAffiliation(DossierExamen dossier)
  {
    ValidationProduit validationProduit = (ValidationProduit)((DossierAffecte)dossier.getDossierAffecte()).getValidationProduit();
    return (validationProduit != null) && (!validationProduit.isEstProduitValide());
  }
  
  protected boolean presenceDonneesForceesValidationProduit(DemandeAssuranceSpec demande)
  {
    return demande.getDonneesTemporaires().getReglementApplicableSpectacle() != null;
  }
  
  private void renseignerAffiliationPourRejetAffi(Decision decision, DossierExamen dossier)
    throws CoucheLogiqueException
  {
    ValidationProduit validationProduit = (ValidationProduit)((DossierAffecte)dossier.getDossierAffecte()).getValidationProduit();
    if (validationProduit != null)
    {
      if (validationProduit.getQuantiteAffiAcquiseRangInitial() != null)
      {
        decision.setValeurQuantiteAffiliation(validationProduit.getQuantiteAffiAcquiseRangInitial().getValeurEntiere());
        decision.setUniteAffiliation(determineNomPourPivotUniteAffiliation(validationProduit.getQuantiteAffiAcquiseRangInitial().getUnite().getNom()));
      }
      if (validationProduit.getJustificationAssimilationAuRangInitial() != null) {
        super.renseignerAssimilation(decision, validationProduit.getJustificationAssimilationAuRangInitial());
      }
      decision.setNbHTravailHorsA8A10(determinerNbreHeuresTravailHorsA8A10(dossier, validationProduit.getPraAuRangInitial()).intValue());
      
      Periode pra = validationProduit.getPraAuRangInitial();
      if (pra != null)
      {
        decision.setDateDebutPra(pra.getDebut());
        decision.setDateFinPra(pra.getFin());
      }
      if (validationProduit.getHeuresRequisesAuRangInitial() != null)
      {
        decision.setValeurQuantiteAffiliationRequise(validationProduit.getHeuresRequisesAuRangInitial().getValeurEntiere());
        decision.setUniteAffiliationRequise(determineNomPourPivotUniteAffiliation(validationProduit.getHeuresRequisesAuRangInitial().getUnite().getNom()));
      }
    }
  }
}

/* Location:
 * Qualified Name:     AlimentationBasePivotSpectacle2016
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */