package fr.unedic.cali.asu.ssp07.p05.liquidation.outilsfonctionnels;

import fr.pe.cali.reglementaire.regles.assurance.cap.beneficeautreproduit.outils.spec.IOutilFonctionnelBeneficeAutreProduitAPS2017;
import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.ConditionQuantiteAffiliationSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.outilsfonctionnels.OutilCalculEligibiliteClauseRattrapage;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ValidationProduit;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.DecisionSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.NaturesDecisions;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;

public class OutilFonctionnelBeneficeAutreProduitAPS2017
  implements IOutilFonctionnelBeneficeAutreProduitAPS2017
{
  private static final int TOP_ELIGIBILE_CRA = 1;
  private Demande demandePrecedente;
  
  public OutilFonctionnelBeneficeAutreProduitAPS2017(Demande demandePrecedente)
  {
    this.demandePrecedente = demandePrecedente;
  }
  
  public boolean estDemandePrecedenteRejetCra()
  {
    return ("ASU_31".equals(recupererEreDemandePrecedente().getTypeExamen())) && (NaturesDecisions.estdeTypeRejet(recupererNatureDecisionDemandePrecedente()));
  }
  
  public boolean estEligibleCra()
    throws ApplicativeException
  {
    boolean estDemandeFinDeDroitSpectacle = "ASU_08".equals(recupererEreDemandePrecedente().getTypeExamen());
    boolean estRejetAffiliation = (NaturesDecisions.estdeTypeRejet(recupererNatureDecisionDemandePrecedente())) && (!estConditionAffiliationSatisfaite());
    return OutilCalculEligibiliteClauseRattrapage.getInstance().determinerTopDectectionClauseRattrapage(estDemandeFinDeDroitSpectacle, estRejetAffiliation, recupererQuantiteAffiliation()) == 1;
  }
  
  protected Quantite recupererQuantiteAffiliation()
    throws ApplicativeException
  {
    Quantite retour = null;
    
    DossierAffectation dossierAffectation = demandePrecedente.getDossierAffectationAdmission();
    ValidationProduit validationProduit = (ValidationProduit)((ProduitAsuSpec)demandePrecedente.getDossierAffectationAdmission().getProduit()).obtenirValidationProduit((ActiviteSalarie)dossierAffectation.getSinistre(), demandePrecedente.getDemandeur(), demandePrecedente, false);
    if (validationProduit != null) {
      retour = validationProduit.getQuantiteAffiAcquiseRangInitial();
    }
    return retour;
  }
  
  protected boolean estConditionAffiliationSatisfaite()
  {
    ConditionQuantiteAffiliationSpec condition = ((DossierExamenAssuranceSpec)demandePrecedente.getDossierExamen()).getConditionQuantiteAffiliation();
    return (condition != null) && (condition.estSatisfait());
  }
  
  protected EvenementReferenceExamenSpec recupererEreDemandePrecedente()
  {
    return demandePrecedente.getEvenementReferenceExamen();
  }
  
  protected int recupererNatureDecisionDemandePrecedente()
  {
    return ((DecisionSpec)demandePrecedente.getDossierExamen()).getNatureDecision();
  }
  
  public void gererSansRejetCraEtEligible()
    throws CoucheLogiqueException
  {
    fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_APS17_ELIGIBLE_CRA_NON_PRESENTE");
  }
}

/* Location:
 * Qualified Name:     OutilFonctionnelBeneficeAutreProduitAPS2017
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */